# load R packages

install.packages(c("demography", "rainbow", "dplyr"))
require(demography)
require(rainbow)
require(dplyr)

# set working directory

df0 = read.csv("asmr.csv", stringsAsFactors = FALSE)

shinyServer(function(input, output)
{
	  # df filtered
	  dff <- reactive({
		    df1 = df0 %>% filter(Code == input$country)
    		if(input$sex == "Female")
    		{
            dd1 = demogdata(data = matrix(df1$MortFemale, nrow = 101),
      						pop = matrix(df1$ExpoFemale, nrow = 101),
      						ages = 0:100, years = unique(df1$Year),
      						type = "mortality", 
      						label = input$country, name = "Female")
        }    
    		if(input$sex == "Male")
    		{	
            dd1 = demogdata(data = matrix(df1$MortMale, nrow = 101),
      						pop = matrix(df1$ExpoMale, nrow = 101),
      						ages = 0:100, years = unique(df1$Year),
      						type = "mortality", 
      						label = input$country, name = "Male")
    		}
    		if(input$sex == "Total")
    		{	
            dd1 = demogdata(data = matrix(df1$MortTotal, nrow = 101),
      						pop = matrix(df1$ExpoTotal, nrow = 101),
      						ages = 0:100, years = unique(df1$Year),
      						type = "mortality", 
      						label = input$country, name = "Total")
    		}
    		list(df1 = df1, dd1 = dd1)
	  })
	
  	output$plot2 <- renderPlot({
  		dff1 <- dff()
  		par(mar=c(2,2,1,0.1))
  		if(input$smooth2 == FALSE)
  			 plot(extract.ages(dff1$dd1, 60:100), ylab = "", main = "", plotlegend = TRUE, legendpos = "topleft")
  		if(input$smooth2 == TRUE)
  			 plot(extract.ages(smooth.demogdata(dff1$dd1), 60:100), ylab = "", main = "", plotlegend = TRUE, legendpos = "topleft")
  	})

  	output$plot_t2 <- renderText({
  		dff1 = dff()
  		paste0(input$sex, " ASMR ", range(dff1$dd1$year)[1], "-", range(dff1$dd1$year)[2])
  	})
})						
		
