###################################################
# read data from Japanese Human Mortality Database
###################################################

read.jpn_death <- function(region, label = region)
{
    path <- paste("http://www.ipss.go.jp/p-toukei/JMD/", region, "/STATS/",   "Deaths_1x1.txt", sep = "")
    txt <- RCurl::getURL(path)
    con <- textConnection(txt)
    mx <- try(read.table(con, skip = 2, header = TRUE, na.strings = "."), TRUE)
    close(con)
    if(class(mx) == "try-error")
      stop("Connection error at www.mortality.org. Please check username, password and country label.")
    path <- paste("http://www.ipss.go.jp/p-toukei/JMD/", region, "/STATS/",   "Exposures_1x1.txt", sep = "")
    txt <- RCurl::getURL(path)
    con <- textConnection(txt)
    pop <- try(read.table(con, skip = 2, header = TRUE, na.strings = "."), TRUE)
    close(con)
    if(class(pop) == "try-error")
      stop("Exposures file not found at www.mortality.org")
    return(list(Deaths = mx, pop = pop))
}

read.jpn <- function (region,  label = region)
{
    path <- paste("http://www.ipss.go.jp/p-toukei/JMD/", region, "/STATS/",   "Mx_1x1.txt", sep = "")
    txt <- RCurl::getURL(path)
    con <- textConnection(txt)
    mx <- try(read.table(con, skip = 2, header = TRUE, na.strings = "."),
              TRUE)
    close(con)
    if (class(mx) == "try-error")
      stop("Connection error at www.mortality.org. Please check username, password and country label.")
    path <- paste("http://www.ipss.go.jp/p-toukei/JMD/", region, "/STATS/",   "Exposures_1x1.txt", sep = "")
    txt <- RCurl::getURL(path)
    con <- textConnection(txt)
    pop <- try(read.table(con, skip = 2, header = TRUE, na.strings = "."),
               TRUE)
    close(con)
    if (class(pop) == "try-error")
      stop("Exposures file not found at www.mortality.org")
    obj <- list(type = "mortality", label = label, lambda = 0)
    obj$year <- sort(unique(mx[, 1]))
    n <- length(obj$year)
    m <- length(unique(mx[, 2]))
    obj$age <- mx[1:m, 2]
    mnames <- names(mx)[-c(1, 2)]
    n.mort <- length(mnames)
    obj$rate <- obj$pop <- list()
    for (i in 1:n.mort) {
      obj$rate[[i]] <- matrix(mx[, i + 2], nrow = m, ncol = n)
      obj$rate[[i]][obj$rate[[i]] < 0] <- NA
      obj$pop[[i]] <- matrix(pop[, i + 2], nrow = m, ncol = n)
      obj$pop[[i]][obj$pop[[i]] < 0] <- NA
      dimnames(obj$rate[[i]]) <- dimnames(obj$pop[[i]]) <- list(obj$age,
                                                                obj$year)
    }
    names(obj$pop) = (names(obj$rate) <- tolower(mnames))
    obj$age <- as.numeric(as.character(obj$age))
    if (is.na(obj$age[m]))
      obj$age[m] <- 2 * obj$age[m - 1] - obj$age[m - 2]
    return(structure(obj, class = "demogdata"))
}

state = c("Japan", "Hokkaido", "Aomori", "Iwate", "Miyagi", "Akita", "Yamagata", "Fukushima",
          "Ibaraki", "Tochigi", "Gunma", "Saitama", "Chiba", "Tokyo", "Kanagawa", "Niigata",
          "Toyama", "Ishikawa", "Fukui", "Yamanashi", "Nagano", "Gifu", "Shizuoka", "Aichi",
          "Mie", "Shiga", "Kyoto", "Osaka", "Hyogo", "Nara", "Wakayama", "Tottori", "Shimane",
          "Okayama", "Hiroshima", "Yamaguchi", "Tokushima", "Kagawa", "Ehime", "Kochi",
          "Fukuoka", "Saga", "Nagasaki", "Kumamoto", "Oita", "Miyazaki", "Kagoshima", "Okinawa")

state_all = c("Japan_all", "Hokkaido_all", "Aomori_all", "Iwate_all", "Miyagi_all", "Akita_all", "Yamagata_all", "Fukushima_all",
              "Ibaraki_all", "Tochigi_all", "Gunma_all", "Saitama_all", "Chiba_all", "Tokyo_all", "Kanagawa_all", "Niigata_all",
              "Toyama_all", "Ishikawa_all", "Fukui_all", "Yamanashi_all", "Nagano_all", "Gifu_all", "Shizuoka_all", "Aichi_all",
              "Mie_all", "Shiga_all", "Kyoto_all", "Osaka_all", "Hyogo_all", "Nara_all", "Wakayama_all", "Tottori_all", "Shimane_all",
              "Okayama_all", "Hiroshima_all", "Yamaguchi_all", "Tokushima_all", "Kagawa_all", "Ehime_all", "Kochi_all",
              "Fukuoka_all", "Saga_all", "Nagasaki_all", "Kumamoto_all", "Oita_all", "Miyazaki_all", "Kagoshima_all", "Okinawa_all")

state_smooth = c("Japan_smooth", "Hokkaido_smooth", "Aomori_smooth", "Iwate_smooth",
                 "Miyagi_smooth", "Akita_smooth", "Yamagata_smooth", "Fukushima_smooth",
                 "Ibaraki_smooth", "Tochigi_smooth", "Gunma_smooth", "Saitama_smooth",
                 "Chiba_smooth", "Tokyo_smooth", "Kanagawa_smooth", "Niigata_smooth",
                 "Toyama_smooth", "Ishikawa_smooth", "Fukui_smooth", "Yamanashi_smooth",
                 "Nagano_smooth", "Gifu_smooth", "Shizuoka_smooth", "Aichi_smooth",
                 "Mie_smooth", "Shiga_smooth", "Kyoto_smooth", "Osaka_smooth", "Hyogo_smooth",
                 "Nara_smooth", "Wakayama_smooth", "Tottori_smooth", "Shimane_smooth",
                 "Okayama_smooth", "Hiroshima_smooth", "Yamaguchi_smooth", "Tokushima_smooth",
                 "Kagawa_smooth", "Ehime_smooth", "Kochi_smooth", "Fukuoka_smooth", "Saga_smooth",
                 "Nagasaki_smooth", "Kumamoto_smooth", "Oita_smooth", "Miyazaki_smooth",
                 "Kagoshima_smooth", "Okinawa_smooth")

###################################################
# full raw data (1975 to 2013) for ages 60 to 110+
###################################################

#######################
# precise death counts
#######################

# Japan

dum = read.jpn_death("00", "Japan")$Deaths
#Japan_count_F = matrix(dum[3109:7659,3], nrow=111)
#Japan_count_M = matrix(dum[3109:7659,4], nrow=111)
#Japan_count_T = matrix(dum[3109:7659,5], nrow=111)
Japan_count_F = matrix(dum[3109:7770,3], nrow = 111)
Japan_count_M = matrix(dum[3109:7770,4], nrow = 111)
Japan_count_T = matrix(dum[3109:7770,5], nrow = 111)

Japan_count_female = rbind(Japan_count_F[1:100,], colSums(Japan_count_F[101:111,]))
Japan_count_male   = rbind(Japan_count_M[1:100,], colSums(Japan_count_M[101:111,]))
Japan_count_total  = rbind(Japan_count_T[1:100,], colSums(Japan_count_T[101:111,]))

# Hokkaido

dum = read.jpn_death("01", "Hokkaido")$Deaths
Hokkaido_count_F = matrix(dum[,3], nrow=111)
Hokkaido_count_M = matrix(dum[,4], nrow=111)
Hokkaido_count_T = matrix(dum[,5], nrow=111)

Hokkaido_count_female = rbind(Hokkaido_count_F[1:100,], colSums(Hokkaido_count_F[101:111,]))
Hokkaido_count_male   = rbind(Hokkaido_count_M[1:100,], colSums(Hokkaido_count_M[101:111,]))
Hokkaido_count_total  = rbind(Hokkaido_count_T[1:100,], colSums(Hokkaido_count_T[101:111,]))

# Aomori

dum = read.jpn_death("02", "Aomori")$Deaths
Aomori_count_F = matrix(dum[,3], nrow=111)
Aomori_count_M = matrix(dum[,4], nrow=111)
Aomori_count_T = matrix(dum[,5], nrow=111)

Aomori_count_female = rbind(Aomori_count_F[1:100,], colSums(Aomori_count_F[101:111,]))
Aomori_count_male   = rbind(Aomori_count_M[1:100,], colSums(Aomori_count_M[101:111,]))
Aomori_count_total  = rbind(Aomori_count_T[1:100,], colSums(Aomori_count_T[101:111,]))

# Iwate

dum = read.jpn_death("03", "Iwate")$Deaths
Iwate_count_F = matrix(dum[,3], nrow=111)
Iwate_count_M = matrix(dum[,4], nrow=111)
Iwate_count_T = matrix(dum[,5], nrow=111)

Iwate_count_female = rbind(Iwate_count_F[1:100,], colSums(Iwate_count_F[101:111,]))
Iwate_count_male   = rbind(Iwate_count_M[1:100,], colSums(Iwate_count_M[101:111,]))
Iwate_count_total  = rbind(Iwate_count_T[1:100,], colSums(Iwate_count_T[101:111,]))

# Miyagi

dum = read.jpn_death("04", "Miyagi")$Deaths
Miyagi_count_F = matrix(dum[,3], nrow=111)
Miyagi_count_M = matrix(dum[,4], nrow=111)
Miyagi_count_T = matrix(dum[,5], nrow=111)

Miyagi_count_female = rbind(Miyagi_count_F[1:100,], colSums(Miyagi_count_F[101:111,]))
Miyagi_count_male   = rbind(Miyagi_count_M[1:100,], colSums(Miyagi_count_M[101:111,]))
Miyagi_count_total  = rbind(Miyagi_count_T[1:100,], colSums(Miyagi_count_T[101:111,]))

# Akita

dum = read.jpn_death("05", "Akita")$Deaths
Akita_count_F = matrix(dum[,3], nrow=111)
Akita_count_M = matrix(dum[,4], nrow=111)
Akita_count_T = matrix(dum[,5], nrow=111)

Akita_count_female = rbind(Akita_count_F[1:100,], colSums(Akita_count_F[101:111,]))
Akita_count_male   = rbind(Akita_count_M[1:100,], colSums(Akita_count_M[101:111,]))
Akita_count_total  = rbind(Akita_count_T[1:100,], colSums(Akita_count_T[101:111,]))

# Yamagata

dum = read.jpn_death("06", "Yamagata")$Deaths
Yamagata_count_F = matrix(dum[,3], nrow=111)
Yamagata_count_M = matrix(dum[,4], nrow=111)
Yamagata_count_T = matrix(dum[,5], nrow=111)

Yamagata_count_female = rbind(Yamagata_count_F[1:100,], colSums(Yamagata_count_F[101:111,]))
Yamagata_count_male   = rbind(Yamagata_count_M[1:100,], colSums(Yamagata_count_M[101:111,]))
Yamagata_count_total  = rbind(Yamagata_count_T[1:100,], colSums(Yamagata_count_T[101:111,]))

# Fukushima

dum = read.jpn_death("07", "Fukushima")$Deaths
Fukushima_count_F = matrix(dum[,3], nrow=111)
Fukushima_count_M = matrix(dum[,4], nrow=111)
Fukushima_count_T = matrix(dum[,5], nrow=111)

Fukushima_count_female = rbind(Fukushima_count_F[1:100,], colSums(Fukushima_count_F[101:111,]))
Fukushima_count_male   = rbind(Fukushima_count_M[1:100,], colSums(Fukushima_count_M[101:111,]))
Fukushima_count_total  = rbind(Fukushima_count_T[1:100,], colSums(Fukushima_count_T[101:111,]))

# Ibaraki

dum = read.jpn_death("08", "Ibaraki")$Deaths
Ibaraki_count_F = matrix(dum[,3], nrow=111)
Ibaraki_count_M = matrix(dum[,4], nrow=111)
Ibaraki_count_T = matrix(dum[,5], nrow=111)

Ibaraki_count_female = rbind(Ibaraki_count_F[1:100,], colSums(Ibaraki_count_F[101:111,]))
Ibaraki_count_male   = rbind(Ibaraki_count_M[1:100,], colSums(Ibaraki_count_M[101:111,]))
Ibaraki_count_total  = rbind(Ibaraki_count_T[1:100,], colSums(Ibaraki_count_T[101:111,]))

# Tochigi

dum = read.jpn_death("09", "Tochigi")$Deaths
Tochigi_count_F = matrix(dum[,3], nrow=111)
Tochigi_count_M = matrix(dum[,4], nrow=111)
Tochigi_count_T = matrix(dum[,5], nrow=111)

Tochigi_count_female = rbind(Tochigi_count_F[1:100,], colSums(Tochigi_count_F[101:111,]))
Tochigi_count_male   = rbind(Tochigi_count_M[1:100,], colSums(Tochigi_count_M[101:111,]))
Tochigi_count_total  = rbind(Tochigi_count_T[1:100,], colSums(Tochigi_count_T[101:111,]))

# Gunma

dum = read.jpn_death("10", "Gunma")$Deaths
Gunma_count_F = matrix(dum[,3], nrow=111)
Gunma_count_M = matrix(dum[,4], nrow=111)
Gunma_count_T = matrix(dum[,5], nrow=111)

Gunma_count_female = rbind(Gunma_count_F[1:100,], colSums(Gunma_count_F[101:111,]))
Gunma_count_male   = rbind(Gunma_count_M[1:100,], colSums(Gunma_count_M[101:111,]))
Gunma_count_total  = rbind(Gunma_count_T[1:100,], colSums(Gunma_count_T[101:111,]))

# Saitama

dum = read.jpn_death("11", "Saitama")$Deaths
Saitama_count_F = matrix(dum[,3], nrow=111)
Saitama_count_M = matrix(dum[,4], nrow=111)
Saitama_count_T = matrix(dum[,5], nrow=111)

Saitama_count_female = rbind(Saitama_count_F[1:100,], colSums(Saitama_count_F[101:111,]))
Saitama_count_male   = rbind(Saitama_count_M[1:100,], colSums(Saitama_count_M[101:111,]))
Saitama_count_total  = rbind(Saitama_count_T[1:100,], colSums(Saitama_count_T[101:111,]))

# Chiba

dum = read.jpn_death("12", "Chiba")$Deaths
Chiba_count_F = matrix(dum[,3], nrow=111)
Chiba_count_M = matrix(dum[,4], nrow=111)
Chiba_count_T = matrix(dum[,5], nrow=111)

Chiba_count_female = rbind(Chiba_count_F[1:100,], colSums(Chiba_count_F[101:111,]))
Chiba_count_male   = rbind(Chiba_count_M[1:100,], colSums(Chiba_count_M[101:111,]))
Chiba_count_total  = rbind(Chiba_count_T[1:100,], colSums(Chiba_count_T[101:111,]))

# Tokyo

dum = read.jpn_death("13", "Tokyo")$Deaths
Tokyo_count_F = matrix(dum[,3], nrow=111)
Tokyo_count_M = matrix(dum[,4], nrow=111)
Tokyo_count_T = matrix(dum[,5], nrow=111)

Tokyo_count_female = rbind(Tokyo_count_F[1:100,], colSums(Tokyo_count_F[101:111,]))
Tokyo_count_male   = rbind(Tokyo_count_M[1:100,], colSums(Tokyo_count_M[101:111,]))
Tokyo_count_total  = rbind(Tokyo_count_T[1:100,], colSums(Tokyo_count_T[101:111,]))

# Kanagawa

dum = read.jpn_death("14", "Kanagawa")$Deaths
Kanagawa_count_F = matrix(dum[,3], nrow=111)
Kanagawa_count_M = matrix(dum[,4], nrow=111)
Kanagawa_count_T = matrix(dum[,5], nrow=111)

Kanagawa_count_female = rbind(Kanagawa_count_F[1:100,], colSums(Kanagawa_count_F[101:111,]))
Kanagawa_count_male   = rbind(Kanagawa_count_M[1:100,], colSums(Kanagawa_count_M[101:111,]))
Kanagawa_count_total  = rbind(Kanagawa_count_T[1:100,], colSums(Kanagawa_count_T[101:111,]))

# Niigata

dum = read.jpn_death("15", "Niigata")$Deaths
Niigata_count_F = matrix(dum[,3], nrow=111)
Niigata_count_M = matrix(dum[,4], nrow=111)
Niigata_count_T = matrix(dum[,5], nrow=111)

Niigata_count_female = rbind(Niigata_count_F[1:100,], colSums(Niigata_count_F[101:111,]))
Niigata_count_male   = rbind(Niigata_count_M[1:100,], colSums(Niigata_count_M[101:111,]))
Niigata_count_total  = rbind(Niigata_count_T[1:100,], colSums(Niigata_count_T[101:111,]))

# Toyama

dum = read.jpn_death("16", "Toyama")$Deaths
Toyama_count_F = matrix(dum[,3], nrow=111)
Toyama_count_M = matrix(dum[,4], nrow=111)
Toyama_count_T = matrix(dum[,5], nrow=111)

Toyama_count_female = rbind(Toyama_count_F[1:100,], colSums(Toyama_count_F[101:111,]))
Toyama_count_male   = rbind(Toyama_count_M[1:100,], colSums(Toyama_count_M[101:111,]))
Toyama_count_total  = rbind(Toyama_count_T[1:100,], colSums(Toyama_count_T[101:111,]))

# Ishikawa

dum = read.jpn_death("17", "Ishikawa")$Deaths
Ishikawa_count_F = matrix(dum[,3], nrow=111)
Ishikawa_count_M = matrix(dum[,4], nrow=111)
Ishikawa_count_T = matrix(dum[,5], nrow=111)

Ishikawa_count_female = rbind(Ishikawa_count_F[1:100,], colSums(Ishikawa_count_F[101:111,]))
Ishikawa_count_male   = rbind(Ishikawa_count_M[1:100,], colSums(Ishikawa_count_M[101:111,]))
Ishikawa_count_total  = rbind(Ishikawa_count_T[1:100,], colSums(Ishikawa_count_T[101:111,]))

# Fukui

dum = read.jpn_death("18", "Fukui")$Deaths
Fukui_count_F = matrix(dum[,3], nrow=111)
Fukui_count_M = matrix(dum[,4], nrow=111)
Fukui_count_T = matrix(dum[,5], nrow=111)

Fukui_count_female = rbind(Fukui_count_F[1:100,], colSums(Fukui_count_F[101:111,]))
Fukui_count_male   = rbind(Fukui_count_M[1:100,], colSums(Fukui_count_M[101:111,]))
Fukui_count_total  = rbind(Fukui_count_T[1:100,], colSums(Fukui_count_T[101:111,]))

# Yamanashi

dum = read.jpn_death("19", "Yamanashi")$Deaths
Yamanashi_count_F = matrix(dum[,3], nrow=111)
Yamanashi_count_M = matrix(dum[,4], nrow=111)
Yamanashi_count_T = matrix(dum[,5], nrow=111)

Yamanashi_count_female = rbind(Yamanashi_count_F[1:100,], colSums(Yamanashi_count_F[101:111,]))
Yamanashi_count_male   = rbind(Yamanashi_count_M[1:100,], colSums(Yamanashi_count_M[101:111,]))
Yamanashi_count_total  = rbind(Yamanashi_count_T[1:100,], colSums(Yamanashi_count_T[101:111,]))

# Nagano

dum = read.jpn_death("20", "Nagano")$Deaths
Nagano_count_F = matrix(dum[,3], nrow=111)
Nagano_count_M = matrix(dum[,4], nrow=111)
Nagano_count_T = matrix(dum[,5], nrow=111)

Nagano_count_female = rbind(Nagano_count_F[1:100,], colSums(Nagano_count_F[101:111,]))
Nagano_count_male   = rbind(Nagano_count_M[1:100,], colSums(Nagano_count_M[101:111,]))
Nagano_count_total  = rbind(Nagano_count_T[1:100,], colSums(Nagano_count_T[101:111,]))

# Gifu

dum = read.jpn_death("21", "Gifu")$Deaths
Gifu_count_F = matrix(dum[,3], nrow=111)
Gifu_count_M = matrix(dum[,4], nrow=111)
Gifu_count_T = matrix(dum[,5], nrow=111)

Gifu_count_female = rbind(Gifu_count_F[1:100,], colSums(Gifu_count_F[101:111,]))
Gifu_count_male   = rbind(Gifu_count_M[1:100,], colSums(Gifu_count_M[101:111,]))
Gifu_count_total  = rbind(Gifu_count_T[1:100,], colSums(Gifu_count_T[101:111,]))

# Shizuoka

dum = read.jpn_death("22", "Shizuoka")$Deaths
Shizuoka_count_F = matrix(dum[,3], nrow=111)
Shizuoka_count_M = matrix(dum[,4], nrow=111)
Shizuoka_count_T = matrix(dum[,5], nrow=111)

Shizuoka_count_female = rbind(Shizuoka_count_F[1:100,], colSums(Shizuoka_count_F[101:111,]))
Shizuoka_count_male   = rbind(Shizuoka_count_M[1:100,], colSums(Shizuoka_count_M[101:111,]))
Shizuoka_count_total  = rbind(Shizuoka_count_T[1:100,], colSums(Shizuoka_count_T[101:111,]))

# Aichi

dum = read.jpn_death("23", "Aichi")$Deaths
Aichi_count_F = matrix(dum[,3], nrow=111)
Aichi_count_M = matrix(dum[,4], nrow=111)
Aichi_count_T = matrix(dum[,5], nrow=111)

Aichi_count_female = rbind(Aichi_count_F[1:100,], colSums(Aichi_count_F[101:111,]))
Aichi_count_male   = rbind(Aichi_count_M[1:100,], colSums(Aichi_count_M[101:111,]))
Aichi_count_total  = rbind(Aichi_count_T[1:100,], colSums(Aichi_count_T[101:111,]))

# Mie

dum = read.jpn_death("24", "Mie")$Deaths
Mie_count_F = matrix(dum[,3], nrow=111)
Mie_count_M = matrix(dum[,4], nrow=111)
Mie_count_T = matrix(dum[,5], nrow=111)

Mie_count_female = rbind(Mie_count_F[1:100,], colSums(Mie_count_F[101:111,]))
Mie_count_male   = rbind(Mie_count_M[1:100,], colSums(Mie_count_M[101:111,]))
Mie_count_total  = rbind(Mie_count_T[1:100,], colSums(Mie_count_T[101:111,]))

# Shiga

dum = read.jpn_death("25", "Shiga")$Deaths
Shiga_count_F = matrix(dum[,3], nrow=111)
Shiga_count_M = matrix(dum[,4], nrow=111)
Shiga_count_T = matrix(dum[,5], nrow=111)

Shiga_count_female = rbind(Shiga_count_F[1:100,], colSums(Shiga_count_F[101:111,]))
Shiga_count_male   = rbind(Shiga_count_M[1:100,], colSums(Shiga_count_M[101:111,]))
Shiga_count_total  = rbind(Shiga_count_T[1:100,], colSums(Shiga_count_T[101:111,]))

# Kyoto

dum = read.jpn_death("26", "Kyoto")$Deaths
Kyoto_count_F = matrix(dum[,3], nrow=111)
Kyoto_count_M = matrix(dum[,4], nrow=111)
Kyoto_count_T = matrix(dum[,5], nrow=111)

Kyoto_count_female = rbind(Kyoto_count_F[1:100,], colSums(Kyoto_count_F[101:111,]))
Kyoto_count_male   = rbind(Kyoto_count_M[1:100,], colSums(Kyoto_count_M[101:111,]))
Kyoto_count_total  = rbind(Kyoto_count_T[1:100,], colSums(Kyoto_count_T[101:111,]))

# Osaka

dum = read.jpn_death("27", "Osaka")$Deaths
Osaka_count_F = matrix(dum[,3], nrow=111)
Osaka_count_M = matrix(dum[,4], nrow=111)
Osaka_count_T = matrix(dum[,5], nrow=111)

Osaka_count_female = rbind(Osaka_count_F[1:100,], colSums(Osaka_count_F[101:111,]))
Osaka_count_male   = rbind(Osaka_count_M[1:100,], colSums(Osaka_count_M[101:111,]))
Osaka_count_total  = rbind(Osaka_count_T[1:100,], colSums(Osaka_count_T[101:111,]))

# Hyogo

dum = read.jpn_death("28", "Hyogo")$Deaths
Hyogo_count_F = matrix(dum[,3], nrow=111)
Hyogo_count_M = matrix(dum[,4], nrow=111)
Hyogo_count_T = matrix(dum[,5], nrow=111)

Hyogo_count_female = rbind(Hyogo_count_F[1:100,], colSums(Hyogo_count_F[101:111,]))
Hyogo_count_male   = rbind(Hyogo_count_M[1:100,], colSums(Hyogo_count_M[101:111,]))
Hyogo_count_total  = rbind(Hyogo_count_T[1:100,], colSums(Hyogo_count_T[101:111,]))

# Nara

dum = read.jpn_death("29", "Nara")$Deaths
Nara_count_F = matrix(dum[,3], nrow=111)
Nara_count_M = matrix(dum[,4], nrow=111)
Nara_count_T = matrix(dum[,5], nrow=111)

Nara_count_female = rbind(Nara_count_F[1:100,], colSums(Nara_count_F[101:111,]))
Nara_count_male   = rbind(Nara_count_M[1:100,], colSums(Nara_count_M[101:111,]))
Nara_count_total  = rbind(Nara_count_T[1:100,], colSums(Nara_count_T[101:111,]))

# Wakayama

dum = read.jpn_death("30", "Wakayama")$Deaths
Wakayama_count_F = matrix(dum[,3], nrow=111)
Wakayama_count_M = matrix(dum[,4], nrow=111)
Wakayama_count_T = matrix(dum[,5], nrow=111)

Wakayama_count_female = rbind(Wakayama_count_F[1:100,], colSums(Wakayama_count_F[101:111,]))
Wakayama_count_male   = rbind(Wakayama_count_M[1:100,], colSums(Wakayama_count_M[101:111,]))
Wakayama_count_total  = rbind(Wakayama_count_T[1:100,], colSums(Wakayama_count_T[101:111,]))

# Tottori

dum = read.jpn_death("31", "Tottori")$Deaths
Tottori_count_F = matrix(dum[,3], nrow=111)
Tottori_count_M = matrix(dum[,4], nrow=111)
Tottori_count_T = matrix(dum[,5], nrow=111)

Tottori_count_female = rbind(Tottori_count_F[1:100,], colSums(Tottori_count_F[101:111,]))
Tottori_count_male   = rbind(Tottori_count_M[1:100,], colSums(Tottori_count_M[101:111,]))
Tottori_count_total  = rbind(Tottori_count_T[1:100,], colSums(Tottori_count_T[101:111,]))

# Shimane

dum = read.jpn_death("32", "Shimane")$Deaths
Shimane_count_F = matrix(dum[,3], nrow=111)
Shimane_count_M = matrix(dum[,4], nrow=111)
Shimane_count_T = matrix(dum[,5], nrow=111)

Shimane_count_female = rbind(Shimane_count_F[1:100,], colSums(Shimane_count_F[101:111,]))
Shimane_count_male   = rbind(Shimane_count_M[1:100,], colSums(Shimane_count_M[101:111,]))
Shimane_count_total  = rbind(Shimane_count_T[1:100,], colSums(Shimane_count_T[101:111,]))

# Okayama

dum = read.jpn_death("33", "Okayama")$Deaths
Okayama_count_F = matrix(dum[,3], nrow=111)
Okayama_count_M = matrix(dum[,4], nrow=111)
Okayama_count_T = matrix(dum[,5], nrow=111)

Okayama_count_female = rbind(Okayama_count_F[1:100,], colSums(Okayama_count_F[101:111,]))
Okayama_count_male   = rbind(Okayama_count_M[1:100,], colSums(Okayama_count_M[101:111,]))
Okayama_count_total  = rbind(Okayama_count_T[1:100,], colSums(Okayama_count_T[101:111,]))

# Hiroshima

dum = read.jpn_death("34", "Hiroshima")$Deaths
Hiroshima_count_F = matrix(dum[,3], nrow=111)
Hiroshima_count_M = matrix(dum[,4], nrow=111)
Hiroshima_count_T = matrix(dum[,5], nrow=111)

Hiroshima_count_female = rbind(Hiroshima_count_F[1:100,], colSums(Hiroshima_count_F[101:111,]))
Hiroshima_count_male   = rbind(Hiroshima_count_M[1:100,], colSums(Hiroshima_count_M[101:111,]))
Hiroshima_count_total  = rbind(Hiroshima_count_T[1:100,], colSums(Hiroshima_count_T[101:111,]))

# Yamaguchi

dum = read.jpn_death("35", "Yamaguchi")$Deaths
Yamaguchi_count_F = matrix(dum[,3], nrow=111)
Yamaguchi_count_M = matrix(dum[,4], nrow=111)
Yamaguchi_count_T = matrix(dum[,5], nrow=111)

Yamaguchi_count_female = rbind(Yamaguchi_count_F[1:100,], colSums(Yamaguchi_count_F[101:111,]))
Yamaguchi_count_male   = rbind(Yamaguchi_count_M[1:100,], colSums(Yamaguchi_count_M[101:111,]))
Yamaguchi_count_total  = rbind(Yamaguchi_count_T[1:100,], colSums(Yamaguchi_count_T[101:111,]))

# Tokushima

dum = read.jpn_death("36", "Tokushima")$Deaths
Tokushima_count_F = matrix(dum[,3], nrow=111)
Tokushima_count_M = matrix(dum[,4], nrow=111)
Tokushima_count_T = matrix(dum[,5], nrow=111)

Tokushima_count_female = rbind(Tokushima_count_F[1:100,], colSums(Tokushima_count_F[101:111,]))
Tokushima_count_male   = rbind(Tokushima_count_M[1:100,], colSums(Tokushima_count_M[101:111,]))
Tokushima_count_total  = rbind(Tokushima_count_T[1:100,], colSums(Tokushima_count_T[101:111,]))

# Kagawa

dum = read.jpn_death("37", "Kagawa")$Deaths
Kagawa_count_F = matrix(dum[,3], nrow=111)
Kagawa_count_M = matrix(dum[,4], nrow=111)
Kagawa_count_T = matrix(dum[,5], nrow=111)

Kagawa_count_female = rbind(Kagawa_count_F[1:100,], colSums(Kagawa_count_F[101:111,]))
Kagawa_count_male   = rbind(Kagawa_count_M[1:100,], colSums(Kagawa_count_M[101:111,]))
Kagawa_count_total  = rbind(Kagawa_count_T[1:100,], colSums(Kagawa_count_T[101:111,]))

# Ehime

dum = read.jpn_death("38", "Ehime")$Deaths
Ehime_count_F = matrix(dum[,3], nrow=111)
Ehime_count_M = matrix(dum[,4], nrow=111)
Ehime_count_T = matrix(dum[,5], nrow=111)

Ehime_count_female = rbind(Ehime_count_F[1:100,], colSums(Ehime_count_F[101:111,]))
Ehime_count_male   = rbind(Ehime_count_M[1:100,], colSums(Ehime_count_M[101:111,]))
Ehime_count_total  = rbind(Ehime_count_T[1:100,], colSums(Ehime_count_T[101:111,]))

# Kochi

dum = read.jpn_death("39", "Kochi")$Deaths
Kochi_count_F = matrix(dum[,3], nrow=111)
Kochi_count_M = matrix(dum[,4], nrow=111)
Kochi_count_T = matrix(dum[,5], nrow=111)

Kochi_count_female = rbind(Kochi_count_F[1:100,], colSums(Kochi_count_F[101:111,]))
Kochi_count_male   = rbind(Kochi_count_M[1:100,], colSums(Kochi_count_M[101:111,]))
Kochi_count_total  = rbind(Kochi_count_T[1:100,], colSums(Kochi_count_T[101:111,]))

# Fukuoka

dum = read.jpn_death("40", "Fukuoka")$Deaths
Fukuoka_count_F = matrix(dum[,3], nrow=111)
Fukuoka_count_M = matrix(dum[,4], nrow=111)
Fukuoka_count_T = matrix(dum[,5], nrow=111)

Fukuoka_count_female = rbind(Fukuoka_count_F[1:100,], colSums(Fukuoka_count_F[101:111,]))
Fukuoka_count_male   = rbind(Fukuoka_count_M[1:100,], colSums(Fukuoka_count_M[101:111,]))
Fukuoka_count_total  = rbind(Fukuoka_count_T[1:100,], colSums(Fukuoka_count_T[101:111,]))

# Saga

dum = read.jpn_death("41", "Saga")$Deaths
Saga_count_F = matrix(dum[,3], nrow=111)
Saga_count_M = matrix(dum[,4], nrow=111)
Saga_count_T = matrix(dum[,5], nrow=111)

Saga_count_female = rbind(Saga_count_F[1:100,], colSums(Saga_count_F[101:111,]))
Saga_count_male   = rbind(Saga_count_M[1:100,], colSums(Saga_count_M[101:111,]))
Saga_count_total  = rbind(Saga_count_T[1:100,], colSums(Saga_count_T[101:111,]))

# Nagasaki

dum = read.jpn_death("42", "Nagasaki")$Deaths
Nagasaki_count_F = matrix(dum[,3], nrow=111)
Nagasaki_count_M = matrix(dum[,4], nrow=111)
Nagasaki_count_T = matrix(dum[,5], nrow=111)

Nagasaki_count_female = rbind(Nagasaki_count_F[1:100,], colSums(Nagasaki_count_F[101:111,]))
Nagasaki_count_male   = rbind(Nagasaki_count_M[1:100,], colSums(Nagasaki_count_M[101:111,]))
Nagasaki_count_total  = rbind(Nagasaki_count_T[1:100,], colSums(Nagasaki_count_T[101:111,]))

# Kumamoto

dum = read.jpn_death("43", "Kumamoto")$Deaths
Kumamoto_count_F = matrix(dum[,3], nrow=111)
Kumamoto_count_M = matrix(dum[,4], nrow=111)
Kumamoto_count_T = matrix(dum[,5], nrow=111)

Kumamoto_count_female = rbind(Kumamoto_count_F[1:100,], colSums(Kumamoto_count_F[101:111,]))
Kumamoto_count_male   = rbind(Kumamoto_count_M[1:100,], colSums(Kumamoto_count_M[101:111,]))
Kumamoto_count_total  = rbind(Kumamoto_count_T[1:100,], colSums(Kumamoto_count_T[101:111,]))

# Oita

dum = read.jpn_death("44", "Oita")$Deaths
Oita_count_F = matrix(dum[,3], nrow=111)
Oita_count_M = matrix(dum[,4], nrow=111)
Oita_count_T = matrix(dum[,5], nrow=111)

Oita_count_female = rbind(Oita_count_F[1:100,], colSums(Oita_count_F[101:111,]))
Oita_count_male   = rbind(Oita_count_M[1:100,], colSums(Oita_count_M[101:111,]))
Oita_count_total  = rbind(Oita_count_T[1:100,], colSums(Oita_count_T[101:111,]))

# Miyazaki

dum = read.jpn_death("45", "Miyazaki")$Deaths
Miyazaki_count_F = matrix(dum[,3], nrow=111)
Miyazaki_count_M = matrix(dum[,4], nrow=111)
Miyazaki_count_T = matrix(dum[,5], nrow=111)

Miyazaki_count_female = rbind(Miyazaki_count_F[1:100,], colSums(Miyazaki_count_F[101:111,]))
Miyazaki_count_male   = rbind(Miyazaki_count_M[1:100,], colSums(Miyazaki_count_M[101:111,]))
Miyazaki_count_total  = rbind(Miyazaki_count_T[1:100,], colSums(Miyazaki_count_T[101:111,]))

# Kagoshima

dum = read.jpn_death("46", "Kagoshima")$Deaths
Kagoshima_count_F = matrix(dum[,3], nrow=111)
Kagoshima_count_M = matrix(dum[,4], nrow=111)
Kagoshima_count_T = matrix(dum[,5], nrow=111)

Kagoshima_count_female = rbind(Kagoshima_count_F[1:100,], colSums(Kagoshima_count_F[101:111,]))
Kagoshima_count_male   = rbind(Kagoshima_count_M[1:100,], colSums(Kagoshima_count_M[101:111,]))
Kagoshima_count_total  = rbind(Kagoshima_count_T[1:100,], colSums(Kagoshima_count_T[101:111,]))

# Okinawa

dum = read.jpn_death("47", "Okinawa")$Deaths
Okinawa_count_F = matrix(dum[,3], nrow=111)
Okinawa_count_M = matrix(dum[,4], nrow=111)
Okinawa_count_T = matrix(dum[,5], nrow=111)

Okinawa_count_female = rbind(Okinawa_count_F[1:100,], colSums(Okinawa_count_F[101:111,]))
Okinawa_count_male   = rbind(Okinawa_count_M[1:100,], colSums(Okinawa_count_M[101:111,]))
Okinawa_count_total  = rbind(Okinawa_count_T[1:100,], colSums(Okinawa_count_T[101:111,]))


# rate (ages 60-110)

Japan     = extract.years(extract.ages(read.jpn("00", "Japan"), 60:100), 1975:2016)
Hokkaido  = extract.ages(read.jpn("01", "Hokkaido"), 60:100)
Aomori    = extract.ages(read.jpn("02", "Aomori"), 60:100)
Iwate     = extract.ages(read.jpn("03", "Iwate"), 60:100)
Miyagi    = extract.ages(read.jpn("04", "Miyagi"), 60:100)
Akita     = extract.ages(read.jpn("05", "Akita"), 60:100)
Yamagata  = extract.ages(read.jpn("06", "Yamagata"), 60:100)
Fukushima = extract.ages(read.jpn("07", "Fukushima"), 60:100)
Ibaraki   = extract.ages(read.jpn("08", "Ibaraki"), 60:100)
Tochigi   = extract.ages(read.jpn("09", "Tochigi"), 60:100)
Gunma     = extract.ages(read.jpn("10", "Gunma"), 60:100)
Saitama   = extract.ages(read.jpn("11", "Saitama"), 60:100)
Chiba     = extract.ages(read.jpn("12", "Chiba"), 60:100)
Tokyo     = extract.ages(read.jpn("13", "Tokyo"), 60:100)
Kanagawa  = extract.ages(read.jpn("14", "Kanagawa"), 60:100)
Niigata   = extract.ages(read.jpn("15", "Niigata"), 60:100)
Toyama    = extract.ages(read.jpn("16", "Toyama"), 60:100)
Ishikawa  = extract.ages(read.jpn("17", "Ishikawa"), 60:100)
Fukui     = extract.ages(read.jpn("18", "Fukui"), 60:100)
Yamanashi = extract.ages(read.jpn("19", "Yamanashi"), 60:100)
Nagano    = extract.ages(read.jpn("20", "Nagano"), 60:100)
Gifu      = extract.ages(read.jpn("21", "Gifu"), 60:100)
Shizuoka  = extract.ages(read.jpn("22", "Shizuoka"), 60:100)
Aichi     = extract.ages(read.jpn("23", "Aichi"), 60:100)
Mie       = extract.ages(read.jpn("24", "Mie"), 60:100)
Shiga     = extract.ages(read.jpn("25", "Shiga"), 60:100)
Kyoto     = extract.ages(read.jpn("26", "Kyoto"), 60:100)
Osaka     = extract.ages(read.jpn("27", "Osaka"), 60:100)
Hyogo     = extract.ages(read.jpn("28", "Hyogo"), 60:100)
Nara      = extract.ages(read.jpn("29", "Nara"), 60:100)
Wakayama  = extract.ages(read.jpn("30", "Wakayama"), 60:100)
Tottori   = extract.ages(read.jpn("31", "Tottori"), 60:100)
Shimane   = extract.ages(read.jpn("32", "Shimane"), 60:100)
Okayama   = extract.ages(read.jpn("33", "Okayama"), 60:100)
Hiroshima = extract.ages(read.jpn("34", "Hiroshima"), 60:100)
Yamaguchi = extract.ages(read.jpn("35", "Yamaguchi"), 60:100)
Tokushima = extract.ages(read.jpn("36", "Tokushima"), 60:100)
Kagawa    = extract.ages(read.jpn("37", "Kagawa"), 60:100)
Ehime     = extract.ages(read.jpn("38", "Ehime"), 60:100)
Kochi     = extract.ages(read.jpn("39", "Kochi"), 60:100)
Fukuoka   = extract.ages(read.jpn("40", "Fukuoka"), 60:100)
Saga      = extract.ages(read.jpn("41", "Saga"), 60:100)
Nagasaki  = extract.ages(read.jpn("42", "Nagasaki"), 60:100)
Kumamoto  = extract.ages(read.jpn("43", "Kumamoto"), 60:100)
Oita      = extract.ages(read.jpn("44", "Oita"), 60:100)
Miyazaki  = extract.ages(read.jpn("45", "Miyazaki"), 60:100)
Kagoshima = extract.ages(read.jpn("46", "Kagoshima"), 60:100)
Okinawa   = extract.ages(read.jpn("47", "Okinawa"), 60:100)

# ages 0-100

Japan_all     = extract.years(extract.ages(read.jpn("00", "Japan"), 0:100), 1975:2016)
Hokkaido_all  = extract.ages(read.jpn("01", "Hokkaido"), 0:100)
Aomori_all    = extract.ages(read.jpn("02", "Aomori"), 0:100)
Iwate_all     = extract.ages(read.jpn("03", "Iwate"), 0:100)
Miyagi_all    = extract.ages(read.jpn("04", "Miyagi"), 0:100)
Akita_all     = extract.ages(read.jpn("05", "Akita"), 0:100)
Yamagata_all  = extract.ages(read.jpn("06", "Yamagata"), 0:100)
Fukushima_all = extract.ages(read.jpn("07", "Fukushima"), 0:100)
Ibaraki_all   = extract.ages(read.jpn("08", "Ibaraki"), 0:100)
Tochigi_all   = extract.ages(read.jpn("09", "Tochigi"), 0:100)
Gunma_all     = extract.ages(read.jpn("10", "Gunma"), 0:100)
Saitama_all   = extract.ages(read.jpn("11", "Saitama"), 0:100)
Chiba_all     = extract.ages(read.jpn("12", "Chiba"), 0:100)
Tokyo_all     = extract.ages(read.jpn("13", "Tokyo"), 0:100)
Kanagawa_all  = extract.ages(read.jpn("14", "Kanagawa"), 0:100)
Niigata_all   = extract.ages(read.jpn("15", "Niigata"), 0:100)
Toyama_all    = extract.ages(read.jpn("16", "Toyama"), 0:100)
Ishikawa_all  = extract.ages(read.jpn("17", "Ishikawa"), 0:100)
Fukui_all     = extract.ages(read.jpn("18", "Fukui"), 0:100)
Yamanashi_all = extract.ages(read.jpn("19", "Yamanashi"), 0:100)
Nagano_all    = extract.ages(read.jpn("20", "Nagano"), 0:100)
Gifu_all      = extract.ages(read.jpn("21", "Gifu"), 0:100)
Shizuoka_all  = extract.ages(read.jpn("22", "Shizuoka"), 0:100)
Aichi_all     = extract.ages(read.jpn("23", "Aichi"), 0:100)
Mie_all       = extract.ages(read.jpn("24", "Mie"), 0:100)
Shiga_all     = extract.ages(read.jpn("25", "Shiga"), 0:100)
Kyoto_all     = extract.ages(read.jpn("26", "Kyoto"), 0:100)
Osaka_all     = extract.ages(read.jpn("27", "Osaka"), 0:100)
Hyogo_all     = extract.ages(read.jpn("28", "Hyogo"), 0:100)
Nara_all      = extract.ages(read.jpn("29", "Nara"), 0:100)
Wakayama_all  = extract.ages(read.jpn("30", "Wakayama"), 0:100)
Tottori_all   = extract.ages(read.jpn("31", "Tottori"), 0:100)
Shimane_all   = extract.ages(read.jpn("32", "Shimane"), 0:100)
Okayama_all   = extract.ages(read.jpn("33", "Okayama"), 0:100)
Hiroshima_all = extract.ages(read.jpn("34", "Hiroshima"), 0:100)
Yamaguchi_all = extract.ages(read.jpn("35", "Yamaguchi"), 0:100)
Tokushima_all = extract.ages(read.jpn("36", "Tokushima"), 0:100)
Kagawa_all    = extract.ages(read.jpn("37", "Kagawa"), 0:100)
Ehime_all     = extract.ages(read.jpn("38", "Ehime"), 0:100)
Kochi_all     = extract.ages(read.jpn("39", "Kochi"), 0:100)
Fukuoka_all   = extract.ages(read.jpn("40", "Fukuoka"), 0:100)
Saga_all      = extract.ages(read.jpn("41", "Saga"), 0:100)
Nagasaki_all  = extract.ages(read.jpn("42", "Nagasaki"), 0:100)
Kumamoto_all  = extract.ages(read.jpn("43", "Kumamoto"), 0:100)
Oita_all      = extract.ages(read.jpn("44", "Oita"), 0:100)
Miyazaki_all  = extract.ages(read.jpn("45", "Miyazaki"), 0:100)
Kagoshima_all = extract.ages(read.jpn("46", "Kagoshima"), 0:100)
Okinawa_all   = extract.ages(read.jpn("47", "Okinawa"), 0:100)

# check if the last year is 2015 for all states

year_store = vector("numeric",47)
for(iw in 1:47)
{
    year_store[iw] = tail(get(state[iw])$year, 1)
}
all(year_store == 2016) # TRUE

# smoothed functional curves using penalized regression spline with monotonic constraint

for(iw in 1:48)
{
    assign(state_smooth[iw], extract.ages(smooth.demogdata(get(state_all[iw])), 60:100))
    print(iw)
}

#######################
# clustering by region
#######################

# R1

ind_R1 = Hokkaido
ind_R1_smooth = extract.ages(smooth.demogdata(Hokkaido_all), 60:100)

# R2

ind_R2_female_count = Aomori_all$pop$female + Iwate_all$pop$female + Miyagi_all$pop$female +
                      Akita_all$pop$female + Yamagata_all$pop$female + Fukushima_all$pop$female
ind_R2_female_rate = (Aomori_count_female + Iwate_count_female + Miyagi_count_female +
                      Akita_count_female + Yamagata_count_female + Fukushima_count_female)/ind_R2_female_count

ind_R2_male_count = Aomori_all$pop$male + Iwate_all$pop$male + Miyagi_all$pop$male + Akita_all$pop$male + Yamagata_all$pop$male + Fukushima_all$pop$male
ind_R2_male_rate = (Aomori_count_male + Iwate_count_male + Miyagi_count_male + Akita_count_male + Yamagata_count_male + Fukushima_count_male)/ind_R2_male_count

ind_R2_total_count = Aomori_all$pop$total + Iwate_all$pop$total + Miyagi_all$pop$total + Akita_all$pop$total + Yamagata_all$pop$total + Fukushima_all$pop$total
ind_R2_total_rate = (Aomori_count_total + Iwate_count_total + Miyagi_count_total + Akita_count_total + Yamagata_count_total + Fukushima_count_total)/ind_R2_total_count


ind_R2_rate_summary = cbind(rep(1975:2016,101), rep(0:100,42), as.numeric(ind_R2_female_rate),
as.numeric(ind_R2_male_rate), as.numeric(ind_R2_total_rate))
colnames(ind_R2_rate_summary) = c("Year","Age","Female","Male","Total")
write.table(ind_R2_rate_summary, "ind_R2_rate.txt", quote = FALSE, row.names=FALSE, col.names=TRUE)

ind_R2_count_summary = cbind(rep(1975:2016,101), rep(0:100,42), as.numeric(ind_R2_female_count),
as.numeric(ind_R2_male_count),
as.numeric(ind_R2_total_count))
colnames(ind_R2_count_summary) = c("Year","Age","Female","Male","Total")
write.table(ind_R2_count_summary, "ind_R2_count.txt", quote = FALSE, row.names=FALSE, col.names=TRUE)

ind_R2_all = read.demogdata("ind_R2_rate.txt", "ind_R2_count.txt", type="mortality", label = "R2", skip=0)

# raw and smoothed mortality rates

ind_R2        = extract.ages(ind_R2_all, 60:100)
ind_R2_smooth = extract.ages(smooth.demogdata(ind_R2_all), 60:100)

# R3

ind_R3_female_count = Ibaraki_all$pop$female + Tochigi_all$pop$female + Gunma_all$pop$female + Saitama_all$pop$female + Chiba_all$pop$female + Tokyo_all$pop$female + Kanagawa_all$pop$female
ind_R3_female_rate = (Ibaraki_count_female + Tochigi_count_female + Gunma_count_female + Saitama_count_female + Chiba_count_female + Tokyo_count_female + Kanagawa_count_female)/ind_R3_female_count

ind_R3_male_count = Ibaraki_all$pop$male + Tochigi_all$pop$male + Gunma_all$pop$male + Saitama_all$pop$male + Chiba_all$pop$male + Tokyo_all$pop$male + Kanagawa_all$pop$male
ind_R3_male_rate = (Ibaraki_count_male + Tochigi_count_male + Gunma_count_male + Saitama_count_male + Chiba_count_male + Tokyo_count_male + Kanagawa_count_male)/ind_R3_male_count

ind_R3_total_count = Ibaraki_all$pop$total + Tochigi_all$pop$total + Gunma_all$pop$total + Saitama_all$pop$total + Chiba_all$pop$total + Tokyo_all$pop$total + Kanagawa_all$pop$total
ind_R3_total_rate = (Ibaraki_count_total + Tochigi_count_total + Gunma_count_total + Saitama_count_total + Chiba_count_total + Tokyo_count_total + Kanagawa_count_total)/ind_R3_total_count

ind_R3_rate_summary = cbind(rep(1975:2016,101), rep(0:100,42), as.numeric(ind_R3_female_rate), as.numeric(ind_R3_male_rate), as.numeric(ind_R3_total_rate))
colnames(ind_R3_rate_summary) = c("Year","Age","Female","Male","Total")
write.table(ind_R3_rate_summary, "ind_R3_rate.txt", quote = FALSE, row.names=FALSE, col.names=TRUE)

ind_R3_count_summary = cbind(rep(1975:2016,101), rep(0:100,42), as.numeric(ind_R3_female_count),
as.numeric(ind_R3_male_count),
as.numeric(ind_R3_total_count))
colnames(ind_R3_count_summary) = c("Year","Age","Female","Male","Total")
write.table(ind_R3_count_summary, "ind_R3_count.txt", quote = FALSE, row.names=FALSE, col.names=TRUE)

ind_R3_all = read.demogdata("ind_R3_rate.txt", "ind_R3_count.txt", type="mortality", label = "R3", skip=0)

# raw and smoothed mortality rates

ind_R3        = extract.ages(ind_R3_all, 60:100)
ind_R3_smooth = extract.ages(smooth.demogdata(ind_R3_all), 60:100)

# R4

ind_R4_female_count = Niigata_all$pop$female + Toyama_all$pop$female + Ishikawa_all$pop$female + Fukui_all$pop$female + Yamanashi_all$pop$female + Nagano_all$pop$female + Gifu_all$pop$female + Shizuoka_all$pop$female + Aichi_all$pop$female
ind_R4_female_rate = (Niigata_count_female + Toyama_count_female + Ishikawa_count_female + Fukui_count_female + Yamanashi_count_female + Nagano_count_female + Gifu_count_female + Shizuoka_count_female + Aichi_count_female)/ind_R4_female_count

ind_R4_male_count = Niigata_all$pop$male + Toyama_all$pop$male + Ishikawa_all$pop$male + Fukui_all$pop$male + Yamanashi_all$pop$male + Nagano_all$pop$male + Gifu_all$pop$male + Shizuoka_all$pop$male + Aichi_all$pop$male
ind_R4_male_rate = (Niigata_count_male + Toyama_count_male + Ishikawa_count_male + Fukui_count_male + Yamanashi_count_male + Nagano_count_male + Gifu_count_male + Shizuoka_count_male + Aichi_count_male)/ind_R4_male_count

ind_R4_total_count = Niigata_all$pop$total + Toyama_all$pop$total + Ishikawa_all$pop$total + Fukui_all$pop$total + Yamanashi_all$pop$total + Nagano_all$pop$total + Gifu_all$pop$total + Shizuoka_all$pop$total + Aichi_all$pop$total
ind_R4_total_rate = (Niigata_count_total + Toyama_count_total + Ishikawa_count_total + Fukui_count_total + Yamanashi_count_total + Nagano_count_total + Gifu_count_total + Shizuoka_count_total + Aichi_count_total)/ind_R4_total_count

ind_R4_rate_summary = cbind(rep(1975:2016,101), rep(0:100,42), as.numeric(ind_R4_female_rate),
as.numeric(ind_R4_male_rate), as.numeric(ind_R4_total_rate))
colnames(ind_R4_rate_summary) = c("Year","Age","Female","Male","Total")
write.table(ind_R4_rate_summary, "ind_R4_rate.txt", quote = FALSE, row.names=FALSE, col.names=TRUE)

ind_R4_count_summary = cbind(rep(1975:2016,101), rep(0:100,42), as.numeric(ind_R4_female_count),
as.numeric(ind_R4_male_count),
as.numeric(ind_R4_total_count))
colnames(ind_R4_count_summary) = c("Year","Age","Female","Male","Total")
write.table(ind_R4_count_summary, "ind_R4_count.txt", quote = FALSE, row.names=FALSE, col.names=TRUE)

ind_R4_all = read.demogdata("ind_R4_rate.txt", "ind_R4_count.txt", type="mortality", label = "R4", skip=0)

# raw and smoothed mortality rates

ind_R4        = extract.ages(ind_R4_all, 60:100)
ind_R4_smooth = extract.ages(smooth.demogdata(ind_R4_all), 60:100)

# R5

ind_R5_female_count = Mie_all$pop$female + Shiga_all$pop$female + Kyoto_all$pop$female + Osaka_all$pop$female + Hyogo_all$pop$female + Nara_all$pop$female + Wakayama_all$pop$female
ind_R5_female_rate = (Mie_count_female + Shiga_count_female + Kyoto_count_female + Osaka_count_female + Hyogo_count_female + Nara_count_female + Wakayama_count_female)/ind_R5_female_count

ind_R5_male_count = Mie_all$pop$male + Shiga_all$pop$male + Kyoto_all$pop$male + Osaka_all$pop$male + Hyogo_all$pop$male + Nara_all$pop$male + Wakayama_all$pop$male
ind_R5_male_rate = (Mie_count_male + Shiga_count_male + Kyoto_count_male + Osaka_count_male + Hyogo_count_male + Nara_count_male + Wakayama_count_male)/ind_R5_male_count

ind_R5_total_count = Mie_all$pop$total + Shiga_all$pop$total + Kyoto_all$pop$total + Osaka_all$pop$total + Hyogo_all$pop$total + Nara_all$pop$total + Wakayama_all$pop$total
ind_R5_total_rate = (Mie_count_total + Shiga_count_total + Kyoto_count_total + Osaka_count_total + Hyogo_count_total + Nara_count_total + Wakayama_count_total)/ind_R5_total_count

ind_R5_rate_summary = cbind(rep(1975:2016,101), rep(0:100,42), as.numeric(ind_R5_female_rate),
as.numeric(ind_R5_male_rate), as.numeric(ind_R5_total_rate))
colnames(ind_R5_rate_summary) = c("Year","Age","Female","Male","Total")
write.table(ind_R5_rate_summary, "ind_R5_rate.txt", quote = FALSE, row.names=FALSE, col.names=TRUE)

ind_R5_count_summary = cbind(rep(1975:2016,101), rep(0:100,42), as.numeric(ind_R5_female_count),
as.numeric(ind_R5_male_count),
as.numeric(ind_R5_total_count))
colnames(ind_R5_count_summary) = c("Year","Age","Female","Male","Total")
write.table(ind_R5_count_summary, "ind_R5_count.txt", quote = FALSE, row.names=FALSE, col.names=TRUE)

ind_R5_all = read.demogdata("ind_R5_rate.txt", "ind_R5_count.txt", type="mortality", label = "R5", skip=0)

# raw and smoothed mortality rates

ind_R5 = extract.ages(ind_R5_all, 60:100)
ind_R5_smooth = extract.ages(smooth.demogdata(ind_R5_all), 60:100)

# R6

ind_R6_female_count = Tottori_all$pop$female + Shimane_all$pop$female + Okayama_all$pop$female + Hiroshima_all$pop$female + Yamaguchi_all$pop$female
ind_R6_female_rate = (Tottori_count_female + Shimane_count_female + Okayama_count_female + Hiroshima_count_female + Yamaguchi_count_female)/ind_R6_female_count

ind_R6_male_count = Tottori_all$pop$male + Shimane_all$pop$male + Okayama_all$pop$male + Hiroshima_all$pop$male + Yamaguchi_all$pop$male
ind_R6_male_rate  = (Tottori_count_male + Shimane_count_male + Okayama_count_male + Hiroshima_count_male + Yamaguchi_count_male)/ind_R6_male_count

ind_R6_total_count = Tottori_all$pop$total + Shimane_all$pop$total + Okayama_all$pop$total + Hiroshima_all$pop$total + Yamaguchi_all$pop$total
ind_R6_total_rate  = (Tottori_count_total + Shimane_count_total + Okayama_count_total + Hiroshima_count_total + Yamaguchi_count_total)/ind_R6_total_count

ind_R6_rate_summary = cbind(rep(1975:2016,101), rep(0:100,42), as.numeric(ind_R6_female_rate),
as.numeric(ind_R6_male_rate), as.numeric(ind_R6_total_rate))
colnames(ind_R6_rate_summary) = c("Year","Age","Female","Male","Total")
write.table(ind_R6_rate_summary, "ind_R6_rate.txt", quote = FALSE, row.names=FALSE, col.names=TRUE)

ind_R6_count_summary = cbind(rep(1975:2016,101), rep(0:100,42), as.numeric(ind_R6_female_count),
as.numeric(ind_R6_male_count),
as.numeric(ind_R6_total_count))
colnames(ind_R6_count_summary) = c("Year","Age","Female","Male","Total")
write.table(ind_R6_count_summary, "ind_R6_count.txt", quote = FALSE, row.names=FALSE, col.names=TRUE)

ind_R6_all = read.demogdata("ind_R6_rate.txt", "ind_R6_count.txt", type="mortality", label = "R6", skip=0)

# raw and smoothed mortality rates

ind_R6        = extract.ages(ind_R6_all, 60:100)
ind_R6_smooth = extract.ages(smooth.demogdata(ind_R6_all), 60:100)

# R7

ind_R7_female_count = Tokushima_all$pop$female + Kagawa_all$pop$female + Ehime_all$pop$female + Kochi_all$pop$female
ind_R7_female_rate  = (Tokushima_count_female + Kagawa_count_female + Ehime_count_female + Kochi_count_female)/ind_R7_female_count

ind_R7_male_count = Tokushima_all$pop$male + Kagawa_all$pop$male + Ehime_all$pop$male + Kochi_all$pop$male
ind_R7_male_rate  = (Tokushima_count_male + Kagawa_count_male + Ehime_count_male + Kochi_count_male)/ind_R7_male_count

ind_R7_total_count = Tokushima_all$pop$total + Kagawa_all$pop$total + Ehime_all$pop$total + Kochi_all$pop$total
ind_R7_total_rate  = (Tokushima_count_total + Kagawa_count_total + Ehime_count_total + Kochi_count_total)/ind_R7_total_count

ind_R7_rate_summary = cbind(rep(1975:2016,101), rep(0:100,42), as.numeric(ind_R7_female_rate),
as.numeric(ind_R7_male_rate), as.numeric(ind_R7_total_rate))
colnames(ind_R7_rate_summary) = c("Year","Age","Female","Male","Total")
write.table(ind_R7_rate_summary, "ind_R7_rate.txt", quote = FALSE, row.names=FALSE, col.names=TRUE)

ind_R7_count_summary = cbind(rep(1975:2016,101), rep(0:100,42), as.numeric(ind_R7_female_count),
as.numeric(ind_R7_male_count),
as.numeric(ind_R7_total_count))
colnames(ind_R7_count_summary) = c("Year","Age","Female","Male","Total")
write.table(ind_R7_count_summary, "ind_R7_count.txt", quote = FALSE, row.names=FALSE, col.names=TRUE)

ind_R7_all = read.demogdata("ind_R7_rate.txt", "ind_R7_count.txt", type="mortality", label = "R7", skip=0)

# raw and smoothed mortality rates

ind_R7        = extract.ages(ind_R7_all, 60:100)
ind_R7_smooth = extract.ages(smooth.demogdata(ind_R7_all), 60:100)

# R8

ind_R8_female_count = Fukuoka_all$pop$female + Saga_all$pop$female + Nagasaki_all$pop$female + Kumamoto_all$pop$female + Oita_all$pop$female + Miyazaki_all$pop$female + Kagoshima_all$pop$female + Okinawa_all$pop$female
ind_R8_female_rate = (Fukuoka_count_female + Saga_count_female + Nagasaki_count_female + Kumamoto_count_female + Oita_count_female + Miyazaki_count_female + Kagoshima_count_female + Okinawa_count_female)/ind_R8_female_count

ind_R8_male_count = Fukuoka_all$pop$male + Saga_all$pop$male + Nagasaki_all$pop$male + Kumamoto_all$pop$male + Oita_all$pop$male + Miyazaki_all$pop$male + Kagoshima_all$pop$male + Okinawa_all$pop$male
ind_R8_male_rate = (Fukuoka_count_male + Saga_count_male + Nagasaki_count_male + Kumamoto_count_male + Oita_count_male + Miyazaki_count_male + Kagoshima_count_male + Okinawa_count_male)/ind_R8_male_count

ind_R8_total_count = Fukuoka_all$pop$total + Saga_all$pop$total + Nagasaki_all$pop$total + Kumamoto_all$pop$total + Oita_all$pop$total + Miyazaki_all$pop$total + Kagoshima_all$pop$total + Okinawa_all$pop$total
ind_R8_total_rate = (Fukuoka_count_total + Saga_count_total + Nagasaki_count_total + Kumamoto_count_total + Oita_count_total + Miyazaki_count_total + Kagoshima_count_total + Okinawa_count_total)/ind_R8_total_count

ind_R8_rate_summary = cbind(rep(1975:2016,101), rep(0:100,42), as.numeric(ind_R8_female_rate),
as.numeric(ind_R8_male_rate), as.numeric(ind_R8_total_rate))
colnames(ind_R8_rate_summary) = c("Year","Age","Female","Male","Total")
write.table(ind_R8_rate_summary, "ind_R8_rate.txt", quote = FALSE, row.names=FALSE, col.names=TRUE)

ind_R8_count_summary = cbind(rep(1975:2016,101), rep(0:100,42), as.numeric(ind_R8_female_count),
as.numeric(ind_R8_male_count),
as.numeric(ind_R8_total_count))
colnames(ind_R8_count_summary) = c("Year","Age","Female","Male","Total")
write.table(ind_R8_count_summary, "ind_R8_count.txt", quote = FALSE, row.names=FALSE, col.names=TRUE)

ind_R8_all = read.demogdata("ind_R8_rate.txt", "ind_R8_count.txt", type="mortality", label = "R8", skip=0)

# raw and smoothed mortality rates

ind_R8        = extract.ages(ind_R8_all, 60:100)
ind_R8_smooth = extract.ages(smooth.demogdata(ind_R8_all), 60:100)

region = c("ind_R1", "ind_R2", "ind_R3", "ind_R4", "ind_R5", "ind_R6", "ind_R7", "ind_R8")
region_smooth = c("ind_R1_smooth", "ind_R2_smooth", "ind_R3_smooth", "ind_R4_smooth",
                  "ind_R5_smooth", "ind_R6_smooth", "ind_R7_smooth", "ind_R8_smooth")

#################################################
# Construct S matrix by age and forecast horizon
#################################################

Smat_fun <- function(kj, age, no_prefecture = 47)
{
    level_0 = level_1_a = level_1_b = matrix(NA, 2 * no_prefecture, (16-kj))
    for(iw in 1:no_prefecture)
    {
        # Level 0
        
        level_0[(2*iw-1),] = get(pop_ratio_P_F_to_T[iw])[kj,age,1:(16-kj)]
        level_0[(2*iw),]   = get(pop_ratio_P_M_to_T[iw])[kj,age,1:(16-kj)]
        
        # Level 1 (disaggregate by sex)
        
        level_1_a[(2*iw-1),] = get(pop_ratio_P_F_to_F[iw])[kj,age,1:(16-kj)]
        level_1_a[(2*iw),]   = rep(0,(16-kj))
        
        level_1_b[(2*iw-1),] = rep(0,(16-kj))
        level_1_b[(2*iw),]   = get(pop_ratio_P_M_to_M[iw])[kj,age,1:(16-kj)]
    }
    level_2_a_1 = level_2_a_2 = level_2_a_3 = level_2_a_4 = level_2_a_5 =
    level_2_a_6 = level_2_a_7 = level_2_a_8 = matrix(NA, 2 * no_prefecture, (16-kj))
  
    ###################################
    # Level 2 (disaggregate by region)
    ###################################
    
    # R1
    
    level_2_a_1[1,] = get(pop_ratio_P_F_to_R1_T[1])[kj,age,1:(16-kj)]
    level_2_a_1[2,] = get(pop_ratio_P_M_to_R1_T[1])[kj,age,1:(16-kj)]
    level_2_a_1[3:(2*no_prefecture),] = matrix(rep(0,(16-kj)*92), ncol=(16-kj))
  
    # R2
    
    level_2_a_2[1:2, ] = matrix(rep(0,(16-kj)*2), ncol=(16-kj))
    for(iw in 1:6)
    {
        level_2_a_2[(2*iw+1),] = get(pop_ratio_P_F_to_R2_T[iw])[kj,age,1:(16-kj)]
        level_2_a_2[(2*iw+2),] = get(pop_ratio_P_M_to_R2_T[iw])[kj,age,1:(16-kj)]
    }
    level_2_a_2[15:(2*no_prefecture),] = matrix(rep(0,(16-kj)*80), ncol=(16-kj))
  
    # R3
    
    level_2_a_3[1:14,] = matrix(rep(0,(16-kj)*14), ncol=(16-kj))
    for(iw in 1:7)
    {
        level_2_a_3[(2*(iw+6)+1),] = get(pop_ratio_P_F_to_R3_T[iw])[kj,age,1:(16-kj)]
        level_2_a_3[(2*(iw+6)+2),] = get(pop_ratio_P_M_to_R3_T[iw])[kj,age,1:(16-kj)]
    }
    level_2_a_3[29:(2*no_prefecture),] = matrix(rep(0,(16-kj)*66), ncol=(16-kj))
    
    # R4
    
    level_2_a_4[1:28,] = matrix(rep(0,(16-kj)*28), ncol=(16-kj))
    for(iw in 1:9)
    {
        level_2_a_4[(2*(iw+13)+1),] = get(pop_ratio_P_F_to_R4_T[iw])[kj,age,1:(16-kj)]
        level_2_a_4[(2*(iw+13)+2),] = get(pop_ratio_P_M_to_R4_T[iw])[kj,age,1:(16-kj)]
    }
    level_2_a_4[47:(2*no_prefecture),] = matrix(rep(0,(16-kj)*48), ncol=(16-kj))
    
    # R5
    
    level_2_a_5[1:46,] = matrix(rep(0,(16-kj)*46), ncol=(16-kj))
    for(iw in 1:7)
    {
        level_2_a_5[(2*(iw+22)+1),] = get(pop_ratio_P_F_to_R5_T[iw])[kj,age,1:(16-kj)]
        level_2_a_5[(2*(iw+22)+2),] = get(pop_ratio_P_M_to_R5_T[iw])[kj,age,1:(16-kj)]
    }
    level_2_a_5[61:(2*no_prefecture),] = matrix(rep(0,(16-kj)*34), ncol=(16-kj))
    
    # R6
    
    level_2_a_6[1:60,] = matrix(rep(0,(16-kj)*60), ncol=(16-kj))
    for(iw in 1:5)
    {
        level_2_a_6[(2*(iw+29)+1),] = get(pop_ratio_P_F_to_R6_T[iw])[kj,age,1:(16-kj)]
        level_2_a_6[(2*(iw+29)+2),] = get(pop_ratio_P_M_to_R6_T[iw])[kj,age,1:(16-kj)]
    }
    level_2_a_6[71:(2*no_prefecture),] = matrix(rep(0,(16-kj)*24), ncol=(16-kj))
    
    # R7
    
    level_2_a_7[1:70,] = matrix(rep(0,(16-kj)*70), ncol=(16-kj))
    for(iw in 1:4)
    {
        level_2_a_7[(2*(iw+34)+1),] = get(pop_ratio_P_F_to_R7_T[iw])[kj,age,1:(16-kj)]
        level_2_a_7[(2*(iw+34)+2),] = get(pop_ratio_P_M_to_R7_T[iw])[kj,age,1:(16-kj)]
    }
    level_2_a_7[79:(2*no_prefecture),] = matrix(rep(0,(16-kj)*16), ncol=(16-kj))
    
    # R8
    
    level_2_a_8[1:78,] = matrix(rep(0,(16-kj)*78), ncol=(16-kj))
    for(iw in 1:8)
    {
        level_2_a_8[(2*(iw+38)+1),] = get(pop_ratio_P_F_to_R8_T[iw])[kj,age,1:(16-kj)]
        level_2_a_8[(2*(iw+38)+2),] = get(pop_ratio_P_M_to_R8_T[iw])[kj,age,1:(16-kj)]
    }
    
    level_2_b_1 = level_2_b_2 = level_2_b_3 = level_2_b_4 = level_2_b_5 = level_2_b_6 =
    level_2_b_7 = level_2_b_8 = matrix(NA, (2 * no_prefecture), (16 - kj))
  
    ##################################################
    # Level 2 (disaggregate by region + sex (female))
    ##################################################
    
    # R1
    
    level_2_b_1[1,] = get(pop_ratio_P_F_to_R1_F[1])[kj,age,1:(16-kj)]
    level_2_b_1[2:(2*no_prefecture),] = matrix(rep(0,(16-kj)*93), ncol = (16-kj))
    
    # R2
    
    level_2_b_2[1:2, ] = matrix(rep(0,(16-kj)*2), ncol=(16-kj))
    for(iw in 1:6)
    {
        level_2_b_2[(2*iw+1),] = get(pop_ratio_P_F_to_R2_F[iw])[kj,age,1:(16-kj)]
        level_2_b_2[(2*iw+2),] = rep(0, (16-kj))
    }
    level_2_b_2[15:(2*no_prefecture),] = matrix(rep(0,(16-kj)*80), ncol=(16-kj))
    
    # R3
    
    level_2_b_3[1:14,] = matrix(rep(0,(16-kj)*14), ncol=(16-kj))
    for(iw in 1:7)
    {
        level_2_b_3[(2*(iw+6)+1),] = get(pop_ratio_P_F_to_R3_F[iw])[kj,age,1:(16-kj)]
        level_2_b_3[(2*(iw+6)+2),] = rep(0, (16-kj))
    }
    level_2_b_3[29:(2*no_prefecture),] = matrix(rep(0,(16-kj)*66), ncol=(16-kj))
    
    # R4
    
    level_2_b_4[1:28,] = matrix(rep(0,(16-kj)*28), ncol=(16-kj))
    for(iw in 1:9)
    {
        level_2_b_4[(2*(iw+13)+1),] = get(pop_ratio_P_F_to_R4_F[iw])[kj,age,1:(16-kj)]
        level_2_b_4[(2*(iw+13)+2),] = rep(0, (16-kj))
    }
    level_2_b_4[47:(2*no_prefecture),] = matrix(rep(0,(16-kj)*48), ncol=(16-kj))
    
    # R5
    
    level_2_b_5[1:46,] = matrix(rep(0,(16-kj)*46), ncol=(16-kj))
    for(iw in 1:7)
    {
        level_2_b_5[(2*(iw+22)+1),] = get(pop_ratio_P_F_to_R5_F[iw])[kj,age,1:(16-kj)]
        level_2_b_5[(2*(iw+22)+2),] = rep(0, (16-kj))
    }
    level_2_b_5[61:(2*no_prefecture),] = matrix(rep(0,(16-kj)*34), ncol=(16-kj))
    
    # R6
    
    level_2_b_6[1:60,] = matrix(rep(0,(16-kj)*60), ncol=(16-kj))
    for(iw in 1:5)
    {
        level_2_b_6[(2*(iw+29)+1),] = get(pop_ratio_P_F_to_R6_F[iw])[kj,age,1:(16-kj)]
        level_2_b_6[(2*(iw+29)+2),] = rep(0, (16-kj))
    }
    level_2_b_6[71:(2*no_prefecture),] = matrix(rep(0,(16-kj)*24), ncol=(16-kj))
    
    # R7
    
    level_2_b_7[1:70,] = matrix(rep(0,(16-kj)*70), ncol=(16-kj))
    for(iw in 1:4)
    {
        level_2_b_7[(2*(iw+34)+1),] = get(pop_ratio_P_F_to_R7_F[iw])[kj,age,1:(16-kj)]
        level_2_b_7[(2*(iw+34)+2),] = rep(0, (16-kj))
    }
    level_2_b_7[79:(2*no_prefecture),] = matrix(rep(0,(16-kj)*16), ncol=(16-kj))
    
    # R8
    
    level_2_b_8[1:78,] = matrix(rep(0,(16-kj)*78), ncol=(16-kj))
    for(iw in 1:8)
    {
        level_2_b_8[(2*(iw+38)+1),] = get(pop_ratio_P_F_to_R8_F[iw])[kj,age,1:(16-kj)]
        level_2_b_8[(2*(iw+38)+2),] = rep(0, (16-kj))
    }
    
    level_2_c_1 = level_2_c_2 = level_2_c_3 = level_2_c_4 = level_2_c_5 = level_2_c_6 =
    level_2_c_7 = level_2_c_8 = matrix(NA, (2 * no_prefecture), (16 - kj))
    
    ################################################
    # Level 2 (disaggregate by region + sex (male))
    ################################################
    
    # R1
    
    level_2_c_1[1,] = rep(0,(16-kj))
    level_2_c_1[2,] = get(pop_ratio_P_M_to_R1_M[1])[kj,age,1:(16-kj)]
    level_2_c_1[3:(2*no_prefecture),] = matrix(rep(0,(16-kj)*92), ncol=(16-kj))
    
    # R2
    
    level_2_c_2[1:2, ] = matrix(rep(0,(16-kj)*2), ncol=(16-kj))
    for(iw in 1:6)
    {
        level_2_c_2[(2*iw+1),] = rep(0,(16-kj))
        level_2_c_2[(2*iw+2),] = get(pop_ratio_P_M_to_R2_M[iw])[kj,age,1:(16-kj)]
    }
    level_2_c_2[15:(2*no_prefecture),] = matrix(rep(0,(16-kj)*80), ncol=(16-kj))
    
    # R3
    
    level_2_c_3[1:14,] = matrix(rep(0,(16-kj)*14), ncol=(16-kj))
    for(iw in 1:7)
    {
        level_2_c_3[(2*(iw+6)+1),] = rep(0,(16-kj))
        level_2_c_3[(2*(iw+6)+2),] = get(pop_ratio_P_M_to_R3_M[iw])[kj,age,1:(16-kj)]
    }
    level_2_c_3[29:(2*no_prefecture),] = matrix(rep(0,(16-kj)*66), ncol=(16-kj))
    
    # R4
    
    level_2_c_4[1:28,] = matrix(rep(0,(16-kj)*28), ncol=(16-kj))
    for(iw in 1:9)
    {
        level_2_c_4[(2*(iw+13)+1),] = rep(0,(16-kj))
        level_2_c_4[(2*(iw+13)+2),] = get(pop_ratio_P_M_to_R4_M[iw])[kj,age,1:(16-kj)]
    }
    level_2_c_4[47:(2*no_prefecture),] = matrix(rep(0,(16-kj)*48), ncol=(16-kj))
    
    # R5
    
    level_2_c_5[1:46,] = matrix(rep(0,(16-kj)*46), ncol=(16-kj))
    for(iw in 1:7)
    {
        level_2_c_5[(2*(iw+22)+1),] = rep(0,(16-kj))
        level_2_c_5[(2*(iw+22)+2),] = get(pop_ratio_P_M_to_R5_M[iw])[kj,age,1:(16-kj)]
    }
    level_2_c_5[61:(2*no_prefecture),] = matrix(rep(0,(16-kj)*34), ncol=(16-kj))
    
    # R6
    
    level_2_c_6[1:60,] = matrix(rep(0,(16-kj)*60), ncol=(16-kj))
    for(iw in 1:5)
    {
        level_2_c_6[(2*(iw+29)+1),] = rep(0,(16-kj))
        level_2_c_6[(2*(iw+29)+2),] = get(pop_ratio_P_M_to_R6_M[iw])[kj,age,1:(16-kj)]
    }
    level_2_c_6[71:(2*no_prefecture),] = matrix(rep(0,(16-kj)*24), ncol=(16-kj))
    
    # R7
    
    level_2_c_7[1:70,] = matrix(rep(0,(16-kj)*70), ncol=(16-kj))
    for(iw in 1:4)
    {
        level_2_c_7[(2*(iw+34)+1),] = rep(0,(16-kj))
        level_2_c_7[(2*(iw+34)+2),] = get(pop_ratio_P_M_to_R7_M[iw])[kj,age,1:(16-kj)]
    }
    level_2_c_7[79:(2*no_prefecture),] = matrix(rep(0,(16-kj)*16), ncol=(16-kj))
    
    # R8
    
    level_2_c_8[1:78,] = matrix(rep(0,(16-kj)*78), ncol=(16-kj))
    for(iw in 1:8)
    {
        level_2_c_8[(2*(iw+38)+1),] = rep(0,(16-kj))
        level_2_c_8[(2*(iw+38)+2),] = get(pop_ratio_P_M_to_R8_M[iw])[kj,age,1:(16-kj)]
    }
    
    ###################################################
    # Level 3 (disaggregate by prefecture + sex (male))
    ###################################################
    
    level_3 = array(0, dim = c((2*no_prefecture), (16-kj), 47))
    for(iw in 1:47)
    {
        level_3[2*iw-1,,iw] = get(pop_ratio_P_F_to_P_T[iw])[kj,age,1:(16-kj)]
        level_3[2*iw,,iw]   = get(pop_ratio_P_M_to_P_T[iw])[kj,age,1:(16-kj)]
    }
    
    S_mat = array(, dim = c(168, (2*no_prefecture), (16-kj)))
    for(ik in 1:(16-kj))
    {
        S_mat[,,ik] = rbind(level_0[,ik], level_1_a[,ik], level_1_b[,ik], level_2_a_1[,ik],
                          level_2_a_2[,ik], level_2_a_3[,ik], level_2_a_4[,ik], level_2_a_5[,ik],
                          level_2_a_6[,ik], level_2_a_7[,ik], level_2_a_8[,ik], level_2_b_1[,ik],
                          level_2_b_2[,ik], level_2_b_3[,ik], level_2_b_4[,ik], level_2_b_5[,ik],
                          level_2_b_6[,ik], level_2_b_7[,ik], level_2_b_8[,ik], level_2_c_1[,ik],
                          level_2_c_2[,ik], level_2_c_3[,ik], level_2_c_4[,ik], level_2_c_5[,ik],
                          level_2_c_6[,ik], level_2_c_7[,ik], level_2_c_8[,ik], t(level_3[,ik,]),
                          diag(94))
    }
    return(S_mat)
}

#######################################
# Exposure-to-risk at the bottom level
#######################################

pop_fore_fun <- function(top, bottom, year_horizon)
{
    Japan_pop_fore = array(NA, dim = c(year_horizon, 41, year_horizon))
    end_year = ncol(top)
    first_year = end_year - (year_horizon - 1)
    for(year in first_year:end_year)
    {
        Japan_pop_fore[1, 2:41, (year - (first_year - 1))] = top[2:41, year]/bottom[2:41, year]
        
        # need forecast birth
        ratio = top[1, 1:year]/bottom[1, 1:year]
        
        # forecast birth
        Japan_pop_fore[, 1, (year - (first_year - 1))] = forecast(auto.arima(ratio), h = year_horizon)$mean
        
        for(ij in 2:year_horizon)
        {
            # x in year t is x+1 in year t+1
            Japan_pop_fore[ij, 2:41, (year - (first_year - 1))] = Japan_pop_fore[ij-1, 1:40, (year - (first_year - 1))]
        }
    }
    return(Japan_pop_fore)
}

# Row 1


pop_ratio_P_F_to_T = c("pop_ratio_P1_F_to_T",  "pop_ratio_P2_F_to_T",  "pop_ratio_P3_F_to_T",
                       "pop_ratio_P4_F_to_T",  "pop_ratio_P5_F_to_T",  "pop_ratio_P6_F_to_T",
                       "pop_ratio_P7_F_to_T",  "pop_ratio_P8_F_to_T",  "pop_ratio_P9_F_to_T",
                       "pop_ratio_P10_F_to_T", "pop_ratio_P11_F_to_T", "pop_ratio_P12_F_to_T",
                       "pop_ratio_P13_F_to_T", "pop_ratio_P14_F_to_T", "pop_ratio_P15_F_to_T",
                       "pop_ratio_P16_F_to_T", "pop_ratio_P17_F_to_T", "pop_ratio_P18_F_to_T",
                       "pop_ratio_P19_F_to_T", "pop_ratio_P20_F_to_T", "pop_ratio_P21_F_to_T",
                       "pop_ratio_P22_F_to_T", "pop_ratio_P23_F_to_T", "pop_ratio_P24_F_to_T",
                       "pop_ratio_P25_F_to_T", "pop_ratio_P26_F_to_T", "pop_ratio_P27_F_to_T",
                       "pop_ratio_P28_F_to_T", "pop_ratio_P29_F_to_T", "pop_ratio_P30_F_to_T",
                       "pop_ratio_P31_F_to_T", "pop_ratio_P32_F_to_T", "pop_ratio_P33_F_to_T",
                       "pop_ratio_P34_F_to_T", "pop_ratio_P35_F_to_T", "pop_ratio_P36_F_to_T",
                       "pop_ratio_P37_F_to_T", "pop_ratio_P38_F_to_T", "pop_ratio_P39_F_to_T",
                       "pop_ratio_P40_F_to_T", "pop_ratio_P41_F_to_T", "pop_ratio_P42_F_to_T",
                       "pop_ratio_P43_F_to_T", "pop_ratio_P44_F_to_T", "pop_ratio_P45_F_to_T",
                       "pop_ratio_P46_F_to_T", "pop_ratio_P47_F_to_T")

pop_ratio_P_M_to_T = c("pop_ratio_P1_M_to_T",  "pop_ratio_P2_M_to_T",  "pop_ratio_P3_M_to_T",
                       "pop_ratio_P4_M_to_T",  "pop_ratio_P5_M_to_T",  "pop_ratio_P6_M_to_T",
                       "pop_ratio_P7_M_to_T",  "pop_ratio_P8_M_to_T",  "pop_ratio_P9_M_to_T",
                       "pop_ratio_P10_M_to_T", "pop_ratio_P11_M_to_T", "pop_ratio_P12_M_to_T",
                       "pop_ratio_P13_M_to_T", "pop_ratio_P14_M_to_T", "pop_ratio_P15_M_to_T",
                       "pop_ratio_P16_M_to_T", "pop_ratio_P17_M_to_T", "pop_ratio_P18_M_to_T",
                       "pop_ratio_P19_M_to_T", "pop_ratio_P20_M_to_T", "pop_ratio_P21_M_to_T",
                       "pop_ratio_P22_M_to_T", "pop_ratio_P23_M_to_T", "pop_ratio_P24_M_to_T",
                       "pop_ratio_P25_M_to_T", "pop_ratio_P26_M_to_T", "pop_ratio_P27_M_to_T",
                       "pop_ratio_P28_M_to_T", "pop_ratio_P29_M_to_T", "pop_ratio_P30_M_to_T",
                       "pop_ratio_P31_M_to_T", "pop_ratio_P32_M_to_T", "pop_ratio_P33_M_to_T",
                       "pop_ratio_P34_M_to_T", "pop_ratio_P35_M_to_T", "pop_ratio_P36_M_to_T",
                       "pop_ratio_P37_M_to_T", "pop_ratio_P38_M_to_T", "pop_ratio_P39_M_to_T",
                       "pop_ratio_P40_M_to_T", "pop_ratio_P41_M_to_T", "pop_ratio_P42_M_to_T",
                       "pop_ratio_P43_M_to_T", "pop_ratio_P44_M_to_T", "pop_ratio_P45_M_to_T",
                       "pop_ratio_P46_M_to_T", "pop_ratio_P47_M_to_T")

for(iw in 2:48)
{
    assign(pop_ratio_P_F_to_T[iw-1], pop_fore_fun(top = get(state[iw])$pop$female, bottom = Japan$pop$total, year_horizon = 15))
    assign(pop_ratio_P_M_to_T[iw-1], pop_fore_fun(top = get(state[iw])$pop$male,   bottom = Japan$pop$total, year_horizon = 15))
    print(iw)
}

# Row 2

pop_ratio_P_F_to_F = c("pop_ratio_P1_F_to_F",  "pop_ratio_P2_F_to_F",  "pop_ratio_P3_F_to_F",
                       "pop_ratio_P4_F_to_F",  "pop_ratio_P5_F_to_F",  "pop_ratio_P6_F_to_F",
                       "pop_ratio_P7_F_to_F",  "pop_ratio_P8_F_to_F",  "pop_ratio_P9_F_to_F",
                       "pop_ratio_P10_F_to_F", "pop_ratio_P11_F_to_F", "pop_ratio_P12_F_to_F",
                       "pop_ratio_P13_F_to_F", "pop_ratio_P14_F_to_F", "pop_ratio_P15_F_to_F",
                       "pop_ratio_P16_F_to_F", "pop_ratio_P17_F_to_F", "pop_ratio_P18_F_to_F",
                       "pop_ratio_P19_F_to_F", "pop_ratio_P20_F_to_F", "pop_ratio_P21_F_to_F",
                       "pop_ratio_P22_F_to_F", "pop_ratio_P23_F_to_F", "pop_ratio_P24_F_to_F",
                       "pop_ratio_P25_F_to_F", "pop_ratio_P26_F_to_F", "pop_ratio_P27_F_to_F",
                       "pop_ratio_P28_F_to_F", "pop_ratio_P29_F_to_F", "pop_ratio_P30_F_to_F",
                       "pop_ratio_P31_F_to_F", "pop_ratio_P32_F_to_F", "pop_ratio_P33_F_to_F",
                       "pop_ratio_P34_F_to_F", "pop_ratio_P35_F_to_F", "pop_ratio_P36_F_to_F",
                       "pop_ratio_P37_F_to_F", "pop_ratio_P38_F_to_F", "pop_ratio_P39_F_to_F",
                       "pop_ratio_P40_F_to_F", "pop_ratio_P41_F_to_F", "pop_ratio_P42_F_to_F",
                       "pop_ratio_P43_F_to_F", "pop_ratio_P44_F_to_F", "pop_ratio_P45_F_to_F",
                       "pop_ratio_P46_F_to_F", "pop_ratio_P47_F_to_F")

# Row 3

pop_ratio_P_M_to_M = c("pop_ratio_P1_M_to_M",  "pop_ratio_P2_M_to_M",  "pop_ratio_P3_M_to_M",
                       "pop_ratio_P4_M_to_M",  "pop_ratio_P5_M_to_M",  "pop_ratio_P6_M_to_M",
                       "pop_ratio_P7_M_to_M",  "pop_ratio_P8_M_to_M",  "pop_ratio_P9_M_to_M",
                       "pop_ratio_P10_M_to_M", "pop_ratio_P11_M_to_M", "pop_ratio_P12_M_to_M",
                       "pop_ratio_P13_M_to_M", "pop_ratio_P14_M_to_M", "pop_ratio_P15_M_to_M",
                       "pop_ratio_P16_M_to_M", "pop_ratio_P17_M_to_M", "pop_ratio_P18_M_to_M",
                       "pop_ratio_P19_M_to_M", "pop_ratio_P20_M_to_M", "pop_ratio_P21_M_to_M",
                       "pop_ratio_P22_M_to_M", "pop_ratio_P23_M_to_M", "pop_ratio_P24_M_to_M",
                       "pop_ratio_P25_M_to_M", "pop_ratio_P26_M_to_M", "pop_ratio_P27_M_to_M",
                       "pop_ratio_P28_M_to_M", "pop_ratio_P29_M_to_M", "pop_ratio_P30_M_to_M",
                       "pop_ratio_P31_M_to_M", "pop_ratio_P32_M_to_M", "pop_ratio_P33_M_to_M",
                       "pop_ratio_P34_M_to_M", "pop_ratio_P35_M_to_M", "pop_ratio_P36_M_to_M",
                       "pop_ratio_P37_M_to_M", "pop_ratio_P38_M_to_M", "pop_ratio_P39_M_to_M",
                       "pop_ratio_P40_M_to_M", "pop_ratio_P41_M_to_M", "pop_ratio_P42_M_to_M",
                       "pop_ratio_P43_M_to_M", "pop_ratio_P44_M_to_M", "pop_ratio_P45_M_to_M",
                       "pop_ratio_P46_M_to_M", "pop_ratio_P47_M_to_M")

for(iw in 2:48)
{
    assign(pop_ratio_P_F_to_F[iw-1], pop_fore_fun(top = get(state[iw])$pop$female, bottom = Japan$pop$female, year_horizon = 15))
    assign(pop_ratio_P_M_to_M[iw-1], pop_fore_fun(top = get(state[iw])$pop$male,   bottom = Japan$pop$male, year_horizon = 15))
    print(iw)
}

# Row 4

pop_ratio_P_F_to_R1_T = "pop_ratio_P1_F_to_R1_T"
pop_ratio_P_F_to_R2_T = c("pop_ratio_P2_F_to_R2_T", "pop_ratio_P3_F_to_R2_T", "pop_ratio_P4_F_to_R2_T",
                          "pop_ratio_P5_F_to_R2_T", "pop_ratio_P6_F_to_R2_T", "pop_ratio_P7_F_to_R2_T")
pop_ratio_P_F_to_R3_T = c("pop_ratio_P8_F_to_R3_T",  "pop_ratio_P9_F_to_R3_T",  "pop_ratio_P10_F_to_R3_T",
                          "pop_ratio_P11_F_to_R3_T", "pop_ratio_P12_F_to_R3_T", "pop_ratio_P13_F_to_R3_T",
                          "pop_ratio_P14_F_to_R3_T")
pop_ratio_P_F_to_R4_T = c("pop_ratio_P15_F_to_R4_T", "pop_ratio_P16_F_to_R4_T", "pop_ratio_P17_F_to_R4_T",
                          "pop_ratio_P18_F_to_R4_T", "pop_ratio_P19_F_to_R4_T", "pop_ratio_P20_F_to_R4_T",
                          "pop_ratio_P21_F_to_R4_T", "pop_ratio_P22_F_to_R4_T", "pop_ratio_P23_F_to_R4_T")
pop_ratio_P_F_to_R5_T = c("pop_ratio_P24_F_to_R5_T", "pop_ratio_P25_F_to_R5_T", "pop_ratio_P26_F_to_R5_T",
                          "pop_ratio_P27_F_to_R5_T", "pop_ratio_P28_F_to_R5_T", "pop_ratio_P29_F_to_R5_T",
                          "pop_ratio_P30_F_to_R5_T")
pop_ratio_P_F_to_R6_T = c("pop_ratio_P31_F_to_R6_T", "pop_ratio_P32_F_to_R6_T", "pop_ratio_P33_F_to_R6_T",
                          "pop_ratio_P34_F_to_R6_T", "pop_ratio_P35_F_to_R6_T")
pop_ratio_P_F_to_R7_T = c("pop_ratio_P36_F_to_R7_T", "pop_ratio_P37_F_to_R7_T", "pop_ratio_P38_F_to_R7_T",
                          "pop_ratio_P39_F_to_R7_T")
pop_ratio_P_F_to_R8_T = c("pop_ratio_P40_F_to_R8_T", "pop_ratio_P41_F_to_R8_T", "pop_ratio_P42_F_to_R8_T",
                          "pop_ratio_P43_F_to_R8_T", "pop_ratio_P44_F_to_R8_T", "pop_ratio_P45_F_to_R8_T",
                          "pop_ratio_P46_F_to_R8_T", "pop_ratio_P47_F_to_R8_T")

assign(pop_ratio_P_F_to_R1_T, pop_fore_fun(top = get(state[2])$pop$female, bottom = ind_R1$pop$total, year_horizon = 15))
for(iw in 2:7)
{
    assign(pop_ratio_P_F_to_R2_T[iw-1], pop_fore_fun(top = get(state[(iw+1)])$pop$female, bottom = ind_R2$pop$total, year_horizon = 15))
    print(iw)
}
for(iw in 8:14)
{
    assign(pop_ratio_P_F_to_R3_T[iw-7], pop_fore_fun(top = get(state[(iw+1)])$pop$female, bottom = ind_R3$pop$total, year_horizon = 15))
    print(iw)
}
for(iw in 15:23)
{
    assign(pop_ratio_P_F_to_R4_T[iw-14], pop_fore_fun(top = get(state[(iw+1)])$pop$female, bottom = ind_R4$pop$total, year_horizon = 15))
    print(iw)
}
for(iw in 24:30)
{
    assign(pop_ratio_P_F_to_R5_T[iw-23], pop_fore_fun(top = get(state[(iw+1)])$pop$female, bottom = ind_R5$pop$total, year_horizon = 15))
    print(iw)
}
for(iw in 31:35)
{
    assign(pop_ratio_P_F_to_R6_T[iw-30], pop_fore_fun(top = get(state[(iw+1)])$pop$female, bottom = ind_R6$pop$total, year_horizon = 15))
    print(iw)
}
for(iw in 36:39)
{
    assign(pop_ratio_P_F_to_R7_T[iw-35], pop_fore_fun(top = get(state[(iw+1)])$pop$female, bottom = ind_R7$pop$total, year_horizon = 15))
    print(iw)
}
for(iw in 40:47)
{
    assign(pop_ratio_P_F_to_R8_T[iw-39], pop_fore_fun(top = get(state[(iw+1)])$pop$female, bottom = ind_R8$pop$total, year_horizon = 15))
    print(iw)
}


pop_ratio_P_M_to_R1_T = "pop_ratio_P1_M_to_R1_T"
pop_ratio_P_M_to_R2_T = c("pop_ratio_P2_M_to_R2_T", "pop_ratio_P3_M_to_R2_T", "pop_ratio_P4_M_to_R2_T",
                          "pop_ratio_P5_M_to_R2_T", "pop_ratio_P6_M_to_R2_T", "pop_ratio_P7_M_to_R2_T")
pop_ratio_P_M_to_R3_T = c("pop_ratio_P8_M_to_R3_T",  "pop_ratio_P9_M_to_R3_T",  "pop_ratio_P10_M_to_R3_T",
                          "pop_ratio_P11_M_to_R3_T", "pop_ratio_P12_M_to_R3_T", "pop_ratio_P13_M_to_R3_T",
                          "pop_ratio_P14_M_to_R3_T")
pop_ratio_P_M_to_R4_T = c("pop_ratio_P15_M_to_R4_T", "pop_ratio_P16_M_to_R4_T", "pop_ratio_P17_M_to_R4_T",
                          "pop_ratio_P18_M_to_R4_T", "pop_ratio_P19_M_to_R4_T", "pop_ratio_P20_M_to_R4_T",
                          "pop_ratio_P21_M_to_R4_T", "pop_ratio_P22_M_to_R4_T", "pop_ratio_P23_M_to_R4_T")
pop_ratio_P_M_to_R5_T = c("pop_ratio_P24_M_to_R5_T", "pop_ratio_P25_M_to_R5_T", "pop_ratio_P26_M_to_R5_T",
                          "pop_ratio_P27_M_to_R5_T", "pop_ratio_P28_M_to_R5_T", "pop_ratio_P29_M_to_R5_T",
                          "pop_ratio_P30_M_to_R5_T")
pop_ratio_P_M_to_R6_T = c("pop_ratio_P31_M_to_R6_T", "pop_ratio_P32_M_to_R6_T", "pop_ratio_P33_M_to_R6_T",
                          "pop_ratio_P34_M_to_R6_T", "pop_ratio_P35_M_to_R6_T")
pop_ratio_P_M_to_R7_T = c("pop_ratio_P36_M_to_R7_T", "pop_ratio_P37_M_to_R7_T", "pop_ratio_P38_M_to_R7_T",
                          "pop_ratio_P39_M_to_R7_T")
pop_ratio_P_M_to_R8_T = c("pop_ratio_P40_M_to_R8_T", "pop_ratio_P41_M_to_R8_T", "pop_ratio_P42_M_to_R8_T",
                          "pop_ratio_P43_M_to_R8_T", "pop_ratio_P44_M_to_R8_T", "pop_ratio_P45_M_to_R8_T",
                          "pop_ratio_P46_M_to_R8_T", "pop_ratio_P47_M_to_R8_T")

assign(pop_ratio_P_M_to_R1_T, pop_fore_fun(top = get(state[2])$pop$male, bottom = ind_R1$pop$total, year_horizon = 15))
for(iw in 2:7)
{
    assign(pop_ratio_P_M_to_R2_T[iw-1], pop_fore_fun(top = get(state[(iw+1)])$pop$male, bottom = ind_R2$pop$total, year_horizon = 15))
    print(iw)
}
for(iw in 8:14)
{
    assign(pop_ratio_P_M_to_R3_T[iw-7], pop_fore_fun(top = get(state[(iw+1)])$pop$male, bottom = ind_R3$pop$total, year_horizon = 15))
    print(iw)
}
for(iw in 15:23)
{
    assign(pop_ratio_P_M_to_R4_T[iw-14], pop_fore_fun(top = get(state[(iw+1)])$pop$male, bottom = ind_R4$pop$total, year_horizon = 15))
    print(iw)
}
for(iw in 24:30)
{
    assign(pop_ratio_P_M_to_R5_T[iw-23], pop_fore_fun(top = get(state[(iw+1)])$pop$male, bottom = ind_R5$pop$total, year_horizon = 15))
    print(iw)
}
for(iw in 31:35)
{
    assign(pop_ratio_P_M_to_R6_T[iw-30], pop_fore_fun(top = get(state[(iw+1)])$pop$male, bottom = ind_R6$pop$total, year_horizon = 15))
    print(iw)
}
for(iw in 36:39)
{
    assign(pop_ratio_P_M_to_R7_T[iw-35], pop_fore_fun(top = get(state[(iw+1)])$pop$male, bottom = ind_R7$pop$total, year_horizon = 15))
    print(iw)
}
for(iw in 40:47)
{
    assign(pop_ratio_P_M_to_R8_T[iw-39], pop_fore_fun(top = get(state[(iw+1)])$pop$male, bottom = ind_R8$pop$total, year_horizon = 15))
    print(iw)
}

# Row 5

pop_ratio_P_F_to_R1_F = "pop_ratio_P1_F_to_R1_F"
pop_ratio_P_F_to_R2_F = c("pop_ratio_P2_F_to_R2_F",  "pop_ratio_P3_F_to_R2_F",  "pop_ratio_P4_F_to_R2_F",
                          "pop_ratio_P5_F_to_R2_F",  "pop_ratio_P6_F_to_R2_F",  "pop_ratio_P7_F_to_R2_F")
pop_ratio_P_F_to_R3_F = c("pop_ratio_P8_F_to_R3_F",  "pop_ratio_P9_F_to_R3_F",  "pop_ratio_P10_F_to_R3_F",
                          "pop_ratio_P11_F_to_R3_F", "pop_ratio_P12_F_to_R3_F", "pop_ratio_P13_F_to_R3_F",
                          "pop_ratio_P14_F_to_R3_F")
pop_ratio_P_F_to_R4_F = c("pop_ratio_P15_F_to_R4_F", "pop_ratio_P16_F_to_R4_F", "pop_ratio_P17_F_to_R4_F",
                          "pop_ratio_P18_F_to_R4_F", "pop_ratio_P19_F_to_R4_F", "pop_ratio_P20_F_to_R4_F",
                          "pop_ratio_P21_F_to_R4_F", "pop_ratio_P22_F_to_R4_F", "pop_ratio_P23_F_to_R4_F")
pop_ratio_P_F_to_R5_F = c("pop_ratio_P24_F_to_R5_F", "pop_ratio_P25_F_to_R5_F", "pop_ratio_P26_F_to_R5_F",
                          "pop_ratio_P27_F_to_R5_F", "pop_ratio_P28_F_to_R5_F", "pop_ratio_P29_F_to_R5_F",
                          "pop_ratio_P30_F_to_R5_F")
pop_ratio_P_F_to_R6_F = c("pop_ratio_P31_F_to_R6_F", "pop_ratio_P32_F_to_R6_F", "pop_ratio_P33_F_to_R6_F",
                          "pop_ratio_P34_F_to_R6_F", "pop_ratio_P35_F_to_R6_F")
pop_ratio_P_F_to_R7_F = c("pop_ratio_P36_F_to_R7_F", "pop_ratio_P37_F_to_R7_F", "pop_ratio_P38_F_to_R7_F",
                          "pop_ratio_P39_F_to_R7_F")
pop_ratio_P_F_to_R8_F = c("pop_ratio_P40_F_to_R8_F", "pop_ratio_P41_F_to_R8_F", "pop_ratio_P42_F_to_R8_F",
                          "pop_ratio_P43_F_to_R8_F", "pop_ratio_P44_F_to_R8_F", "pop_ratio_P45_F_to_R8_F",
                          "pop_ratio_P46_F_to_R8_F", "pop_ratio_P47_F_to_R8_F")


assign(pop_ratio_P_F_to_R1_F, pop_fore_fun(top = get(state[2])$pop$female, bottom = ind_R1$pop$female, year_horizon = 15))
for(iw in 2:7)
{
    assign(pop_ratio_P_F_to_R2_F[iw-1], pop_fore_fun(top = get(state[(iw+1)])$pop$female, bottom = ind_R2$pop$female, year_horizon = 15))
    print(iw)
}
for(iw in 8:14)
{
    assign(pop_ratio_P_F_to_R3_F[iw-7], pop_fore_fun(top = get(state[(iw+1)])$pop$female, bottom = ind_R3$pop$female, year_horizon = 15))
    print(iw)
}
for(iw in 15:23)
{
    assign(pop_ratio_P_F_to_R4_F[iw-14], pop_fore_fun(top = get(state[(iw+1)])$pop$female, bottom = ind_R4$pop$female, year_horizon = 15))
    print(iw)
}
for(iw in 24:30)
{
    assign(pop_ratio_P_F_to_R5_F[iw-23], pop_fore_fun(top = get(state[(iw+1)])$pop$female, bottom = ind_R5$pop$female, year_horizon = 15))
    print(iw)
}
for(iw in 31:35)
{
    assign(pop_ratio_P_F_to_R6_F[iw-30], pop_fore_fun(top = get(state[(iw+1)])$pop$female, bottom = ind_R6$pop$female, year_horizon = 15))
    print(iw)
}
for(iw in 36:39)
{
    assign(pop_ratio_P_F_to_R7_F[iw-35], pop_fore_fun(top = get(state[(iw+1)])$pop$female, bottom = ind_R7$pop$female, year_horizon = 15))
    print(iw)
}
for(iw in 40:47)
{
    assign(pop_ratio_P_F_to_R8_F[iw-39], pop_fore_fun(top = get(state[(iw+1)])$pop$female, bottom = ind_R8$pop$female, year_horizon = 15))
    print(iw)
}

# Row 6

pop_ratio_P_M_to_R1_M = "pop_ratio_P1_M_to_R1_M"
pop_ratio_P_M_to_R2_M = c("pop_ratio_P2_M_to_R2_M",  "pop_ratio_P3_M_to_R2_M",  "pop_ratio_P4_M_to_R2_M",
                          "pop_ratio_P5_M_to_R2_M",  "pop_ratio_P6_M_to_R2_M",  "pop_ratio_P7_M_to_R2_M")
pop_ratio_P_M_to_R3_M = c("pop_ratio_P8_M_to_R3_M",  "pop_ratio_P9_M_to_R3_M",  "pop_ratio_P10_M_to_R3_M",
                          "pop_ratio_P11_M_to_R3_M", "pop_ratio_P12_M_to_R3_M", "pop_ratio_P13_M_to_R3_M",
                          "pop_ratio_P14_M_to_R3_M")
pop_ratio_P_M_to_R4_M = c("pop_ratio_P15_M_to_R4_M", "pop_ratio_P16_M_to_R4_M", "pop_ratio_P17_M_to_R4_M",
                          "pop_ratio_P18_M_to_R4_M", "pop_ratio_P19_M_to_R4_M", "pop_ratio_P20_M_to_R4_M",
                          "pop_ratio_P21_M_to_R4_M", "pop_ratio_P22_M_to_R4_M", "pop_ratio_P23_M_to_R4_M")
pop_ratio_P_M_to_R5_M = c("pop_ratio_P24_M_to_R5_M", "pop_ratio_P25_M_to_R5_M", "pop_ratio_P26_M_to_R5_M",
                          "pop_ratio_P27_M_to_R5_M", "pop_ratio_P28_M_to_R5_M", "pop_ratio_P29_M_to_R5_M",
                          "pop_ratio_P30_M_to_R5_M")
pop_ratio_P_M_to_R6_M = c("pop_ratio_P31_M_to_R6_M", "pop_ratio_P32_M_to_R6_M", "pop_ratio_P33_M_to_R6_M",
                          "pop_ratio_P34_M_to_R6_M", "pop_ratio_P35_M_to_R6_M")
pop_ratio_P_M_to_R7_M = c("pop_ratio_P36_M_to_R7_M", "pop_ratio_P37_M_to_R7_M", "pop_ratio_P38_M_to_R7_M",
                          "pop_ratio_P39_M_to_R7_M")
pop_ratio_P_M_to_R8_M = c("pop_ratio_P40_M_to_R8_M", "pop_ratio_P41_M_to_R8_M", "pop_ratio_P42_M_to_R8_M",
                          "pop_ratio_P43_M_to_R8_M", "pop_ratio_P44_M_to_R8_M", "pop_ratio_P45_M_to_R8_M",
                          "pop_ratio_P46_M_to_R8_M", "pop_ratio_P47_M_to_R8_M")

assign(pop_ratio_P_M_to_R1_M, pop_fore_fun(top = get(state[2])$pop$male, bottom = ind_R1$pop$male, year_horizon = 15))
for(iw in 2:7)
{
    assign(pop_ratio_P_M_to_R2_M[iw-1], pop_fore_fun(top = get(state[(iw+1)])$pop$male, bottom = ind_R2$pop$male, year_horizon = 15))
    print(iw)
}
for(iw in 8:14)
{
    assign(pop_ratio_P_M_to_R3_M[iw-7], pop_fore_fun(top = get(state[(iw+1)])$pop$male, bottom = ind_R3$pop$male, year_horizon = 15))
    print(iw)
}
for(iw in 15:23)
{
    assign(pop_ratio_P_M_to_R4_M[iw-14], pop_fore_fun(top = get(state[(iw+1)])$pop$male, bottom = ind_R4$pop$male, year_horizon = 15))
    print(iw)
}
for(iw in 24:30)
{
    assign(pop_ratio_P_M_to_R5_M[iw-23], pop_fore_fun(top = get(state[(iw+1)])$pop$male, bottom = ind_R5$pop$male, year_horizon = 15))
    print(iw)
}
for(iw in 31:35)
{
    assign(pop_ratio_P_M_to_R6_M[iw-30], pop_fore_fun(top = get(state[(iw+1)])$pop$male, bottom = ind_R6$pop$male, year_horizon = 15))
    print(iw)
}
for(iw in 36:39)
{
    assign(pop_ratio_P_M_to_R7_M[iw-35], pop_fore_fun(top = get(state[(iw+1)])$pop$male, bottom = ind_R7$pop$male, year_horizon = 15))
    print(iw)
}
for(iw in 40:47)
{
    assign(pop_ratio_P_M_to_R8_M[iw-39], pop_fore_fun(top = get(state[(iw+1)])$pop$male, bottom = ind_R8$pop$male, year_horizon = 15))
    print(iw)
}

# Row 7

pop_ratio_P_F_to_P_T = c("pop_ratio_P1_F_to_P1_T",   "pop_ratio_P2_F_to_P2_T",   "pop_ratio_P3_F_to_P3_T",
                         "pop_ratio_P4_F_to_P4_T",   "pop_ratio_P5_F_to_P5_T",   "pop_ratio_P6_F_to_P6_T",
                         "pop_ratio_P7_F_to_P7_T",   "pop_ratio_P8_F_to_P8_T",   "pop_ratio_P9_F_to_P9_T",
                         "pop_ratio_P10_F_to_P10_T", "pop_ratio_P11_F_to_P11_T", "pop_ratio_P12_F_to_P12_T",
                         "pop_ratio_P13_F_to_P13_T", "pop_ratio_P14_F_to_P14_T", "pop_ratio_P15_F_to_P15_T",
                         "pop_ratio_P16_F_to_P16_T", "pop_ratio_P17_F_to_P17_T",
                         "pop_ratio_P18_F_to_P18_T", "pop_ratio_P19_F_to_P19_T", "pop_ratio_P20_F_to_P20_T",
                         "pop_ratio_P21_F_to_P21_T", "pop_ratio_P22_F_to_P22_T", "pop_ratio_P23_F_to_P23_T",
                         "pop_ratio_P24_F_to_P24_T", "pop_ratio_P25_F_to_P25_T", "pop_ratio_P26_F_to_P26_T",
                         "pop_ratio_P27_F_to_P27_T", "pop_ratio_P28_F_to_P28_T", "pop_ratio_P29_F_to_P29_T",
                         "pop_ratio_P30_F_to_P30_T", "pop_ratio_P31_F_to_P31_T", "pop_ratio_P32_F_to_P32_T",
                         "pop_ratio_P33_F_to_P33_T", "pop_ratio_P34_F_to_P34_T", "pop_ratio_P35_F_to_P35_T",
                         "pop_ratio_P36_F_to_P36_T", "pop_ratio_P37_F_to_P37_T", "pop_ratio_P38_F_to_P38_T",
                         "pop_ratio_P39_F_to_P39_T", "pop_ratio_P40_F_to_P40_T", "pop_ratio_P41_F_to_P41_T",
                         "pop_ratio_P42_F_to_P42_T", "pop_ratio_P43_F_to_P43_T", "pop_ratio_P44_F_to_P44_T",
                         "pop_ratio_P45_F_to_P45_T", "pop_ratio_P46_F_to_P46_T", "pop_ratio_P47_F_to_P47_T")

pop_ratio_P_M_to_P_T = c("pop_ratio_P1_M_to_P1_T",   "pop_ratio_P2_M_to_P2_T",   "pop_ratio_P3_M_to_P3_T",
                         "pop_ratio_P4_M_to_P4_T",   "pop_ratio_P5_M_to_P5_T",   "pop_ratio_P6_M_to_P6_T",
                         "pop_ratio_P7_M_to_P7_T",   "pop_ratio_P8_M_to_P8_T",   "pop_ratio_P9_M_to_P9_T",
                         "pop_ratio_P10_M_to_P10_T", "pop_ratio_P11_M_to_P11_T", "pop_ratio_P12_M_to_P12_T",
                         "pop_ratio_P13_M_to_P13_T", "pop_ratio_P14_M_to_P14_T",
                         "pop_ratio_P15_M_to_P15_T", "pop_ratio_P16_M_to_P16_T", "pop_ratio_P17_M_to_P17_T",
                         "pop_ratio_P18_M_to_P18_T", "pop_ratio_P19_M_to_P19_T", "pop_ratio_P20_M_to_P20_T",
                         "pop_ratio_P21_M_to_P21_T", "pop_ratio_P22_M_to_P22_T", "pop_ratio_P23_M_to_P23_T",
                         "pop_ratio_P24_M_to_P24_T", "pop_ratio_P25_M_to_P25_T", "pop_ratio_P26_M_to_P26_T",
                         "pop_ratio_P27_M_to_P27_T", "pop_ratio_P28_M_to_P28_T", "pop_ratio_P29_M_to_P29_T",
                         "pop_ratio_P30_M_to_P30_T", "pop_ratio_P31_M_to_P31_T", "pop_ratio_P32_M_to_P32_T",
                         "pop_ratio_P33_M_to_P33_T", "pop_ratio_P34_M_to_P34_T", "pop_ratio_P35_M_to_P35_T",
                         "pop_ratio_P36_M_to_P36_T", "pop_ratio_P37_M_to_P37_T", "pop_ratio_P38_M_to_P38_T",
                         "pop_ratio_P39_M_to_P39_T", "pop_ratio_P40_M_to_P40_T", "pop_ratio_P41_M_to_P41_T",
                         "pop_ratio_P42_M_to_P42_T", "pop_ratio_P43_M_to_P43_T", "pop_ratio_P44_M_to_P44_T",
                         "pop_ratio_P45_M_to_P45_T", "pop_ratio_P46_M_to_P46_T", "pop_ratio_P47_M_to_P47_T")

for(iw in 2:48)
{
    assign(pop_ratio_P_F_to_P_T[iw-1], pop_fore_fun(top = get(state[iw])$pop$female, bottom = get(state[iw])$pop$total, year_horizon = 15))
    assign(pop_ratio_P_M_to_P_T[iw-1], pop_fore_fun(top = get(state[iw])$pop$male,   bottom = get(state[iw])$pop$total, year_horizon = 15))
    print(iw)
}

############################################################################
# Compute R square for univariate functional time series forecasting method
############################################################################

fun_R_square <- function(iw, sex, var_prop, character = c("raw", "smooth"))
{
    character = match.arg(character)
    
    # select the number of components based on 99% explained variation
  
      fdm_order = head(which(cumsum(fdm(get(state_smooth[iw]), series = sex, order = 10)$varprop)>=var_prop), 1)
      Japan_smooth_fit = fdm(get(state_smooth[iw]), series = sex, order = fdm_order)

      if(sex == "male")
      {
        if(character == "smooth")
        {
            male_rate_or = get(state_smooth[iw])$rate$male
        }
        if(character == "raw")
        {
            male_rate_or = get(state[iw])$rate$male
        }
            if(length(which(male_rate_or > 1)) != 0)
            {
                  index = which(male_rate_or > 1)
                  male_rate = replace(male_rate_or, index, 1)
            }
            else
            {
                  male_rate = male_rate_or
            }
            
            top = (male_rate - exp(Japan_smooth_fit$fitted$y))^2
            bottom = (male_rate - rowMeans(male_rate, na.rm = TRUE))^2
      }
      if(sex == "female")
      {
        if(character == "smooth")
        {
            female_rate_or = get(state_smooth[iw])$rate$female
        }
        if(character == "raw")
        {
            female_rate_or = get(state[iw])$rate$female
        }
            if(length(which(female_rate_or > 1)) != 0)
            {
                  index = which(female_rate_or > 1)
                  female_rate = replace(female_rate_or, index, 1)
            }
            else
            {
                  female_rate = female_rate_or
            }
            
            top = (female_rate - exp(Japan_smooth_fit$fitted$y))^2
            bottom = (female_rate - rowMeans(female_rate, na.rm = TRUE))^2
      }
      if(sex == "total")
      {
            if(character == "total")
        {
            total_rate_or = get(state_smooth[iw])$rate$total
        }
        if(character == "raw")
        {
            total_rate_or = get(state[iw])$rate$total
        }
            if(length(which(total_rate_or > 1)) != 0)
            {
                  index = which(total_rate_or > 1)
                  total_rate = replace(total_rate_or, index, 1)
            }
            else
            {
                  total_rate = total_rate_or
            }
        
            top = (total_rate - exp(Japan_smooth_fit$fitted$y))^2
            bottom = (total_rate - rowMeans(total_rate, na.rm = TRUE))^2
    }
      index_top = which(!is.finite(top))
      index_bottom = which(!is.finite(bottom))
      index_all = union(index_top, index_bottom)
    
      if(length(index_all) == 0)
      {
            top_new = top
            bottom_new = bottom
      }
      else
      {
            top_new = top[-index_all]
            bottom_new = bottom[-index_all]
      }
      ratio = 1 - sum(top_new)/sum(bottom_new)
      rm(top); rm(bottom); rm(top_new); rm(bottom_new); rm(index_top); rm(index_all);
      rm(index_bottom)
      return(round(ratio, 4))
}
    
#####################################################
# Compute R square values for male, female and total
#####################################################

R_square_male_raw = R_square_female_raw = vector("numeric", 48)
for(ik in 1:48)
{
    R_square_male_raw[ik] = fun_R_square(iw = ik, sex = "male", var_prop = 0.9, character = "raw")
    R_square_female_raw[ik] = fun_R_square(iw = ik, sex = "female", var_prop = 0.9, character = "raw")
    print(ik); rm(ik)
}

R_square_male_smooth = R_square_female_smooth = vector("numeric", 48)
for(ik in 1:48)
{
    R_square_male_smooth[ik] = fun_R_square(iw = ik, sex = "male", var_prop = 0.9, character = "smooth")
    R_square_female_smooth[ik] = fun_R_square(iw = ik, sex = "female", var_prop = 0.9, character = "smooth")
    print(ik); rm(ik)
}

##################
# Combine results
##################

# raw

R_square_all_raw = cbind(R_square_female_raw, R_square_male_raw)
rownames(R_square_all_raw) = state
colnames(R_square_all_raw) = c("Female", "Male")

# smooth

R_square_all_smooth = cbind(R_square_female_smooth, R_square_male_smooth)
rownames(R_square_all_smooth) = state
colnames(R_square_all_smooth) = c("Female", "Male")

R_square_univariate_FTS = cbind(R_square_all_raw, R_square_all_smooth)

##############################################################################
# Compute R square for multivariate functional time series forecasting method
##############################################################################

fun_R_square_mfts <- function(iw, sex, var_prop)
{
    # select the number of components based on 90% explained variation
    
    dat_smooth = mfts_decomp(dat = get(state_smooth[iw]), year_horizon = 20, fmethod = "arima",
                             variation_prop = var_prop)
    if(sex == "male")
    {
        # male_rate_or = get(state_smooth[iw])$rate$male
        male_rate_or = get(state[iw])$rate$male
        if(length(which(male_rate_or > 1)) != 0)
        {
            index = which(male_rate_or > 1)
            male_rate = replace(male_rate_or, index, 1)
        }
        else
        {
            male_rate = male_rate_or
        }
        
        top = (male_rate - exp(dat_smooth$fitted_res[42:82,]))^2
        bottom = (male_rate - rowMeans(male_rate, na.rm = TRUE))^2
    }
    if(sex == "female")
    {
        # female_rate_or = get(state_smooth[iw])$rate$female
        female_rate_or = get(state[iw])$rate$female
        if(length(which(female_rate_or > 1)) != 0)
        {
            index = which(female_rate_or > 1)
            female_rate = replace(female_rate_or, index, 1)
        }
        else
        {
            female_rate = female_rate_or
        }
        
        top = (female_rate - exp(dat_smooth$fitted_res[1:41,]))^2
        bottom = (female_rate - rowMeans(female_rate, na.rm = TRUE))^2
    }
    index_top = which(!is.finite(top))
    index_bottom = which(!is.finite(bottom))
    index_all = union(index_top, index_bottom)
    
    if(length(index_all) == 0)
    {
        top_new = top
        bottom_new = bottom
    }
    else
    {
        top_new = top[-index_all]
        bottom_new = bottom[-index_all]
    }
    ratio = 1 - sum(top_new)/sum(bottom_new)
    rm(top); rm(bottom); rm(top_new); rm(bottom_new); rm(index_top); rm(index_all);
    rm(index_bottom)
    return(round(ratio, 4))
}

R_square_male_mfts = R_square_female_mfts = vector("numeric", 48)
for(ik in 1:48)
{
    R_square_male_mfts[ik] = fun_R_square_mfts(iw = ik, sex = "male", var_prop = 0.9)
    R_square_female_mfts[ik] = fun_R_square_mfts(iw = ik, sex = "female", var_prop = 0.9)
    print(ik)
}

R_square_all_mfts = cbind(R_square_female_mfts, R_square_male_mfts)
rownames(R_square_all_mfts) = state
colnames(R_square_all_mfts) = c("Female", "Male")

require(xtable)
xtable(cbind(R_square_univariate_FTS[,1:2], R_square_all_mfts), digits = 3)


######################################
# Multivariate functional time series
######################################

mfts_decomp <- function(dat, year_horizon, fmethod, variation_prop)
{
    n = length(names(dat$rate))
    # if the data contains female, male and total, then we consider only female and male
    if(n == 3)
    {
        n_pop = 2
    }
    else
    {
        n_pop = n
    }
    log_object = rowmeans_object = sd_object = decenter_object = list()
    for(ik in 1:n_pop)
    {
        log_object[[ik]] = log(dat$rate[[ik]])
        # compute mean and standard deviation functions
        rowmeans_object[[ik]] = rowMeans(log(dat$rate[[ik]]), na.rm=TRUE)
        sd_object[[ik]] = apply(log(dat$rate[[ik]]), 1, sd, na.rm=TRUE)
        
        # de-center functional data
        decenter_object[[ik]] = t(scale(t(log(dat$rate[[ik]])), center = TRUE, scale = TRUE))
    }
    comb_object = do.call(rbind, decenter_object)
    variation_explain = ftsm(fts(1:nrow(comb_object), comb_object), order = 20)$varprop
    ncomp_comb = head(which(cumsum(ftsm(fts(1:nrow(comb_object), comb_object), order = 20)$varprop) >= variation_prop), 1)
    ftsm_obj = ftsm(fts(1:nrow(comb_object), comb_object), order = ncomp_comb, mean = FALSE)
    fore_ftsm = forecast(ftsm_obj, h = year_horizon, method = fmethod)
    fore_res = exp(fore_ftsm$mean$y * do.call(c,sd_object) + do.call(c, rowmeans_object))
    fitted_res = comb_object * do.call(c,sd_object) + do.call(c, rowmeans_object)
    return(list(rowmeans_object = do.call(c, rowmeans_object), ftsm_obj = ftsm_obj, fore_ftsm = fore_ftsm, fore_res = fore_res,
                fitted_res = fitted_res, ncomp_comb = ncomp_comb, variation_explain = variation_explain))
}

#############################
# install and load R package
#############################

install.packages(c("demography", "ftsa"))
require(demography)
require(ftsa)

mfts_decomp <- function(dat, year_horizon, fmethod, variation_prop)
{
    n = length(names(dat$rate))
    # if the data contains female, male and total, then we consider only female and male
    if(n == 3)
    {
        n_pop = 2
    }
    else
    {
        n_pop = n
    }
    log_object = rowmeans_object = sd_object = decenter_object = list()
    for(ik in 1:n_pop)
    {
        log_object[[ik]] = log(dat$rate[[ik]])
        # compute mean and standard deviation functions
        rowmeans_object[[ik]] = rowMeans(log(dat$rate[[ik]]), na.rm=TRUE)
        sd_object[[ik]] = apply(log(dat$rate[[ik]]), 1, sd, na.rm=TRUE)
        
        # de-center functional data
        decenter_object[[ik]] = t(scale(t(log(dat$rate[[ik]])), center = TRUE, scale = TRUE))
    }
    comb_object = do.call(rbind, decenter_object)
    variation_explain = ftsm(fts(1:nrow(comb_object), comb_object), order = 20)$varprop
    ncomp_comb = head(which(cumsum(ftsm(fts(1:nrow(comb_object), comb_object), order = 20)$varprop) >= variation_prop), 1)
    ftsm_obj = ftsm(fts(1:nrow(comb_object), comb_object), order = ncomp_comb, mean = FALSE)
    fore_ftsm = forecast(ftsm_obj, h = year_horizon, method = fmethod)
    fore_res = exp(fore_ftsm$mean$y * do.call(c,sd_object) + do.call(c, rowmeans_object))
    fitted_res = comb_object * do.call(c,sd_object) + do.call(c, rowmeans_object)
    return(list(rowmeans_object = do.call(c, rowmeans_object), sd_object = do.call(c, sd_object),
                ftsm_obj = ftsm_obj, fore_ftsm = fore_ftsm, fore_res = fore_res,
                fitted_res = fitted_res, ncomp_comb = ncomp_comb, variation_explain = variation_explain))
}

Hokkaido_dat_smooth = mfts_decomp(dat = Hokkaido_smooth, year_horizon = 20, fmethod = "rwdrift", variation_prop = 0.9)

savepdf("mfts_sd", width = 12, height = 10, toplines = 0.8)
plot(60:100, Hokkaido_dat_smooth$sd_object[1:41], ylim = c(0.14, 0.42), xlab = "Age", ylab = "Standard deviation", main = "Hokkaido female data")
dev.off()

savepdf("mfts_sd_2", width = 12, height = 10, toplines = 0.8)
plot(60:100, Hokkaido_dat_smooth$sd_object[42:82], ylim = c(0.14, 0.42), xlab = "Age", ylab = "Standard deviation", main = "Hokkaido male data")
dev.off()

####################
# fdm model fitting
####################

savepdf("Fig_1", width = 14, height = 10, toplines = 0.8)
par(mfrow = c(2,3))
plot(60:100, Hokkaido_dat_smooth$rowmeans_object[1:41], xlab = "", ylab = "Mean", main = "Main effects", type = "l", ylim = c(-5.5, 0))
plot(60:100, -1 * Hokkaido_dat_smooth$ftsm_obj$basis[1:41,1], xlab = "", ylab = "Basis function 1", type = "l", ylim = c(0.08, 0.113))
plot(forecast(auto.arima(ts(-1 * Hokkaido_dat_smooth$ftsm_obj$coeff[,1], start = 1975, end = 2015)), h = 20), xlab = "",
     ylab = "Coefficient 1", main = "")

plot(60:100, Hokkaido_dat_smooth$rowmeans_object[42:82], xlab = "Age", ylab = "Mean", main = "Main effects", type = "l", ylim = c(-5.5, 0))
plot(60:100, -1 * Hokkaido_dat_smooth$ftsm_obj$basis[42:82,1], xlab = "Age", ylab = "Basis function 1", type = "l", ylim = c(0.08, 0.113))
plot(forecast(auto.arima(ts(-1 * Hokkaido_dat_smooth$ftsm_obj$coeff[,1], start = 1975, end = 2015)), h = 20), xlab = "Year",
     ylab = "Coefficient 1", main = "")
dev.off()

#############################
# fitted and residual values
#############################

savepdf("Fig_2a", width = 12, height = 10, toplines = 0.8)
plot(fts(60:100, Hokkaido_dat_smooth$fitted_res[1:41,]), xlab = "Age", ylab = "Log mortality rate", main = "Female data", ylim = c(-5.8, 0))
dev.off()

savepdf("Fig_2c", width = 12, height = 10, toplines = 0.8)
plot(fts(60:100, Hokkaido_dat_smooth$fitted_res[42:82,]), xlab = "Age", ylab = "Log mortality rate", main = "Male data", ylim = c(-5.8, 0))
dev.off()

savepdf("Fig_2b", width = 12, height = 10, toplines = 0.8)
filled.contour(60:100, 1975:2016, Hokkaido$rate$female - exp(Hokkaido_dat_smooth$fitted_res[1:41,]), main = "Female data")
dev.off()

savepdf("Fig_2d", width = 12, height = 10, toplines = 0.8)
Hokkaido_male_replace = replace(Hokkaido$rate$male, which(Hokkaido$rate$male > 1), 1)
filled.contour(60:100, 1975:2016, Hokkaido_male_replace - exp(Hokkaido_dat_smooth$fitted_res[42:82,]), main = "Male data")
dev.off()

##################
# point forecasts
##################

savepdf("Fig_3a_black", width = 12, height = 10, toplines = 0.8)
# plot(Hokkaido_smooth, series = "female", main = "Hokkaido: female death rates",
#     colorchoice = "gray", ylim = c(-6, 0))
plot(Hokkaido_smooth, series = "female", main = "Hokkaido: female death rates",
     col = "black", ylim = c(-6, 0))
lines(fts(60:100, log(Hokkaido_dat_smooth$fore_res[1:41,])))
dev.off()

savepdf("Fig_3b_black", width = 12, height = 10, toplines = 0.8)
# plot(Hokkaido_smooth, series = "male", main = "Hokkaido: male death rates",
#     colorchoice = "gray", ylim = c(-6, 0))
plot(Hokkaido_smooth, series = "male", main = "Hokkaido: male death rates",
     col = "black", ylim = c(-6, 0))
lines(fts(60:100, log(Hokkaido_dat_smooth$fore_res[42:82,])))
dev.off()

################################################################################
# number of retained components (by explaining at least 90% of total variation)
################################################################################

mfts_sex_order_tally = vector("numeric", 48)
for(iw in 1:48)
{
    ind_dat = get(state_smooth[iw])
    mfts_sex_order_tally[iw] = mfts_decomp(dat = ind_dat, year_horizon = 15, fmethod = "arima", variation_prop = 0.9)$ncomp_comb
    print(iw)
}

all(mfts_sex_order_tally == 1) # TRUE

######################################################################################
# Point forecast evaluation with univariate functional time series forecasting method
######################################################################################

ind_state_forc_female = c("ind_Japan_forc_female",     "ind_Hokkaido_forc_female",  "ind_Aomori_forc_female",
                          "ind_Iwate_forc_female",     "ind_Miyagi_forc_female",    "ind_Akita_forc_female",
                          "ind_Yamagata_forc_female",  "ind_Fukushima_forc_female", "ind_Ibaraki_forc_female",
                          "ind_Tochigi_forc_female",   "ind_Gunma_forc_female",     "ind_Saitama_forc_female",
                          "ind_Chiba_forc_female",     "ind_Tokyo_forc_female",     "ind_Kanagawa_forc_female",
                          "ind_Niigata_forc_female",   "ind_Toyama_forc_female",    "ind_Ishikawa_forc_female",
                          "ind_Fukui_forc_female",     "ind_Yamanashi_forc_female", "ind_Nagano_forc_female",
                          "ind_Gifu_forc_female",      "ind_Shizuoka_forc_female",  "ind_Aichi_forc_female",
                          "ind_Mie_forc_female",       "ind_Shiga_forc_female",     "ind_Kyoto_forc_female",
                          "ind_Osaka_forc_female",     "ind_Hyogo_forc_female",     "ind_Nara_forc_female",
                          "ind_Wakayama_forc_female",  "ind_Tottori_forc_female",   "ind_Shimane_forc_female",
                          "ind_Okayama_forc_female",   "ind_Hiroshima_forc_female", "ind_Yamaguchi_forc_female",
                          "ind_Tokushima_forc_female", "ind_Kagawa_forc_female",    "ind_Ehime_forc_female",
                          "ind_Kochi_forc_female",     "ind_Fukuoka_forc_female",   "ind_Saga_forc_female",
                          "ind_Nagasaki_forc_female",  "ind_Kumamoto_forc_female",  "ind_Oita_forc_female",
                          "ind_Miyazaki_forc_female",  "ind_Kagoshima_forc_female", "ind_Okinawa_forc_female")

ind_state_forc_male = c("ind_Japan_forc_male",     "ind_Hokkaido_forc_male",  "ind_Aomori_forc_male",
                        "ind_Iwate_forc_male",     "ind_Miyagi_forc_male",    "ind_Akita_forc_male",
                        "ind_Yamagata_forc_male",  "ind_Fukushima_forc_male", "ind_Ibaraki_forc_male",
                        "ind_Tochigi_forc_male",   "ind_Gunma_forc_male",     "ind_Saitama_forc_male",
                        "ind_Chiba_forc_male",     "ind_Tokyo_forc_male",     "ind_Kanagawa_forc_male",
                        "ind_Niigata_forc_male",   "ind_Toyama_forc_male",    "ind_Ishikawa_forc_male",
                        "ind_Fukui_forc_male",     "ind_Yamanashi_forc_male", "ind_Nagano_forc_male",
                        "ind_Gifu_forc_male",      "ind_Shizuoka_forc_male",  "ind_Aichi_forc_male",
                        "ind_Mie_forc_male",       "ind_Shiga_forc_male",     "ind_Kyoto_forc_male",
                        "ind_Osaka_forc_male",     "ind_Hyogo_forc_male",     "ind_Nara_forc_male",
                        "ind_Wakayama_forc_male",  "ind_Tottori_forc_male",   "ind_Shimane_forc_male",
                        "ind_Okayama_forc_male",   "ind_Hiroshima_forc_male", "ind_Yamaguchi_forc_male",
                        "ind_Tokushima_forc_male", "ind_Kagawa_forc_male",    "ind_Ehime_forc_male",
                        "ind_Kochi_forc_male",     "ind_Fukuoka_forc_male",   "ind_Saga_forc_male",
                        "ind_Nagasaki_forc_male",  "ind_Kumamoto_forc_male",  "ind_Oita_forc_male",
                        "ind_Miyazaki_forc_male",  "ind_Kagoshima_forc_male", "ind_Okinawa_forc_male")

ind_state_forc_total = c("ind_Japan_forc_total",     "ind_Hokkaido_forc_total",  "ind_Aomori_forc_total",
                        "ind_Iwate_forc_total",     "ind_Miyagi_forc_total",    "ind_Akita_forc_total",
                        "ind_Yamagata_forc_total",  "ind_Fukushima_forc_total", "ind_Ibaraki_forc_total",
                        "ind_Tochigi_forc_total",   "ind_Gunma_forc_total",     "ind_Saitama_forc_total",
                        "ind_Chiba_forc_total",     "ind_Tokyo_forc_total",     "ind_Kanagawa_forc_total",
                        "ind_Niigata_forc_total",   "ind_Toyama_forc_total",    "ind_Ishikawa_forc_total",
                        "ind_Fukui_forc_total",     "ind_Yamanashi_forc_total", "ind_Nagano_forc_total",
                        "ind_Gifu_forc_total",      "ind_Shizuoka_forc_total",  "ind_Aichi_forc_total",
                        "ind_Mie_forc_total",       "ind_Shiga_forc_total",     "ind_Kyoto_forc_total",
                        "ind_Osaka_forc_total",     "ind_Hyogo_forc_total",     "ind_Nara_forc_total",
                        "ind_Wakayama_forc_total",  "ind_Tottori_forc_total",   "ind_Shimane_forc_total",
                        "ind_Okayama_forc_total",   "ind_Hiroshima_forc_total", "ind_Yamaguchi_forc_total",
                        "ind_Tokushima_forc_total", "ind_Kagawa_forc_total",    "ind_Ehime_forc_total",
                        "ind_Kochi_forc_total",     "ind_Fukuoka_forc_total",   "ind_Saga_forc_total",
                        "ind_Nagasaki_forc_total",  "ind_Kumamoto_forc_total",  "ind_Oita_forc_total",
                        "ind_Miyazaki_forc_total",  "ind_Kagoshima_forc_total", "ind_Okinawa_forc_total")

ind_state_me_female = c("ind_Japan_me_female", "ind_Hokkaido_me_female", "ind_Aomori_me_female",
                      "ind_Iwate_me_female", "ind_Miyagi_me_female", "ind_Akita_me_female",
                      "ind_Yamagata_me_female", "ind_Fukushima_me_female", "ind_Ibaraki_me_female",
                      "ind_Tochigi_me_female", "ind_Gunma_me_female", "ind_Saitama_me_female",
                      "ind_Chiba_me_female", "ind_Tokyo_me_female", "ind_Kanagawa_me_female",
                      "ind_Niigata_me_female", "ind_Toyama_me_female", "ind_Ishikawa_me_female",
                      "ind_Fukui_me_female", "ind_Yamanashi_me_female", "ind_Nagano_me_female",
                      "ind_Gifu_me_female", "ind_Shizuoka_me_female", "ind_Aichi_me_female",
                      "ind_Mie_me_female", "ind_Shiga_me_female", "ind_Kyoto_me_female",
                      "ind_Osaka_me_female", "ind_Hyogo_me_female", "ind_Nara_me_female",
                      "ind_Wakayama_me_female", "ind_Tottori_me_female", "ind_Shimane_me_female",
                      "ind_Okayama_me_female", "ind_Hiroshima_me_female", "ind_Yamaguchi_me_female",
                      "ind_Tokushima_me_female", "ind_Kagawa_me_female", "ind_Ehime_me_female",
                      "ind_Kochi_me_female", "ind_Fukuoka_me_female", "ind_Saga_me_female",
                      "ind_Nagasaki_me_female", "ind_Kumamoto_me_female", "ind_Oita_me_female",
                      "ind_Miyazaki_me_female", "ind_Kagoshima_me_female", "ind_Okinawa_me_female")

ind_state_me_male = c("ind_Japan_me_male", "ind_Hokkaido_me_male", "ind_Aomori_me_male",
                    "ind_Iwate_me_male", "ind_Miyagi_me_male", "ind_Akita_me_male",
                    "ind_Yamagata_me_male", "ind_Fukushima_me_male", "ind_Ibaraki_me_male",
                    "ind_Tochigi_me_male", "ind_Gunma_me_male", "ind_Saitama_me_male",
                    "ind_Chiba_me_male", "ind_Tokyo_me_male", "ind_Kanagawa_me_male",
                    "ind_Niigata_me_male", "ind_Toyama_me_male", "ind_Ishikawa_me_male",
                    "ind_Fukui_me_male", "ind_Yamanashi_me_male", "ind_Nagano_me_male",
                    "ind_Gifu_me_male", "ind_Shizuoka_me_male", "ind_Aichi_me_male",
                    "ind_Mie_me_male", "ind_Shiga_me_male", "ind_Kyoto_me_male",
                    "ind_Osaka_me_male", "ind_Hyogo_me_male", "ind_Nara_me_male",
                    "ind_Wakayama_me_male", "ind_Tottori_me_male", "ind_Shimane_me_male",
                    "ind_Okayama_me_male", "ind_Hiroshima_me_male", "ind_Yamaguchi_me_male",
                    "ind_Tokushima_me_male", "ind_Kagawa_me_male", "ind_Ehime_me_male",
                    "ind_Kochi_me_male", "ind_Fukuoka_me_male", "ind_Saga_me_male",
                    "ind_Nagasaki_me_male", "ind_Kumamoto_me_male", "ind_Oita_me_male",
                    "ind_Miyazaki_me_male", "ind_Kagoshima_me_male", "ind_Okinawa_me_male")

ind_state_me_total = c("ind_Japan_me_total", "ind_Hokkaido_me_total", "ind_Aomori_me_total",
                      "ind_Iwate_me_total", "ind_Miyagi_me_total", "ind_Akita_me_total",
                      "ind_Yamagata_me_total", "ind_Fukushima_me_total", "ind_Ibaraki_me_total",
                      "ind_Tochigi_me_total", "ind_Gunma_me_total", "ind_Saitama_me_total",
                      "ind_Chiba_me_total", "ind_Tokyo_me_total", "ind_Kanagawa_me_total",
                      "ind_Niigata_me_total", "ind_Toyama_me_total", "ind_Ishikawa_me_total",
                      "ind_Fukui_me_total", "ind_Yamanashi_me_total", "ind_Nagano_me_total",
                      "ind_Gifu_me_total", "ind_Shizuoka_me_total", "ind_Aichi_me_total",
                      "ind_Mie_me_total", "ind_Shiga_me_total", "ind_Kyoto_me_total",
                      "ind_Osaka_me_total", "ind_Hyogo_me_total", "ind_Nara_me_total",
                      "ind_Wakayama_me_total", "ind_Tottori_me_total", "ind_Shimane_me_total",
                      "ind_Okayama_me_total", "ind_Hiroshima_me_total", "ind_Yamaguchi_me_total",
                      "ind_Tokushima_me_total", "ind_Kagawa_me_total", "ind_Ehime_me_total",
                      "ind_Kochi_me_total", "ind_Fukuoka_me_total", "ind_Saga_me_total",
                      "ind_Nagasaki_me_total", "ind_Kumamoto_me_total", "ind_Oita_me_total",
                      "ind_Miyazaki_me_total", "ind_Kagoshima_me_total", "ind_Okinawa_me_total")

ind_state_rmse_female = c("ind_Japan_rmse_female", "ind_Hokkaido_rmse_female", "ind_Aomori_rmse_female",
                        "ind_Iwate_rmse_female", "ind_Miyagi_rmse_female", "ind_Akita_rmse_female",
                        "ind_Yamagata_rmse_female", "ind_Fukushima_rmse_female", "ind_Ibaraki_rmse_female",
                        "ind_Tochigi_rmse_female", "ind_Gunma_rmse_female", "ind_Saitama_rmse_female",
                        "ind_Chiba_rmse_female", "ind_Tokyo_rmse_female", "ind_Kanagawa_rmse_female",
                        "ind_Niigata_rmse_female", "ind_Toyama_rmse_female", "ind_Ishikawa_rmse_female",
                        "ind_Fukui_rmse_female", "ind_Yamanashi_rmse_female", "ind_Nagano_rmse_female",
                        "ind_Gifu_rmse_female", "ind_Shizuoka_rmse_female", "ind_Aichi_rmse_female",
                        "ind_Mie_rmse_female", "ind_Shiga_rmse_female", "ind_Kyoto_rmse_female",
                        "ind_Osaka_rmse_female", "ind_Hyogo_rmse_female", "ind_Nara_rmse_female",
                        "ind_Wakayama_rmse_female", "ind_Tottori_rmse_female", "ind_Shimane_rmse_female",
                        "ind_Okayama_rmse_female", "ind_Hiroshima_rmse_female", "ind_Yamaguchi_rmse_female",
                        "ind_Tokushima_rmse_female", "ind_Kagawa_rmse_female", "ind_Ehime_rmse_female",
                        "ind_Kochi_rmse_female", "ind_Fukuoka_rmse_female", "ind_Saga_rmse_female",
                        "ind_Nagasaki_rmse_female", "ind_Kumamoto_rmse_female", "ind_Oita_rmse_female",
                        "ind_Miyazaki_rmse_female", "ind_Kagoshima_rmse_female", "ind_Okinawa_rmse_female")

ind_state_rmse_male = c("ind_Japan_rmse_male", "ind_Hokkaido_rmse_male", "ind_Aomori_rmse_male",
                        "ind_Iwate_rmse_male", "ind_Miyagi_rmse_male", "ind_Akita_rmse_male",
                        "ind_Yamagata_rmse_male", "ind_Fukushima_rmse_male", "ind_Ibaraki_rmse_male",
                        "ind_Tochigi_rmse_male", "ind_Gunma_rmse_male", "ind_Saitama_rmse_male",
                        "ind_Chiba_rmse_male", "ind_Tokyo_rmse_male", "ind_Kanagawa_rmse_male",
                        "ind_Niigata_rmse_male", "ind_Toyama_rmse_male", "ind_Ishikawa_rmse_male",
                        "ind_Fukui_rmse_male", "ind_Yamanashi_rmse_male", "ind_Nagano_rmse_male",
                        "ind_Gifu_rmse_male", "ind_Shizuoka_rmse_male", "ind_Aichi_rmse_male",
                        "ind_Mie_rmse_male", "ind_Shiga_rmse_male", "ind_Kyoto_rmse_male",
                        "ind_Osaka_rmse_male", "ind_Hyogo_rmse_male", "ind_Nara_rmse_male",
                        "ind_Wakayama_rmse_male", "ind_Tottori_rmse_male", "ind_Shimane_rmse_male",
                        "ind_Okayama_rmse_male", "ind_Hiroshima_rmse_male", "ind_Yamaguchi_rmse_male",
                        "ind_Tokushima_rmse_male", "ind_Kagawa_rmse_male", "ind_Ehime_rmse_male",
                        "ind_Kochi_rmse_male", "ind_Fukuoka_rmse_male", "ind_Saga_rmse_male",
                        "ind_Nagasaki_rmse_male", "ind_Kumamoto_rmse_male", "ind_Oita_rmse_male",
                        "ind_Miyazaki_rmse_male", "ind_Kagoshima_rmse_male", "ind_Okinawa_rmse_male")

ind_state_rmse_total = c("ind_Japan_rmse_total", "ind_Hokkaido_rmse_total", "ind_Aomori_rmse_total",
                        "ind_Iwate_rmse_total", "ind_Miyagi_rmse_total", "ind_Akita_rmse_total",
                        "ind_Yamagata_rmse_total", "ind_Fukushima_rmse_total", "ind_Ibaraki_rmse_total",
                        "ind_Tochigi_rmse_total", "ind_Gunma_rmse_total", "ind_Saitama_rmse_total",
                        "ind_Chiba_rmse_total", "ind_Tokyo_rmse_total", "ind_Kanagawa_rmse_total",
                        "ind_Niigata_rmse_total", "ind_Toyama_rmse_total", "ind_Ishikawa_rmse_total",
                        "ind_Fukui_rmse_total", "ind_Yamanashi_rmse_total", "ind_Nagano_rmse_total",
                        "ind_Gifu_rmse_total", "ind_Shizuoka_rmse_total", "ind_Aichi_rmse_total",
                        "ind_Mie_rmse_total", "ind_Shiga_rmse_total", "ind_Kyoto_rmse_total",
                        "ind_Osaka_rmse_total", "ind_Hyogo_rmse_total", "ind_Nara_rmse_total",
                        "ind_Wakayama_rmse_total", "ind_Tottori_rmse_total", "ind_Shimane_rmse_total",
                        "ind_Okayama_rmse_total", "ind_Hiroshima_rmse_total", "ind_Yamaguchi_rmse_total",
                        "ind_Tokushima_rmse_total", "ind_Kagawa_rmse_total", "ind_Ehime_rmse_total",
                        "ind_Kochi_rmse_total", "ind_Fukuoka_rmse_total", "ind_Saga_rmse_total",
                        "ind_Nagasaki_rmse_total", "ind_Kumamoto_rmse_total", "ind_Oita_rmse_total",
                        "ind_Miyazaki_rmse_total", "ind_Kagoshima_rmse_total", "ind_Okinawa_rmse_total")

ind_state_mae_female = c("ind_Japan_mae_female", "ind_Hokkaido_mae_female", "ind_Aomori_mae_female",
                        "ind_Iwate_mae_female", "ind_Miyagi_mae_female", "ind_Akita_mae_female",
                        "ind_Yamagata_mae_female", "ind_Fukushima_mae_female", "ind_Ibaraki_mae_female",
                        "ind_Tochigi_mae_female", "ind_Gunma_mae_female", "ind_Saitama_mae_female",
                        "ind_Chiba_mae_female", "ind_Tokyo_mae_female", "ind_Kanagawa_mae_female",
                        "ind_Niigata_mae_female", "ind_Toyama_mae_female", "ind_Ishikawa_mae_female",
                        "ind_Fukui_mae_female", "ind_Yamanashi_mae_female", "ind_Nagano_mae_female",
                        "ind_Gifu_mae_female", "ind_Shizuoka_mae_female", "ind_Aichi_mae_female",
                        "ind_Mie_mae_female", "ind_Shiga_mae_female", "ind_Kyoto_mae_female",
                        "ind_Osaka_mae_female", "ind_Hyogo_mae_female", "ind_Nara_mae_female",
                        "ind_Wakayama_mae_female", "ind_Tottori_mae_female", "ind_Shimane_mae_female",
                        "ind_Okayama_mae_female", "ind_Hiroshima_mae_female", "ind_Yamaguchi_mae_female",
                        "ind_Tokushima_mae_female", "ind_Kagawa_mae_female", "ind_Ehime_mae_female",
                        "ind_Kochi_mae_female", "ind_Fukuoka_mae_female", "ind_Saga_mae_female",
                        "ind_Nagasaki_mae_female", "ind_Kumamoto_mae_female", "ind_Oita_mae_female",
                        "ind_Miyazaki_mae_female", "ind_Kagoshima_mae_female", "ind_Okinawa_mae_female")

ind_state_mae_male = c("ind_Japan_mae_male", "ind_Hokkaido_mae_male", "ind_Aomori_mae_male",
                      "ind_Iwate_mae_male", "ind_Miyagi_mae_male", "ind_Akita_mae_male",
                      "ind_Yamagata_mae_male", "ind_Fukushima_mae_male", "ind_Ibaraki_mae_male",
                      "ind_Tochigi_mae_male", "ind_Gunma_mae_male", "ind_Saitama_mae_male",
                      "ind_Chiba_mae_male", "ind_Tokyo_mae_male", "ind_Kanagawa_mae_male",
                      "ind_Niigata_mae_male", "ind_Toyama_mae_male", "ind_Ishikawa_mae_male",
                      "ind_Fukui_mae_male", "ind_Yamanashi_mae_male", "ind_Nagano_mae_male",
                      "ind_Gifu_mae_male", "ind_Shizuoka_mae_male", "ind_Aichi_mae_male",
                      "ind_Mie_mae_male", "ind_Shiga_mae_male", "ind_Kyoto_mae_male",
                      "ind_Osaka_mae_male", "ind_Hyogo_mae_male", "ind_Nara_mae_male",
                      "ind_Wakayama_mae_male", "ind_Tottori_mae_male", "ind_Shimane_mae_male",
                      "ind_Okayama_mae_male", "ind_Hiroshima_mae_male", "ind_Yamaguchi_mae_male",
                      "ind_Tokushima_mae_male", "ind_Kagawa_mae_male", "ind_Ehime_mae_male",
                      "ind_Kochi_mae_male", "ind_Fukuoka_mae_male", "ind_Saga_mae_male",
                      "ind_Nagasaki_mae_male", "ind_Kumamoto_mae_male", "ind_Oita_mae_male",
                      "ind_Miyazaki_mae_male", "ind_Kagoshima_mae_male", "ind_Okinawa_mae_male")

ind_state_mae_total = c("ind_Japan_mae_total", "ind_Hokkaido_mae_total", "ind_Aomori_mae_total",
                      "ind_Iwate_mae_total", "ind_Miyagi_mae_total", "ind_Akita_mae_total",
                      "ind_Yamagata_mae_total", "ind_Fukushima_mae_total", "ind_Ibaraki_mae_total",
                      "ind_Tochigi_mae_total", "ind_Gunma_mae_total", "ind_Saitama_mae_total",
                      "ind_Chiba_mae_total", "ind_Tokyo_mae_total", "ind_Kanagawa_mae_total",
                      "ind_Niigata_mae_total", "ind_Toyama_mae_total", "ind_Ishikawa_mae_total",
                      "ind_Fukui_mae_total", "ind_Yamanashi_mae_total", "ind_Nagano_mae_total",
                      "ind_Gifu_mae_total", "ind_Shizuoka_mae_total", "ind_Aichi_mae_total",
                      "ind_Mie_mae_total", "ind_Shiga_mae_total", "ind_Kyoto_mae_total",
                      "ind_Osaka_mae_total", "ind_Hyogo_mae_total", "ind_Nara_mae_total",
                      "ind_Wakayama_mae_total", "ind_Tottori_mae_total", "ind_Shimane_mae_total",
                      "ind_Okayama_mae_total", "ind_Hiroshima_mae_total", "ind_Yamaguchi_mae_total",
                      "ind_Tokushima_mae_total", "ind_Kagawa_mae_total", "ind_Ehime_mae_total",
                      "ind_Kochi_mae_total", "ind_Fukuoka_mae_total", "ind_Saga_mae_total",
                      "ind_Nagasaki_mae_total", "ind_Kumamoto_mae_total", "ind_Oita_mae_total",
                      "ind_Miyazaki_mae_total", "ind_Kagoshima_mae_total", "ind_Okinawa_mae_total")

# regions

ind_region_forc_female = c("ind_region_R1_forc_female", "ind_region_R2_forc_female", "ind_region_R3_forc_female",
                          "ind_region_R4_forc_female", "ind_region_R5_forc_female", "ind_region_R6_forc_female",
                          "ind_region_R7_forc_female", "ind_region_R8_forc_female")

ind_region_forc_male = c("ind_region_R1_forc_male", "ind_region_R2_forc_male", "ind_region_R3_forc_male",
                        "ind_region_R4_forc_male", "ind_region_R5_forc_male", "ind_region_R6_forc_male",
                        "ind_region_R7_forc_male", "ind_region_R8_forc_male")

ind_region_forc_total = c("ind_region_R1_forc_total", "ind_region_R2_forc_total", "ind_region_R3_forc_total",
                        "ind_region_R4_forc_total", "ind_region_R5_forc_total", "ind_region_R6_forc_total",
                        "ind_region_R7_forc_total", "ind_region_R8_forc_total")

ind_region_me_female = c("ind_region_R1_me_female", "ind_region_R2_me_female", "ind_region_R3_me_female",
                        "ind_region_R4_me_female", "ind_region_R5_me_female", "ind_region_R6_me_female",
                        "ind_region_R7_me_female", "ind_region_R8_me_female")

ind_region_me_male = c("ind_region_R1_me_male", "ind_region_R2_me_male", "ind_region_R3_me_male",
                      "ind_region_R4_me_male", "ind_region_R5_me_male", "ind_region_R6_me_male",
                      "ind_region_R7_me_male", "ind_region_R8_me_male")

ind_region_me_total = c("ind_region_R1_me_total", "ind_region_R2_me_total", "ind_region_R3_me_total",
                        "ind_region_R4_me_total", "ind_region_R5_me_total", "ind_region_R6_me_total",
                        "ind_region_R7_me_total", "ind_region_R8_me_total")

ind_region_rmse_female = c("ind_region_R1_rmse_female", "ind_region_R2_rmse_female", "ind_region_R3_rmse_female",
                          "ind_region_R4_rmse_female", "ind_region_R5_rmse_female", "ind_region_R6_rmse_female",
                          "ind_region_R7_rmse_female", "ind_region_R8_rmse_female")

ind_region_rmse_male = c("ind_region_R1_rmse_male", "ind_region_R2_rmse_male", "ind_region_R3_rmse_male",
                        "ind_region_R4_rmse_male", "ind_region_R5_rmse_male", "ind_region_R6_rmse_male",
                        "ind_region_R7_rmse_male", "ind_region_R8_rmse_male")

ind_region_rmse_total = c("ind_region_R1_rmse_total", "ind_region_R2_rmse_total", "ind_region_R3_rmse_total",
                        "ind_region_R4_rmse_total", "ind_region_R5_rmse_total", "ind_region_R6_rmse_total",
                        "ind_region_R7_rmse_total", "ind_region_R8_rmse_total")

ind_region_mae_female = c("ind_region_R1_mae_female", "ind_region_R2_mae_female", "ind_region_R3_mae_female",
                          "ind_region_R4_mae_female", "ind_region_R5_mae_female", "ind_region_R6_mae_female",
                          "ind_region_R7_mae_female", "ind_region_R8_mae_female")
                          
ind_region_mae_male = c("ind_region_R1_mae_male", "ind_region_R2_mae_male", "ind_region_R3_mae_male",
                      "ind_region_R4_mae_male", "ind_region_R5_mae_male", "ind_region_R6_mae_male",
                      "ind_region_R7_mae_male", "ind_region_R8_mae_male")

ind_region_mae_total = c("ind_region_R1_mae_total", "ind_region_R2_mae_total", "ind_region_R3_mae_total",
                        "ind_region_R4_mae_total", "ind_region_R5_mae_total", "ind_region_R6_mae_total",
                        "ind_region_R7_mae_total", "ind_region_R8_mae_total")

#########
# Region
#########

ind_back_test_region <- function(iw, fmethod = "classical", year_horizon, var_prop)
{
    forecast_year = year_horizon + 1
    n_year = tail(get(region_smooth[1])$year, 1) - forecast_year
    
    res_male = res_female = res_total = array(NA, dim = c(year_horizon, length(get(region_smooth[1])$age), year_horizon))
    for(ij in 1:year_horizon)
    {
        ind_dat = extract.years(get(region_smooth[iw]), years = 1975:(n_year+ij))
        
        fdm_female_order = head(which(round(cumsum(fdm(ind_dat, series = "female", max.age = 100, method = fmethod, order = length(ind_dat$year))$varprop),3) >= var_prop),1)
        fdm_male_order = head(which(round(cumsum(fdm(ind_dat, series = "male",max.age = 100, method = fmethod, order = length(ind_dat$year))$varprop),3) >= var_prop),1)
        fdm_total_order = head(which(round(cumsum(fdm(ind_dat, series = "total", max.age = 100, method = fmethod, order = length(ind_dat$year))$varprop),3) >= var_prop),1)
        
        # functional time series models
        
        fun_forc_female = forecast(fdm(ind_dat, series = "female", order = fdm_female_order, max.age = 100, method = fmethod), h = 15)
        fun_forc_male = forecast(fdm(ind_dat, series = "male", order = fdm_male_order, max.age = 100, method = fmethod), h = 15)
        fun_forc_total = forecast(fdm(ind_dat, series = "total", order = fdm_total_order, max.age = 100, method = fmethod), h = 15)
        
        res_female[,,ij] = t(fun_forc_female$rate$female)
        res_male[,,ij] = t(fun_forc_male$rate$male)
        res_total[,,ij] = t(fun_forc_total$rate$total)

        rm(fdm_female_order); rm(fun_forc_female)
        rm(fdm_male_order); rm(fun_forc_male)
        rm(fdm_total_order); rm(fun_forc_total)
    }
    
    # error measures
    female_me = male_me = total_me = female_rmse = male_rmse = total_rmse = female_mae = male_mae = total_mae = vector("numeric", year_horizon)
    for(ik in 1:year_horizon)
    {
        total_me[ik] = me(res_total[ik,,1:(forecast_year-ik)], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        female_me[ik] = me(res_female[ik,,1:(forecast_year-ik)], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        male_me[ik]   = me(res_male[ik,,1:(forecast_year-ik)],   extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
        
        total_mae[ik] = mae(res_total[ik,,1:(forecast_year-ik)], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        female_mae[ik] = mae(res_female[ik,,1:(forecast_year-ik)], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        male_mae[ik]   = mae(res_male[ik,,1:(forecast_year-ik)],   extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
        
        total_rmse[ik] = rmse(res_total[ik,,1:(forecast_year-ik)], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        female_rmse[ik] = rmse(res_female[ik,,1:(forecast_year-ik)], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        male_rmse[ik]   = rmse(res_male[ik,,1:(forecast_year-ik)],   extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
    }
    return(list(res_female = res_female, res_male = res_male, res_total = res_total,
                female_me = female_me, male_me = male_me, total_me = total_me,
                female_mae = female_mae, male_mae = male_mae, total_mae = total_mae,
                female_rmse = female_rmse, male_rmse = male_rmse, total_rmse = total_rmse))
}

# MFE, MAFE, RMSFE criteria

me = ftsa:::me
mae = ftsa:::mae
rmse = ftsa:::rmse

# Eight regions

for(ik in 1:8)
{
    dum = ind_back_test_region(iw = ik, fmethod = "classical", year_horizon = 15, var_prop = 0.9)
    
    assign(ind_region_forc_total[ik],   dum$res_total)
    assign(ind_region_forc_female[ik], dum$res_female)
    assign(ind_region_forc_male[ik],   dum$res_male)
    
    assign(ind_region_me_total[ik], dum$total_me)
    assign(ind_region_me_female[ik], dum$female_me)
    assign(ind_region_me_male[ik],   dum$male_me)
    
    assign(ind_region_mae_total[ik], dum$total_mae)
    assign(ind_region_mae_female[ik], dum$female_mae)
    assign(ind_region_mae_male[ik],   dum$male_mae)
    
    assign(ind_region_rmse_total[ik], dum$total_rmse)
    assign(ind_region_rmse_female[ik], dum$female_rmse)
    assign(ind_region_rmse_male[ik],   dum$male_rmse)
    print(ik)
    rm(dum)
}


#############
# Prefecture
#############

ind_back_test <- function(iw, fmethod = "classical", year_horizon, var_prop)
{
    forecast_year = (year_horizon + 1)
    n_year = tail(get(state_smooth[1])$year,1) - forecast_year
    res_male = res_female = res_total = array(NA, dim = c(year_horizon, length(get(state_smooth[1])$age), year_horizon))
    for(ij in 1:year_horizon)
    {
        ind_dat = extract.years(get(state_smooth[iw]), years = 1975:(n_year+ij))
        
        fdm_female_order = head(which(round(cumsum(fdm(ind_dat, series = "female", max.age = 100, method = fmethod, order = length(ind_dat$year))$varprop),3) >= var_prop),1)
        fdm_male_order = head(which(round(cumsum(fdm(ind_dat, series = "male",max.age = 100, method = fmethod, order = length(ind_dat$year))$varprop),3) >= var_prop),1)
        fdm_total_order = head(which(round(cumsum(fdm(ind_dat, series = "total", max.age = 100, method = fmethod, order = length(ind_dat$year))$varprop),3) >= var_prop),1)
        
        # functional time series models
        
        fun_forc_female = forecast(fdm(ind_dat, series = "female", order = fdm_female_order, max.age = 100, method = fmethod), h = 15)
        fun_forc_male = forecast(fdm(ind_dat, series = "male", order = fdm_male_order, max.age = 100, method = fmethod), h = 15)
        fun_forc_total = forecast(fdm(ind_dat, series = "total", order = fdm_total_order, max.age = 100, method = fmethod), h = 15)
        
        res_female[,,ij] = t(fun_forc_female$rate$female)
        res_male[,,ij] = t(fun_forc_male$rate$male)
        res_total[,,ij] = t(fun_forc_total$rate$total)
        
        rm(fdm_female_order); rm(fun_forc_female)
        rm(fdm_male_order); rm(fun_forc_male)
        rm(fdm_total_order); rm(fun_forc_total)
    }
    
    # error measures
    female_me = male_me = total_me = female_rmse = male_rmse = total_rmse = female_mae = male_mae  = total_mae = vector("numeric", year_horizon)
    for(ik in 1:year_horizon)
    {
        # me
        total_me[ik] = me(res_total[ik,,1:(forecast_year-ik)], extract.years(get(state[iw]), years = (2001+ik):2016)$rate$total)
        female_me[ik] = me(res_female[ik,,1:(forecast_year-ik)], extract.years(get(state[iw]), years = (2001+ik):2016)$rate$female)
        male_me[ik]   = me(res_male[ik,,1:(forecast_year-ik)],   extract.years(get(state[iw]), years = (2001+ik):2016)$rate$male)
        
        # mae
        total_mae[ik] = mae(res_total[ik,,1:(forecast_year-ik)], extract.years(get(state[iw]), years = (2001+ik):2016)$rate$total)
        female_mae[ik] = mae(res_female[ik,,1:(forecast_year-ik)], extract.years(get(state[iw]), years = (2001+ik):2016)$rate$female)
        male_mae[ik]   = mae(res_male[ik,,1:(forecast_year-ik)],   extract.years(get(state[iw]), years = (2001+ik):2016)$rate$male)
        
        # rmse
        total_rmse[ik] = rmse(res_total[ik,,1:(forecast_year-ik)], extract.years(get(state[iw]), years = (2001+ik):2016)$rate$total)
        female_rmse[ik] = rmse(res_female[ik,,1:(forecast_year-ik)], extract.years(get(state[iw]), years = (2001+ik):2016)$rate$female)
        male_rmse[ik]   = rmse(res_male[ik,,1:(forecast_year-ik)],   extract.years(get(state[iw]), years = (2001+ik):2016)$rate$male)
    }
    return(list(res_female = res_female, res_male = res_male, res_total = res_total,
                total_me = total_me, female_me = female_me, male_me = male_me,
                total_mae = total_mae, female_mae = female_mae, male_mae = male_mae,
                total_rmse = total_rmse, female_rmse = female_rmse, male_rmse = male_rmse))
}

for(ik in 1:48)
{
    dum = ind_back_test(iw = ik, fmethod = "classical", year_horizon = 15, var_prop = 0.9)
    
    assign(ind_state_forc_total[ik], dum$res_total)
    assign(ind_state_forc_female[ik], dum$res_female)
    assign(ind_state_forc_male[ik],   dum$res_male)
    
    assign(ind_state_me_total[ik], dum$total_me)
    assign(ind_state_me_female[ik], dum$female_me)
    assign(ind_state_me_male[ik],   dum$male_me)
    
    assign(ind_state_mae_total[ik], dum$total_mae)
    assign(ind_state_mae_female[ik], dum$female_mae)
    assign(ind_state_mae_male[ik],   dum$male_mae)
    
    assign(ind_state_rmse_total[ik], dum$total_rmse)
    assign(ind_state_rmse_female[ik], dum$female_rmse)
    assign(ind_state_rmse_male[ik],   dum$male_rmse)
    
    print(ik)
    rm(dum)
}


########################################################
# summarize results of mortality rates (base forecasts)
########################################################

# region & sex

ind_region_me_female_mean_overall = ind_region_me_male_mean_overall = ind_region_me_total_mean_overall =
ind_region_mae_female_mean_overall  = ind_region_mae_male_mean_overall  =
ind_region_rmse_female_mean_overall = ind_region_rmse_male_mean_overall =
ind_region_mae_total_mean_overall = ind_region_rmse_total_mean_overall = NULL
for(ik in 1:8)
{
    ind_region_me_female_mean_overall = cbind(ind_region_me_female_mean_overall, get(ind_region_me_female[ik]))
    ind_region_me_male_mean_overall   = cbind(ind_region_me_male_mean_overall,   get(ind_region_me_male[ik]))
    ind_region_me_total_mean_overall  = cbind(ind_region_me_total_mean_overall,  get(ind_region_me_total[ik]))
    
    ind_region_mae_female_mean_overall = cbind(ind_region_mae_female_mean_overall, get(ind_region_mae_female[ik]))
    ind_region_mae_male_mean_overall   = cbind(ind_region_mae_male_mean_overall,   get(ind_region_mae_male[ik]))
    ind_region_mae_total_mean_overall  = cbind(ind_region_mae_total_mean_overall,  get(ind_region_mae_total[ik]))
    
    ind_region_rmse_female_mean_overall = cbind(ind_region_rmse_female_mean_overall, get(ind_region_rmse_female[ik]))
    ind_region_rmse_male_mean_overall   = cbind(ind_region_rmse_male_mean_overall,   get(ind_region_rmse_male[ik]))
    ind_region_rmse_total_mean_overall  = cbind(ind_region_rmse_total_mean_overall,  get(ind_region_rmse_total[ik]))
}

# prefecture & sex

ind_me_female_mean_overall = ind_me_male_mean_overall = ind_me_total_mean_overall =
ind_mae_female_mean_overall = ind_mae_male_mean_overall = ind_mae_total_mean_overall =
ind_rmse_female_mean_overall = ind_rmse_male_mean_overall = ind_rmse_total_mean_overall = NULL
for(ik in 1:48)
{
    ind_me_female_mean_overall  = cbind(ind_me_female_mean_overall, get(ind_state_me_female[ik]))
    ind_me_male_mean_overall    = cbind(ind_me_male_mean_overall,   get(ind_state_me_male[ik]))
    ind_me_total_mean_overall   = cbind(ind_me_total_mean_overall,   get(ind_state_me_total[ik]))

    ind_mae_female_mean_overall  = cbind(ind_mae_female_mean_overall, get(ind_state_mae_female[ik]))
    ind_mae_male_mean_overall    = cbind(ind_mae_male_mean_overall,   get(ind_state_mae_male[ik]))
    ind_mae_total_mean_overall   = cbind(ind_mae_total_mean_overall,   get(ind_state_mae_total[ik]))
    
    ind_rmse_female_mean_overall  = cbind(ind_rmse_female_mean_overall, get(ind_state_rmse_female[ik]))
    ind_rmse_male_mean_overall    = cbind(ind_rmse_male_mean_overall,   get(ind_state_rmse_male[ik]))
    ind_rmse_total_mean_overall   = cbind(ind_rmse_total_mean_overall,   get(ind_state_rmse_total[ik]))
}

# prefecture

rowmeans_ind_me_female_mean_overall = apply(ind_me_female_mean_overall[,2:48], 1, mean)
rowmeans_ind_me_male_mean_overall   = apply(ind_me_male_mean_overall[,2:48], 1, mean)
rowmeans_ind_me_total_mean_overall  = apply(ind_me_total_mean_overall[,2:48], 1, mean)

rowmeans_ind_mae_female_mean_overall = apply(ind_mae_female_mean_overall[,2:48], 1, mean)
rowmeans_ind_mae_male_mean_overall   = apply(ind_mae_male_mean_overall[,2:48], 1, mean)
rowmeans_ind_mae_total_mean_overall  = apply(ind_mae_total_mean_overall[,2:48], 1, mean)

rowmeans_ind_rmse_female_mean_overall = apply(ind_rmse_female_mean_overall[,2:48], 1, mean)
rowmeans_ind_rmse_male_mean_overall   = apply(ind_rmse_male_mean_overall[,2:48], 1, mean)
rowmeans_ind_rmse_total_mean_overall  = apply(ind_rmse_total_mean_overall[,2:48], 1, mean)


####################
# summarise results
####################

# MFE

ind_all_level_err_me = cbind(ind_me_total_mean_overall[,1], apply(cbind(ind_me_female_mean_overall[,1], ind_me_male_mean_overall[,1]), 1,mean),
                              apply(ind_region_me_total_mean_overall, 1, mean), apply(cbind(ind_region_me_female_mean_overall, ind_region_me_male_mean_overall),1,mean),
                              rowmeans_ind_me_total_mean_overall, apply(cbind(rowmeans_ind_me_female_mean_overall, rowmeans_ind_me_male_mean_overall),1,mean))
ind_all_level_err_me_all = rbind(ind_all_level_err_me, colMeans(ind_all_level_err_me), apply(ind_all_level_err_me, 2, median))


# MAFE

ind_all_level_err_mae = cbind(ind_mae_total_mean_overall[,1], apply(cbind(ind_mae_female_mean_overall[,1], ind_mae_male_mean_overall[,1]), 1,mean),
                                apply(ind_region_mae_total_mean_overall, 1, mean), apply(cbind(ind_region_mae_female_mean_overall, ind_region_mae_male_mean_overall),1,mean),
                                rowmeans_ind_mae_total_mean_overall, apply(cbind(rowmeans_ind_mae_female_mean_overall, rowmeans_ind_mae_male_mean_overall),1,mean))
ind_all_level_err_mae_all = rbind(ind_all_level_err_mae, colMeans(ind_all_level_err_mae), apply(ind_all_level_err_mae, 2, median))

# RMSFE

ind_all_level_err_rmse = cbind(ind_rmse_total_mean_overall[,1], apply(cbind(ind_rmse_female_mean_overall[,1], ind_rmse_male_mean_overall[,1]), 1,mean),
                                apply(ind_region_rmse_total_mean_overall, 1, mean), apply(cbind(ind_region_rmse_female_mean_overall, ind_region_rmse_male_mean_overall),1,mean),
                                rowmeans_ind_rmse_total_mean_overall, apply(cbind(rowmeans_ind_rmse_female_mean_overall, rowmeans_ind_rmse_male_mean_overall),1,mean))
ind_all_level_err_rmse_all = rbind(ind_all_level_err_rmse, colMeans(ind_all_level_err_rmse), apply(ind_all_level_err_rmse, 2, median))

colnames(ind_all_level_err_me_all) = colnames(ind_all_level_err_rmse_all) = colnames(ind_all_level_err_mae_all) = c("Total", "Sex", "Region", "Region + Sex", "Prefecture", "Prefecture + Sex")
rownames(ind_all_level_err_me_all) = rownames(ind_all_level_err_rmse_all) = rownames(ind_all_level_err_mae_all) = c(1:15, "Mean", "Median")

#####################################
# Multivariate Functional Data Model
#####################################

# MFE, MAFE, RMSFE criteria

me = ftsa:::me
mae = ftsa:::mae
rmse = ftsa:::rmse

mfts_state_forc_female = c("mfts_Japan_forc_female",     "mfts_Hokkaido_forc_female",  "mfts_Aomori_forc_female",
                           "mfts_Iwate_forc_female",     "mfts_Miyagi_forc_female",    "mfts_Akita_forc_female",
                           "mfts_Yamagata_forc_female",  "mfts_Fukushima_forc_female", "mfts_Ibaraki_forc_female",
                           "mfts_Tochigi_forc_female",   "mfts_Gunma_forc_female",     "mfts_Saitama_forc_female",
                           "mfts_Chiba_forc_female",     "mfts_Tokyo_forc_female",     "mfts_Kanagawa_forc_female",
                           "mfts_Niigata_forc_female",   "mfts_Toyama_forc_female",    "mfts_Ishikawa_forc_female",
                           "mfts_Fukui_forc_female",     "mfts_Yamanashi_forc_female", "mfts_Nagano_forc_female",
                           "mfts_Gifu_forc_female",      "mfts_Shizuoka_forc_female",  "mfts_Aichi_forc_female",
                           "mfts_Mie_forc_female",       "mfts_Shiga_forc_female",     "mfts_Kyoto_forc_female",
                           "mfts_Osaka_forc_female",     "mfts_Hyogo_forc_female",     "mfts_Nara_forc_female",
                           "mfts_Wakayama_forc_female",  "mfts_Tottori_forc_female",   "mfts_Shimane_forc_female",
                           "mfts_Okayama_forc_female",   "mfts_Hiroshima_forc_female", "mfts_Yamaguchi_forc_female",
                           "mfts_Tokushima_forc_female", "mfts_Kagawa_forc_female",    "mfts_Ehime_forc_female",
                           "mfts_Kochi_forc_female",     "mfts_Fukuoka_forc_female",   "mfts_Saga_forc_female",
                           "mfts_Nagasaki_forc_female",  "mfts_Kumamoto_forc_female",  "mfts_Oita_forc_female",
                           "mfts_Miyazaki_forc_female",  "mfts_Kagoshima_forc_female", "mfts_Okinawa_forc_female")

mfts_state_forc_male = c("mfts_Japan_forc_male",     "mfts_Hokkaido_forc_male",  "mfts_Aomori_forc_male",
                         "mfts_Iwate_forc_male",     "mfts_Miyagi_forc_male",    "mfts_Akita_forc_male",
                         "mfts_Yamagata_forc_male",  "mfts_Fukushima_forc_male", "mfts_Ibaraki_forc_male",
                         "mfts_Tochigi_forc_male",   "mfts_Gunma_forc_male",     "mfts_Saitama_forc_male",
                         "mfts_Chiba_forc_male",     "mfts_Tokyo_forc_male",     "mfts_Kanagawa_forc_male",
                         "mfts_Niigata_forc_male",   "mfts_Toyama_forc_male",    "mfts_Ishikawa_forc_male",
                         "mfts_Fukui_forc_male",     "mfts_Yamanashi_forc_male", "mfts_Nagano_forc_male",
                         "mfts_Gifu_forc_male",      "mfts_Shizuoka_forc_male",  "mfts_Aichi_forc_male",
                         "mfts_Mie_forc_male",       "mfts_Shiga_forc_male",     "mfts_Kyoto_forc_male",
                         "mfts_Osaka_forc_male",     "mfts_Hyogo_forc_male",     "mfts_Nara_forc_male",
                         "mfts_Wakayama_forc_male",  "mfts_Tottori_forc_male",   "mfts_Shimane_forc_male",
                         "mfts_Okayama_forc_male",   "mfts_Hiroshima_forc_male", "mfts_Yamaguchi_forc_male",
                         "mfts_Tokushima_forc_male", "mfts_Kagawa_forc_male",    "mfts_Ehime_forc_male",
                         "mfts_Kochi_forc_male",     "mfts_Fukuoka_forc_male",   "mfts_Saga_forc_male",
                         "mfts_Nagasaki_forc_male",  "mfts_Kumamoto_forc_male",  "mfts_Oita_forc_male",
                         "mfts_Miyazaki_forc_male",  "mfts_Kagoshima_forc_male", "mfts_Okinawa_forc_male")

mfts_state_forc_total = c("mfts_Japan_forc_total",     "mfts_Hokkaido_forc_total",  "mfts_Aomori_forc_total",
                          "mfts_Iwate_forc_total",     "mfts_Miyagi_forc_total",    "mfts_Akita_forc_total",
                          "mfts_Yamagata_forc_total",  "mfts_Fukushima_forc_total", "mfts_Ibaraki_forc_total",
                          "mfts_Tochigi_forc_total",   "mfts_Gunma_forc_total",     "mfts_Saitama_forc_total",
                          "mfts_Chiba_forc_total",     "mfts_Tokyo_forc_total",     "mfts_Kanagawa_forc_total",
                          "mfts_Niigata_forc_total",   "mfts_Toyama_forc_total",    "mfts_Ishikawa_forc_total",
                          "mfts_Fukui_forc_total",     "mfts_Yamanashi_forc_total", "mfts_Nagano_forc_total",
                          "mfts_Gifu_forc_total",      "mfts_Shizuoka_forc_total",  "mfts_Aichi_forc_total",
                          "mfts_Mie_forc_total",       "mfts_Shiga_forc_total",     "mfts_Kyoto_forc_total",
                          "mfts_Osaka_forc_total",     "mfts_Hyogo_forc_total",     "mfts_Nara_forc_total",
                          "mfts_Wakayama_forc_total",  "mfts_Tottori_forc_total",   "mfts_Shimane_forc_total",
                          "mfts_Okayama_forc_total",   "mfts_Hiroshima_forc_total", "mfts_Yamaguchi_forc_total",
                          "mfts_Tokushima_forc_total", "mfts_Kagawa_forc_total",    "mfts_Ehime_forc_total",
                          "mfts_Kochi_forc_total",     "mfts_Fukuoka_forc_total",   "mfts_Saga_forc_total",
                          "mfts_Nagasaki_forc_total",  "mfts_Kumamoto_forc_total",  "mfts_Oita_forc_total",
                          "mfts_Miyazaki_forc_total",  "mfts_Kagoshima_forc_total", "mfts_Okinawa_forc_total")

mfts_state_me_female = c("mfts_Japan_me_female", "mfts_Hokkaido_me_female", "mfts_Aomori_me_female",
                         "mfts_Iwate_me_female", "mfts_Miyagi_me_female", "mfts_Akita_me_female",
                         "mfts_Yamagata_me_female", "mfts_Fukushima_me_female", "mfts_Ibaraki_me_female",
                         "mfts_Tochigi_me_female", "mfts_Gunma_me_female", "mfts_Saitama_me_female",
                         "mfts_Chiba_me_female", "mfts_Tokyo_me_female", "mfts_Kanagawa_me_female",
                         "mfts_Niigata_me_female", "mfts_Toyama_me_female", "mfts_Ishikawa_me_female",
                         "mfts_Fukui_me_female", "mfts_Yamanashi_me_female", "mfts_Nagano_me_female",
                         "mfts_Gifu_me_female", "mfts_Shizuoka_me_female", "mfts_Aichi_me_female",
                         "mfts_Mie_me_female", "mfts_Shiga_me_female", "mfts_Kyoto_me_female",
                         "mfts_Osaka_me_female", "mfts_Hyogo_me_female", "mfts_Nara_me_female",
                         "mfts_Wakayama_me_female", "mfts_Tottori_me_female", "mfts_Shimane_me_female",
                         "mfts_Okayama_me_female", "mfts_Hiroshima_me_female", "mfts_Yamaguchi_me_female",
                         "mfts_Tokushima_me_female", "mfts_Kagawa_me_female", "mfts_Ehime_me_female",
                         "mfts_Kochi_me_female", "mfts_Fukuoka_me_female", "mfts_Saga_me_female",
                         "mfts_Nagasaki_me_female", "mfts_Kumamoto_me_female", "mfts_Oita_me_female",
                         "mfts_Miyazaki_me_female", "mfts_Kagoshima_me_female", "mfts_Okinawa_me_female")

mfts_state_me_male = c("mfts_Japan_me_male", "mfts_Hokkaido_me_male", "mfts_Aomori_me_male",
                       "mfts_Iwate_me_male", "mfts_Miyagi_me_male", "mfts_Akita_me_male",
                       "mfts_Yamagata_me_male", "mfts_Fukushima_me_male", "mfts_Ibaraki_me_male",
                       "mfts_Tochigi_me_male", "mfts_Gunma_me_male", "mfts_Saitama_me_male",
                       "mfts_Chiba_me_male", "mfts_Tokyo_me_male", "mfts_Kanagawa_me_male",
                       "mfts_Niigata_me_male", "mfts_Toyama_me_male", "mfts_Ishikawa_me_male",
                       "mfts_Fukui_me_male", "mfts_Yamanashi_me_male", "mfts_Nagano_me_male",
                       "mfts_Gifu_me_male", "mfts_Shizuoka_me_male", "mfts_Aichi_me_male",
                       "mfts_Mie_me_male", "mfts_Shiga_me_male", "mfts_Kyoto_me_male",
                       "mfts_Osaka_me_male", "mfts_Hyogo_me_male", "mfts_Nara_me_male",
                       "mfts_Wakayama_me_male", "mfts_Tottori_me_male", "mfts_Shimane_me_male",
                       "mfts_Okayama_me_male", "mfts_Hiroshima_me_male", "mfts_Yamaguchi_me_male",
                       "mfts_Tokushima_me_male", "mfts_Kagawa_me_male", "mfts_Ehime_me_male",
                       "mfts_Kochi_me_male", "mfts_Fukuoka_me_male", "mfts_Saga_me_male",
                       "mfts_Nagasaki_me_male", "mfts_Kumamoto_me_male", "mfts_Oita_me_male",
                       "mfts_Miyazaki_me_male", "mfts_Kagoshima_me_male", "mfts_Okinawa_me_male")

mfts_state_me_total = c("mfts_Japan_me_total", "mfts_Hokkaido_me_total", "mfts_Aomori_me_total",
                        "mfts_Iwate_me_total", "mfts_Miyagi_me_total", "mfts_Akita_me_total",
                        "mfts_Yamagata_me_total", "mfts_Fukushima_me_total", "mfts_Ibaraki_me_total",
                        "mfts_Tochigi_me_total", "mfts_Gunma_me_total", "mfts_Saitama_me_total",
                        "mfts_Chiba_me_total", "mfts_Tokyo_me_total", "mfts_Kanagawa_me_total",
                        "mfts_Niigata_me_total", "mfts_Toyama_me_total", "mfts_Ishikawa_me_total",
                        "mfts_Fukui_me_total", "mfts_Yamanashi_me_total", "mfts_Nagano_me_total",
                        "mfts_Gifu_me_total", "mfts_Shizuoka_me_total", "mfts_Aichi_me_total",
                        "mfts_Mie_me_total", "mfts_Shiga_me_total", "mfts_Kyoto_me_total",
                        "mfts_Osaka_me_total", "mfts_Hyogo_me_total", "mfts_Nara_me_total",
                        "mfts_Wakayama_me_total", "mfts_Tottori_me_total", "mfts_Shimane_me_total",
                        "mfts_Okayama_me_total", "mfts_Hiroshima_me_total", "mfts_Yamaguchi_me_total",
                        "mfts_Tokushima_me_total", "mfts_Kagawa_me_total", "mfts_Ehime_me_total",
                        "mfts_Kochi_me_total", "mfts_Fukuoka_me_total", "mfts_Saga_me_total",
                        "mfts_Nagasaki_me_total", "mfts_Kumamoto_me_total", "mfts_Oita_me_total",
                        "mfts_Miyazaki_me_total", "mfts_Kagoshima_me_total", "mfts_Okinawa_me_total")

mfts_state_rmse_female = c("mfts_Japan_rmse_female", "mfts_Hokkaido_rmse_female", "mfts_Aomori_rmse_female",
                           "mfts_Iwate_rmse_female", "mfts_Miyagi_rmse_female", "mfts_Akita_rmse_female",
                           "mfts_Yamagata_rmse_female", "mfts_Fukushima_rmse_female", "mfts_Ibaraki_rmse_female",
                           "mfts_Tochigi_rmse_female", "mfts_Gunma_rmse_female", "mfts_Saitama_rmse_female",
                           "mfts_Chiba_rmse_female", "mfts_Tokyo_rmse_female", "mfts_Kanagawa_rmse_female",
                           "mfts_Niigata_rmse_female", "mfts_Toyama_rmse_female", "mfts_Ishikawa_rmse_female",
                           "mfts_Fukui_rmse_female", "mfts_Yamanashi_rmse_female", "mfts_Nagano_rmse_female",
                           "mfts_Gifu_rmse_female", "mfts_Shizuoka_rmse_female", "mfts_Aichi_rmse_female",
                           "mfts_Mie_rmse_female", "mfts_Shiga_rmse_female", "mfts_Kyoto_rmse_female",
                           "mfts_Osaka_rmse_female", "mfts_Hyogo_rmse_female", "mfts_Nara_rmse_female",
                           "mfts_Wakayama_rmse_female", "mfts_Tottori_rmse_female", "mfts_Shimane_rmse_female",
                           "mfts_Okayama_rmse_female", "mfts_Hiroshima_rmse_female", "mfts_Yamaguchi_rmse_female",
                           "mfts_Tokushima_rmse_female", "mfts_Kagawa_rmse_female", "mfts_Ehime_rmse_female",
                           "mfts_Kochi_rmse_female", "mfts_Fukuoka_rmse_female", "mfts_Saga_rmse_female",
                           "mfts_Nagasaki_rmse_female", "mfts_Kumamoto_rmse_female", "mfts_Oita_rmse_female",
                           "mfts_Miyazaki_rmse_female", "mfts_Kagoshima_rmse_female", "mfts_Okinawa_rmse_female")

mfts_state_rmse_male = c("mfts_Japan_rmse_male", "mfts_Hokkaido_rmse_male", "mfts_Aomori_rmse_male",
                         "mfts_Iwate_rmse_male", "mfts_Miyagi_rmse_male", "mfts_Akita_rmse_male",
                         "mfts_Yamagata_rmse_male", "mfts_Fukushima_rmse_male", "mfts_Ibaraki_rmse_male",
                         "mfts_Tochigi_rmse_male", "mfts_Gunma_rmse_male", "mfts_Saitama_rmse_male",
                         "mfts_Chiba_rmse_male", "mfts_Tokyo_rmse_male", "mfts_Kanagawa_rmse_male",
                         "mfts_Niigata_rmse_male", "mfts_Toyama_rmse_male", "mfts_Ishikawa_rmse_male",
                         "mfts_Fukui_rmse_male", "mfts_Yamanashi_rmse_male", "mfts_Nagano_rmse_male",
                         "mfts_Gifu_rmse_male", "mfts_Shizuoka_rmse_male", "mfts_Aichi_rmse_male",
                         "mfts_Mie_rmse_male", "mfts_Shiga_rmse_male", "mfts_Kyoto_rmse_male",
                         "mfts_Osaka_rmse_male", "mfts_Hyogo_rmse_male", "mfts_Nara_rmse_male",
                         "mfts_Wakayama_rmse_male", "mfts_Tottori_rmse_male", "mfts_Shimane_rmse_male",
                         "mfts_Okayama_rmse_male", "mfts_Hiroshima_rmse_male", "mfts_Yamaguchi_rmse_male",
                         "mfts_Tokushima_rmse_male", "mfts_Kagawa_rmse_male", "mfts_Ehime_rmse_male",
                         "mfts_Kochi_rmse_male", "mfts_Fukuoka_rmse_male", "mfts_Saga_rmse_male",
                         "mfts_Nagasaki_rmse_male", "mfts_Kumamoto_rmse_male", "mfts_Oita_rmse_male",
                         "mfts_Miyazaki_rmse_male", "mfts_Kagoshima_rmse_male", "mfts_Okinawa_rmse_male")

mfts_state_rmse_total = c("mfts_Japan_rmse_total", "mfts_Hokkaido_rmse_total", "mfts_Aomori_rmse_total",
                          "mfts_Iwate_rmse_total", "mfts_Miyagi_rmse_total", "mfts_Akita_rmse_total",
                          "mfts_Yamagata_rmse_total", "mfts_Fukushima_rmse_total", "mfts_Ibaraki_rmse_total",
                          "mfts_Tochigi_rmse_total", "mfts_Gunma_rmse_total", "mfts_Saitama_rmse_total",
                          "mfts_Chiba_rmse_total", "mfts_Tokyo_rmse_total", "mfts_Kanagawa_rmse_total",
                          "mfts_Niigata_rmse_total", "mfts_Toyama_rmse_total", "mfts_Ishikawa_rmse_total",
                          "mfts_Fukui_rmse_total", "mfts_Yamanashi_rmse_total", "mfts_Nagano_rmse_total",
                          "mfts_Gifu_rmse_total", "mfts_Shizuoka_rmse_total", "mfts_Aichi_rmse_total",
                          "mfts_Mie_rmse_total", "mfts_Shiga_rmse_total", "mfts_Kyoto_rmse_total",
                          "mfts_Osaka_rmse_total", "mfts_Hyogo_rmse_total", "mfts_Nara_rmse_total",
                          "mfts_Wakayama_rmse_total", "mfts_Tottori_rmse_total", "mfts_Shimane_rmse_total",
                          "mfts_Okayama_rmse_total", "mfts_Hiroshima_rmse_total", "mfts_Yamaguchi_rmse_total",
                          "mfts_Tokushima_rmse_total", "mfts_Kagawa_rmse_total", "mfts_Ehime_rmse_total",
                          "mfts_Kochi_rmse_total", "mfts_Fukuoka_rmse_total", "mfts_Saga_rmse_total",
                          "mfts_Nagasaki_rmse_total", "mfts_Kumamoto_rmse_total", "mfts_Oita_rmse_total",
                          "mfts_Miyazaki_rmse_total", "mfts_Kagoshima_rmse_total", "mfts_Okinawa_rmse_total")

mfts_state_mae_female = c("mfts_Japan_mae_female", "mfts_Hokkaido_mae_female", "mfts_Aomori_mae_female",
                          "mfts_Iwate_mae_female", "mfts_Miyagi_mae_female", "mfts_Akita_mae_female",
                          "mfts_Yamagata_mae_female", "mfts_Fukushima_mae_female", "mfts_Ibaraki_mae_female",
                          "mfts_Tochigi_mae_female", "mfts_Gunma_mae_female", "mfts_Saitama_mae_female",
                          "mfts_Chiba_mae_female", "mfts_Tokyo_mae_female", "mfts_Kanagawa_mae_female",
                          "mfts_Niigata_mae_female", "mfts_Toyama_mae_female", "mfts_Ishikawa_mae_female",
                          "mfts_Fukui_mae_female", "mfts_Yamanashi_mae_female", "mfts_Nagano_mae_female",
                          "mfts_Gifu_mae_female", "mfts_Shizuoka_mae_female", "mfts_Aichi_mae_female",
                          "mfts_Mie_mae_female", "mfts_Shiga_mae_female", "mfts_Kyoto_mae_female",
                          "mfts_Osaka_mae_female", "mfts_Hyogo_mae_female", "mfts_Nara_mae_female",
                          "mfts_Wakayama_mae_female", "mfts_Tottori_mae_female", "mfts_Shimane_mae_female",
                          "mfts_Okayama_mae_female", "mfts_Hiroshima_mae_female", "mfts_Yamaguchi_mae_female",
                          "mfts_Tokushima_mae_female", "mfts_Kagawa_mae_female", "mfts_Ehime_mae_female",
                          "mfts_Kochi_mae_female", "mfts_Fukuoka_mae_female", "mfts_Saga_mae_female",
                          "mfts_Nagasaki_mae_female", "mfts_Kumamoto_mae_female", "mfts_Oita_mae_female",
                          "mfts_Miyazaki_mae_female", "mfts_Kagoshima_mae_female", "mfts_Okinawa_mae_female")

mfts_state_mae_male = c("mfts_Japan_mae_male", "mfts_Hokkaido_mae_male", "mfts_Aomori_mae_male",
                        "mfts_Iwate_mae_male", "mfts_Miyagi_mae_male", "mfts_Akita_mae_male",
                        "mfts_Yamagata_mae_male", "mfts_Fukushima_mae_male", "mfts_Ibaraki_mae_male",
                        "mfts_Tochigi_mae_male", "mfts_Gunma_mae_male", "mfts_Saitama_mae_male",
                        "mfts_Chiba_mae_male", "mfts_Tokyo_mae_male", "mfts_Kanagawa_mae_male",
                        "mfts_Niigata_mae_male", "mfts_Toyama_mae_male", "mfts_Ishikawa_mae_male",
                        "mfts_Fukui_mae_male", "mfts_Yamanashi_mae_male", "mfts_Nagano_mae_male",
                        "mfts_Gifu_mae_male", "mfts_Shizuoka_mae_male", "mfts_Aichi_mae_male",
                        "mfts_Mie_mae_male", "mfts_Shiga_mae_male", "mfts_Kyoto_mae_male",
                        "mfts_Osaka_mae_male", "mfts_Hyogo_mae_male", "mfts_Nara_mae_male",
                        "mfts_Wakayama_mae_male", "mfts_Tottori_mae_male", "mfts_Shimane_mae_male",
                        "mfts_Okayama_mae_male", "mfts_Hiroshima_mae_male", "mfts_Yamaguchi_mae_male",
                        "mfts_Tokushima_mae_male", "mfts_Kagawa_mae_male", "mfts_Ehime_mae_male",
                        "mfts_Kochi_mae_male", "mfts_Fukuoka_mae_male", "mfts_Saga_mae_male",
                        "mfts_Nagasaki_mae_male", "mfts_Kumamoto_mae_male", "mfts_Oita_mae_male",
                        "mfts_Miyazaki_mae_male", "mfts_Kagoshima_mae_male", "mfts_Okinawa_mae_male")

mfts_state_mae_total = c("mfts_Japan_mae_total", "mfts_Hokkaido_mae_total", "mfts_Aomori_mae_total",
                         "mfts_Iwate_mae_total", "mfts_Miyagi_mae_total", "mfts_Akita_mae_total",
                         "mfts_Yamagata_mae_total", "mfts_Fukushima_mae_total", "mfts_Ibaraki_mae_total",
                         "mfts_Tochigi_mae_total", "mfts_Gunma_mae_total", "mfts_Saitama_mae_total",
                         "mfts_Chiba_mae_total", "mfts_Tokyo_mae_total", "mfts_Kanagawa_mae_total",
                         "mfts_Niigata_mae_total", "mfts_Toyama_mae_total", "mfts_Ishikawa_mae_total",
                         "mfts_Fukui_mae_total", "mfts_Yamanashi_mae_total", "mfts_Nagano_mae_total",
                         "mfts_Gifu_mae_total", "mfts_Shizuoka_mae_total", "mfts_Aichi_mae_total",
                         "mfts_Mie_mae_total", "mfts_Shiga_mae_total", "mfts_Kyoto_mae_total",
                         "mfts_Osaka_mae_total", "mfts_Hyogo_mae_total", "mfts_Nara_mae_total",
                         "mfts_Wakayama_mae_total", "mfts_Tottori_mae_total", "mfts_Shimane_mae_total",
                         "mfts_Okayama_mae_total", "mfts_Hiroshima_mae_total", "mfts_Yamaguchi_mae_total",
                         "mfts_Tokushima_mae_total", "mfts_Kagawa_mae_total", "mfts_Ehime_mae_total",
                         "mfts_Kochi_mae_total", "mfts_Fukuoka_mae_total", "mfts_Saga_mae_total",
                         "mfts_Nagasaki_mae_total", "mfts_Kumamoto_mae_total", "mfts_Oita_mae_total",
                         "mfts_Miyazaki_mae_total", "mfts_Kagoshima_mae_total", "mfts_Okinawa_mae_total")

# regions

mfts_region_forc_female = c("mfts_region_R1_forc_female", "mfts_region_R2_forc_female", "mfts_region_R3_forc_female",
                            "mfts_region_R4_forc_female", "mfts_region_R5_forc_female", "mfts_region_R6_forc_female",
                            "mfts_region_R7_forc_female", "mfts_region_R8_forc_female")

mfts_region_forc_male = c("mfts_region_R1_forc_male", "mfts_region_R2_forc_male", "mfts_region_R3_forc_male",
                          "mfts_region_R4_forc_male", "mfts_region_R5_forc_male", "mfts_region_R6_forc_male",
                          "mfts_region_R7_forc_male", "mfts_region_R8_forc_male")

mfts_region_forc_total = c("mfts_region_R1_forc_total", "mfts_region_R2_forc_total", "mfts_region_R3_forc_total",
                           "mfts_region_R4_forc_total", "mfts_region_R5_forc_total", "mfts_region_R6_forc_total",
                           "mfts_region_R7_forc_total", "mfts_region_R8_forc_total")

mfts_region_me_female = c("mfts_region_R1_me_female", "mfts_region_R2_me_female", "mfts_region_R3_me_female",
                          "mfts_region_R4_me_female", "mfts_region_R5_me_female", "mfts_region_R6_me_female",
                          "mfts_region_R7_me_female", "mfts_region_R8_me_female")

mfts_region_me_male = c("mfts_region_R1_me_male", "mfts_region_R2_me_male", "mfts_region_R3_me_male",
                        "mfts_region_R4_me_male", "mfts_region_R5_me_male", "mfts_region_R6_me_male",
                        "mfts_region_R7_me_male", "mfts_region_R8_me_male")

mfts_region_me_total = c("mfts_region_R1_me_total", "mfts_region_R2_me_total", "mfts_region_R3_me_total",
                         "mfts_region_R4_me_total", "mfts_region_R5_me_total", "mfts_region_R6_me_total",
                         "mfts_region_R7_me_total", "mfts_region_R8_me_total")

mfts_region_rmse_female = c("mfts_region_R1_rmse_female", "mfts_region_R2_rmse_female", "mfts_region_R3_rmse_female",
                            "mfts_region_R4_rmse_female", "mfts_region_R5_rmse_female", "mfts_region_R6_rmse_female",
                            "mfts_region_R7_rmse_female", "mfts_region_R8_rmse_female")

mfts_region_rmse_male = c("mfts_region_R1_rmse_male", "mfts_region_R2_rmse_male", "mfts_region_R3_rmse_male",
                          "mfts_region_R4_rmse_male", "mfts_region_R5_rmse_male", "mfts_region_R6_rmse_male",
                          "mfts_region_R7_rmse_male", "mfts_region_R8_rmse_male")

mfts_region_rmse_total = c("mfts_region_R1_rmse_total", "mfts_region_R2_rmse_total", "mfts_region_R3_rmse_total",
                           "mfts_region_R4_rmse_total", "mfts_region_R5_rmse_total", "mfts_region_R6_rmse_total",
                           "mfts_region_R7_rmse_total", "mfts_region_R8_rmse_total")

mfts_region_mae_female = c("mfts_region_R1_mae_female", "mfts_region_R2_mae_female", "mfts_region_R3_mae_female",
                           "mfts_region_R4_mae_female", "mfts_region_R5_mae_female", "mfts_region_R6_mae_female",
                           "mfts_region_R7_mae_female", "mfts_region_R8_mae_female")

mfts_region_mae_male = c("mfts_region_R1_mae_male", "mfts_region_R2_mae_male", "mfts_region_R3_mae_male",
                         "mfts_region_R4_mae_male", "mfts_region_R5_mae_male", "mfts_region_R6_mae_male",
                         "mfts_region_R7_mae_male", "mfts_region_R8_mae_male")

mfts_region_mae_total = c("mfts_region_R1_mae_total", "mfts_region_R2_mae_total", "mfts_region_R3_mae_total",
                          "mfts_region_R4_mae_total", "mfts_region_R5_mae_total", "mfts_region_R6_mae_total",
                          "mfts_region_R7_mae_total", "mfts_region_R8_mae_total")

# multivariate functional time series model

mfts <- function(dat, year_horizon, variation_prop)
{
    n = length(names(dat$rate))
    # if the data contains female, male and total, then we consider only female and male
    if(n == 3)
    {
       n_pop = 2
    }
    else
    {
        n_pop = n
    }
    log_object = rowmeans_object = sd_object = decenter_object = list()
    for(ik in 1:n_pop)
    {
        log_object[[ik]] = log(dat$rate[[ik]])
        # compute mean and standard deviation functions
        rowmeans_object[[ik]] = rowMeans(log(dat$rate[[ik]]), na.rm=TRUE)
        sd_object[[ik]] = apply(log(dat$rate[[ik]]), 1, sd, na.rm=TRUE)
    
        # de-center functional data
        decenter_object[[ik]] = t(scale(t(log(dat$rate[[ik]])), center = TRUE, scale = TRUE))
    }
    comb_object = do.call(rbind, decenter_object)
    ncomp_comb = head(which(cumsum(ftsm(fts(1:nrow(comb_object), comb_object), order = 20)$varprop) >= variation_prop), 1)
    fore_ftsm = forecast(ftsm(fts(1:nrow(comb_object), comb_object), order = ncomp_comb), h = year_horizon)
    fore_res = exp(fore_ftsm$mean$y * do.call(c,sd_object) + do.call(c, rowmeans_object))
    return(fore_res)
}


#######################################
# Forecast mortality rates (8 regions)
#######################################

mfts_back_test_region <- function(iw, fmethod = "classical", year_horizon, prop_var)
{
    forecast_year = (year_horizon + 1)
    n_year = tail(get(region_smooth[1])$year,1) - forecast_year
  
    res_male = res_female = array(NA, dim = c(year_horizon, length(get(region_smooth[1])$age), year_horizon))
    for(ij in 1:year_horizon)
    {
        ind_dat = extract.years(get(region_smooth[iw]), years = 1975:(n_year+ij))
        fun_forc = mfts(ind_dat, year_horizon = year_horizon, variation_prop = prop_var)
    
        res_female[,,ij] = t(fun_forc[1:length(get(region_smooth[1])$age),])
        res_male[,,ij]   = t(fun_forc[(length(get(region_smooth[1])$age)+1):(2*length(get(region_smooth[1])$age)),])
    }
  
    # error measures
    female_me = male_me = female_rmse = male_rmse = female_mae = male_mae = vector("numeric", year_horizon)
    for(ik in 1:year_horizon)
    {
        female_me[ik] = me(res_female[ik,,1:(forecast_year-ik)], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        male_me[ik]   = me(res_male[ik,,1:(forecast_year-ik)],   extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
    
        female_mae[ik] = mae(res_female[ik,,1:(forecast_year-ik)], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        male_mae[ik]   = mae(res_male[ik,,1:(forecast_year-ik)],   extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
    
        female_rmse[ik] = rmse(res_female[ik,,1:(forecast_year-ik)], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        male_rmse[ik]   = rmse(res_male[ik,,1:(forecast_year-ik)],   extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
    }
    return(list(res_female = res_female, res_male = res_male,
                female_me = female_me, male_me = male_me,
                female_mae = female_mae, male_mae = male_mae,
                female_rmse = female_rmse, male_rmse = male_rmse))
}

for(ik in 1:8)
{
    dum = mfts_back_test_region(iw = ik, year_horizon = 15, prop_var = 0.9)
  
    assign(mfts_region_forc_female[ik], dum$res_female)
    assign(mfts_region_forc_male[ik],   dum$res_male)
  
    assign(mfts_region_me_female[ik], dum$female_me)
    assign(mfts_region_me_male[ik],   dum$male_me)
  
    assign(mfts_region_mae_female[ik], dum$female_mae)
    assign(mfts_region_mae_male[ik],   dum$male_mae)
  
    assign(mfts_region_rmse_female[ik], dum$female_rmse)
    assign(mfts_region_rmse_male[ik],   dum$male_rmse)
    print(ik)
    rm(dum)
}

##############################
# Forecasts at 47 prefectures
##############################

mfts_back_test <- function(iw, fmethod = "classical", year_horizon, prop_var)
{
    forecast_year = (year_horizon + 1)
    n_year = tail(get(state_smooth[1])$year,1) - forecast_year
    res_male = res_female = array(NA, dim = c(year_horizon, length(get(state_smooth[1])$age), year_horizon))
    for(ij in 1:year_horizon)
    {
        ind_dat = extract.years(get(state_smooth[iw]), years = 1975:(n_year+ij))
        fun_forc = mfts(ind_dat, year_horizon = year_horizon, variation_prop = prop_var)
    
        res_female[,,ij] = t(fun_forc[1:length(get(state_smooth[1])$age),])
        res_male[,,ij]   = t(fun_forc[(length(get(state_smooth[1])$age)+1):(2*length(get(state_smooth[1])$age)),])
    }
    # ME & MAE & RMSE
    female_me = male_me = female_rmse = male_rmse = female_mae = male_mae  = vector("numeric", year_horizon)
    for(ik in 1:year_horizon)
    {
        # me
        female_me[ik] = me(res_female[ik,,1:(forecast_year-ik)], extract.years(get(state[iw]), years = (2001+ik):2016)$rate$female)
        male_me[ik]   = me(res_male[ik,,1:(forecast_year-ik)],   extract.years(get(state[iw]), years = (2001+ik):2016)$rate$male)
    
        # mae
        female_mae[ik] = mae(res_female[ik,,1:(forecast_year-ik)], extract.years(get(state[iw]), years = (2001+ik):2016)$rate$female)
        male_mae[ik]   = mae(res_male[ik,,1:(forecast_year-ik)],   extract.years(get(state[iw]), years = (2001+ik):2016)$rate$male)
    
        # rmse
        female_rmse[ik] = rmse(res_female[ik,,1:(forecast_year-ik)], extract.years(get(state[iw]), years = (2001+ik):2016)$rate$female)
        male_rmse[ik]   = rmse(res_male[ik,,1:(forecast_year-ik)],   extract.years(get(state[iw]), years = (2001+ik):2016)$rate$male)
    }
    return(list(res_female = res_female, res_male = res_male,
                female_me = female_me, male_me = male_me,
                female_mae = female_mae, male_mae = male_mae,
                female_rmse = female_rmse, male_rmse = male_rmse))
}

# mortality rate

for(ik in 1:48)
{
    dum = mfts_back_test(iw = ik, fmethod = "classical", year_horizon = 15, prop_var = 0.9)
    
    assign(mfts_state_forc_female[ik], dum$res_female)
    assign(mfts_state_forc_male[ik],   dum$res_male)
    
    assign(mfts_state_me_female[ik], dum$female_me)
    assign(mfts_state_me_male[ik],   dum$male_me)
    
    assign(mfts_state_mae_female[ik], dum$female_mae)
    assign(mfts_state_mae_male[ik],   dum$male_mae)
    
    assign(mfts_state_rmse_female[ik], dum$female_rmse)
    assign(mfts_state_rmse_male[ik],   dum$male_rmse)
  
    print(ik)
    rm(dum)
}


##########################################
# Forecast mortality rates (Total region)
##########################################

coherent_back_test_region_total = function(fmethod = "classical", year_horizon, prop_var)
{
    forecast_year = (year_horizon + 1)
    n_year = tail(get(region_smooth[1])$year,1) - forecast_year
    total_region_comb = total_region_comb_pop = matrix(NA, length(get(region_smooth[1])$age) * length(get(region_smooth[1])$year), 8)
    for(iw in 1:8)
    {
        total_region_comb[,iw] = as.numeric(get(region_smooth[iw])$rate$total)
        total_region_comb_pop[,iw] = as.numeric(get(region_smooth[iw])$pop$total)
    }
    total_region_comb_v2 = cbind(rep(get(region_smooth[1])$year, each = length(get(state_smooth[1])$age)),
                                 rep(0:(length(get(region_smooth[1])$age)-1), length(get(region_smooth[1])$year)),
                                 total_region_comb)
    total_region_comb_pop_v2 = cbind(rep(get(region_smooth[1])$year, each = length(get(state_smooth[1])$age)),
                                     rep(0:(length(get(region_smooth[1])$age)-1), length(get(region_smooth[1])$year)),
                                     total_region_comb_pop)
    colnames(total_region_comb_v2) = colnames(total_region_comb_pop_v2) = c("Year", "Age", region)
  
    write.table(total_region_comb_v2, file = "total_region_comb.txt", quote = FALSE, row.names = TRUE,
                col.names = TRUE)
    write.table(total_region_comb_pop_v2, file = "total_region_comb_pop.txt", quote = FALSE, row.names = TRUE,
                col.names = TRUE)
  
    total_region_comb_demogdata = read.demogdata("total_region_comb.txt", "total_region_comb_pop.txt",
                                                 type = "mortality", label = "total_region_comb", skip = 0)
  
    res_region = array(NA, dim = c(year_horizon, length(get(state_smooth[1])$age), year_horizon, 8))
    for(ij in 1:year_horizon)
    {
        ind_dat = extract.years(total_region_comb_demogdata, years = 1975:(n_year+ij))
        fun_forc = mfts(ind_dat, year_horizon = year_horizon, variation_prop = prop_var)
    
        for(iwk in 1:8)
        {
            res_region[,,ij,iwk] = t(fun_forc[(length(get(state_smooth[1])$age)*(iwk-1)+1):(length(get(state_smooth[1])$age)*iwk),])
        }
    }
    # error measures
    total_region_me = total_region_rmse = total_region_mae = matrix(NA, year_horizon, 8)
    for(iw in 1:8)
    {
        for(ik in 1:year_horizon)
        {
            total_region_me[ik,iw] = me(res_region[ik,,1:(forecast_year-ik),iw], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
            total_region_mae[ik,iw] = mae(res_region[ik,,1:(forecast_year-ik),iw], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
            total_region_rmse[ik,iw] = rmse(res_region[ik,,1:(forecast_year-ik),iw], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        }
    }
    return(list(res_region = res_region, total_region_me = total_region_me,
              total_region_mae = total_region_mae,
              total_region_rmse = total_region_rmse))
}

# mortality rate

dum_region = coherent_back_test_region_total(year_horizon = 15, prop_var = 0.9)
mfts_region_me_total = dum_region$total_region_me
mfts_region_mae_total = dum_region$total_region_mae
mfts_region_rmse_total = dum_region$total_region_rmse
colnames(mfts_region_me_total) = colnames(mfts_region_mae_total) = colnames(mfts_region_rmse_total) = region

for(ik in 1:8)
{
    assign(mfts_region_forc_total[ik], dum_region$res_region[,,,ik])
}
rm(dum_region)


#################################################
# Forecasting mortality rates (Total prefecture)
#################################################

coherent_back_test_total <- function(fmethod = "classical", year_horizon, prop_var)
{
    forecast_year = (year_horizon + 1)
    n_year = tail(get(region_smooth[1])$year,1) - forecast_year
  
    total_comb = total_comb_pop =  matrix(NA, length(get(region_smooth[1])$age) * length(get(region_smooth[1])$year), 47)
    for(iw in 2:48)
    {
        total_comb[,iw-1] = as.numeric(get(state_smooth[iw])$rate$total)
        total_comb_pop[,iw-1] = as.numeric(get(state_smooth[iw])$pop$total)
    }
    total_comb_v2 = cbind(rep(1975:2016, each=length(get(region_smooth[1])$age)),
                          rep(0:(length(get(region_smooth[1])$age)-1), length(get(region_smooth[1])$year)),
                          total_comb)
    total_comb_pop_v2 = cbind(rep(1975:2016, each=length(get(region_smooth[1])$age)),
                              rep(0:(length(get(region_smooth[1])$age)-1), length(get(region_smooth[1])$year)),
                              total_comb_pop)
    colnames(total_comb_v2) = colnames(total_comb_pop_v2) = c("Year", "Age", state[2:48])
  
    write.table(total_comb_v2, file = "total_comb.txt", quote = FALSE, row.names = TRUE, col.names=TRUE)
    write.table(total_comb_pop_v2, file = "total_comb_pop.txt", quote = FALSE, row.names = TRUE, col.names=TRUE)
  
    total_comb_demogdata = read.demogdata("total_comb.txt", "total_comb_pop.txt",
                                          type = "mortality", label="total_comb", skip = 0)
  
    res_prefecture = array(NA, dim = c(year_horizon, length(get(region_smooth[1])$age), year_horizon, 47))
    for(ij in 1:year_horizon)
    {
        ind_dat = extract.years(total_comb_demogdata, years = 1975:(n_year+ij))
        fun_forc = mfts(ind_dat, year_horizon = year_horizon, variation_prop = prop_var)
    
        for(iwk in 1:47)
        {
            res_prefecture[,,ij,iwk] = t(fun_forc[(length(get(region_smooth[1])$age)*(iwk-1)+1):(length(get(region_smooth[1])$age)*iwk),])
        }
    }
  
    # ME & MAE & RMSE
    total_prefecture_me = total_prefecture_rmse = total_prefecture_mae = matrix(NA, year_horizon, 47)
    for(iw in 1:47)
    {
        for(ik in 1:year_horizon)
        {
            # me
            total_prefecture_me[ik,iw] = me(res_prefecture[ik,,1:(forecast_year-ik),iw], extract.years(get(state[iw+1]), years = (2001+ik):2016)$rate$total)
      
            # mae
            total_prefecture_mae[ik,iw] = mae(res_prefecture[ik,,1:(forecast_year-ik),iw], extract.years(get(state[iw+1]), years = (2001+ik):2016)$rate$total)
      
            # rmse
            total_prefecture_rmse[ik,iw] = rmse(res_prefecture[ik,,1:(forecast_year-ik),iw], extract.years(get(state[iw+1]), years = (2001+ik):2016)$rate$total)
        }
    }
    return(list(res_prefecture = res_prefecture, total_prefecture_me = total_prefecture_me,
              total_prefecture_mae = total_prefecture_mae,
              total_prefecture_rmse = total_prefecture_rmse))
}

dum_state = coherent_back_test_total(year_horizon = 15, prop_var = 0.9)
mfts_state_me_total = dum_state$total_prefecture_me
mfts_state_mae_total = dum_state$total_prefecture_mae
mfts_state_rmse_total = dum_state$total_prefecture_rmse
colnames(mfts_state_me_total) = colnames(mfts_state_mae_total) = colnames(mfts_state_rmse_total) = state[2:48]

for(ik in 1:47)
{
    assign(mfts_state_forc_total[ik+1], dum_state$res_prefecture[,,,ik])
}
rm(dum_state)

# independent for Japan total

ind_back_test <- function(iw, fmethod = "classical", year_horizon, variation_prop)
{
    forecast_year = (year_horizon + 1)
    n_year = tail(get(state_smooth[1])$year,1) - forecast_year
    
    res_male  = res_female = res_total = array(NA, dim = c(year_horizon, length(get(state_smooth[1])$age), year_horizon))
    for(j in 1:year_horizon)
    {
        ind_dat = extract.years(get(state_smooth[iw]), years = 1975:(n_year+j))
      
        # select the number of components
        ncomp_total  = head(which(cumsum(fdm(ind_dat, series = "total", order = 10, method = fmethod)$varprop) >= variation_prop), 1)
        ncomp_female = head(which(cumsum(fdm(ind_dat, series = "female", order = 10, method = fmethod)$varprop) >= variation_prop), 1)
        ncomp_male   = head(which(cumsum(fdm(ind_dat, series = "male", order = 10, method = fmethod)$varprop) >= variation_prop), 1)
      
        fun_forc_total  = forecast(fdm(ind_dat, series = "total", order = ncomp_total, method = fmethod), h = year_horizon)
        fun_forc_female = forecast(fdm(ind_dat, series = "female", order = ncomp_female, method = fmethod), h = year_horizon)
        fun_forc_male   = forecast(fdm(ind_dat, series = "male", order = ncomp_male, method = fmethod), h = year_horizon)
      
        res_female[,,j] = t(fun_forc_female$rate$female)
        res_male[,,j] = t(fun_forc_male$rate$male)
        res_total[,,j] = t(fun_forc_total$rate$total)
    }
    rm(ncomp_total); rm(ncomp_female); rm(ncomp_male)
    
    # MFE and RMSFE of mortality
    female_me = male_me = total_me =
    female_mae = male_mae = total_mae =
    female_rmse = male_rmse = total_rmse = vector("numeric",year_horizon)
    for(k in 1:year_horizon)
    {
        female_me[k]  = me(res_female[k,,1:(forecast_year-k)],  extract.years(get(state[iw]), years = (2001+k):2016)$rate$female)
        male_me[k]    = me(res_male[k,,1:(forecast_year-k)],  extract.years(get(state[iw]), years = (2001+k):2016)$rate$male)
        total_me[k]   = me(res_total[k,,1:(forecast_year-k)], extract.years(get(state[iw]), years = (2001+k):2016)$rate$total)
        
        female_mae[k]  = mae(res_female[k,,1:(forecast_year-k)],  extract.years(get(state[iw]), years = (2001+k):2016)$rate$female)
        male_mae[k]    = mae(res_male[k,,1:(forecast_year-k)],  extract.years(get(state[iw]), years = (2001+k):2016)$rate$male)
        total_mae[k]   = mae(res_total[k,,1:(forecast_year-k)], extract.years(get(state[iw]), years = (2001+k):2016)$rate$total)
        
        female_rmse[k]  = rmse(res_female[k,,1:(forecast_year-k)],  extract.years(get(state[iw]), years = (2001+k):2016)$rate$female)
        male_rmse[k]    = rmse(res_male[k,,1:(forecast_year-k)],  extract.years(get(state[iw]), years = (2001+k):2016)$rate$male)
        total_rmse[k]   = rmse(res_total[k,,1:(forecast_year-k)], extract.years(get(state[iw]), years = (2001+k):2016)$rate$total)
    }
    return(list(res_female = res_female, res_male = res_male, res_total = res_total,
                female_me = female_me, male_me = male_me, total_me = total_me,
                female_mae = female_mae, male_mae = male_mae, total_mae = total_mae,
                female_rmse = female_rmse, male_rmse = male_rmse, total_rmse = total_rmse))
}

dum = ind_back_test(iw = 1, year_horizon = 15, variation_prop = 0.9)
ind_Japan_forc_total = dum$res_total
ind_Japan_me_total = dum$total_me
ind_Japan_mae_total = dum$total_mae
ind_Japan_rmse_total = dum$total_rmse
rm(dum)

assign(mfts_state_forc_total[1], ind_Japan_forc_total)


#######################################
# summarize results of mortality rates
#######################################

## region & sex

# mortality rate

mfts_region_me_female_mean_overall  = mfts_region_me_male_mean_overall  =
mfts_region_mae_female_mean_overall  = mfts_region_mae_male_mean_overall  =
mfts_region_rmse_female_mean_overall = mfts_region_rmse_male_mean_overall = NULL
for(ik in 1:8)
{
    # me
    mfts_region_me_female_mean_overall = cbind(mfts_region_me_female_mean_overall, get(mfts_region_me_female[ik]))
    mfts_region_me_male_mean_overall   = cbind(mfts_region_me_male_mean_overall,   get(mfts_region_me_male[ik]))
  
    # mae
    mfts_region_mae_female_mean_overall = cbind(mfts_region_mae_female_mean_overall, get(mfts_region_mae_female[ik]))
    mfts_region_mae_male_mean_overall   = cbind(mfts_region_mae_male_mean_overall,   get(mfts_region_mae_male[ik]))
  
    # rmse
    mfts_region_rmse_female_mean_overall = cbind(mfts_region_rmse_female_mean_overall, get(mfts_region_rmse_female[ik]))
    mfts_region_rmse_male_mean_overall   = cbind(mfts_region_rmse_male_mean_overall,   get(mfts_region_rmse_male[ik]))
}

colnames(mfts_region_me_female_mean_overall)   = colnames(mfts_region_me_male_mean_overall)   =
colnames(mfts_region_mae_female_mean_overall)   = colnames(mfts_region_mae_male_mean_overall)   =
colnames(mfts_region_rmse_female_mean_overall) = colnames(mfts_region_rmse_male_mean_overall) = region


####################
## prefecture & sex
####################

# mortality rate

mfts_me_female_mean_overall = mfts_me_male_mean_overall =
mfts_mae_female_mean_overall = mfts_mae_male_mean_overall =
mfts_rmse_female_mean_overall = mfts_rmse_male_mean_overall = NULL
for(ik in 1:48)
{
    # me
    mfts_me_female_mean_overall  = cbind(mfts_me_female_mean_overall, get(mfts_state_me_female[ik]))
    mfts_me_male_mean_overall    = cbind(mfts_me_male_mean_overall,   get(mfts_state_me_male[ik]))
    
    # mae
    mfts_mae_female_mean_overall  = cbind(mfts_mae_female_mean_overall, get(mfts_state_mae_female[ik]))
    mfts_mae_male_mean_overall    = cbind(mfts_mae_male_mean_overall,   get(mfts_state_mae_male[ik]))
    
    # rmse
    mfts_rmse_female_mean_overall  = cbind(mfts_rmse_female_mean_overall, get(mfts_state_rmse_female[ik]))
    mfts_rmse_male_mean_overall    = cbind(mfts_rmse_male_mean_overall,   get(mfts_state_rmse_male[ik]))
}

## Averages

# mortality rate

rowmeans_mfts_me_female_mean_overall = apply(mfts_me_female_mean_overall[,2:48], 1, mean)
rowmeans_mfts_me_male_mean_overall   = apply(mfts_me_male_mean_overall[,2:48], 1, mean)
rowmeans_mfts_me_total_mean_overall  = apply(mfts_state_me_total, 1, mean)

rowmeans_mfts_mae_female_mean_overall = apply(mfts_mae_female_mean_overall[,2:48], 1, mean)
rowmeans_mfts_mae_male_mean_overall   = apply(mfts_mae_male_mean_overall[,2:48], 1, mean)
rowmeans_mfts_mae_total_mean_overall  = apply(mfts_state_mae_total, 1, mean)

rowmeans_mfts_rmse_female_mean_overall = apply(mfts_rmse_female_mean_overall[,2:48], 1, mean)
rowmeans_mfts_rmse_male_mean_overall   = apply(mfts_rmse_male_mean_overall[,2:48], 1, mean)
rowmeans_mfts_rmse_total_mean_overall  = apply(mfts_state_rmse_total, 1, mean)


####################
# summarise results
####################

## mortality rate

# me

mfts_me_total_mean_overall =  ind_Japan_me_total

mfts_all_level_err_me = cbind(mfts_me_total_mean_overall,
                              apply(cbind(mfts_me_female_mean_overall[,1], mfts_me_male_mean_overall[,1]), 1,mean),
                              apply(mfts_region_me_total, 1, mean),
                              apply(cbind(mfts_region_me_female_mean_overall, mfts_region_me_male_mean_overall),1,mean),
                              rowmeans_mfts_me_total_mean_overall,
                              apply(cbind(rowmeans_mfts_me_female_mean_overall, rowmeans_mfts_me_male_mean_overall),1,mean))

mfts_all_level_err_me_all = rbind(mfts_all_level_err_me, colMeans(mfts_all_level_err_me), apply(mfts_all_level_err_me, 2, median))

colnames(mfts_all_level_err_me_all) = c("Total", "Sex", "Region", "Region + Sex", "Prefecture", "Prefecture + Sex")
rownames(mfts_all_level_err_me_all) = c(1:15, "Mean", "Median")
  
# mae

mfts_mae_total_mean_overall = ind_Japan_mae_total

mfts_all_level_err_mae = cbind(mfts_mae_total_mean_overall,
                               apply(cbind(mfts_mae_female_mean_overall[,1], mfts_mae_male_mean_overall[,1]), 1,mean),
                               apply(mfts_region_mae_total, 1, mean),
                               apply(cbind(mfts_region_mae_female_mean_overall, mfts_region_mae_male_mean_overall),1,mean),
                               rowmeans_mfts_mae_total_mean_overall,
                               apply(cbind(rowmeans_mfts_mae_female_mean_overall, rowmeans_mfts_mae_male_mean_overall),1,mean))

mfts_all_level_err_mae_all = rbind(mfts_all_level_err_mae, colMeans(mfts_all_level_err_mae), apply(mfts_all_level_err_mae, 2, median))

colnames(mfts_all_level_err_mae_all) = c("Total", "Sex", "Region", "Region + Sex", "Prefecture", "Prefecture + Sex")
rownames(mfts_all_level_err_mae_all) = c(1:15, "Mean", "Median")

# rmse

mfts_rmse_total_mean_overall = ind_Japan_rmse_total

mfts_all_level_err_rmse = cbind(mfts_rmse_total_mean_overall,
                                apply(cbind(mfts_rmse_female_mean_overall[,1], mfts_rmse_male_mean_overall[,1]), 1,mean),
                                apply(mfts_region_rmse_total, 1, mean),
                                apply(cbind(mfts_region_rmse_female_mean_overall, mfts_region_rmse_male_mean_overall),1,mean),
                                rowmeans_mfts_rmse_total_mean_overall,
                                apply(cbind(rowmeans_mfts_rmse_female_mean_overall, rowmeans_mfts_rmse_male_mean_overall),1,mean))

mfts_all_level_err_rmse_all = rbind(mfts_all_level_err_rmse, colMeans(mfts_all_level_err_rmse), apply(mfts_all_level_err_rmse, 2, median))

colnames(mfts_all_level_err_rmse_all) = c("Total", "Sex", "Region", "Region + Sex", "Prefecture", "Prefecture + Sex")
rownames(mfts_all_level_err_rmse_all) = c(1:15, "Mean", "Median")

############################################################
# female_data_raw: Female age-specific exposure-to-risk
# male_data_raw: Male age-specific exposure-to-risk
# female_data_raw_rate: Female age-specific mortality rates
# male_data_raw_rate: Male age-specific mortality rates
# age: Age variable
# kj: forecast horizon
# hier_method: bottom-up or optimal combination method
############################################################

BU_optim_hier_for <- function(total_data_raw_rate_region, female_data_raw_rate_region,
                              male_data_raw_rate_region, female_data_raw_rate,
                              male_data_raw_rate, total_data_raw_rate,
                              age, kj, hier_method = c("BU", "OLS"))
{
    hier_method = match.arg(hier_method)
    
    hier_rate = matrix(NA, 168, (16-kj))
    # Level_0 (Total)
    hier_rate[1,] = get(total_data_raw_rate[1])[kj, age, 1:(16-kj)]
    # Level_1 (Sex)
    hier_rate[2,] = get(female_data_raw_rate[1])[kj, age, 1:(16-kj)]
    hier_rate[3,] = get(male_data_raw_rate[1])[kj, age, 1:(16-kj)]
    
    # Level_2 (Region + Total, Female, Male)
    for(iw in 1:8)
    {
        hier_rate[4:11,]  = get(total_data_raw_rate_region[iw])[kj, age, 1:(16-kj)]
        hier_rate[12:19,] = get(female_data_raw_rate_region[iw])[kj, age, 1:(16-kj)]
        hier_rate[20:27,] = get(male_data_raw_rate_region[iw])[kj, age, 1:(16-kj)]
    }
    
    # Level_3 (Prefecture + Total, Female, Male)
    for(iw in 2:48)
    {
        hier_rate[iw+26,] = get(total_data_raw_rate[iw])[kj, age, 1:(16-kj)]
        hier_rate[(2*iw+71),] = get(female_data_raw_rate[iw])[kj, age, 1:(16-kj)]
        hier_rate[(2*iw+72),] = get(male_data_raw_rate[iw])[kj, age, 1:(16-kj)]
    }
    
    # forecast via bottom-up or optimal combination
    hier_fore = matrix(NA, 168, (16-kj))
    summing_mat = Smat_fun(kj = kj, age = age)
    for(ik in 1:(16-kj))
    {
        hier = summing_mat[,,ik]
        if(hier_method == "BU")
        {
            hier_fore[,ik] = (hier %*% hier_rate[75:168,ik])
        }
        if(hier_method == "OLS")
        {
            hier_fore[,ik] = hier %*% ginv(t(hier) %*% hier) %*% t(hier) %*% hier_rate[,ik]
        }
    }
    return(hier_fore)
}


############################################################
# ik: forecast horizon
# fmethod: bottom-up or optimal combination
# female_data_raw: Female age-specific exposure-to-risk
# male_data_raw: Male age-specific exposure-to-risk
# female_data_raw_rate: Female age-specific mortality rates
# male_data_raw_rate: Male age-specific mortality rates
# total_data_raw_rate: Total age-specific mortality rates
############################################################

BU_optim_err <- function(ik, hier_method, total_data_raw_rate_region, female_data_raw_rate_region,
                         male_data_raw_rate_region, female_data_raw_rate, male_data_raw_rate, total_data_raw_rate)
{
    BU_optim_hier_comb = array(NA, dim = c(41, 168, (16-ik)))
    for(ik_age in 1:41)
    {
        BU_optim_hier_comb[ik_age,,] = BU_optim_hier_for(total_data_raw_rate_region, female_data_raw_rate_region,
                                                         male_data_raw_rate_region,  female_data_raw_rate,
                                                         male_data_raw_rate,         total_data_raw_rate,
                                                         age = ik_age, kj = ik, hier_method = hier_method)
    }
    
    ######
    # MAE
    ######
    
    # Level 0 (Total)
    me_total_err  = me(BU_optim_hier_comb[,1,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$total)
    mae_total_err  = mae(BU_optim_hier_comb[,1,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$total)
    rmse_total_err = rmse(BU_optim_hier_comb[,1,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$total)
    
    # Level 1 (Sex)
    me_female_err = me(BU_optim_hier_comb[,2,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$female)
    me_male_err   = me(BU_optim_hier_comb[,3,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$male)
    
    mae_female_err = mae(BU_optim_hier_comb[,2,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$female)
    mae_male_err   = mae(BU_optim_hier_comb[,3,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$male)
    
    rmse_female_err = rmse(BU_optim_hier_comb[,2,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$female)
    rmse_male_err   = rmse(BU_optim_hier_comb[,3,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$male)
    
    # Level 2 (Region + Total, Female and Male)
    me_total_R_err = me_female_R_err = me_male_R_err =
    mae_total_R_err = mae_female_R_err = mae_male_R_err =
    rmse_total_R_err = rmse_female_R_err = rmse_male_R_err = vector("numeric",8)
    for(iw in 1:8)
    {
        me_total_R_err[iw]  = me(BU_optim_hier_comb[,(iw+3),],  extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        me_female_R_err[iw] = me(BU_optim_hier_comb[,(iw+11),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        me_male_R_err[iw]   = me(BU_optim_hier_comb[,(iw+19),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
      
        mae_total_R_err[iw]  = mae(BU_optim_hier_comb[,(iw+3),],  extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        mae_female_R_err[iw] = mae(BU_optim_hier_comb[,(iw+11),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        mae_male_R_err[iw]   = mae(BU_optim_hier_comb[,(iw+19),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
        
        rmse_total_R_err[iw]  = rmse(BU_optim_hier_comb[,(iw+3),],  extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        rmse_female_R_err[iw] = rmse(BU_optim_hier_comb[,(iw+11),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        rmse_male_R_err[iw]   = rmse(BU_optim_hier_comb[,(iw+19),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
    }
    
    # Level 3 (Prefecture + Total)
    
    rmse_state_err = mae_state_err = me_state_err =
    bottom_female_rmse = bottom_female_mae = bottom_female_me =
    bottom_male_mae = bottom_male_rmse = bottom_male_me = vector("numeric",47)
    for(iwk in 2:48)
    {
        me_state_err[iwk-1]     = me(BU_optim_hier_comb[,(iwk+26),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$total)
        bottom_female_me[iwk-1] = me(BU_optim_hier_comb[,(71+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$female)
        bottom_male_me[iwk-1]   = me(BU_optim_hier_comb[,(72+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$male)
      
        mae_state_err[iwk-1]     = mae(BU_optim_hier_comb[,(iwk+26),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$total)
        bottom_female_mae[iwk-1] = mae(BU_optim_hier_comb[,(71+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$female)
        bottom_male_mae[iwk-1]   = mae(BU_optim_hier_comb[,(72+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$male)
        
        rmse_state_err[iwk-1]     = rmse(BU_optim_hier_comb[,(iwk+26),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$total)
        bottom_female_rmse[iwk-1] = rmse(BU_optim_hier_comb[,(71+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$female)
        bottom_male_rmse[iwk-1]   = rmse(BU_optim_hier_comb[,(72+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$male)
    }
    return(list(BU_optim_hier_comb = BU_optim_hier_comb,
                me_total_err = me_total_err, me_female_err = me_female_err, me_male_err = me_male_err,
                me_total_R_err = me_total_R_err, me_female_R_err = me_female_R_err, me_male_R_err = me_male_R_err,
                me_state_err = me_state_err, me_bottom_female_err = bottom_female_me, me_bottom_male_err = bottom_male_me,
                
                mae_total_err = mae_total_err, mae_female_err = mae_female_err, mae_male_err = mae_male_err,
                mae_total_R_err = mae_total_R_err, mae_female_R_err = mae_female_R_err, mae_male_R_err = mae_male_R_err,
                mae_state_err = mae_state_err, mae_bottom_female_err = bottom_female_mae, mae_bottom_male_err = bottom_male_mae,
                
                rmse_total_err = rmse_total_err, rmse_female_err = rmse_female_err, rmse_male_err = rmse_male_err,
                rmse_total_R_err = rmse_total_R_err, rmse_female_R_err = rmse_female_R_err, rmse_male_R_err = rmse_male_R_err,
                rmse_state_err = rmse_state_err, rmse_bottom_female_err = bottom_female_rmse, rmse_bottom_male_err = bottom_male_rmse))
}


###############################
# Point forecast errors (MAFE)
###############################

# fmethod = "BU"

BU_fore_ufts = list()
Level_0_err = Level_F_err = Level_M_err = matrix(NA,15,3)
Level_T_R_err = Level_F_R_err = Level_M_R_err = array(NA, dim = c(15,3,8))

Level_State_err = Level_State_F_err = Level_State_M_err = array(NA, dim = c(47,15,3))
for(ikw in 1:15)
{
    dum = BU_optim_err(ik = ikw, hier_method = "BU",
                       total_data_raw_rate_region = ind_region_forc_total,
                       female_data_raw_rate_region = ind_region_forc_female,
                       male_data_raw_rate_region = ind_region_forc_male,
                       female_data_raw_rate = ind_state_forc_female,
                       male_data_raw_rate = ind_state_forc_male,
                       total_data_raw_rate = ind_state_forc_total)
    
    # Forecast
    
    BU_fore_ufts[[ikw]] = dum$BU_optim_hier_comb
    
    # Total + Sex
    Level_0_err[ikw, 1] = dum$me_total_err
    Level_F_err[ikw, 1] = dum$me_female_err
    Level_M_err[ikw, 1] = dum$me_male_err
    
    Level_0_err[ikw, 2] = dum$mae_total_err
    Level_F_err[ikw, 2] = dum$mae_female_err
    Level_M_err[ikw, 2] = dum$mae_male_err
    
    Level_0_err[ikw, 3] = dum$rmse_total_err
    Level_F_err[ikw, 3] = dum$rmse_female_err
    Level_M_err[ikw, 3] = dum$rmse_male_err
    
    # Region + Sex
    Level_T_R_err[ikw, 1, ] = dum$me_total_R_err
    Level_F_R_err[ikw, 1, ] = dum$me_female_R_err
    Level_M_R_err[ikw, 1, ] = dum$me_male_R_err

    Level_T_R_err[ikw, 2, ] = dum$mae_total_R_err
    Level_F_R_err[ikw, 2, ] = dum$mae_female_R_err
    Level_M_R_err[ikw, 2, ] = dum$mae_male_R_err
    
    Level_T_R_err[ikw, 3, ] = dum$rmse_total_R_err
    Level_F_R_err[ikw, 3, ] = dum$rmse_female_R_err
    Level_M_R_err[ikw, 3, ] = dum$rmse_male_R_err
    
    # Prefecture + Sex
    
    Level_State_err[, ikw, 1]   = dum$me_state_err
    Level_State_F_err[, ikw, 1] = dum$me_bottom_female_err
    Level_State_M_err[, ikw, 1] = dum$me_bottom_male_err

    Level_State_err[, ikw, 2]   = dum$mae_state_err
    Level_State_F_err[, ikw, 2] = dum$mae_bottom_female_err
    Level_State_M_err[, ikw, 2] = dum$mae_bottom_male_err
    
    Level_State_err[, ikw, 3]   = dum$rmse_state_err
    Level_State_F_err[, ikw, 3] = dum$rmse_bottom_female_err
    Level_State_M_err[, ikw, 3] = dum$rmse_bottom_male_err
    print(ikw)
    rm(dum)
}

BU_all_level_err_me = cbind(Level_0_err[,1], rowMeans(cbind(Level_F_err[,1], Level_M_err[,1])),
                             rowMeans(Level_T_R_err[,1,]), rowMeans(cbind(rowMeans(Level_F_R_err[,1,]), rowMeans(Level_M_R_err[,1,]))),
                             colMeans(Level_State_err[,,1]), colMeans(rbind(Level_State_F_err[,,1], Level_State_M_err[,,1])))

BU_all_level_err_mae = cbind(Level_0_err[,2], rowMeans(cbind(Level_F_err[,2], Level_M_err[,2])),
                              rowMeans(Level_T_R_err[,2,]), rowMeans(cbind(rowMeans(Level_F_R_err[,2,]), rowMeans(Level_M_R_err[,2,]))),
                              colMeans(Level_State_err[,,2]), colMeans(rbind(Level_State_F_err[,,2], Level_State_M_err[,,2])))

BU_all_level_err_rmse = cbind(Level_0_err[,3], rowMeans(cbind(Level_F_err[,3], Level_M_err[,3])),
                             rowMeans(Level_T_R_err[,3,]), rowMeans(cbind(rowMeans(Level_F_R_err[,3,]), rowMeans(Level_M_R_err[,3,]))),
                             colMeans(Level_State_err[,,3]), colMeans(rbind(Level_State_F_err[,,3], Level_State_M_err[,,3])))


BU_all_level_err_me_mean  = rbind(BU_all_level_err_me,  colMeans(BU_all_level_err_me),  apply(BU_all_level_err_me, 2, median))
BU_all_level_err_mae_mean  = rbind(BU_all_level_err_mae,  colMeans(BU_all_level_err_mae),  apply(BU_all_level_err_mae, 2, median))
BU_all_level_err_rmse_mean = rbind(BU_all_level_err_rmse, colMeans(BU_all_level_err_rmse), apply(BU_all_level_err_rmse, 2, median))

colnames(BU_all_level_err_me_mean) = colnames(BU_all_level_err_mae_mean) = colnames(BU_all_level_err_rmse_mean) = c("Total", "Sex", "Region", "Region + Sex", "Prefecture", "Prefecture + Sex")
rownames(BU_all_level_err_me_mean) = rownames(BU_all_level_err_mae_mean) = rownames(BU_all_level_err_rmse_mean) = c(1:15, "Mean", "Median")

##################
# fmethod = "OLS"
##################

OLS_fore_ufts = list()
optim_Level_0_err = optim_Level_F_err = optim_Level_M_err = matrix(NA, 15, 3)
optim_Level_T_R_err = optim_Level_F_R_err = optim_Level_M_R_err = array(NA, dim = c(15, 3, 8))

optim_Level_State_err = optim_Level_State_F_err = optim_Level_State_M_err = array(NA, dim = c(47, 15, 3))
for(ikw in 1:15)
{
    dum = BU_optim_err(ik = ikw, hier_method = "OLS",
                       total_data_raw_rate_region = ind_region_forc_total,
                       female_data_raw_rate_region = ind_region_forc_female,
                       male_data_raw_rate_region = ind_region_forc_male,
                       female_data_raw_rate = ind_state_forc_female,
                       male_data_raw_rate = ind_state_forc_male,
                       total_data_raw_rate = ind_state_forc_total)
    
    # Forecast
    
    OLS_fore_ufts[[ikw]] = dum$BU_optim_hier_comb
    
    #####
    # ME
    #####
    
    # Total + Sex
    optim_Level_0_err[ikw, 1] = dum$me_total_err
    optim_Level_F_err[ikw, 1] = dum$me_female_err
    optim_Level_M_err[ikw, 1] = dum$me_male_err
    
    # Region + Sex
    optim_Level_T_R_err[ikw, 1, ] = dum$me_total_R_err
    optim_Level_F_R_err[ikw, 1, ] = dum$me_female_R_err
    optim_Level_M_R_err[ikw, 1, ] = dum$me_male_R_err
    
    # Prefecture + Sex
    optim_Level_State_err[, ikw, 1] = dum$me_state_err
    optim_Level_State_F_err[, ikw, 1] = dum$me_bottom_female_err
    optim_Level_State_M_err[, ikw, 1] = dum$me_bottom_male_err
    
    ######
    # MAE
    ######
    
    # Total + Sex
    optim_Level_0_err[ikw, 2] = dum$mae_total_err
    optim_Level_F_err[ikw, 2] = dum$mae_female_err
    optim_Level_M_err[ikw, 2] = dum$mae_male_err
    
    # Region + Sex
    optim_Level_T_R_err[ikw, 2, ] = dum$mae_total_R_err
    optim_Level_F_R_err[ikw, 2, ] = dum$mae_female_R_err
    optim_Level_M_R_err[ikw, 2, ] = dum$mae_male_R_err
    
    # Prefecture + Sex
    optim_Level_State_err[, ikw, 2] = dum$mae_state_err
    optim_Level_State_F_err[, ikw, 2] = dum$mae_bottom_female_err
    optim_Level_State_M_err[, ikw, 2] = dum$mae_bottom_male_err
    
    #######
    # RMSE
    #######
    
    # Total + Sex
    optim_Level_0_err[ikw, 3] = dum$rmse_total_err
    optim_Level_F_err[ikw, 3] = dum$rmse_female_err
    optim_Level_M_err[ikw, 3] = dum$rmse_male_err
    
    # Region + Sex
    optim_Level_T_R_err[ikw, 3, ] = dum$rmse_total_R_err
    optim_Level_F_R_err[ikw, 3, ] = dum$rmse_female_R_err
    optim_Level_M_R_err[ikw, 3, ] = dum$rmse_male_R_err
    
    # Prefecture + Sex
    optim_Level_State_err[, ikw, 3] = dum$rmse_state_err
    optim_Level_State_F_err[, ikw, 3] = dum$rmse_bottom_female_err
    optim_Level_State_M_err[, ikw, 3] = dum$rmse_bottom_male_err
    print(ikw)
    rm(dum)
}

optim_all_level_err_me = cbind(optim_Level_0_err[,1], rowMeans(cbind(optim_Level_F_err[,1], optim_Level_M_err[,1])),
                                rowMeans(optim_Level_T_R_err[,1,]), rowMeans(cbind(rowMeans(optim_Level_F_R_err[,1,]), rowMeans(optim_Level_M_R_err[,1,]))),
                                colMeans(optim_Level_State_err[,,1]), colMeans(rbind(optim_Level_State_F_err[,,1], optim_Level_State_M_err[,,1])))

optim_all_level_err_mae = cbind(optim_Level_0_err[,2], rowMeans(cbind(optim_Level_F_err[,2], optim_Level_M_err[,2])),
                                 rowMeans(optim_Level_T_R_err[,2,]), rowMeans(cbind(rowMeans(optim_Level_F_R_err[,2,]), rowMeans(optim_Level_M_R_err[,2,]))),
                                 colMeans(optim_Level_State_err[,,2]), colMeans(rbind(optim_Level_State_F_err[,,2], optim_Level_State_M_err[,,2])))

optim_all_level_err_rmse = cbind(optim_Level_0_err[,3], rowMeans(cbind(optim_Level_F_err[,3], optim_Level_M_err[,3])),
                                rowMeans(optim_Level_T_R_err[,3,]), rowMeans(cbind(rowMeans(optim_Level_F_R_err[,3,]), rowMeans(optim_Level_M_R_err[,3,]))),
                                colMeans(optim_Level_State_err[,,3]), colMeans(rbind(optim_Level_State_F_err[,,3], optim_Level_State_M_err[,,3])))

optim_all_level_err_me_mean  = rbind(optim_all_level_err_me,  colMeans(optim_all_level_err_me),  apply(optim_all_level_err_me,  2, median))
optim_all_level_err_mae_mean  = rbind(optim_all_level_err_mae,  colMeans(optim_all_level_err_mae),  apply(optim_all_level_err_mae,  2, median))
optim_all_level_err_rmse_mean = rbind(optim_all_level_err_rmse, colMeans(optim_all_level_err_rmse), apply(optim_all_level_err_rmse, 2, median))

colnames(optim_all_level_err_me_mean) = colnames(optim_all_level_err_mae_mean) = colnames(optim_all_level_err_rmse_mean) = c("Total", "Sex", "Region", "Region + Sex", "Prefecture", "Prefecture + Sex")
rownames(optim_all_level_err_me_mean) = rownames(optim_all_level_err_mae_mean) = rownames(optim_all_level_err_rmse_mean) = c(1:15, "Mean", "Median")

# Combination (Av)

combination_err <- function(method_1_fore, method_2_fore, ik)
{
    BU_optim_hier_comb = (method_1_fore[[ik]] + method_2_fore[[ik]])/2
  
    # Level 0 (Total)
    me_total_err  = me(BU_optim_hier_comb[,1,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$total)
    mae_total_err  = mae(BU_optim_hier_comb[,1,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$total)
    rmse_total_err = rmse(BU_optim_hier_comb[,1,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$total)

    # Level 1 (Sex)
    me_female_err = me(BU_optim_hier_comb[,2,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$female)
    me_male_err   = me(BU_optim_hier_comb[,3,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$male)

    mae_female_err = mae(BU_optim_hier_comb[,2,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$female)
    mae_male_err   = mae(BU_optim_hier_comb[,3,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$male)

    rmse_female_err = rmse(BU_optim_hier_comb[,2,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$female)
    rmse_male_err   = rmse(BU_optim_hier_comb[,3,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$male)

    # Level 2 (Region + Total, Female and Male)
    me_total_R_err = me_female_R_err = me_male_R_err =
    mae_total_R_err = mae_female_R_err = mae_male_R_err =
    rmse_total_R_err = rmse_female_R_err = rmse_male_R_err = vector("numeric",8)
    for(iw in 1:8)
    {
        me_total_R_err[iw]  = me(BU_optim_hier_comb[,(iw+3),],  extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        me_female_R_err[iw] = me(BU_optim_hier_comb[,(iw+11),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        me_male_R_err[iw]   = me(BU_optim_hier_comb[,(iw+19),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
        
        mae_total_R_err[iw]  = mae(BU_optim_hier_comb[,(iw+3),],  extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        mae_female_R_err[iw] = mae(BU_optim_hier_comb[,(iw+11),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        mae_male_R_err[iw]   = mae(BU_optim_hier_comb[,(iw+19),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
        
        rmse_total_R_err[iw]  = rmse(BU_optim_hier_comb[,(iw+3),],  extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        rmse_female_R_err[iw] = rmse(BU_optim_hier_comb[,(iw+11),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        rmse_male_R_err[iw]   = rmse(BU_optim_hier_comb[,(iw+19),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
    }

    # Level 3 (Prefecture + Total)

    rmse_state_err = mae_state_err = me_state_err =
    bottom_female_rmse = bottom_female_mae = bottom_female_me =
    bottom_male_mae = bottom_male_rmse = bottom_male_me = vector("numeric",47)
    for(iwk in 2:48)
    {
        me_state_err[iwk-1]     = me(BU_optim_hier_comb[,(iwk+26),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$total)
        bottom_female_me[iwk-1] = me(BU_optim_hier_comb[,(71+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$female)
        bottom_male_me[iwk-1]   = me(BU_optim_hier_comb[,(72+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$male)
        
        mae_state_err[iwk-1]     = mae(BU_optim_hier_comb[,(iwk+26),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$total)
        bottom_female_mae[iwk-1] = mae(BU_optim_hier_comb[,(71+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$female)
        bottom_male_mae[iwk-1]   = mae(BU_optim_hier_comb[,(72+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$male)
        
        rmse_state_err[iwk-1]     = rmse(BU_optim_hier_comb[,(iwk+26),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$total)
        bottom_female_rmse[iwk-1] = rmse(BU_optim_hier_comb[,(71+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$female)
        bottom_male_rmse[iwk-1]   = rmse(BU_optim_hier_comb[,(72+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$male)
    }
    rm(BU_optim_hier_comb)
    return(list(me_total_err = me_total_err, me_female_err = me_female_err, me_male_err = me_male_err,
                me_total_R_err = me_total_R_err, me_female_R_err = me_female_R_err, me_male_R_err = me_male_R_err,
                me_state_err = me_state_err, me_bottom_female_err = bottom_female_me, me_bottom_male_err = bottom_male_me,
                
                mae_total_err = mae_total_err, mae_female_err = mae_female_err, mae_male_err = mae_male_err,
                mae_total_R_err = mae_total_R_err, mae_female_R_err = mae_female_R_err, mae_male_R_err = mae_male_R_err,
                mae_state_err = mae_state_err, mae_bottom_female_err = bottom_female_mae, mae_bottom_male_err = bottom_male_mae,
                
                rmse_total_err = rmse_total_err, rmse_female_err = rmse_female_err, rmse_male_err = rmse_male_err,
                rmse_total_R_err = rmse_total_R_err, rmse_female_R_err = rmse_female_R_err, rmse_male_R_err = rmse_male_R_err,
                rmse_state_err = rmse_state_err, rmse_bottom_female_err = bottom_female_rmse, rmse_bottom_male_err = bottom_male_rmse))
}

comb_Level_0_err = comb_Level_F_err = comb_Level_M_err = matrix(NA, 15, 3)
comb_Level_T_R_err = comb_Level_F_R_err = comb_Level_M_R_err = array(NA, dim = c(15, 3, 8))

comb_Level_State_err = comb_Level_State_F_err = comb_Level_State_M_err = array(NA, dim = c(47,15,3))
for(ikw in 1:15)
{
    dum = combination_err(method_1_fore = BU_fore_ufts, method_2_fore = OLS_fore_ufts, ik = ikw)
    
    # Total + Sex
    comb_Level_0_err[ikw, 1] = dum$me_total_err
    comb_Level_F_err[ikw, 1] = dum$me_female_err
    comb_Level_M_err[ikw, 1] = dum$me_male_err
    
    comb_Level_0_err[ikw, 2] = dum$mae_total_err
    comb_Level_F_err[ikw, 2] = dum$mae_female_err
    comb_Level_M_err[ikw, 2] = dum$mae_male_err
    
    comb_Level_0_err[ikw, 3] = dum$rmse_total_err
    comb_Level_F_err[ikw, 3] = dum$rmse_female_err
    comb_Level_M_err[ikw, 3] = dum$rmse_male_err
    
    # Region + Sex
    comb_Level_T_R_err[ikw, 1, ] = dum$me_total_R_err
    comb_Level_F_R_err[ikw, 1, ] = dum$me_female_R_err
    comb_Level_M_R_err[ikw, 1, ] = dum$me_male_R_err
    
    comb_Level_T_R_err[ikw, 2, ] = dum$mae_total_R_err
    comb_Level_F_R_err[ikw, 2, ] = dum$mae_female_R_err
    comb_Level_M_R_err[ikw, 2, ] = dum$mae_male_R_err
    
    comb_Level_T_R_err[ikw, 3, ] = dum$rmse_total_R_err
    comb_Level_F_R_err[ikw, 3, ] = dum$rmse_female_R_err
    comb_Level_M_R_err[ikw, 3, ] = dum$rmse_male_R_err
    
    # Prefecture + Sex
    
    comb_Level_State_err[, ikw, 1]   = dum$me_state_err
    comb_Level_State_F_err[, ikw, 1] = dum$me_bottom_female_err
    comb_Level_State_M_err[, ikw, 1] = dum$me_bottom_male_err
    
    comb_Level_State_err[, ikw, 2]   = dum$mae_state_err
    comb_Level_State_F_err[, ikw, 2] = dum$mae_bottom_female_err
    comb_Level_State_M_err[, ikw, 2] = dum$mae_bottom_male_err
    
    comb_Level_State_err[, ikw, 3]   = dum$rmse_state_err
    comb_Level_State_F_err[, ikw, 3] = dum$rmse_bottom_female_err
    comb_Level_State_M_err[, ikw, 3] = dum$rmse_bottom_male_err
    print(ikw)
    rm(dum)
}
  

comb_all_level_err_me = cbind(comb_Level_0_err[,1], rowMeans(cbind(comb_Level_F_err[,1], comb_Level_M_err[,1])),
                              rowMeans(comb_Level_T_R_err[,1,]), rowMeans(cbind(rowMeans(comb_Level_F_R_err[,1,]), rowMeans(comb_Level_M_R_err[,1,]))),
                              colMeans(comb_Level_State_err[,,1]), colMeans(rbind(comb_Level_State_F_err[,,1], comb_Level_State_M_err[,,1])))

comb_all_level_err_mae = cbind(comb_Level_0_err[,2], rowMeans(cbind(comb_Level_F_err[,2], comb_Level_M_err[,2])),
                               rowMeans(comb_Level_T_R_err[,2,]), rowMeans(cbind(rowMeans(comb_Level_F_R_err[,2,]), rowMeans(comb_Level_M_R_err[,2,]))),
                               colMeans(comb_Level_State_err[,,2]), colMeans(rbind(comb_Level_State_F_err[,,2], comb_Level_State_M_err[,,2])))

comb_all_level_err_rmse = cbind(comb_Level_0_err[,3], rowMeans(cbind(comb_Level_F_err[,3], comb_Level_M_err[,3])),
                                rowMeans(comb_Level_T_R_err[,3,]), rowMeans(cbind(rowMeans(comb_Level_F_R_err[,3,]), rowMeans(comb_Level_M_R_err[,3,]))),
                                colMeans(comb_Level_State_err[,,3]), colMeans(rbind(comb_Level_State_F_err[,,3], comb_Level_State_M_err[,,3])))

comb_all_level_err_me_mean  = rbind(comb_all_level_err_me,  colMeans(comb_all_level_err_me),  apply(comb_all_level_err_me,  2, median))
comb_all_level_err_mae_mean  = rbind(comb_all_level_err_mae,  colMeans(comb_all_level_err_mae),  apply(comb_all_level_err_mae,  2, median))
comb_all_level_err_rmse_mean = rbind(comb_all_level_err_rmse, colMeans(comb_all_level_err_rmse), apply(comb_all_level_err_rmse, 2, median))

colnames(comb_all_level_err_me_mean) = colnames(comb_all_level_err_mae_mean) = colnames(comb_all_level_err_rmse_mean) = c("Total", "Sex", "Region", "Region + Sex", "Prefecture", "Prefecture + Sex")
rownames(comb_all_level_err_me_mean) = rownames(comb_all_level_err_mae_mean) = rownames(comb_all_level_err_rmse_mean) = c(1:15, "Mean", "Median")

# Combination (AvInt)

combination_err_AvInt <- function(method_fore, ik)
{
    BU_optim_hier_comb = method_fore[[ik]]
    
    # Level 0 (Total)
    me_total_err  = me(BU_optim_hier_comb[,1,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$total)
    mae_total_err  = mae(BU_optim_hier_comb[,1,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$total)
    rmse_total_err = rmse(BU_optim_hier_comb[,1,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$total)
    
    # Level 1 (Sex)
    me_female_err = me(BU_optim_hier_comb[,2,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$female)
    me_male_err   = me(BU_optim_hier_comb[,3,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$male)
    
    mae_female_err = mae(BU_optim_hier_comb[,2,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$female)
    mae_male_err   = mae(BU_optim_hier_comb[,3,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$male)
    
    rmse_female_err = rmse(BU_optim_hier_comb[,2,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$female)
    rmse_male_err   = rmse(BU_optim_hier_comb[,3,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$male)
    
    # Level 2 (Region + Total, Female and Male)
    me_total_R_err = me_female_R_err = me_male_R_err =
    mae_total_R_err = mae_female_R_err = mae_male_R_err =
    rmse_total_R_err = rmse_female_R_err = rmse_male_R_err = vector("numeric",8)
    for(iw in 1:8)
    {
        me_total_R_err[iw]  = me(BU_optim_hier_comb[,(iw+3),],  extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        me_female_R_err[iw] = me(BU_optim_hier_comb[,(iw+11),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        me_male_R_err[iw]   = me(BU_optim_hier_comb[,(iw+19),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
        
        mae_total_R_err[iw]  = mae(BU_optim_hier_comb[,(iw+3),],  extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        mae_female_R_err[iw] = mae(BU_optim_hier_comb[,(iw+11),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        mae_male_R_err[iw]   = mae(BU_optim_hier_comb[,(iw+19),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
        
        rmse_total_R_err[iw]  = rmse(BU_optim_hier_comb[,(iw+3),],  extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        rmse_female_R_err[iw] = rmse(BU_optim_hier_comb[,(iw+11),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        rmse_male_R_err[iw]   = rmse(BU_optim_hier_comb[,(iw+19),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
    }
    
    # Level 3 (Prefecture + Total)
    
    rmse_state_err = mae_state_err = me_state_err =
    bottom_female_rmse = bottom_female_mae = bottom_female_me =
    bottom_male_mae = bottom_male_rmse = bottom_male_me = vector("numeric",47)
    for(iwk in 2:48)
    {
        me_state_err[iwk-1]     = me(BU_optim_hier_comb[,(iwk+26),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$total)
        bottom_female_me[iwk-1] = me(BU_optim_hier_comb[,(71+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$female)
        bottom_male_me[iwk-1]   = me(BU_optim_hier_comb[,(72+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$male)
        
        mae_state_err[iwk-1]     = mae(BU_optim_hier_comb[,(iwk+26),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$total)
        bottom_female_mae[iwk-1] = mae(BU_optim_hier_comb[,(71+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$female)
        bottom_male_mae[iwk-1]   = mae(BU_optim_hier_comb[,(72+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$male)
        
        rmse_state_err[iwk-1]     = rmse(BU_optim_hier_comb[,(iwk+26),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$total)
        bottom_female_rmse[iwk-1] = rmse(BU_optim_hier_comb[,(71+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$female)
        bottom_male_rmse[iwk-1]   = rmse(BU_optim_hier_comb[,(72+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$male)
    }
    rm(BU_optim_hier_comb)
    return(list(me_total_err = me_total_err, me_female_err = me_female_err, me_male_err = me_male_err,
    me_total_R_err = me_total_R_err, me_female_R_err = me_female_R_err, me_male_R_err = me_male_R_err,
    me_state_err = me_state_err, me_bottom_female_err = bottom_female_me, me_bottom_male_err = bottom_male_me,
    
    mae_total_err = mae_total_err, mae_female_err = mae_female_err, mae_male_err = mae_male_err,
    mae_total_R_err = mae_total_R_err, mae_female_R_err = mae_female_R_err, mae_male_R_err = mae_male_R_err,
    mae_state_err = mae_state_err, mae_bottom_female_err = bottom_female_mae, mae_bottom_male_err = bottom_male_mae,
    
    rmse_total_err = rmse_total_err, rmse_female_err = rmse_female_err, rmse_male_err = rmse_male_err,
    rmse_total_R_err = rmse_total_R_err, rmse_female_R_err = rmse_female_R_err, rmse_male_R_err = rmse_male_R_err,
    rmse_state_err = rmse_state_err, rmse_bottom_female_err = bottom_female_rmse, rmse_bottom_male_err = bottom_male_rmse))
}
    
comb_AvInt_Level_0_err = comb_AvInt_Level_F_err = comb_AvInt_Level_M_err = matrix(NA, 15, 3)
comb_AvInt_Level_T_R_err = comb_AvInt_Level_F_R_err = comb_AvInt_Level_M_R_err = array(NA, dim = c(15, 3, 8))

comb_AvInt_Level_State_err = comb_AvInt_Level_State_F_err = comb_AvInt_Level_State_M_err = array(NA, dim = c(47,15,3))
for(ikw in 1:15)
{
    dum = combination_err_AvInt(method_fore = comb_hier_comb_midpoints, ik = ikw)
    
    # Total + Sex
    comb_AvInt_Level_0_err[ikw, 1] = dum$me_total_err
    comb_AvInt_Level_F_err[ikw, 1] = dum$me_female_err
    comb_AvInt_Level_M_err[ikw, 1] = dum$me_male_err
    
    comb_AvInt_Level_0_err[ikw, 2] = dum$mae_total_err
    comb_AvInt_Level_F_err[ikw, 2] = dum$mae_female_err
    comb_AvInt_Level_M_err[ikw, 2] = dum$mae_male_err
    
    comb_AvInt_Level_0_err[ikw, 3] = dum$rmse_total_err
    comb_AvInt_Level_F_err[ikw, 3] = dum$rmse_female_err
    comb_AvInt_Level_M_err[ikw, 3] = dum$rmse_male_err
    
    # Region + Sex
    comb_AvInt_Level_T_R_err[ikw, 1, ] = dum$me_total_R_err
    comb_AvInt_Level_F_R_err[ikw, 1, ] = dum$me_female_R_err
    comb_AvInt_Level_M_R_err[ikw, 1, ] = dum$me_male_R_err
    
    comb_AvInt_Level_T_R_err[ikw, 2, ] = dum$mae_total_R_err
    comb_AvInt_Level_F_R_err[ikw, 2, ] = dum$mae_female_R_err
    comb_AvInt_Level_M_R_err[ikw, 2, ] = dum$mae_male_R_err
    
    comb_AvInt_Level_T_R_err[ikw, 3, ] = dum$rmse_total_R_err
    comb_AvInt_Level_F_R_err[ikw, 3, ] = dum$rmse_female_R_err
    comb_AvInt_Level_M_R_err[ikw, 3, ] = dum$rmse_male_R_err
    
    # Prefecture + Sex
    
    comb_AvInt_Level_State_err[, ikw, 1]   = dum$me_state_err
    comb_AvInt_Level_State_F_err[, ikw, 1] = dum$me_bottom_female_err
    comb_AvInt_Level_State_M_err[, ikw, 1] = dum$me_bottom_male_err
    
    comb_AvInt_Level_State_err[, ikw, 2]   = dum$mae_state_err
    comb_AvInt_Level_State_F_err[, ikw, 2] = dum$mae_bottom_female_err
    comb_AvInt_Level_State_M_err[, ikw, 2] = dum$mae_bottom_male_err
    
    comb_AvInt_Level_State_err[, ikw, 3]   = dum$rmse_state_err
    comb_AvInt_Level_State_F_err[, ikw, 3] = dum$rmse_bottom_female_err
    comb_AvInt_Level_State_M_err[, ikw, 3] = dum$rmse_bottom_male_err
    print(ikw)
    rm(dum)
}

comb_AvInt_all_level_err_me = cbind(comb_AvInt_Level_0_err[,1], rowMeans(cbind(comb_AvInt_Level_F_err[,1], comb_AvInt_Level_M_err[,1])),
rowMeans(comb_AvInt_Level_T_R_err[,1,]), rowMeans(cbind(rowMeans(comb_AvInt_Level_F_R_err[,1,]), rowMeans(comb_AvInt_Level_M_R_err[,1,]))),
colMeans(comb_AvInt_Level_State_err[,,1]), colMeans(rbind(comb_AvInt_Level_State_F_err[,,1], comb_AvInt_Level_State_M_err[,,1])))

comb_AvInt_all_level_err_mae = cbind(comb_AvInt_Level_0_err[,2], rowMeans(cbind(comb_AvInt_Level_F_err[,2], comb_AvInt_Level_M_err[,2])),
rowMeans(comb_AvInt_Level_T_R_err[,2,]), rowMeans(cbind(rowMeans(comb_AvInt_Level_F_R_err[,2,]), rowMeans(comb_AvInt_Level_M_R_err[,2,]))),
colMeans(comb_AvInt_Level_State_err[,,2]), colMeans(rbind(comb_AvInt_Level_State_F_err[,,2], comb_AvInt_Level_State_M_err[,,2])))

comb_AvInt_all_level_err_rmse = cbind(comb_AvInt_Level_0_err[,3], rowMeans(cbind(comb_AvInt_Level_F_err[,3], comb_AvInt_Level_M_err[,3])),
rowMeans(comb_AvInt_Level_T_R_err[,3,]), rowMeans(cbind(rowMeans(comb_AvInt_Level_F_R_err[,3,]), rowMeans(comb_AvInt_Level_M_R_err[,3,]))),
colMeans(comb_AvInt_Level_State_err[,,3]), colMeans(rbind(comb_AvInt_Level_State_F_err[,,3], comb_AvInt_Level_State_M_err[,,3])))

comb_AvInt_all_level_err_me_mean  = rbind(comb_AvInt_all_level_err_me,  colMeans(comb_AvInt_all_level_err_me),  apply(comb_AvInt_all_level_err_me,  2, median))
comb_AvInt_all_level_err_mae_mean  = rbind(comb_AvInt_all_level_err_mae,  colMeans(comb_AvInt_all_level_err_mae),  apply(comb_AvInt_all_level_err_mae,  2, median))
comb_AvInt_all_level_err_rmse_mean = rbind(comb_AvInt_all_level_err_rmse, colMeans(comb_AvInt_all_level_err_rmse), apply(comb_AvInt_all_level_err_rmse, 2, median))

colnames(comb_AvInt_all_level_err_me_mean) = colnames(comb_AvInt_all_level_err_mae_mean) = colnames(comb_AvInt_all_level_err_rmse_mean) = c("Total", "Sex", "Region", "Region + Sex", "Prefecture", "Prefecture + Sex")
rownames(comb_AvInt_all_level_err_me_mean) = rownames(comb_AvInt_all_level_err_mae_mean) = rownames(comb_AvInt_all_level_err_rmse_mean) = c(1:15, "Mean", "Median")

##############
# MFTS (MAFE)
##############

BU_fore_mfts = list()
mfts_Level_0_err = mfts_Level_F_err = mfts_Level_M_err = matrix(NA, 15, 3)
mfts_Level_T_R_err = mfts_Level_F_R_err = mfts_Level_M_R_err = array(NA, dim = c(15, 3, 8))

mfts_Level_State_err = mfts_Level_State_F_err = mfts_Level_State_M_err = array(NA, dim = c(47, 15, 3))
for(ikw in 1:15)
{
    dum = BU_optim_err(ik = ikw, hier_method = "BU",
                       total_data_raw_rate_region = mfts_region_forc_total,
                       female_data_raw_rate_region = mfts_region_forc_female,
                       male_data_raw_rate_region = mfts_region_forc_male,
                       female_data_raw_rate = mfts_state_forc_female,
                       male_data_raw_rate = mfts_state_forc_male,
                       total_data_raw_rate = mfts_state_forc_total)
    # Forecast
    
    BU_fore_mfts[[ikw]] = dum$BU_optim_hier_comb
    
    # Total + Sex
    mfts_Level_0_err[ikw, 1] = dum$me_total_err
    mfts_Level_F_err[ikw, 1] = dum$me_female_err
    mfts_Level_M_err[ikw, 1] = dum$me_male_err
    
    mfts_Level_0_err[ikw, 2] = dum$mae_total_err
    mfts_Level_F_err[ikw, 2] = dum$mae_female_err
    mfts_Level_M_err[ikw, 2] = dum$mae_male_err
    
    mfts_Level_0_err[ikw, 3] = dum$rmse_total_err
    mfts_Level_F_err[ikw, 3] = dum$rmse_female_err
    mfts_Level_M_err[ikw, 3] = dum$rmse_male_err
    
    # Region + Sex
    mfts_Level_T_R_err[ikw, 1, ] = dum$me_total_R_err
    mfts_Level_F_R_err[ikw, 1, ] = dum$me_female_R_err
    mfts_Level_M_R_err[ikw, 1, ] = dum$me_male_R_err
    
    mfts_Level_T_R_err[ikw, 2, ] = dum$mae_total_R_err
    mfts_Level_F_R_err[ikw, 2, ] = dum$mae_female_R_err
    mfts_Level_M_R_err[ikw, 2, ] = dum$mae_male_R_err
    
    mfts_Level_T_R_err[ikw, 3, ] = dum$rmse_total_R_err
    mfts_Level_F_R_err[ikw, 3, ] = dum$rmse_female_R_err
    mfts_Level_M_R_err[ikw, 3, ] = dum$rmse_male_R_err
    
    # Prefecture + Sex
    
    mfts_Level_State_err[, ikw, 1]   = dum$me_state_err
    mfts_Level_State_F_err[, ikw, 1] = dum$me_bottom_female_err
    mfts_Level_State_M_err[, ikw, 1] = dum$me_bottom_male_err
    
    mfts_Level_State_err[, ikw, 2]   = dum$mae_state_err
    mfts_Level_State_F_err[, ikw, 2] = dum$mae_bottom_female_err
    mfts_Level_State_M_err[, ikw, 2] = dum$mae_bottom_male_err
    
    mfts_Level_State_err[, ikw, 3]   = dum$rmse_state_err
    mfts_Level_State_F_err[, ikw, 3] = dum$rmse_bottom_female_err
    mfts_Level_State_M_err[, ikw, 3] = dum$rmse_bottom_male_err
    print(ikw)
    rm(dum)
}

mfts_BU_all_level_err_me = cbind(mfts_Level_0_err[,1], rowMeans(cbind(mfts_Level_F_err[,1], mfts_Level_M_err[,1])),
                            rowMeans(mfts_Level_T_R_err[,1,]), rowMeans(cbind(rowMeans(mfts_Level_F_R_err[,1,]), rowMeans(mfts_Level_M_R_err[,1,]))),
                            colMeans(mfts_Level_State_err[,,1]), colMeans(rbind(mfts_Level_State_F_err[,,1], mfts_Level_State_M_err[,,1])))

mfts_BU_all_level_err_mae = cbind(mfts_Level_0_err[,2], rowMeans(cbind(mfts_Level_F_err[,2], mfts_Level_M_err[,2])),
                             rowMeans(mfts_Level_T_R_err[,2,]), rowMeans(cbind(rowMeans(mfts_Level_F_R_err[,2,]), rowMeans(mfts_Level_M_R_err[,2,]))),
                             colMeans(mfts_Level_State_err[,,2]), colMeans(rbind(mfts_Level_State_F_err[,,2], mfts_Level_State_M_err[,,2])))

mfts_BU_all_level_err_rmse = cbind(mfts_Level_0_err[,3], rowMeans(cbind(mfts_Level_F_err[,3], mfts_Level_M_err[,3])),
                              rowMeans(mfts_Level_T_R_err[,3,]), rowMeans(cbind(rowMeans(mfts_Level_F_R_err[,3,]), rowMeans(mfts_Level_M_R_err[,3,]))),
                              colMeans(mfts_Level_State_err[,,3]), colMeans(rbind(mfts_Level_State_F_err[,,3], mfts_Level_State_M_err[,,3])))


mfts_BU_all_level_err_me_mean  = rbind(mfts_BU_all_level_err_me,  colMeans(mfts_BU_all_level_err_me),  apply(mfts_BU_all_level_err_me, 2, median))
mfts_BU_all_level_err_mae_mean  = rbind(mfts_BU_all_level_err_mae,  colMeans(mfts_BU_all_level_err_mae),  apply(mfts_BU_all_level_err_mae, 2, median))
mfts_BU_all_level_err_rmse_mean = rbind(mfts_BU_all_level_err_rmse, colMeans(mfts_BU_all_level_err_rmse), apply(mfts_BU_all_level_err_rmse, 2, median))

colnames(mfts_BU_all_level_err_me_mean) = colnames(mfts_BU_all_level_err_mae_mean) = colnames(mfts_BU_all_level_err_rmse_mean) = c("Total", "Sex", "Region", "Region + Sex", "Prefecture", "Prefecture + Sex")
rownames(mfts_BU_all_level_err_me_mean) = rownames(mfts_BU_all_level_err_mae_mean) = rownames(mfts_BU_all_level_err_rmse_mean) = c(1:15, "Mean", "Median")

# fmethod = "OLS"

OLS_fore_mfts = list()
mfts_optim_Level_0_err = mfts_optim_Level_F_err = mfts_optim_Level_M_err = matrix(NA, 15, 3)
mfts_optim_Level_T_R_err = mfts_optim_Level_F_R_err = mfts_optim_Level_M_R_err = array(NA, dim = c(15, 3, 8))

mfts_optim_Level_State_err = mfts_optim_Level_State_F_err = mfts_optim_Level_State_M_err = array(NA, dim = c(47, 15, 3))
for(ikw in 1:15)
{
    dum = BU_optim_err(ik = ikw, hier_method = "OLS",
                       total_data_raw_rate_region = mfts_region_forc_total,
                       female_data_raw_rate_region = mfts_region_forc_female,
                       male_data_raw_rate_region = mfts_region_forc_male,
                       female_data_raw_rate = mfts_state_forc_female,
                       male_data_raw_rate = mfts_state_forc_male,
                       total_data_raw_rate = mfts_state_forc_total)
    
    # Forecast
    
    OLS_fore_mfts[[ikw]] = dum$BU_optim_hier_comb
    
    #####
    # ME
    #####
    
    # Total + Sex
    mfts_optim_Level_0_err[ikw, 1] = dum$me_total_err
    mfts_optim_Level_F_err[ikw, 1] = dum$me_female_err
    mfts_optim_Level_M_err[ikw, 1] = dum$me_male_err
    
    # Region + Sex
    mfts_optim_Level_T_R_err[ikw, 1, ] = dum$me_total_R_err
    mfts_optim_Level_F_R_err[ikw, 1, ] = dum$me_female_R_err
    mfts_optim_Level_M_R_err[ikw, 1, ] = dum$me_male_R_err
    
    # Prefecture + Sex
    mfts_optim_Level_State_err[, ikw, 1] = dum$me_state_err
    mfts_optim_Level_State_F_err[, ikw, 1] = dum$me_bottom_female_err
    mfts_optim_Level_State_M_err[, ikw, 1] = dum$me_bottom_male_err
    
    ######
    # MAE
    ######
    
    # Total + Sex
    mfts_optim_Level_0_err[ikw, 2] = dum$mae_total_err
    mfts_optim_Level_F_err[ikw, 2] = dum$mae_female_err
    mfts_optim_Level_M_err[ikw, 2] = dum$mae_male_err
    
    # Region + Sex
    mfts_optim_Level_T_R_err[ikw, 2, ] = dum$mae_total_R_err
    mfts_optim_Level_F_R_err[ikw, 2, ] = dum$mae_female_R_err
    mfts_optim_Level_M_R_err[ikw, 2, ] = dum$mae_male_R_err
    
    # Prefecture + Sex
    mfts_optim_Level_State_err[, ikw, 2] = dum$mae_state_err
    mfts_optim_Level_State_F_err[, ikw, 2] = dum$mae_bottom_female_err
    mfts_optim_Level_State_M_err[, ikw, 2] = dum$mae_bottom_male_err
    
    #######
    # RMSE
    #######
    
    # Total + Sex
    mfts_optim_Level_0_err[ikw, 3] = dum$rmse_total_err
    mfts_optim_Level_F_err[ikw, 3] = dum$rmse_female_err
    mfts_optim_Level_M_err[ikw, 3] = dum$rmse_male_err
    
    # Region + Sex
    mfts_optim_Level_T_R_err[ikw, 3, ] = dum$rmse_total_R_err
    mfts_optim_Level_F_R_err[ikw, 3, ] = dum$rmse_female_R_err
    mfts_optim_Level_M_R_err[ikw, 3, ] = dum$rmse_male_R_err
    
    # Prefecture + Sex
    mfts_optim_Level_State_err[, ikw, 3] = dum$rmse_state_err
    mfts_optim_Level_State_F_err[, ikw, 3] = dum$rmse_bottom_female_err
    mfts_optim_Level_State_M_err[, ikw, 3] = dum$rmse_bottom_male_err
    print(ikw)
    rm(dum)
}

mfts_optim_all_level_err_me = cbind(mfts_optim_Level_0_err[,1], rowMeans(cbind(mfts_optim_Level_F_err[,1], mfts_optim_Level_M_err[,1])),
                               rowMeans(mfts_optim_Level_T_R_err[,1,]), rowMeans(cbind(rowMeans(mfts_optim_Level_F_R_err[,1,]), rowMeans(mfts_optim_Level_M_R_err[,1,]))),
                               colMeans(mfts_optim_Level_State_err[,,1]), colMeans(rbind(mfts_optim_Level_State_F_err[,,1], mfts_optim_Level_State_M_err[,,1])))

mfts_optim_all_level_err_mae = cbind(mfts_optim_Level_0_err[,2], rowMeans(cbind(mfts_optim_Level_F_err[,2], mfts_optim_Level_M_err[,2])),
                                rowMeans(mfts_optim_Level_T_R_err[,2,]), rowMeans(cbind(rowMeans(mfts_optim_Level_F_R_err[,2,]), rowMeans(mfts_optim_Level_M_R_err[,2,]))),
                                colMeans(mfts_optim_Level_State_err[,,2]), colMeans(rbind(mfts_optim_Level_State_F_err[,,2], mfts_optim_Level_State_M_err[,,2])))

mfts_optim_all_level_err_rmse = cbind(mfts_optim_Level_0_err[,3], rowMeans(cbind(mfts_optim_Level_F_err[,3], mfts_optim_Level_M_err[,3])),
                                 rowMeans(mfts_optim_Level_T_R_err[,3,]), rowMeans(cbind(rowMeans(mfts_optim_Level_F_R_err[,3,]), rowMeans(mfts_optim_Level_M_R_err[,3,]))),
                                 colMeans(mfts_optim_Level_State_err[,,3]), colMeans(rbind(mfts_optim_Level_State_F_err[,,3], mfts_optim_Level_State_M_err[,,3])))

mfts_optim_all_level_err_me_mean  = rbind(mfts_optim_all_level_err_me,  colMeans(mfts_optim_all_level_err_me),  apply(mfts_optim_all_level_err_me,  2, median))
mfts_optim_all_level_err_mae_mean  = rbind(mfts_optim_all_level_err_mae,  colMeans(mfts_optim_all_level_err_mae),  apply(mfts_optim_all_level_err_mae,  2, median))
mfts_optim_all_level_err_rmse_mean = rbind(mfts_optim_all_level_err_rmse, colMeans(mfts_optim_all_level_err_rmse), apply(mfts_optim_all_level_err_rmse, 2, median))

colnames(mfts_optim_all_level_err_me_mean) = colnames(mfts_optim_all_level_err_mae_mean) = colnames(mfts_optim_all_level_err_rmse_mean) = c("Total", "Sex", "Region", "Region + Sex", "Prefecture", "Prefecture + Sex")
rownames(mfts_optim_all_level_err_me_mean) = rownames(mfts_optim_all_level_err_mae_mean) = rownames(mfts_optim_all_level_err_rmse_mean) = c(1:15, "Mean", "Median")

# Combination

combination_mfts_err <- function(method_1_fore, method_2_fore, ik)
{
    BU_optim_hier_comb = (method_1_fore[[ik]] + method_2_fore[[ik]])/2
    
    # Level 0 (Total)
    me_total_err  = me(BU_optim_hier_comb[,1,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$total)
    mae_total_err  = mae(BU_optim_hier_comb[,1,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$total)
    rmse_total_err = rmse(BU_optim_hier_comb[,1,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$total)
    
    # Level 1 (Sex)
    me_female_err = me(BU_optim_hier_comb[,2,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$female)
    me_male_err   = me(BU_optim_hier_comb[,3,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$male)
    
    mae_female_err = mae(BU_optim_hier_comb[,2,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$female)
    mae_male_err   = mae(BU_optim_hier_comb[,3,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$male)
    
    rmse_female_err = rmse(BU_optim_hier_comb[,2,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$female)
    rmse_male_err   = rmse(BU_optim_hier_comb[,3,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$male)
    
    # Level 2 (Region + Total, Female and Male)
    me_total_R_err = me_female_R_err = me_male_R_err =
    mae_total_R_err = mae_female_R_err = mae_male_R_err =
    rmse_total_R_err = rmse_female_R_err = rmse_male_R_err = vector("numeric",8)
    for(iw in 1:8)
    {
        me_total_R_err[iw]  = me(BU_optim_hier_comb[,(iw+3),],  extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        me_female_R_err[iw] = me(BU_optim_hier_comb[,(iw+11),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        me_male_R_err[iw]   = me(BU_optim_hier_comb[,(iw+19),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
        
        mae_total_R_err[iw]  = mae(BU_optim_hier_comb[,(iw+3),],  extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        mae_female_R_err[iw] = mae(BU_optim_hier_comb[,(iw+11),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        mae_male_R_err[iw]   = mae(BU_optim_hier_comb[,(iw+19),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
        
        rmse_total_R_err[iw]  = rmse(BU_optim_hier_comb[,(iw+3),],  extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        rmse_female_R_err[iw] = rmse(BU_optim_hier_comb[,(iw+11),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        rmse_male_R_err[iw]   = rmse(BU_optim_hier_comb[,(iw+19),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
    }
    
    # Level 3 (Prefecture + Total)
    
    rmse_state_err = mae_state_err = me_state_err =
    bottom_female_rmse = bottom_female_mae = bottom_female_me =
    bottom_male_mae = bottom_male_rmse = bottom_male_me = vector("numeric",47)
    for(iwk in 2:48)
    {
        me_state_err[iwk-1]     = me(BU_optim_hier_comb[,(iwk+26),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$total)
        bottom_female_me[iwk-1] = me(BU_optim_hier_comb[,(71+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$female)
        bottom_male_me[iwk-1]   = me(BU_optim_hier_comb[,(72+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$male)
        
        mae_state_err[iwk-1]     = mae(BU_optim_hier_comb[,(iwk+26),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$total)
        bottom_female_mae[iwk-1] = mae(BU_optim_hier_comb[,(71+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$female)
        bottom_male_mae[iwk-1]   = mae(BU_optim_hier_comb[,(72+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$male)
        
        rmse_state_err[iwk-1]     = rmse(BU_optim_hier_comb[,(iwk+26),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$total)
        bottom_female_rmse[iwk-1] = rmse(BU_optim_hier_comb[,(71+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$female)
        bottom_male_rmse[iwk-1]   = rmse(BU_optim_hier_comb[,(72+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$male)
    }
    rm(BU_optim_hier_comb)
    return(list(me_total_err = me_total_err, me_female_err = me_female_err, me_male_err = me_male_err,
                me_total_R_err = me_total_R_err, me_female_R_err = me_female_R_err, me_male_R_err = me_male_R_err,
                me_state_err = me_state_err, me_bottom_female_err = bottom_female_me, me_bottom_male_err = bottom_male_me,
                
                mae_total_err = mae_total_err, mae_female_err = mae_female_err, mae_male_err = mae_male_err,
                mae_total_R_err = mae_total_R_err, mae_female_R_err = mae_female_R_err, mae_male_R_err = mae_male_R_err,
                mae_state_err = mae_state_err, mae_bottom_female_err = bottom_female_mae, mae_bottom_male_err = bottom_male_mae,
                
                rmse_total_err = rmse_total_err, rmse_female_err = rmse_female_err, rmse_male_err = rmse_male_err,
                rmse_total_R_err = rmse_total_R_err, rmse_female_R_err = rmse_female_R_err, rmse_male_R_err = rmse_male_R_err,
                rmse_state_err = rmse_state_err, rmse_bottom_female_err = bottom_female_rmse, rmse_bottom_male_err = bottom_male_rmse))
}


mfts_comb_Level_0_err = mfts_comb_Level_F_err = mfts_comb_Level_M_err = matrix(NA,15,3)
mfts_comb_Level_T_R_err = mfts_comb_Level_F_R_err = mfts_comb_Level_M_R_err = array(NA, dim = c(15,3,8))

mfts_comb_Level_State_err = mfts_comb_Level_State_F_err = mfts_comb_Level_State_M_err = array(NA, dim = c(47,15,3))
for(ikw in 1:15)
{
    dum = combination_mfts_err(method_1_fore = BU_fore_mfts, method_2_fore = OLS_fore_mfts, ik = ikw)
    
    # Total + Sex
    mfts_comb_Level_0_err[ikw, 1] = dum$me_total_err
    mfts_comb_Level_F_err[ikw, 1] = dum$me_female_err
    mfts_comb_Level_M_err[ikw, 1] = dum$me_male_err
    
    mfts_comb_Level_0_err[ikw, 2] = dum$mae_total_err
    mfts_comb_Level_F_err[ikw, 2] = dum$mae_female_err
    mfts_comb_Level_M_err[ikw, 2] = dum$mae_male_err
    
    mfts_comb_Level_0_err[ikw, 3] = dum$rmse_total_err
    mfts_comb_Level_F_err[ikw, 3] = dum$rmse_female_err
    mfts_comb_Level_M_err[ikw, 3] = dum$rmse_male_err
    
    # Region + Sex
    mfts_comb_Level_T_R_err[ikw, 1, ] = dum$me_total_R_err
    mfts_comb_Level_F_R_err[ikw, 1, ] = dum$me_female_R_err
    mfts_comb_Level_M_R_err[ikw, 1, ] = dum$me_male_R_err
    
    mfts_comb_Level_T_R_err[ikw, 2, ] = dum$mae_total_R_err
    mfts_comb_Level_F_R_err[ikw, 2, ] = dum$mae_female_R_err
    mfts_comb_Level_M_R_err[ikw, 2, ] = dum$mae_male_R_err
    
    mfts_comb_Level_T_R_err[ikw, 3, ] = dum$rmse_total_R_err
    mfts_comb_Level_F_R_err[ikw, 3, ] = dum$rmse_female_R_err
    mfts_comb_Level_M_R_err[ikw, 3, ] = dum$rmse_male_R_err
    
    # Prefecture + Sex
    
    mfts_comb_Level_State_err[, ikw, 1]   = dum$me_state_err
    mfts_comb_Level_State_F_err[, ikw, 1] = dum$me_bottom_female_err
    mfts_comb_Level_State_M_err[, ikw, 1] = dum$me_bottom_male_err
    
    mfts_comb_Level_State_err[, ikw, 2]   = dum$mae_state_err
    mfts_comb_Level_State_F_err[, ikw, 2] = dum$mae_bottom_female_err
    mfts_comb_Level_State_M_err[, ikw, 2] = dum$mae_bottom_male_err
    
    mfts_comb_Level_State_err[, ikw, 3]   = dum$rmse_state_err
    mfts_comb_Level_State_F_err[, ikw, 3] = dum$rmse_bottom_female_err
    mfts_comb_Level_State_M_err[, ikw, 3] = dum$rmse_bottom_male_err
    print(ikw)
    rm(dum)
}

mfts_comb_all_level_err_me = cbind(mfts_comb_Level_0_err[,1], rowMeans(cbind(mfts_comb_Level_F_err[,1], mfts_comb_Level_M_err[,1])),
                                   rowMeans(mfts_comb_Level_T_R_err[,1,]), rowMeans(cbind(rowMeans(mfts_comb_Level_F_R_err[,1,]), rowMeans(mfts_comb_Level_M_R_err[,1,]))),
                                   colMeans(mfts_comb_Level_State_err[,,1]), colMeans(rbind(mfts_comb_Level_State_F_err[,,1], mfts_comb_Level_State_M_err[,,1])))

mfts_comb_all_level_err_mae = cbind(mfts_comb_Level_0_err[,2], rowMeans(cbind(mfts_comb_Level_F_err[,2], mfts_comb_Level_M_err[,2])),
                                    rowMeans(mfts_comb_Level_T_R_err[,2,]), rowMeans(cbind(rowMeans(mfts_comb_Level_F_R_err[,2,]), rowMeans(mfts_comb_Level_M_R_err[,2,]))),
                                    colMeans(mfts_comb_Level_State_err[,,2]), colMeans(rbind(mfts_comb_Level_State_F_err[,,2], mfts_comb_Level_State_M_err[,,2])))

mfts_comb_all_level_err_rmse = cbind(mfts_comb_Level_0_err[,3], rowMeans(cbind(mfts_comb_Level_F_err[,3], mfts_comb_Level_M_err[,3])),
                                     rowMeans(mfts_comb_Level_T_R_err[,3,]), rowMeans(cbind(rowMeans(mfts_comb_Level_F_R_err[,3,]), rowMeans(mfts_comb_Level_M_R_err[,3,]))),
                                     colMeans(mfts_comb_Level_State_err[,,3]), colMeans(rbind(mfts_comb_Level_State_F_err[,,3], mfts_comb_Level_State_M_err[,,3])))

mfts_comb_all_level_err_me_mean  = rbind(mfts_comb_all_level_err_me,  colMeans(mfts_comb_all_level_err_me),  apply(mfts_comb_all_level_err_me,  2, median))
mfts_comb_all_level_err_mae_mean  = rbind(mfts_comb_all_level_err_mae,  colMeans(mfts_comb_all_level_err_mae),  apply(mfts_comb_all_level_err_mae,  2, median))
mfts_comb_all_level_err_rmse_mean = rbind(mfts_comb_all_level_err_rmse, colMeans(mfts_comb_all_level_err_rmse), apply(mfts_comb_all_level_err_rmse, 2, median))

colnames(mfts_comb_all_level_err_me_mean) = colnames(mfts_comb_all_level_err_mae_mean) = colnames(mfts_comb_all_level_err_rmse_mean) = c("Total", "Sex", "Region", "Region + Sex", "Prefecture", "Prefecture + Sex")
rownames(mfts_comb_all_level_err_me_mean) = rownames(mfts_comb_all_level_err_mae_mean) = rownames(mfts_comb_all_level_err_rmse_mean) = c(1:15, "Mean", "Median")

###############
# Comb (AvInt)
###############

combination_AvInt_mfts_err <- function(method_fore, ik)
{
    BU_optim_hier_comb = method_fore[[ik]]
    
    # Level 0 (Total)
    me_total_err  = me(BU_optim_hier_comb[,1,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$total)
    mae_total_err  = mae(BU_optim_hier_comb[,1,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$total)
    rmse_total_err = rmse(BU_optim_hier_comb[,1,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$total)
    
    # Level 1 (Sex)
    me_female_err = me(BU_optim_hier_comb[,2,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$female)
    me_male_err   = me(BU_optim_hier_comb[,3,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$male)
    
    mae_female_err = mae(BU_optim_hier_comb[,2,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$female)
    mae_male_err   = mae(BU_optim_hier_comb[,3,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$male)
    
    rmse_female_err = rmse(BU_optim_hier_comb[,2,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$female)
    rmse_male_err   = rmse(BU_optim_hier_comb[,3,], extract.years(get(state[1]), years = (2001+ik):2016)$rate$male)
    
    # Level 2 (Region + Total, Female and Male)
    me_total_R_err = me_female_R_err = me_male_R_err =
    mae_total_R_err = mae_female_R_err = mae_male_R_err =
    rmse_total_R_err = rmse_female_R_err = rmse_male_R_err = vector("numeric",8)
    for(iw in 1:8)
    {
        me_total_R_err[iw]  = me(BU_optim_hier_comb[,(iw+3),],  extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        me_female_R_err[iw] = me(BU_optim_hier_comb[,(iw+11),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        me_male_R_err[iw]   = me(BU_optim_hier_comb[,(iw+19),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
        
        mae_total_R_err[iw]  = mae(BU_optim_hier_comb[,(iw+3),],  extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        mae_female_R_err[iw] = mae(BU_optim_hier_comb[,(iw+11),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        mae_male_R_err[iw]   = mae(BU_optim_hier_comb[,(iw+19),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
        
        rmse_total_R_err[iw]  = rmse(BU_optim_hier_comb[,(iw+3),],  extract.years(get(region[iw]), years = (2001+ik):2016)$rate$total)
        rmse_female_R_err[iw] = rmse(BU_optim_hier_comb[,(iw+11),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$female)
        rmse_male_R_err[iw]   = rmse(BU_optim_hier_comb[,(iw+19),], extract.years(get(region[iw]), years = (2001+ik):2016)$rate$male)
    }
    
    # Level 3 (Prefecture + Total)
    
    rmse_state_err = mae_state_err = me_state_err =
    bottom_female_rmse = bottom_female_mae = bottom_female_me =
    bottom_male_mae = bottom_male_rmse = bottom_male_me = vector("numeric",47)
    for(iwk in 2:48)
    {
        me_state_err[iwk-1]     = me(BU_optim_hier_comb[,(iwk+26),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$total)
        bottom_female_me[iwk-1] = me(BU_optim_hier_comb[,(71+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$female)
        bottom_male_me[iwk-1]   = me(BU_optim_hier_comb[,(72+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$male)
        
        mae_state_err[iwk-1]     = mae(BU_optim_hier_comb[,(iwk+26),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$total)
        bottom_female_mae[iwk-1] = mae(BU_optim_hier_comb[,(71+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$female)
        bottom_male_mae[iwk-1]   = mae(BU_optim_hier_comb[,(72+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$male)
        
        rmse_state_err[iwk-1]     = rmse(BU_optim_hier_comb[,(iwk+26),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$total)
        bottom_female_rmse[iwk-1] = rmse(BU_optim_hier_comb[,(71+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$female)
        bottom_male_rmse[iwk-1]   = rmse(BU_optim_hier_comb[,(72+2*iwk),], extract.years(get(state[iwk]), years = (2001+ik):2016)$rate$male)
    }
    rm(BU_optim_hier_comb)
    return(list(me_total_err = me_total_err, me_female_err = me_female_err, me_male_err = me_male_err,
                me_total_R_err = me_total_R_err, me_female_R_err = me_female_R_err, me_male_R_err = me_male_R_err,
                me_state_err = me_state_err, me_bottom_female_err = bottom_female_me, me_bottom_male_err = bottom_male_me,
                
                mae_total_err = mae_total_err, mae_female_err = mae_female_err, mae_male_err = mae_male_err,
                mae_total_R_err = mae_total_R_err, mae_female_R_err = mae_female_R_err, mae_male_R_err = mae_male_R_err,
                mae_state_err = mae_state_err, mae_bottom_female_err = bottom_female_mae, mae_bottom_male_err = bottom_male_mae,
                
                rmse_total_err = rmse_total_err, rmse_female_err = rmse_female_err, rmse_male_err = rmse_male_err,
                rmse_total_R_err = rmse_total_R_err, rmse_female_R_err = rmse_female_R_err, rmse_male_R_err = rmse_male_R_err,
                rmse_state_err = rmse_state_err, rmse_bottom_female_err = bottom_female_rmse, rmse_bottom_male_err = bottom_male_rmse))
}

mfts_comb_AvInt_Level_0_err = mfts_comb_AvInt_Level_F_err = mfts_comb_AvInt_Level_M_err = matrix(NA,15,3)
mfts_comb_AvInt_Level_T_R_err = mfts_comb_AvInt_Level_F_R_err = mfts_comb_AvInt_Level_M_R_err = array(NA, dim = c(15,3,8))

mfts_comb_AvInt_Level_State_err = mfts_comb_AvInt_Level_State_F_err = mfts_comb_AvInt_Level_State_M_err = array(NA, dim = c(47,15,3))
for(ikw in 1:15)
{
    dum = combination_AvInt_mfts_err(method_fore = comb_hier_comb_mfts_midpoints, ik = ikw)
    
    # Total + Sex
    mfts_comb_AvInt_Level_0_err[ikw, 1] = dum$me_total_err
    mfts_comb_AvInt_Level_F_err[ikw, 1] = dum$me_female_err
    mfts_comb_AvInt_Level_M_err[ikw, 1] = dum$me_male_err
    
    mfts_comb_AvInt_Level_0_err[ikw, 2] = dum$mae_total_err
    mfts_comb_AvInt_Level_F_err[ikw, 2] = dum$mae_female_err
    mfts_comb_AvInt_Level_M_err[ikw, 2] = dum$mae_male_err
    
    mfts_comb_AvInt_Level_0_err[ikw, 3] = dum$rmse_total_err
    mfts_comb_AvInt_Level_F_err[ikw, 3] = dum$rmse_female_err
    mfts_comb_AvInt_Level_M_err[ikw, 3] = dum$rmse_male_err
    
    # Region + Sex
    mfts_comb_AvInt_Level_T_R_err[ikw, 1, ] = dum$me_total_R_err
    mfts_comb_AvInt_Level_F_R_err[ikw, 1, ] = dum$me_female_R_err
    mfts_comb_AvInt_Level_M_R_err[ikw, 1, ] = dum$me_male_R_err
    
    mfts_comb_AvInt_Level_T_R_err[ikw, 2, ] = dum$mae_total_R_err
    mfts_comb_AvInt_Level_F_R_err[ikw, 2, ] = dum$mae_female_R_err
    mfts_comb_AvInt_Level_M_R_err[ikw, 2, ] = dum$mae_male_R_err
    
    mfts_comb_AvInt_Level_T_R_err[ikw, 3, ] = dum$rmse_total_R_err
    mfts_comb_AvInt_Level_F_R_err[ikw, 3, ] = dum$rmse_female_R_err
    mfts_comb_AvInt_Level_M_R_err[ikw, 3, ] = dum$rmse_male_R_err
    
    # Prefecture + Sex
    
    mfts_comb_AvInt_Level_State_err[, ikw, 1]   = dum$me_state_err
    mfts_comb_AvInt_Level_State_F_err[, ikw, 1] = dum$me_bottom_female_err
    mfts_comb_AvInt_Level_State_M_err[, ikw, 1] = dum$me_bottom_male_err
    
    mfts_comb_AvInt_Level_State_err[, ikw, 2]   = dum$mae_state_err
    mfts_comb_AvInt_Level_State_F_err[, ikw, 2] = dum$mae_bottom_female_err
    mfts_comb_AvInt_Level_State_M_err[, ikw, 2] = dum$mae_bottom_male_err
    
    mfts_comb_AvInt_Level_State_err[, ikw, 3]   = dum$rmse_state_err
    mfts_comb_AvInt_Level_State_F_err[, ikw, 3] = dum$rmse_bottom_female_err
    mfts_comb_AvInt_Level_State_M_err[, ikw, 3] = dum$rmse_bottom_male_err
    print(ikw)
    rm(dum)
}

mfts_comb_AvInt_all_level_err_me = cbind(mfts_comb_AvInt_Level_0_err[,1], rowMeans(cbind(mfts_comb_AvInt_Level_F_err[,1], mfts_comb_AvInt_Level_M_err[,1])),
                                         rowMeans(mfts_comb_AvInt_Level_T_R_err[,1,]), rowMeans(cbind(rowMeans(mfts_comb_AvInt_Level_F_R_err[,1,]), rowMeans(mfts_comb_AvInt_Level_M_R_err[,1,]))),
                                         colMeans(mfts_comb_AvInt_Level_State_err[,,1]), colMeans(rbind(mfts_comb_AvInt_Level_State_F_err[,,1], mfts_comb_AvInt_Level_State_M_err[,,1])))

mfts_comb_AvInt_all_level_err_mae = cbind(mfts_comb_AvInt_Level_0_err[,2], rowMeans(cbind(mfts_comb_AvInt_Level_F_err[,2], mfts_comb_AvInt_Level_M_err[,2])),
                                          rowMeans(mfts_comb_AvInt_Level_T_R_err[,2,]), rowMeans(cbind(rowMeans(mfts_comb_AvInt_Level_F_R_err[,2,]), rowMeans(mfts_comb_AvInt_Level_M_R_err[,2,]))),
                                          colMeans(mfts_comb_AvInt_Level_State_err[,,2]), colMeans(rbind(mfts_comb_AvInt_Level_State_F_err[,,2], mfts_comb_AvInt_Level_State_M_err[,,2])))

mfts_comb_AvInt_all_level_err_rmse = cbind(mfts_comb_AvInt_Level_0_err[,3], rowMeans(cbind(mfts_comb_AvInt_Level_F_err[,3], mfts_comb_AvInt_Level_M_err[,3])),
                                           rowMeans(mfts_comb_AvInt_Level_T_R_err[,3,]), rowMeans(cbind(rowMeans(mfts_comb_AvInt_Level_F_R_err[,3,]), rowMeans(mfts_comb_AvInt_Level_M_R_err[,3,]))),
                                           colMeans(mfts_comb_AvInt_Level_State_err[,,3]), colMeans(rbind(mfts_comb_AvInt_Level_State_F_err[,,3], mfts_comb_AvInt_Level_State_M_err[,,3])))

mfts_comb_AvInt_all_level_err_me_mean  = rbind(mfts_comb_AvInt_all_level_err_me,  colMeans(mfts_comb_AvInt_all_level_err_me),  apply(mfts_comb_AvInt_all_level_err_me,  2, median))
mfts_comb_AvInt_all_level_err_mae_mean  = rbind(mfts_comb_AvInt_all_level_err_mae,  colMeans(mfts_comb_AvInt_all_level_err_mae),  apply(mfts_comb_AvInt_all_level_err_mae,  2, median))
mfts_comb_AvInt_all_level_err_rmse_mean = rbind(mfts_comb_AvInt_all_level_err_rmse, colMeans(mfts_comb_AvInt_all_level_err_rmse), apply(mfts_comb_AvInt_all_level_err_rmse, 2, median))

colnames(mfts_comb_AvInt_all_level_err_me_mean) = colnames(mfts_comb_AvInt_all_level_err_mae_mean) = colnames(mfts_comb_AvInt_all_level_err_rmse_mean) = c("Total", "Sex", "Region", "Region + Sex", "Prefecture", "Prefecture + Sex")
rownames(mfts_comb_AvInt_all_level_err_me_mean) = rownames(mfts_comb_AvInt_all_level_err_mae_mean) = rownames(mfts_comb_AvInt_all_level_err_rmse_mean) = c(1:15, "Mean", "Median")

######
# MFE
######

# FTS

xtable(rbind(t(ind_all_level_err_me_all[c(1,5,10,15:17),])[1,],
t(BU_all_level_err_me_mean[c(1,5,10,15:17),])[1,],
t(optim_all_level_err_me_mean[c(1,5,10,15:17),])[1,],
t(comb_all_level_err_me_mean[c(1,5,10,15:17),])[1,],
t(comb_AvInt_all_level_err_me_mean[c(1,5,10,15:17),])[1,],

t(ind_all_level_err_me_all[c(1,5,10,15:17),])[2,],
t(BU_all_level_err_me_mean[c(1,5,10,15:17),])[2,],
t(optim_all_level_err_me_mean[c(1,5,10,15:17),])[2,],
t(comb_all_level_err_me_mean[c(1,5,10,15:17),])[2,],
t(comb_AvInt_all_level_err_me_mean[c(1,5,10,15:17),])[2,],

t(ind_all_level_err_me_all[c(1,5,10,15:17),])[3,],
t(BU_all_level_err_me_mean[c(1,5,10,15:17),])[3,],
t(optim_all_level_err_me_mean[c(1,5,10,15:17),])[3,],
t(comb_all_level_err_me_mean[c(1,5,10,15:17),])[3,],
t(comb_AvInt_all_level_err_me_mean[c(1,5,10,15:17),])[3,],

t(ind_all_level_err_me_all[c(1,5,10,15:17),])[4,],
t(BU_all_level_err_me_mean[c(1,5,10,15:17),])[4,],
t(optim_all_level_err_me_mean[c(1,5,10,15:17),])[4,],
t(comb_all_level_err_me_mean[c(1,5,10,15:17),])[4,],
t(comb_AvInt_all_level_err_me_mean[c(1,5,10,15:17),])[4,],

t(ind_all_level_err_me_all[c(1,5,10,15:17),])[5,],
t(BU_all_level_err_me_mean[c(1,5,10,15:17),])[5,],
t(optim_all_level_err_me_mean[c(1,5,10,15:17),])[5,],
t(comb_all_level_err_me_mean[c(1,5,10,15:17),])[5,],
t(comb_AvInt_all_level_err_me_mean[c(1,5,10,15:17),])[5,],

t(ind_all_level_err_me_all[c(1,5,10,15:17),])[6,],
t(BU_all_level_err_me_mean[c(1,5,10,15:17),])[6,],
t(optim_all_level_err_me_mean[c(1,5,10,15:17),])[6,],
t(comb_all_level_err_me_mean[c(1,5,10,15:17),])[6,],
t(comb_AvInt_all_level_err_me_mean[c(1,5,10,15:17),])[6,]) * 100, digits = 2)

# MFTS

xtable(rbind(t(mfts_all_level_err_me_all[c(1,5,10,15:17),])[1,],
t(mfts_BU_all_level_err_me_mean[c(1,5,10,15:17),])[1,],
t(mfts_optim_all_level_err_me_mean[c(1,5,10,15:17),])[1,],
t(mfts_comb_all_level_err_me_mean[c(1,5,10,15:17),])[1,],
t(mfts_comb_AvInt_all_level_err_me_mean[c(1,5,10,15:17),])[1,],

t(mfts_all_level_err_me_all[c(1,5,10,15:17),])[2,],
t(mfts_BU_all_level_err_me_mean[c(1,5,10,15:17),])[2,],
t(mfts_optim_all_level_err_me_mean[c(1,5,10,15:17),])[2,],
t(mfts_comb_all_level_err_me_mean[c(1,5,10,15:17),])[2,],
t(mfts_comb_AvInt_all_level_err_me_mean[c(1,5,10,15:17),])[2,],

t(mfts_all_level_err_me_all[c(1,5,10,15:17),])[3,],
t(mfts_BU_all_level_err_me_mean[c(1,5,10,15:17),])[3,],
t(mfts_optim_all_level_err_me_mean[c(1,5,10,15:17),])[3,],
t(mfts_comb_all_level_err_me_mean[c(1,5,10,15:17),])[3,],
t(mfts_comb_AvInt_all_level_err_me_mean[c(1,5,10,15:17),])[3,],

t(mfts_all_level_err_me_all[c(1,5,10,15:17),])[4,],
t(mfts_BU_all_level_err_me_mean[c(1,5,10,15:17),])[4,],
t(mfts_optim_all_level_err_me_mean[c(1,5,10,15:17),])[4,],
t(mfts_comb_all_level_err_me_mean[c(1,5,10,15:17),])[4,],
t(mfts_comb_AvInt_all_level_err_me_mean[c(1,5,10,15:17),])[4,],

t(mfts_all_level_err_me_all[c(1,5,10,15:17),])[5,],
t(mfts_BU_all_level_err_me_mean[c(1,5,10,15:17),])[5,],
t(mfts_optim_all_level_err_me_mean[c(1,5,10,15:17),])[5,],
t(mfts_comb_all_level_err_me_mean[c(1,5,10,15:17),])[5,],
t(mfts_comb_AvInt_all_level_err_me_mean[c(1,5,10,15:17),])[5,],

t(mfts_all_level_err_me_all[c(1,5,10,15:17),])[6,],
t(mfts_BU_all_level_err_me_mean[c(1,5,10,15:17),])[6,],
t(mfts_optim_all_level_err_me_mean[c(1,5,10,15:17),])[6,],
t(mfts_comb_all_level_err_me_mean[c(1,5,10,15:17),])[6,],
t(mfts_comb_AvInt_all_level_err_me_mean[c(1,5,10,15:17),])[6,]) * 100, digits = 2)

## ggplot

library(tidyverse)
library(ggplot2)

data_series <- map2_dfr(.x = 1:6, .y = c("Total", "Sex", "Region", "Region + Sex", "Prefecture", "Prefecture + Sex"),
                        ~tibble(
                          variety = forcats::as_factor(rep(c("Ind", "BU", "OLS", "Comb_Av", "Comb_AvInt",
                                                             "Ind", "BU", "OLS", "Comb_Av", "Comb_AvInt"), each = 15)),
                          Method  = forcats::as_factor(rep(c("Univariate FTS", "Multivariate FTS"), each = 75)),
                          series = c(ind_all_level_err_me_all[1:15, .x],
                                     BU_all_level_err_me_mean[1:15, .x],
                                     optim_all_level_err_me_mean[1:15, .x],
                                     comb_all_level_err_me_mean[1:15, .x],
                                     comb_AvInt_all_level_err_me_mean[1:15, .x],
                                     mfts_all_level_err_me_all[1:15, .x],
                                     mfts_BU_all_level_err_me_mean[1:15, .x],
                                     mfts_optim_all_level_err_me_mean[1:15, .x],
                                     mfts_comb_all_level_err_me_mean[1:15, .x],
                                     mfts_comb_AvInt_all_level_err_me_mean[1:15, .x]),
                          type = factor(paste(.y, "series"), levels = c("Total series", "Region series", "Prefecture series", "Sex series", "Region + Sex series", "Prefecture + Sex series"))
                        ))


ggplot(data_series, aes(x = variety, y = series, fill = Method)) +
  geom_boxplot() + ylab("MFE") + xlab("") +
  facet_wrap(~type)
ggsave("MFE_plot.png")


#######
# MAFE
#######

# FTS

xtable(rbind(t(ind_all_level_err_mae_all[c(1,5,10,15:17),])[1,],
t(BU_all_level_err_mae_mean[c(1,5,10,15:17),])[1,],
t(optim_all_level_err_mae_mean[c(1,5,10,15:17),])[1,],
t(comb_all_level_err_mae_mean[c(1,5,10,15:17),])[1,],
t(comb_AvInt_all_level_err_mae_mean[c(1,5,10,15:17),])[1,],

t(ind_all_level_err_mae_all[c(1,5,10,15:17),])[2,],
t(BU_all_level_err_mae_mean[c(1,5,10,15:17),])[2,],
t(optim_all_level_err_mae_mean[c(1,5,10,15:17),])[2,],
t(comb_all_level_err_mae_mean[c(1,5,10,15:17),])[2,],
t(comb_AvInt_all_level_err_mae_mean[c(1,5,10,15:17),])[2,],

t(ind_all_level_err_mae_all[c(1,5,10,15:17),])[3,],
t(BU_all_level_err_mae_mean[c(1,5,10,15:17),])[3,],
t(optim_all_level_err_mae_mean[c(1,5,10,15:17),])[3,],
t(comb_all_level_err_mae_mean[c(1,5,10,15:17),])[3,],
t(comb_AvInt_all_level_err_mae_mean[c(1,5,10,15:17),])[3,],

t(ind_all_level_err_mae_all[c(1,5,10,15:17),])[4,],
t(BU_all_level_err_mae_mean[c(1,5,10,15:17),])[4,],
t(optim_all_level_err_mae_mean[c(1,5,10,15:17),])[4,],
t(comb_all_level_err_mae_mean[c(1,5,10,15:17),])[4,],
t(comb_AvInt_all_level_err_mae_mean[c(1,5,10,15:17),])[4,],

t(ind_all_level_err_mae_all[c(1,5,10,15:17),])[5,],
t(BU_all_level_err_mae_mean[c(1,5,10,15:17),])[5,],
t(optim_all_level_err_mae_mean[c(1,5,10,15:17),])[5,],
t(comb_all_level_err_mae_mean[c(1,5,10,15:17),])[5,],
t(comb_AvInt_all_level_err_mae_mean[c(1,5,10,15:17),])[5,],

t(ind_all_level_err_mae_all[c(1,5,10,15:17),])[6,],
t(BU_all_level_err_mae_mean[c(1,5,10,15:17),])[6,],
t(optim_all_level_err_mae_mean[c(1,5,10,15:17),])[6,],
t(comb_all_level_err_mae_mean[c(1,5,10,15:17),])[6,],
t(comb_AvInt_all_level_err_mae_mean[c(1,5,10,15:17),])[6,]) * 100, digits = 2)

# MFTS

xtable(rbind(t(mfts_all_level_err_mae_all[c(1,5,10,15:17),])[1,],
t(mfts_BU_all_level_err_mae_mean[c(1,5,10,15:17),])[1,],
t(mfts_optim_all_level_err_mae_mean[c(1,5,10,15:17),])[1,],
t(mfts_comb_all_level_err_mae_mean[c(1,5,10,15:17),])[1,],
t(mfts_comb_AvInt_all_level_err_mae_mean[c(1,5,10,15:17),])[1,],

t(mfts_all_level_err_mae_all[c(1,5,10,15:17),])[2,],
t(mfts_BU_all_level_err_mae_mean[c(1,5,10,15:17),])[2,],
t(mfts_optim_all_level_err_mae_mean[c(1,5,10,15:17),])[2,],
t(mfts_comb_all_level_err_mae_mean[c(1,5,10,15:17),])[2,],
t(mfts_comb_AvInt_all_level_err_mae_mean[c(1,5,10,15:17),])[2,],

t(mfts_all_level_err_mae_all[c(1,5,10,15:17),])[3,],
t(mfts_BU_all_level_err_mae_mean[c(1,5,10,15:17),])[3,],
t(mfts_optim_all_level_err_mae_mean[c(1,5,10,15:17),])[3,],
t(mfts_comb_all_level_err_mae_mean[c(1,5,10,15:17),])[3,],
t(mfts_comb_AvInt_all_level_err_mae_mean[c(1,5,10,15:17),])[3,],

t(mfts_all_level_err_mae_all[c(1,5,10,15:17),])[4,],
t(mfts_BU_all_level_err_mae_mean[c(1,5,10,15:17),])[4,],
t(mfts_optim_all_level_err_mae_mean[c(1,5,10,15:17),])[4,],
t(mfts_comb_all_level_err_mae_mean[c(1,5,10,15:17),])[4,],
t(mfts_comb_AvInt_all_level_err_mae_mean[c(1,5,10,15:17),])[4,],

t(mfts_all_level_err_mae_all[c(1,5,10,15:17),])[5,],
t(mfts_BU_all_level_err_mae_mean[c(1,5,10,15:17),])[5,],
t(mfts_optim_all_level_err_mae_mean[c(1,5,10,15:17),])[5,],
t(mfts_comb_all_level_err_mae_mean[c(1,5,10,15:17),])[5,],
t(mfts_comb_AvInt_all_level_err_mae_mean[c(1,5,10,15:17),])[5,],

t(mfts_all_level_err_mae_all[c(1,5,10,15:17),])[6,],
t(mfts_BU_all_level_err_mae_mean[c(1,5,10,15:17),])[6,],
t(mfts_optim_all_level_err_mae_mean[c(1,5,10,15:17),])[6,],
t(mfts_comb_all_level_err_mae_mean[c(1,5,10,15:17),])[6,],
t(mfts_comb_AvInt_all_level_err_mae_mean[c(1,5,10,15:17),])[6,]) * 100, digits = 2)


data_series <- map2_dfr(.x = 1:6, .y = c("Total", "Sex", "Region", "Region + Sex", "Prefecture", "Prefecture + Sex"),
                        ~tibble(
                          variety = forcats::as_factor(rep(c("Ind", "BU", "OLS", "Comb_Av", "Comb_AvInt",
                                                             "Ind", "BU", "OLS", "Comb_Av", "Comb_AvInt"), each = 15)),
                          Method  = forcats::as_factor(rep(c("Univariate FTS", "Multivariate FTS"), each = 75)),
                          series = c(ind_all_level_err_mae_all[1:15, .x],
                                     BU_all_level_err_mae_mean[1:15, .x],
                                     optim_all_level_err_mae_mean[1:15, .x],
                                     comb_all_level_err_mae_mean[1:15, .x],
                                     comb_AvInt_all_level_err_mae_mean[1:15, .x],
                                     mfts_all_level_err_mae_all[1:15, .x],
                                     mfts_BU_all_level_err_mae_mean[1:15, .x],
                                     mfts_optim_all_level_err_mae_mean[1:15, .x],
                                     mfts_comb_all_level_err_mae_mean[1:15, .x],
                                     mfts_comb_AvInt_all_level_err_mae_mean[1:15, .x]),
                          type = factor(paste(.y, "series"), levels = c("Total series", "Region series", "Prefecture series", "Sex series", "Region + Sex series", "Prefecture + Sex series"))
                        ))


ggplot(data_series, aes(x = variety, y = series, fill = Method)) +
  geom_boxplot() + ylab("MAFE") + xlab("") +
  facet_wrap(~type)
ggsave("MAFE_plot.png")


########
# RMSFE
########

# FTS

xtable(rbind(t(ind_all_level_err_rmse_all[c(1,5,10,15:17),])[1,],
t(BU_all_level_err_rmse_mean[c(1,5,10,15:17),])[1,],
t(optim_all_level_err_rmse_mean[c(1,5,10,15:17),])[1,],
t(comb_all_level_err_rmse_mean[c(1,5,10,15:17),])[1,],
t(comb_AvInt_all_level_err_rmse_mean[c(1,5,10,15:17),])[1,],

t(ind_all_level_err_rmse_all[c(1,5,10,15:17),])[2,],
t(BU_all_level_err_rmse_mean[c(1,5,10,15:17),])[2,],
t(optim_all_level_err_rmse_mean[c(1,5,10,15:17),])[2,],
t(comb_all_level_err_rmse_mean[c(1,5,10,15:17),])[2,],
t(comb_AvInt_all_level_err_rmse_mean[c(1,5,10,15:17),])[2,],

t(ind_all_level_err_rmse_all[c(1,5,10,15:17),])[3,],
t(BU_all_level_err_rmse_mean[c(1,5,10,15:17),])[3,],
t(optim_all_level_err_rmse_mean[c(1,5,10,15:17),])[3,],
t(comb_all_level_err_rmse_mean[c(1,5,10,15:17),])[3,],
t(comb_AvInt_all_level_err_rmse_mean[c(1,5,10,15:17),])[3,],

t(ind_all_level_err_rmse_all[c(1,5,10,15:17),])[4,],
t(BU_all_level_err_rmse_mean[c(1,5,10,15:17),])[4,],
t(optim_all_level_err_rmse_mean[c(1,5,10,15:17),])[4,],
t(comb_all_level_err_rmse_mean[c(1,5,10,15:17),])[4,],
t(comb_AvInt_all_level_err_rmse_mean[c(1,5,10,15:17),])[4,],

t(ind_all_level_err_rmse_all[c(1,5,10,15:17),])[5,],
t(BU_all_level_err_rmse_mean[c(1,5,10,15:17),])[5,],
t(optim_all_level_err_rmse_mean[c(1,5,10,15:17),])[5,],
t(comb_all_level_err_rmse_mean[c(1,5,10,15:17),])[5,],
t(comb_AvInt_all_level_err_rmse_mean[c(1,5,10,15:17),])[5,],

t(ind_all_level_err_rmse_all[c(1,5,10,15:17),])[6,],
t(BU_all_level_err_rmse_mean[c(1,5,10,15:17),])[6,],
t(optim_all_level_err_rmse_mean[c(1,5,10,15:17),])[6,],
t(comb_all_level_err_rmse_mean[c(1,5,10,15:17),])[6,],
t(comb_AvInt_all_level_err_rmse_mean[c(1,5,10,15:17),])[6,]) * 100, digits = 2)

# MFTS

xtable(rbind(t(mfts_all_level_err_rmse_all[c(1,5,10,15:17),])[1,],
t(mfts_BU_all_level_err_rmse_mean[c(1,5,10,15:17),])[1,],
t(mfts_optim_all_level_err_rmse_mean[c(1,5,10,15:17),])[1,],
t(mfts_comb_all_level_err_rmse_mean[c(1,5,10,15:17),])[1,],
t(mfts_comb_AvInt_all_level_err_rmse_mean[c(1,5,10,15:17),])[1,],

t(mfts_all_level_err_rmse_all[c(1,5,10,15:17),])[2,],
t(mfts_BU_all_level_err_rmse_mean[c(1,5,10,15:17),])[2,],
t(mfts_optim_all_level_err_rmse_mean[c(1,5,10,15:17),])[2,],
t(mfts_comb_all_level_err_rmse_mean[c(1,5,10,15:17),])[2,],
t(mfts_comb_AvInt_all_level_err_rmse_mean[c(1,5,10,15:17),])[2,],

t(mfts_all_level_err_rmse_all[c(1,5,10,15:17),])[3,],
t(mfts_BU_all_level_err_rmse_mean[c(1,5,10,15:17),])[3,],
t(mfts_optim_all_level_err_rmse_mean[c(1,5,10,15:17),])[3,],
t(mfts_comb_all_level_err_rmse_mean[c(1,5,10,15:17),])[3,],
t(mfts_comb_AvInt_all_level_err_rmse_mean[c(1,5,10,15:17),])[3,],

t(mfts_all_level_err_rmse_all[c(1,5,10,15:17),])[4,],
t(mfts_BU_all_level_err_rmse_mean[c(1,5,10,15:17),])[4,],
t(mfts_optim_all_level_err_rmse_mean[c(1,5,10,15:17),])[4,],
t(mfts_comb_all_level_err_rmse_mean[c(1,5,10,15:17),])[4,],
t(mfts_comb_AvInt_all_level_err_rmse_mean[c(1,5,10,15:17),])[4,],

t(mfts_all_level_err_rmse_all[c(1,5,10,15:17),])[5,],
t(mfts_BU_all_level_err_rmse_mean[c(1,5,10,15:17),])[5,],
t(mfts_optim_all_level_err_rmse_mean[c(1,5,10,15:17),])[5,],
t(mfts_comb_all_level_err_rmse_mean[c(1,5,10,15:17),])[5,],
t(mfts_comb_AvInt_all_level_err_rmse_mean[c(1,5,10,15:17),])[5,],

t(mfts_all_level_err_rmse_all[c(1,5,10,15:17),])[6,],
t(mfts_BU_all_level_err_rmse_mean[c(1,5,10,15:17),])[6,],
t(mfts_optim_all_level_err_rmse_mean[c(1,5,10,15:17),])[6,],
t(mfts_comb_all_level_err_rmse_mean[c(1,5,10,15:17),])[6,],
t(mfts_comb_AvInt_all_level_err_rmse_mean[c(1,5,10,15:17),])[6,]) * 100, digits = 2)

######################################################
# construct prediction interval for single population
######################################################

find_enlarge_val <- function(smooth_data, raw_data, series, fh, var_prop = 0.9, alpha = 0.8,
                             transformation = c("log", "logit"))
{
    pca_dat = fdm(smooth_data, series = series, order = 10)
    ncomp = head(which(round(cumsum(pca_dat$varprop), 3) >= var_prop), 1)
    if(class(ncomp) != "integer")
    {
        warning("ncomp is out of 10")
    }
    pca_dat = fdm(smooth_data, series = series, order = ncomp)
    
    # calculate in-sample forecast curves
    fore_curve_pre = matrix(NA, length(smooth_data$age), length(smooth_data$year) - ncomp - fh + 1)
    for(ij in 1:(length(smooth_data$year) - ncomp - fh + 1))
    {
        fore_coef = matrix(NA, ncomp, 1)
        for(ik in 2:(ncomp + 1))
        {
            fore_coef[ik-1, 1] = forecast(auto.arima(pca_dat$coeff[1:(ij+ncomp-1), ik]), h = fh)$mean[fh]
        }
        fore_curve_pre[,ij] = pca_dat$basis[,1] + pca_dat$basis[,2:(ncomp+1)] %*% fore_coef
    }
    if(transformation == "log")
    {
        fore_curve = fore_curve_pre
    }
    if(transformation == "logit")
    {
        fore_curve = logit(exp(fore_curve_pre))
    }
    
    # holdout data example
    true_dat = extract.years(raw_data, raw_data$year[(ncomp + fh): length(raw_data$year)])
    if(transformation == "log")
    {
        if(series == "total")
        {
            holdout_val = log(true_dat$rate$total)
        }
        if(series == "male")
        {
            holdout_val = log(true_dat$rate$male)
        }
        if(series == "female")
        {
            holdout_val = log(true_dat$rate$female)
        }
    }
    if(transformation == "logit")
    {
        if(series == "total")
        {
            holdout_val = logit(true_dat$rate$total)
        }
        if(series == "male")
        {
            holdout_val = logit(true_dat$rate$male)
        }
        if(series == "female")
        {
            holdout_val = logit(true_dat$rate$female)
        }
    }
    if(length(which(!is.finite(holdout_val))) > 0)
    {
        warning("some holdout data have Inf.")
        index = which(!is.finite(holdout_val))
        holdout_mat = replace(holdout_val, index, NA)
        rm(holdout_val)
        holdout_val = matrix(NA, nrow(holdout_mat), ncol(holdout_mat))
        for(ik in 1:ncol(holdout_mat))
        {
            holdout_val[,ik] = na.interp(holdout_mat[,ik])
        }
    }
    
    # calculate in-sample forecast errors
    err = holdout_val - fore_curve
    
    # bootstrap error function
    
    if(ncol(err) == 1)
    {
        prediction_err_sd = sd(err)
    }
    else
    {
        prediction_err_sd = apply(err, 1, sd)
    }
    
    select_pointwise_tuning_parameter <- function(tuning_parameter, nominal_coverage)
    {
        nB = ncol(err)
        lb = -1 * tuning_parameter * prediction_err_sd
        ub = tuning_parameter * prediction_err_sd
        out_number = vector("numeric", nB)
        for(ik in 1:nB)
        {
            holdout = err[,ik]
            out_number[ik] = length(union(which(lb > holdout), which(ub < holdout)))
        }
        empirical_coverage = 1 - (sum(out_number)/length(err))
        return(abs(empirical_coverage - nominal_coverage))
    }
   
    pointwise_tuning_parameter_PI = optimize(f = select_pointwise_tuning_parameter, interval = c(0.1, 5), nominal_coverage = alpha)$minimum
    
    # constructing PI
    if(series == "female")
    {
        fore_pca_dat = log(forecast(pca_dat, h = fh)$rate$female)[,fh]
    }
    if(series == "male")
    {
        fore_pca_dat = log(forecast(pca_dat, h = fh)$rate$male)[,fh]
    }
    if(series == "total")
    {
        fore_pca_dat = log(forecast(pca_dat, h = fh)$rate$total)[,fh]
    }
    # bootPI = err_boot_fore + matrix(rep(fore_pca_dat, nboot), nrow = length(smooth_data$age), ncol = nboot)
    
    parametric_pointwise_out = cbind(fore_pca_dat - prediction_err_sd * pointwise_tuning_parameter_PI,
                                     fore_pca_dat + prediction_err_sd * pointwise_tuning_parameter_PI)
    colnames(parametric_pointwise_out) = c("lb", "ub")
    return(parametric_pointwise_out)
}

##################################################################
# pointwise prediction interval for a particular forecast horizon
##################################################################

PI_fh <- function(smooth_series, raw_series, series, fh, transform = c("log", "logit"))
{
    transform = match.arg(transform)
    PI_pointwise_res = array(NA, dim = c(41, 2, (16 - fh)))
    for(ij in 1:(16-fh))
    {
        PI_pointwise_res[,,ij] = find_enlarge_val(smooth_data = extract.years(smooth_series, 1975:(2000+ij)),
                                                  raw_data = extract.years(raw_series, 1975:(2000+ij)),
                                                  series = series, fh = fh, transformation = transform)
    }
    return(PI_pointwise_res)
}

###########################################################
# compute interval score for a particular forecast horizon
###########################################################

interval_score <- function(PI_val, data_series, series, fh, alpha = 0.8)
{
    if(series == "female")
    {
        test_val = extract.years(data_series, (2001+fh):2016)$rate$female
    }
    if(series == "male")
    {
        test_val = extract.years(data_series, (2001+fh):2016)$rate$male
    }
    if(series == "total")
    {
        test_val = extract.years(data_series, (2001+fh):2016)$rate$total
    }
    # transform back to the original scale
    boot_sample = exp(PI_val[[fh]])
    index = which(boot_sample > 1)
    if(length(index) > 0)
    {
        boot_sample_v1 = replace(boot_sample, index, 1)
    }
    else
    {
        boot_sample_v1 = boot_sample
    }
    index_below = which(boot_sample < 0)
    if(length(index_below) > 0)
    {
        boot_sample_v2 = replace(boot_sample_v1, index_below, 0)
    }
    else
    {
        boot_sample_v2 = boot_sample_v1
    }
    # dummy = apply(boot_sample_v2, c(1,3), quantile, c((1 - alpha)/2, (1 + alpha)/2), na.rm = TRUE)
    PI_lb_val = boot_sample_v2[,1,]
    PI_ub_val = boot_sample_v2[,2,]
    
    lb_ind = ifelse(test_val < PI_lb_val, 1, 0)
    ub_ind = ifelse(test_val > PI_ub_val, 1, 0)
    score = mean((PI_ub_val - PI_lb_val) + 2/(1 - alpha) * (PI_lb_val - test_val) * lb_ind + 2/(1 - alpha) * (test_val - PI_ub_val) * ub_ind, na.rm = TRUE)
    return(score)
}

########
# Japan
########

install.packages("doMC")
require(doMC)
registerDoMC(15)
Japan_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Japan_smooth, raw_series = Japan, series = "female", fh = ik)
Japan_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Japan_smooth, raw_series = Japan, series = "male", fh = ik)
Japan_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Japan_smooth, raw_series = Japan, series = "total", fh = ik)

###########
# Hokkaido
###########

Hokkaido_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Hokkaido_smooth, raw_series = Hokkaido, series = "female", fh = ik)
Hokkaido_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Hokkaido_smooth, raw_series = Hokkaido, series = "male", fh = ik)
Hokkaido_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Hokkaido_smooth, raw_series = Hokkaido, series = "total", fh = ik)

#########
# Aomori
#########

Aomori_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Aomori_smooth, raw_series = Aomori, series = "female", fh = ik)
Aomori_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Aomori_smooth, raw_series = Aomori, series = "male", fh = ik)
Aomori_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Aomori_smooth, raw_series = Aomori, series = "total", fh = ik)

########
# Iwate
########

Iwate_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Iwate_smooth, raw_series = Iwate, series = "female", fh = ik)
Iwate_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Iwate_smooth, raw_series = Iwate, series = "male", fh = ik)
Iwate_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Iwate_smooth, raw_series = Iwate, series = "total", fh = ik)

#########
# Miyagi
#########

Miyagi_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Miyagi_smooth, raw_series = Miyagi, series = "female", fh = ik)
Miyagi_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Miyagi_smooth, raw_series = Miyagi, series = "male", fh = ik)
Miyagi_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Miyagi_smooth, raw_series = Miyagi, series = "total", fh = ik)

########
# Akita
########

Akita_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Akita_smooth, raw_series = Akita, series = "female", fh = ik)
Akita_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Akita_smooth, raw_series = Akita, series = "male", fh = ik)
Akita_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Akita_smooth, raw_series = Akita, series = "total", fh = ik)

###########
# Yamagata
###########

Yamagata_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Yamagata_smooth, raw_series = Yamagata, series = "female", fh = ik)
Yamagata_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Yamagata_smooth, raw_series = Yamagata, series = "male", fh = ik)
Yamagata_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Yamagata_smooth, raw_series = Yamagata, series = "total", fh = ik)

############
# Fukushima
############

Fukushima_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Fukushima_smooth, raw_series = Fukushima, series = "female", fh = ik)
Fukushima_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Fukushima_smooth, raw_series = Fukushima, series = "male", fh = ik)
Fukushima_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Fukushima_smooth, raw_series = Fukushima, series = "total", fh = ik)

##########
# Ibaraki
##########

Ibaraki_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Ibaraki_smooth, raw_series = Ibaraki, series = "female", fh = ik)
Ibaraki_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Ibaraki_smooth, raw_series = Ibaraki, series = "male", fh = ik)
Ibaraki_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Ibaraki_smooth, raw_series = Ibaraki, series = "total", fh = ik)

##########
# Tochigi
##########

Tochigi_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Tochigi_smooth, raw_series = Tochigi, series = "female", fh = ik)
Tochigi_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Tochigi_smooth, raw_series = Tochigi, series = "male", fh = ik)
Tochigi_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Tochigi_smooth, raw_series = Tochigi, series = "total", fh = ik)

########
# Gunma
########

Gunma_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Gunma_smooth, raw_series = Gunma, series = "female", fh = ik)
Gunma_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Gunma_smooth, raw_series = Gunma, series = "male", fh = ik)
Gunma_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Gunma_smooth, raw_series = Gunma, series = "total", fh = ik)

##########
# Saitama
##########

Saitama_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Saitama_smooth, raw_series = Saitama, series = "female", fh = ik)
Saitama_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Saitama_smooth, raw_series = Saitama, series = "male", fh = ik)
Saitama_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Saitama_smooth, raw_series = Saitama, series = "total", fh = ik)

########
# Chiba
########

Chiba_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Chiba_smooth, raw_series = Chiba, series = "female", fh = ik)
Chiba_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Chiba_smooth, raw_series = Chiba, series = "male", fh = ik)
Chiba_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Chiba_smooth, raw_series = Chiba, series = "total", fh = ik)

########
# Tokyo
########

Tokyo_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Tokyo_smooth, raw_series = Tokyo, series = "female", fh = ik)
Tokyo_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Tokyo_smooth, raw_series = Tokyo, series = "male", fh = ik)
Tokyo_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Tokyo_smooth, raw_series = Tokyo, series = "total", fh = ik)

###########
# Kanagawa
###########

Kanagawa_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kanagawa_smooth, raw_series = Kanagawa, series = "female", fh = ik)
Kanagawa_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kanagawa_smooth, raw_series = Kanagawa, series = "male", fh = ik)
Kanagawa_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kanagawa_smooth, raw_series = Kanagawa, series = "total", fh = ik)

##########
# Niigata
##########

Niigata_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Niigata_smooth, raw_series = Niigata, series = "female", fh = ik)
Niigata_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Niigata_smooth, raw_series = Niigata, series = "male", fh = ik)
Niigata_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Niigata_smooth, raw_series = Niigata, series = "total", fh = ik)

#########
# Toyama
#########

Toyama_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Toyama_smooth, raw_series = Toyama, series = "female", fh = ik)
Toyama_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Toyama_smooth, raw_series = Toyama, series = "male", fh = ik)
Toyama_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Toyama_smooth, raw_series = Toyama, series = "total", fh = ik)

###########
# Ishikawa
###########

Ishikawa_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Ishikawa_smooth, raw_series = Ishikawa, series = "female", fh = ik)
Ishikawa_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Ishikawa_smooth, raw_series = Ishikawa, series = "male", fh = ik)
Ishikawa_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Ishikawa_smooth, raw_series = Ishikawa, series = "total", fh = ik)

########
# Fukui
########

Fukui_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Fukui_smooth, raw_series = Fukui, series = "female", fh = ik)
Fukui_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Fukui_smooth, raw_series = Fukui, series = "male", fh = ik)
Fukui_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Fukui_smooth, raw_series = Fukui, series = "total", fh = ik)

############
# Yamanashi
############

Yamanashi_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Yamanashi_smooth, raw_series = Yamanashi, series = "female", fh = ik)
Yamanashi_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Yamanashi_smooth, raw_series = Yamanashi, series = "male", fh = ik)
Yamanashi_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Yamanashi_smooth, raw_series = Yamanashi, series = "total", fh = ik)

#########
# Nagano
#########

Nagano_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Nagano_smooth, raw_series = Nagano, series = "female", fh = ik)
Nagano_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Nagano_smooth, raw_series = Nagano, series = "male", fh = ik)
Nagano_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Nagano_smooth, raw_series = Nagano, series = "total", fh = ik)

#######
# Gifu
#######

Gifu_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Gifu_smooth, raw_series = Gifu, series = "female", fh = ik)
Gifu_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Gifu_smooth, raw_series = Gifu, series = "male", fh = ik)
Gifu_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Gifu_smooth, raw_series = Gifu, series = "total", fh = ik)

###########
# Shizuoka
###########

Shizuoka_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Shizuoka_smooth, raw_series = Shizuoka, series = "female", fh = ik)
Shizuoka_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Shizuoka_smooth, raw_series = Shizuoka, series = "male", fh = ik)
Shizuoka_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Shizuoka_smooth, raw_series = Shizuoka, series = "total", fh = ik)

########
# Aichi
########

Aichi_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Aichi_smooth, raw_series = Aichi, series = "female", fh = ik)
Aichi_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Aichi_smooth, raw_series = Aichi, series = "male", fh = ik)
Aichi_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Aichi_smooth, raw_series = Aichi, series = "total", fh = ik)

######
# Mie
######

Mie_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Mie_smooth, raw_series = Mie, series = "female", fh = ik)
Mie_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Mie_smooth, raw_series = Mie, series = "male", fh = ik)
Mie_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Mie_smooth, raw_series = Mie, series = "total", fh = ik)

########
# Shiga
########

Shiga_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Shiga_smooth, raw_series = Shiga, series = "female", fh = ik)
Shiga_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Shiga_smooth, raw_series = Shiga, series = "male", fh = ik)
Shiga_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Shiga_smooth, raw_series = Shiga, series = "total", fh = ik)

########
# Kyoto
########

Kyoto_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kyoto_smooth, raw_series = Kyoto, series = "female", fh = ik)
Kyoto_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kyoto_smooth, raw_series = Kyoto, series = "male", fh = ik)
Kyoto_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kyoto_smooth, raw_series = Kyoto, series = "total", fh = ik)

########
# Osaka
########

Osaka_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Osaka_smooth, raw_series = Osaka, series = "female", fh = ik)
Osaka_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Osaka_smooth, raw_series = Osaka, series = "male", fh = ik)
Osaka_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Osaka_smooth, raw_series = Osaka, series = "total", fh = ik)

########
# Hyogo
########

Hyogo_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Hyogo_smooth, raw_series = Hyogo, series = "female", fh = ik)
Hyogo_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Hyogo_smooth, raw_series = Hyogo, series = "male", fh = ik)
Hyogo_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Hyogo_smooth, raw_series = Hyogo, series = "total", fh = ik)

#######
# Nara
#######

Nara_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Nara_smooth, raw_series = Nara, series = "female", fh = ik)
Nara_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Nara_smooth, raw_series = Nara, series = "male", fh = ik)
Nara_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Nara_smooth, raw_series = Nara, series = "total", fh = ik)

###########
# Wakayama
###########

Wakayama_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Wakayama_smooth, raw_series = Wakayama, series = "female", fh = ik)
Wakayama_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Wakayama_smooth, raw_series = Wakayama, series = "male", fh = ik)
Wakayama_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Wakayama_smooth, raw_series = Wakayama, series = "total", fh = ik)

##########
# Tottori
##########

Tottori_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Tottori_smooth, raw_series = Tottori, series = "female", fh = ik)
Tottori_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Tottori_smooth, raw_series = Tottori, series = "male", fh = ik)
Tottori_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Tottori_smooth, raw_series = Tottori, series = "total", fh = ik)

##########
# Shimane
##########

Shimane_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Shimane_smooth, raw_series = Shimane, series = "female", fh = ik)
Shimane_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Shimane_smooth, raw_series = Shimane, series = "male", fh = ik)
Shimane_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Shimane_smooth, raw_series = Shimane, series = "total", fh = ik)

##########
# Okayama
##########

Okayama_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Okayama_smooth, raw_series = Okayama, series = "female", fh = ik)
Okayama_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Okayama_smooth, raw_series = Okayama, series = "male", fh = ik)
Okayama_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Okayama_smooth, raw_series = Okayama, series = "total", fh = ik)

############
# Hiroshima
############

Hiroshima_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Hiroshima_smooth, raw_series = Hiroshima, series = "female", fh = ik)
Hiroshima_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Hiroshima_smooth, raw_series = Hiroshima, series = "male", fh = ik)
Hiroshima_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Hiroshima_smooth, raw_series = Hiroshima, series = "total", fh = ik)

############
# Yamaguchi
############

Yamaguchi_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Yamaguchi_smooth, raw_series = Yamaguchi, series = "female", fh = ik)
Yamaguchi_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Yamaguchi_smooth, raw_series = Yamaguchi, series = "male", fh = ik)
Yamaguchi_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Yamaguchi_smooth, raw_series = Yamaguchi, series = "total", fh = ik)

############
# Tokushima
############

Tokushima_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Tokushima_smooth, raw_series = Tokushima, series = "female", fh = ik)
Tokushima_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Tokushima_smooth, raw_series = Tokushima, series = "male", fh = ik)
Tokushima_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Tokushima_smooth, raw_series = Tokushima, series = "total", fh = ik)

#########
# Kagawa
#########

Kagawa_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kagawa_smooth, raw_series = Kagawa, series = "female", fh = ik)
Kagawa_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kagawa_smooth, raw_series = Kagawa, series = "male", fh = ik)
Kagawa_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kagawa_smooth, raw_series = Kagawa, series = "total", fh = ik)

########
# Ehime
########

Ehime_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Ehime_smooth, raw_series = Ehime, series = "female", fh = ik)
Ehime_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Ehime_smooth, raw_series = Ehime, series = "male", fh = ik)
Ehime_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Ehime_smooth, raw_series = Ehime, series = "total", fh = ik)

########
# Kochi
########

Kochi_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kochi_smooth, raw_series = Kochi, series = "female", fh = ik)
Kochi_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kochi_smooth, raw_series = Kochi, series = "male", fh = ik)
Kochi_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kochi_smooth, raw_series = Kochi, series = "total", fh = ik)

##########
# Fukuoka
##########

Fukuoka_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Fukuoka_smooth, raw_series = Fukuoka, series = "female", fh = ik)
Fukuoka_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Fukuoka_smooth, raw_series = Fukuoka, series = "male", fh = ik)
Fukuoka_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Fukuoka_smooth, raw_series = Fukuoka, series = "total", fh = ik)

#######
# Saga
#######

Saga_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Saga_smooth, raw_series = Saga, series = "female", fh = ik)
Saga_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Saga_smooth, raw_series = Saga, series = "male", fh = ik)
Saga_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Saga_smooth, raw_series = Saga, series = "total", fh = ik)

###########
# Nagasaki
###########

Nagasaki_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Nagasaki_smooth, raw_series = Nagasaki, series = "female", fh = ik)
Nagasaki_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Nagasaki_smooth, raw_series = Nagasaki, series = "male", fh = ik)
Nagasaki_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Nagasaki_smooth, raw_series = Nagasaki, series = "total", fh = ik)

###########
# Kumamoto
###########

Kumamoto_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kumamoto_smooth, raw_series = Kumamoto, series = "female", fh = ik)
Kumamoto_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kumamoto_smooth, raw_series = Kumamoto, series = "male", fh = ik)
Kumamoto_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kumamoto_smooth, raw_series = Kumamoto, series = "total", fh = ik)

#######
# Oita
#######

Oita_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Oita_smooth, raw_series = Oita, series = "female", fh = ik)
Oita_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Oita_smooth, raw_series = Oita, series = "male", fh = ik)
Oita_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Oita_smooth, raw_series = Oita, series = "total", fh = ik)

###########
# Miyazaki
###########

Miyazaki_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Miyazaki_smooth, raw_series = Miyazaki, series = "female", fh = ik)
Miyazaki_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Miyazaki_smooth, raw_series = Miyazaki, series = "male", fh = ik)
Miyazaki_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Miyazaki_smooth, raw_series = Miyazaki, series = "total", fh = ik)

############
# Kagoshima
############

Kagoshima_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kagoshima_smooth, raw_series = Kagoshima, series = "female", fh = ik)
Kagoshima_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kagoshima_smooth, raw_series = Kagoshima, series = "male", fh = ik)
Kagoshima_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Kagoshima_smooth, raw_series = Kagoshima, series = "total", fh = ik)

##########
# Okinawa
##########

Okinawa_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Okinawa_smooth, raw_series = Okinawa, series = "female", fh = ik)
Okinawa_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Okinawa_smooth, raw_series = Okinawa, series = "male", fh = ik)
Okinawa_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = Okinawa_smooth, raw_series = Okinawa, series = "total", fh = ik)

###########
# Region 1
###########

R1_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R1_smooth, raw_series = ind_R1, series = "female", fh = ik)
R1_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R1_smooth, raw_series = ind_R1, series = "male", fh = ik)
R1_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R1_smooth, raw_series = ind_R1, series = "total", fh = ik)

###########
# Region 2
###########

R2_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R2_smooth, raw_series = ind_R2, series = "female", fh = ik)
R2_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R2_smooth, raw_series = ind_R2, series = "male", fh = ik)
R2_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R2_smooth, raw_series = ind_R2, series = "total", fh = ik)

###########
# Region 3
###########

R3_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R3_smooth, raw_series = ind_R3, series = "female", fh = ik)
R3_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R3_smooth, raw_series = ind_R3, series = "male", fh = ik)
R3_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R3_smooth, raw_series = ind_R3, series = "total", fh = ik)

###########
# Region 4
###########

R4_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R4_smooth, raw_series = ind_R4, series = "female", fh = ik)
R4_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R4_smooth, raw_series = ind_R4, series = "male", fh = ik)
R4_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R4_smooth, raw_series = ind_R4, series = "total", fh = ik)

###########
# Region 5
###########

R5_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R5_smooth, raw_series = ind_R5, series = "female", fh = ik)
R5_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R5_smooth, raw_series = ind_R5, series = "male", fh = ik)
R5_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R5_smooth, raw_series = ind_R5, series = "total", fh = ik)

###########
# Region 6
###########

R6_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R6_smooth, raw_series = ind_R6, series = "female", fh = ik)
R6_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R6_smooth, raw_series = ind_R6, series = "male", fh = ik)
R6_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R6_smooth, raw_series = ind_R6, series = "total", fh = ik)

###########
# Region 7
###########

R7_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R7_smooth, raw_series = ind_R7, series = "female", fh = ik)
R7_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R7_smooth, raw_series = ind_R7, series = "male", fh = ik)
R7_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R7_smooth, raw_series = ind_R7, series = "total", fh = ik)

###########
# Region 8
###########

R8_female_fh_PI = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R8_smooth, raw_series = ind_R8, series = "female", fh = ik)
R8_male_fh_PI   = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R8_smooth, raw_series = ind_R8, series = "male", fh = ik)
R8_total_fh_PI  = foreach(ik = 1:15) %dopar% PI_fh(smooth_series = ind_R8_smooth, raw_series = ind_R8, series = "total", fh = ik)


#################
# Interval score
#################

# Japan

interval_score_Japan_female = interval_score_Japan_male = interval_score_Japan_total = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Japan_female[ij] = interval_score(PI_val = Japan_female_fh_PI,
                                                     data_series = Japan, series = "female",
                                                     fh = ij)
    
    interval_score_Japan_male[ij] = interval_score(PI_val = Japan_male_fh_PI,
                                                   data_series = Japan, series = "male",
                                                   fh = ij)
    
    interval_score_Japan_total[ij] = interval_score(PI_val = Japan_total_fh_PI,
                                                    data_series = Japan, series = "total",
                                                    fh = ij)
}

# Hokkaido

interval_score_Hokkaido_female = interval_score_Hokkaido_male = interval_score_Hokkaido_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Hokkaido_female[ij] = interval_score(PI_val = Hokkaido_female_fh_PI,
                                                        data_series = Hokkaido, series = "female",
                                                        fh = ij)
    
    interval_score_Hokkaido_male[ij] = interval_score(PI_val = Hokkaido_male_fh_PI,
                                                      data_series = Hokkaido, series = "male",
                                                      fh = ij)
    
    interval_score_Hokkaido_total[ij] = interval_score(PI_val = Hokkaido_total_fh_PI,
                                                       data_series = Hokkaido, series = "total",
                                                       fh = ij)
}

# Aomori

interval_score_Aomori_female = interval_score_Aomori_male = interval_score_Aomori_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Aomori_female[ij] = interval_score(PI_val = Aomori_female_fh_PI,
                                                      data_series = Aomori, series = "female",
                                                      fh = ij)
    
    interval_score_Aomori_male[ij] = interval_score(PI_val = Aomori_male_fh_PI,
                                                    data_series = Aomori, series = "male",
                                                    fh = ij)
    
    interval_score_Aomori_total[ij] = interval_score(PI_val = Aomori_total_fh_PI,
                                                     data_series = Aomori, series = "total",
                                                     fh = ij)
}

# Iwate

interval_score_Iwate_female = interval_score_Iwate_male = interval_score_Iwate_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Iwate_female[ij] = interval_score(PI_val = Iwate_female_fh_PI,
                                                     data_series = Iwate, series = "female",
                                                     fh = ij)
    
    interval_score_Iwate_male[ij] = interval_score(PI_val = Iwate_male_fh_PI,
                                                   data_series = Iwate, series = "male",
                                                   fh = ij)
    
    interval_score_Iwate_total[ij] = interval_score(PI_val = Iwate_total_fh_PI,
                                                    data_series = Iwate, series = "total",
                                                    fh = ij)
}

# Miyagi

interval_score_Miyagi_female = interval_score_Miyagi_male = interval_score_Miyagi_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Miyagi_female[ij] = interval_score(PI_val = Miyagi_female_fh_PI,
                                                      data_series = Miyagi, series = "female",
                                                      fh = ij)
    
    interval_score_Miyagi_male[ij] = interval_score(PI_val = Miyagi_male_fh_PI,
                                                    data_series = Miyagi, series = "male",
                                                    fh = ij)
    
    interval_score_Miyagi_total[ij] = interval_score(PI_val = Miyagi_total_fh_PI,
                                                     data_series = Miyagi, series = "total",
                                                     fh = ij)
}

# Akita

interval_score_Akita_female = interval_score_Akita_male = interval_score_Akita_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Akita_female[ij] = interval_score(PI_val = Akita_female_fh_PI,
                                                     data_series = Akita, series = "female",
                                                     fh = ij)
    
    interval_score_Akita_male[ij] = interval_score(PI_val = Akita_male_fh_PI,
                                                   data_series = Akita, series = "male",
                                                   fh = ij)
    
    interval_score_Akita_total[ij] = interval_score(PI_val = Akita_total_fh_PI,
                                                    data_series = Akita, series = "total",
                                                    fh = ij)
}

# Yamagata

interval_score_Yamagata_female = interval_score_Yamagata_male = interval_score_Yamagata_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Yamagata_female[ij] = interval_score(PI_val = Yamagata_female_fh_PI,
                                                        data_series = Yamagata, series = "female",
                                                        fh = ij)
    
    interval_score_Yamagata_male[ij] = interval_score(PI_val = Yamagata_male_fh_PI,
                                                      data_series = Yamagata, series = "male",
                                                      fh = ij)
    
    interval_score_Yamagata_total[ij] = interval_score(PI_val = Yamagata_total_fh_PI,
                                                       data_series = Yamagata, series = "total",
                                                       fh = ij)
}

# Fukushima

interval_score_Fukushima_female = interval_score_Fukushima_male = interval_score_Fukushima_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Fukushima_female[ij] = interval_score(PI_val = Fukushima_female_fh_PI,
                                                         data_series = Fukushima,
                                                         series = "female", fh = ij)
    
    interval_score_Fukushima_male[ij] = interval_score(PI_val = Fukushima_male_fh_PI,
                                                       data_series = Fukushima,
                                                       series = "male", fh = ij)
    
    interval_score_Fukushima_total[ij] = interval_score(PI_val = Fukushima_total_fh_PI,
                                                        data_series = Fukushima,
                                                        series = "total", fh = ij)
}

# Ibaraki

interval_score_Ibaraki_female = interval_score_Ibaraki_male = interval_score_Ibaraki_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Ibaraki_female[ij] = interval_score(PI_val = Ibaraki_female_fh_PI,
                                                       data_series = Ibaraki,
                                                       series = "female", fh = ij)
    
    interval_score_Ibaraki_male[ij] = interval_score(PI_val = Ibaraki_male_fh_PI,
                                                     data_series = Ibaraki,
                                                     series = "male", fh = ij)
    
    interval_score_Ibaraki_total[ij] = interval_score(PI_val = Ibaraki_total_fh_PI,
                                                      data_series = Ibaraki,
                                                      series = "total", fh = ij)
}

# Tochigi

interval_score_Tochigi_female = interval_score_Tochigi_male = interval_score_Tochigi_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Tochigi_female[ij] = interval_score(PI_val = Tochigi_female_fh_PI,
                                                       data_series = Tochigi,
                                                       series = "female", fh = ij)
    
    interval_score_Tochigi_male[ij] = interval_score(PI_val = Tochigi_male_fh_PI,
                                                     data_series = Tochigi,
                                                     series = "male", fh = ij)
    
    interval_score_Tochigi_total[ij] = interval_score(PI_val = Tochigi_total_fh_PI,
                                                      data_series = Tochigi,
                                                      series = "total", fh = ij)
}

# Gunma

interval_score_Gunma_female = interval_score_Gunma_male = interval_score_Gunma_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Gunma_female[ij] = interval_score(PI_val = Gunma_female_fh_PI,
                                                     data_series = Gunma,
                                                     series = "female", fh = ij)
    
    interval_score_Gunma_male[ij] = interval_score(PI_val = Gunma_male_fh_PI,
                                                   data_series = Gunma,
                                                   series = "male", fh = ij)
    
    interval_score_Gunma_total[ij] = interval_score(PI_val = Gunma_total_fh_PI,
                                                    data_series = Gunma,
                                                    series = "total", fh = ij)
}

# Saitama

interval_score_Saitama_female = interval_score_Saitama_male = interval_score_Saitama_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Saitama_female[ij] = interval_score(PI_val = Saitama_female_fh_PI,
                                                       data_series = Saitama,
                                                       series = "female", fh = ij)
    
    interval_score_Saitama_male[ij] = interval_score(PI_val = Saitama_male_fh_PI,
                                                     data_series = Saitama,
                                                     series = "male", fh = ij)
    
    interval_score_Saitama_total[ij] = interval_score(PI_val = Saitama_total_fh_PI,
                                                      data_series = Saitama,
                                                      series = "total", fh = ij)
}

# Chiba

interval_score_Chiba_female = interval_score_Chiba_male = interval_score_Chiba_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Chiba_female[ij] = interval_score(PI_val = Chiba_female_fh_PI,
                                                     data_series = Chiba,
                                                     series = "female", fh = ij)
    
    interval_score_Chiba_male[ij] = interval_score(PI_val = Chiba_male_fh_PI,
                                                   data_series = Chiba,
                                                   series = "male", fh = ij)
    
    interval_score_Chiba_total[ij] = interval_score(PI_val = Chiba_total_fh_PI,
                                                    data_series = Chiba,
                                                    series = "total", fh = ij)
}

# Tokyo

interval_score_Tokyo_female = interval_score_Tokyo_male = interval_score_Tokyo_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Tokyo_female[ij] = interval_score(PI_val = Tokyo_female_fh_PI,
                                                     data_series = Tokyo,
                                                     series = "female", fh = ij)
    
    interval_score_Tokyo_male[ij] = interval_score(PI_val = Tokyo_male_fh_PI,
                                                   data_series = Tokyo,
                                                   series = "male", fh = ij)
    
    interval_score_Tokyo_total[ij] = interval_score(PI_val = Tokyo_total_fh_PI,
                                                    data_series = Tokyo,
                                                    series = "total", fh = ij)
}

# Kanagawa

interval_score_Kanagawa_female = interval_score_Kanagawa_male = interval_score_Kanagawa_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Kanagawa_female[ij] = interval_score(PI_val = Kanagawa_female_fh_PI,
                                                        data_series = Kanagawa,
                                                        series = "female", fh = ij)
    
    interval_score_Kanagawa_male[ij] = interval_score(PI_val = Kanagawa_male_fh_PI,
                                                      data_series = Kanagawa,
                                                      series = "male", fh = ij)
    
    interval_score_Kanagawa_total[ij] = interval_score(PI_val = Kanagawa_total_fh_PI,
                                                       data_series = Kanagawa,
                                                       series = "total", fh = ij)
}

# Niigata

interval_score_Niigata_female = interval_score_Niigata_male = interval_score_Niigata_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Niigata_female[ij] = interval_score(PI_val = Niigata_female_fh_PI,
                                                       data_series = Niigata,
                                                       series = "female", fh = ij)
    
    interval_score_Niigata_male[ij] = interval_score(PI_val = Niigata_male_fh_PI,
                                                     data_series = Niigata,
                                                     series = "male", fh = ij)
    
    interval_score_Niigata_total[ij] = interval_score(PI_val = Niigata_total_fh_PI,
                                                      data_series = Niigata,
                                                      series = "total", fh = ij)
}

# Toyama

interval_score_Toyama_female = interval_score_Toyama_male = interval_score_Toyama_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Toyama_female[ij] = interval_score(PI_val = Toyama_female_fh_PI,
                                                      data_series = Toyama,
                                                      series = "female", fh = ij)
    
    interval_score_Toyama_male[ij] = interval_score(PI_val = Toyama_male_fh_PI,
                                                    data_series = Toyama,
                                                    series = "male", fh = ij)
    
    interval_score_Toyama_total[ij] = interval_score(PI_val = Toyama_total_fh_PI,
                                                     data_series = Toyama,
                                                     series = "total", fh = ij)
}

# Ishikawa

interval_score_Ishikawa_female = interval_score_Ishikawa_male = interval_score_Ishikawa_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Ishikawa_female[ij] = interval_score(PI_val = Ishikawa_female_fh_PI,
                                                        data_series = Ishikawa,
                                                        series = "female", fh = ij)
    
    interval_score_Ishikawa_male[ij] = interval_score(PI_val = Ishikawa_male_fh_PI,
                                                      data_series = Ishikawa,
                                                      series = "male", fh = ij)
    
    interval_score_Ishikawa_total[ij] = interval_score(PI_val = Ishikawa_total_fh_PI,
                                                       data_series = Ishikawa,
                                                       series = "total", fh = ij)
}

# Fukui

interval_score_Fukui_female = interval_score_Fukui_male = interval_score_Fukui_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Fukui_female[ij] = interval_score(PI_val = Fukui_female_fh_PI,
                                                     data_series = Fukui,
                                                     series = "female", fh = ij)
    
    interval_score_Fukui_male[ij] = interval_score(PI_val = Fukui_male_fh_PI,
                                                   data_series = Fukui,
                                                   series = "male", fh = ij)
    
    interval_score_Fukui_total[ij] = interval_score(PI_val = Fukui_total_fh_PI,
                                                    data_series = Fukui,
                                                    series = "total", fh = ij)
}

# Yamanashi

interval_score_Yamanashi_female = interval_score_Yamanashi_male = interval_score_Yamanashi_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Yamanashi_female[ij] = interval_score(PI_val = Yamanashi_female_fh_PI,
                                                         data_series = Yamanashi,
                                                         series = "female", fh = ij)
    
    interval_score_Yamanashi_male[ij] = interval_score(PI_val = Yamanashi_male_fh_PI,
                                                       data_series = Yamanashi,
                                                       series = "male", fh = ij)
    
    interval_score_Yamanashi_total[ij] = interval_score(PI_val = Yamanashi_total_fh_PI,
                                                        data_series = Yamanashi,
                                                        series = "total", fh = ij)
}

# Nagano

interval_score_Nagano_female = interval_score_Nagano_male = interval_score_Nagano_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Nagano_female[ij] = interval_score(PI_val = Nagano_female_fh_PI,
                                                      data_series = Nagano,
                                                      series = "female", fh = ij)
    
    interval_score_Nagano_male[ij] = interval_score(PI_val = Nagano_male_fh_PI,
                                                    data_series = Nagano,
                                                    series = "male", fh = ij)
    
    interval_score_Nagano_total[ij] = interval_score(PI_val = Nagano_total_fh_PI,
                                                     data_series = Nagano,
                                                     series = "total", fh = ij)
}

# Gifu

interval_score_Gifu_female = interval_score_Gifu_male = interval_score_Gifu_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Gifu_female[ij] = interval_score(PI_val = Gifu_female_fh_PI,
                                                    data_series = Gifu, series = "female",
                                                    fh = ij)
    
    interval_score_Gifu_male[ij] = interval_score(PI_val = Gifu_male_fh_PI,
                                                  data_series = Gifu, series = "male",
                                                  fh = ij)
    
    interval_score_Gifu_total[ij] = interval_score(PI_val = Gifu_total_fh_PI,
                                                   data_series = Gifu, series = "total",
                                                   fh = ij)
}

# Shizuoka

interval_score_Shizuoka_female = interval_score_Shizuoka_male = interval_score_Shizuoka_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Shizuoka_female[ij] = interval_score(PI_val = Shizuoka_female_fh_PI,
                                                        data_series = Shizuoka,
                                                        series = "female", fh = ij)
    
    interval_score_Shizuoka_male[ij] = interval_score(PI_val = Shizuoka_male_fh_PI,
                                                      data_series = Shizuoka,
                                                      series = "male", fh = ij)
    
    interval_score_Shizuoka_total[ij] = interval_score(PI_val = Shizuoka_total_fh_PI,
                                                       data_series = Shizuoka,
                                                       series = "total", fh = ij)
}

# Aichi

interval_score_Aichi_female = interval_score_Aichi_male = interval_score_Aichi_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Aichi_female[ij] = interval_score(PI_val = Aichi_female_fh_PI,
                                                     data_series = Aichi,
                                                     series = "female", fh = ij)
    
    interval_score_Aichi_male[ij] = interval_score(PI_val = Aichi_male_fh_PI,
                                                   data_series = Aichi,
                                                   series = "male", fh = ij)
    
    interval_score_Aichi_total[ij] = interval_score(PI_val = Aichi_total_fh_PI,
                                                    data_series = Aichi,
                                                    series = "total", fh = ij)
}

# Mie

interval_score_Mie_female = interval_score_Mie_male = interval_score_Mie_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Mie_female[ij] = interval_score(PI_val = Mie_female_fh_PI,
                                                   data_series = Mie,
                                                   series = "female", fh = ij)
    
    interval_score_Mie_male[ij] = interval_score(PI_val = Mie_male_fh_PI,
                                                 data_series = Mie,
                                                 series = "male", fh = ij)
    
    interval_score_Mie_total[ij] = interval_score(PI_val = Mie_total_fh_PI,
                                                  data_series = Mie,
                                                  series = "total", fh = ij)
}

# Shiga

interval_score_Shiga_female = interval_score_Shiga_male = interval_score_Shiga_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Shiga_female[ij] = interval_score(PI_val = Shiga_female_fh_PI,
                                                     data_series = Shiga,
                                                     series = "female", fh = ij)
    
    interval_score_Shiga_male[ij] = interval_score(PI_val = Shiga_male_fh_PI,
                                                   data_series = Shiga,
                                                   series = "male", fh = ij)
    
    interval_score_Shiga_total[ij] = interval_score(PI_val = Shiga_total_fh_PI,
                                                    data_series = Shiga,
                                                    series = "total", fh = ij)
}

# Kyoto

interval_score_Kyoto_female = interval_score_Kyoto_male = interval_score_Kyoto_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Kyoto_female[ij] = interval_score(PI_val = Kyoto_female_fh_PI,
                                                     data_series = Kyoto,
                                                     series = "female", fh = ij)
    
    interval_score_Kyoto_male[ij] = interval_score(PI_val = Kyoto_male_fh_PI,
                                                   data_series = Kyoto,
                                                   series = "male", fh = ij)
    
    interval_score_Kyoto_total[ij] = interval_score(PI_val = Kyoto_total_fh_PI,
                                                    data_series = Kyoto,
                                                    series = "total", fh = ij)
}

# Osaka

interval_score_Osaka_female = interval_score_Osaka_male = interval_score_Osaka_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Osaka_female[ij] = interval_score(PI_val = Osaka_female_fh_PI,
                                                     data_series = Osaka,
                                                     series = "female", fh = ij)
    
    interval_score_Osaka_male[ij] = interval_score(PI_val = Osaka_male_fh_PI,
                                                   data_series = Osaka,
                                                   series = "male", fh = ij)
    
    interval_score_Osaka_total[ij] = interval_score(PI_val = Osaka_total_fh_PI,
                                                    data_series = Osaka,
                                                    series = "total", fh = ij)
}

# Hyogo

interval_score_Hyogo_female = interval_score_Hyogo_male = interval_score_Hyogo_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Hyogo_female[ij] = interval_score(PI_val = Hyogo_female_fh_PI,
                                                     data_series = Hyogo,
                                                     series = "female", fh = ij)
    
    interval_score_Hyogo_male[ij] = interval_score(PI_val = Hyogo_male_fh_PI,
                                                   data_series = Hyogo,
                                                   series = "male", fh = ij)
    
    interval_score_Hyogo_total[ij] = interval_score(PI_val = Hyogo_total_fh_PI,
                                                    data_series = Hyogo,
                                                    series = "total", fh = ij)
}

# Nara

interval_score_Nara_female = interval_score_Nara_male = interval_score_Nara_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Nara_female[ij] = interval_score(PI_val = Nara_female_fh_PI,
                                                    data_series = Nara,
                                                    series = "female", fh = ij)
    
    interval_score_Nara_male[ij] = interval_score(PI_val = Nara_male_fh_PI,
                                                  data_series = Nara,
                                                  series = "male", fh = ij)
    
    interval_score_Nara_total[ij] = interval_score(PI_val = Nara_total_fh_PI,
                                                   data_series = Nara,
                                                   series = "total", fh = ij)
}

# Wakayama

interval_score_Wakayama_female = interval_score_Wakayama_male = interval_score_Wakayama_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Wakayama_female[ij] = interval_score(PI_val = Wakayama_female_fh_PI,
                                                        data_series = Wakayama,
                                                        series = "female", fh = ij)
    
    interval_score_Wakayama_male[ij] = interval_score(PI_val = Wakayama_male_fh_PI,
                                                      data_series = Wakayama,
                                                      series = "male", fh = ij)
    
    interval_score_Wakayama_total[ij] = interval_score(PI_val = Wakayama_total_fh_PI,
                                                       data_series = Wakayama,
                                                       series = "total", fh = ij)
}

# Tottori

interval_score_Tottori_female = interval_score_Tottori_male = interval_score_Tottori_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Tottori_female[ij] = interval_score(PI_val = Tottori_female_fh_PI,
                                                       data_series = Tottori,
                                                       series = "female", fh = ij)
    
    interval_score_Tottori_male[ij] = interval_score(PI_val = Tottori_male_fh_PI,
                                                     data_series = Tottori,
                                                     series = "male", fh = ij)
    
    interval_score_Tottori_total[ij] = interval_score(PI_val = Tottori_total_fh_PI,
                                                      data_series = Tottori,
                                                      series = "total", fh = ij)
}

# Shimane

interval_score_Shimane_female = interval_score_Shimane_male = interval_score_Shimane_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Shimane_female[ij] = interval_score(PI_val = Shimane_female_fh_PI,
                                                       data_series = Shimane,
                                                       series = "female", fh = ij)
    
    interval_score_Shimane_male[ij] = interval_score(PI_val = Shimane_male_fh_PI,
                                                     data_series = Shimane,
                                                     series = "male", fh = ij)
    
    interval_score_Shimane_total[ij] = interval_score(PI_val = Shimane_total_fh_PI,
                                                      data_series = Shimane,
                                                      series = "total", fh = ij)
}

# Okayama

interval_score_Okayama_female = interval_score_Okayama_male = interval_score_Okayama_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Okayama_female[ij] = interval_score(PI_val = Okayama_female_fh_PI,
                                                       data_series = Okayama,
                                                       series = "female", fh = ij)
    
    interval_score_Okayama_male[ij] = interval_score(PI_val = Okayama_male_fh_PI,
                                                     data_series = Okayama,
                                                     series = "male", fh = ij)
    
    interval_score_Okayama_total[ij] = interval_score(PI_val = Okayama_total_fh_PI,
                                                      data_series = Okayama,
                                                      series = "total", fh = ij)
}

# Hiroshima

interval_score_Hiroshima_female = interval_score_Hiroshima_male = interval_score_Hiroshima_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Hiroshima_female[ij] = interval_score(PI_val = Hiroshima_female_fh_PI,
                                                         data_series = Hiroshima,
                                                         series = "female", fh = ij)
    
    interval_score_Hiroshima_male[ij] = interval_score(PI_val = Hiroshima_male_fh_PI,
                                                       data_series = Hiroshima,
                                                       series = "male", fh = ij)
    
    interval_score_Hiroshima_total[ij] = interval_score(PI_val = Hiroshima_total_fh_PI,
                                                        data_series = Hiroshima,
                                                        series = "total", fh = ij)
}

# Yamaguchi

interval_score_Yamaguchi_female = interval_score_Yamaguchi_male = interval_score_Yamaguchi_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Yamaguchi_female[ij] = interval_score(PI_val = Yamaguchi_female_fh_PI,
                                                         data_series = Yamaguchi,
                                                         series = "female", fh = ij)
    
    interval_score_Yamaguchi_male[ij] = interval_score(PI_val = Yamaguchi_male_fh_PI,
                                                       data_series = Yamaguchi,
                                                       series = "male", fh = ij)
    
    interval_score_Yamaguchi_total[ij] = interval_score(PI_val = Yamaguchi_total_fh_PI,
                                                        data_series = Yamaguchi,
                                                        series = "total", fh = ij)
}

# Tokushima

interval_score_Tokushima_female = interval_score_Tokushima_male = interval_score_Tokushima_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Tokushima_female[ij] = interval_score(PI_val = Tokushima_female_fh_PI,
                                                         data_series = Tokushima,
                                                         series = "female", fh = ij)
    
    interval_score_Tokushima_male[ij] = interval_score(PI_val = Tokushima_male_fh_PI,
                                                       data_series = Tokushima,
                                                       series = "male", fh = ij)
    
    interval_score_Tokushima_total[ij] = interval_score(PI_val = Tokushima_total_fh_PI,
                                                        data_series = Tokushima,
                                                        series = "total", fh = ij)
}

# Kagawa

interval_score_Kagawa_female = interval_score_Kagawa_male = interval_score_Kagawa_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Kagawa_female[ij] = interval_score(PI_val = Kagawa_female_fh_PI,
                                                      data_series = Kagawa,
                                                      series = "female", fh = ij)
    
    interval_score_Kagawa_male[ij] = interval_score(PI_val = Kagawa_male_fh_PI,
                                                    data_series = Kagawa,
                                                    series = "male", fh = ij)
    
    interval_score_Kagawa_total[ij] = interval_score(PI_val = Kagawa_total_fh_PI,
                                                     data_series = Kagawa,
                                                     series = "total", fh = ij)
}

# Ehime

interval_score_Ehime_female = interval_score_Ehime_male = interval_score_Ehime_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Ehime_female[ij] = interval_score(PI_val = Ehime_female_fh_PI,
                                                     data_series = Ehime,
                                                     series = "female", fh = ij)
    
    interval_score_Ehime_male[ij] = interval_score(PI_val = Ehime_male_fh_PI,
                                                   data_series = Ehime,
                                                   series = "male", fh = ij)
    
    interval_score_Ehime_total[ij] = interval_score(PI_val = Ehime_total_fh_PI,
                                                    data_series = Ehime,
                                                    series = "total", fh = ij)
}

# Kochi

interval_score_Kochi_female = interval_score_Kochi_male = interval_score_Kochi_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Kochi_female[ij] = interval_score(PI_val = Kochi_female_fh_PI,
                                                     data_series = Kochi,
                                                     series = "female", fh = ij)
    
    interval_score_Kochi_male[ij] = interval_score(PI_val = Kochi_male_fh_PI,
                                                   data_series = Kochi,
                                                   series = "male", fh = ij)
    
    interval_score_Kochi_total[ij] = interval_score(PI_val = Kochi_total_fh_PI,
                                                    data_series = Kochi,
                                                    series = "total", fh = ij)
}

# Fukuoka

interval_score_Fukuoka_female = interval_score_Fukuoka_male = interval_score_Fukuoka_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Fukuoka_female[ij] = interval_score(PI_val = Fukuoka_female_fh_PI,
                                                       data_series = Fukuoka,
                                                       series = "female", fh = ij)
    
    interval_score_Fukuoka_male[ij] = interval_score(PI_val = Fukuoka_male_fh_PI,
                                                     data_series = Fukuoka,
                                                     series = "male", fh = ij)
    
    interval_score_Fukuoka_total[ij] = interval_score(PI_val = Fukuoka_total_fh_PI,
                                                      data_series = Fukuoka,
                                                      series = "total", fh = ij)
}

# Saga

interval_score_Saga_female = interval_score_Saga_male = interval_score_Saga_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Saga_female[ij] = interval_score(PI_val = Saga_female_fh_PI,
                                                    data_series = Saga,
                                                    series = "female", fh = ij)
    
    interval_score_Saga_male[ij] = interval_score(PI_val = Saga_male_fh_PI,
                                                  data_series = Saga,
                                                  series = "male", fh = ij)
    
    interval_score_Saga_total[ij] = interval_score(PI_val = Saga_total_fh_PI,
                                                   data_series = Saga,
                                                   series = "total", fh = ij)
}

# Nagasaki

interval_score_Nagasaki_female = interval_score_Nagasaki_male = interval_score_Nagasaki_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Nagasaki_female[ij] = interval_score(PI_val = Nagasaki_female_fh_PI,
                                                        data_series = Nagasaki,
                                                        series = "female", fh = ij)
    
    interval_score_Nagasaki_male[ij] = interval_score(PI_val = Nagasaki_male_fh_PI,
                                                      data_series = Nagasaki,
                                                      series = "male", fh = ij)
    
    interval_score_Nagasaki_total[ij] = interval_score(PI_val = Nagasaki_total_fh_PI,
                                                       data_series = Nagasaki,
                                                       series = "total", fh = ij)
}

# Kumamoto

interval_score_Kumamoto_female = interval_score_Kumamoto_male = interval_score_Kumamoto_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Kumamoto_female[ij] = interval_score(PI_val = Kumamoto_female_fh_PI,
                                                        data_series = Kumamoto,
                                                        series = "female", fh = ij)
    
    interval_score_Kumamoto_male[ij] = interval_score(PI_val = Kumamoto_male_fh_PI,
                                                      data_series = Kumamoto,
                                                      series = "male", fh = ij)
    
    interval_score_Kumamoto_total[ij] = interval_score(PI_val = Kumamoto_total_fh_PI,
                                                       data_series = Kumamoto,
                                                       series = "total", fh = ij)
}

# Oita

interval_score_Oita_female = interval_score_Oita_male = interval_score_Oita_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Oita_female[ij] = interval_score(PI_val = Oita_female_fh_PI,
                                                    data_series = Oita,
                                                    series = "female", fh = ij)
    
    interval_score_Oita_male[ij] = interval_score(PI_val = Oita_male_fh_PI,
                                                  data_series = Oita,
                                                  series = "male", fh = ij)
    
    interval_score_Oita_total[ij] = interval_score(PI_val = Oita_total_fh_PI,
                                                   data_series = Oita,
                                                   series = "total", fh = ij)
}

# Miyazaki

interval_score_Miyazaki_female = interval_score_Miyazaki_male = interval_score_Miyazaki_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Miyazaki_female[ij] = interval_score(PI_val = Miyazaki_female_fh_PI,
                                                        data_series = Miyazaki,
                                                        series = "female", fh = ij)
    
    interval_score_Miyazaki_male[ij] = interval_score(PI_val = Miyazaki_male_fh_PI,
                                                      data_series = Miyazaki,
                                                      series = "male", fh = ij)
    
    interval_score_Miyazaki_total[ij] = interval_score(PI_val = Miyazaki_total_fh_PI,
                                                       data_series = Miyazaki,
                                                       series = "total", fh = ij)
}

# Kagoshima

interval_score_Kagoshima_female = interval_score_Kagoshima_male = interval_score_Kagoshima_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Kagoshima_female[ij] = interval_score(PI_val = Kagoshima_female_fh_PI,
                                                         data_series = Kagoshima,
                                                         series = "female", fh = ij)
    
    interval_score_Kagoshima_male[ij] = interval_score(PI_val = Kagoshima_male_fh_PI,
                                                       data_series = Kagoshima,
                                                       series = "male", fh = ij)
    
    interval_score_Kagoshima_total[ij] = interval_score(PI_val = Kagoshima_total_fh_PI,
                                                        data_series = Kagoshima,
                                                        series = "total", fh = ij)
}

# Okinawa

interval_score_Okinawa_female = interval_score_Okinawa_male = interval_score_Okinawa_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_Okinawa_female[ij] = interval_score(PI_val = Okinawa_female_fh_PI,
                                                       data_series = Okinawa,
                                                       series = "female", fh = ij)
    
    interval_score_Okinawa_male[ij] = interval_score(PI_val = Okinawa_male_fh_PI,
                                                     data_series = Okinawa,
                                                     series = "male", fh = ij)
    
    interval_score_Okinawa_total[ij] = interval_score(PI_val = Okinawa_total_fh_PI,
                                                      data_series = Okinawa,
                                                      series = "total", fh = ij)
}

# R1

interval_score_R1_female = interval_score_R1_male = interval_score_R1_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_R1_female[ij] = interval_score(PI_val = R1_female_fh_PI,
                                                  data_series = ind_R1, series = "female",
                                                  fh = ij)
    
    interval_score_R1_male[ij] = interval_score(PI_val = R1_male_fh_PI,
                                                data_series = ind_R1, series = "male",
                                                fh = ij)
    
    interval_score_R1_total[ij] = interval_score(PI_val = R1_total_fh_PI,
                                                 data_series = ind_R1, series = "total",
                                                 fh = ij)
}

# R2

interval_score_R2_female = interval_score_R2_male = interval_score_R2_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_R2_female[ij] = interval_score(PI_val = R2_female_fh_PI,
                                                  data_series = ind_R2, series = "female",
                                                  fh = ij)
    
    interval_score_R2_male[ij] = interval_score(PI_val = R2_male_fh_PI,
                                                data_series = ind_R2, series = "male",
                                                fh = ij)
    
    interval_score_R2_total[ij] = interval_score(PI_val = R2_total_fh_PI,
                                                 data_series = ind_R2, series = "total",
                                                 fh = ij)
}

# R3

interval_score_R3_female = interval_score_R3_male = interval_score_R3_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_R3_female[ij] = interval_score(PI_val = R3_female_fh_PI,
                                                  data_series = ind_R3,
                                                  series = "female", fh = ij)
    
    interval_score_R3_male[ij] = interval_score(PI_val = R3_male_fh_PI,
                                                data_series = ind_R3,
                                                series = "male", fh = ij)
    
    interval_score_R3_total[ij] = interval_score(PI_val = R3_total_fh_PI,
                                                 data_series = ind_R3,
                                                 series = "total", fh = ij)
}

# R4

interval_score_R4_female = interval_score_R4_male = interval_score_R4_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_R4_female[ij] = interval_score(PI_val = R4_female_fh_PI,
                                                  data_series = ind_R4,
                                                  series = "female", fh = ij)
    
    interval_score_R4_male[ij] = interval_score(PI_val = R4_male_fh_PI,
                                                data_series = ind_R4,
                                                series = "male", fh = ij)
    
    interval_score_R4_total[ij] = interval_score(PI_val = R4_total_fh_PI,
                                                 data_series = ind_R4,
                                                 series = "total", fh = ij)
}

# R5

interval_score_R5_female = interval_score_R5_male = interval_score_R5_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_R5_female[ij] = interval_score(PI_val = R5_female_fh_PI,
                                                  data_series = ind_R5,
                                                  series = "female", fh = ij)
    
    interval_score_R5_male[ij] = interval_score(PI_val = R5_male_fh_PI,
                                                data_series = ind_R5,
                                                series = "male", fh = ij)
    
    interval_score_R5_total[ij] = interval_score(PI_val = R5_total_fh_PI,
                                                 data_series = ind_R5,
                                                 series = "total", fh = ij)
}

# R6

interval_score_R6_female = interval_score_R6_male = interval_score_R6_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_R6_female[ij] = interval_score(PI_val = R6_female_fh_PI,
                                                  data_series = ind_R6,
                                                  series = "female", fh = ij)
    
    interval_score_R6_male[ij] = interval_score(PI_val = R6_male_fh_PI,
                                                data_series = ind_R6,
                                                series = "male", fh = ij)
    
    interval_score_R6_total[ij] = interval_score(PI_val = R6_total_fh_PI,
                                                 data_series = ind_R6,
                                                 series = "total", fh = ij)
}

# R7

interval_score_R7_female = interval_score_R7_male = interval_score_R7_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_R7_female[ij] = interval_score(PI_val = R7_female_fh_PI,
                                                  data_series = ind_R7,
                                                  series = "female", fh = ij)
    
    interval_score_R7_male[ij] = interval_score(PI_val = R7_male_fh_PI,
                                                data_series = ind_R7,
                                                series = "male", fh = ij)
    
    interval_score_R7_total[ij] = interval_score(PI_val = R7_total_fh_PI,
                                                 data_series = ind_R7,
                                                 series = "total", fh = ij)
}

# R8

interval_score_R8_female = interval_score_R8_male = interval_score_R8_total = vector("numeric",15)
for(ij in 1:15)
{
    interval_score_R8_female[ij] = interval_score(PI_val = R8_female_fh_PI,
                                                  data_series = ind_R8,
                                                  series = "female", fh = ij)
    
    interval_score_R8_male[ij] = interval_score(PI_val = R8_male_fh_PI,
                                                data_series = ind_R8,
                                                series = "male", fh = ij)
    
    interval_score_R8_total[ij] = interval_score(PI_val = R8_total_fh_PI,
                                                 data_series = ind_R8,
                                                 series = "total", fh = ij)
}

######################################################
# Interval score at different levels of the hierarchy
######################################################

# Japan (total)

interval_score_Level_0 = interval_score_Japan_total

# Japan (female + male)

interval_score_Level_1 = rowMeans(cbind(interval_score_Japan_female, interval_score_Japan_male))

# Japan region (total)

interval_score_Level_2 = rowMeans(cbind(interval_score_R1_total, interval_score_R2_total, interval_score_R3_total, interval_score_R4_total,
                                        interval_score_R5_total, interval_score_R6_total, interval_score_R7_total, interval_score_R8_total))

# Japan region (female + male)

interval_score_Level_3 = rowMeans(cbind(interval_score_R1_female, interval_score_R2_female, interval_score_R3_female, interval_score_R4_female,
                                        interval_score_R5_female, interval_score_R6_female, interval_score_R7_female, interval_score_R8_female,
                                        interval_score_R1_male,   interval_score_R2_male,   interval_score_R3_male,   interval_score_R4_male,
                                        interval_score_R5_male,   interval_score_R6_male,   interval_score_R7_male,   interval_score_R8_male))

# Japan prefecture (total)

interval_score_Level_4 = rowMeans(cbind(interval_score_Hokkaido_total, interval_score_Aomori_total,
                                        interval_score_Iwate_total, interval_score_Miyagi_total,
                                        interval_score_Akita_total, interval_score_Yamagata_total,
                                        interval_score_Fukushima_total, interval_score_Ibaraki_total,
                                        interval_score_Tochigi_total, interval_score_Gunma_total,
                                        interval_score_Saitama_total, interval_score_Chiba_total,
                                        interval_score_Tokyo_total, interval_score_Kanagawa_total,
                                        interval_score_Niigata_total, interval_score_Toyama_total,
                                        interval_score_Ishikawa_total, interval_score_Fukui_total,
                                        interval_score_Yamanashi_total, interval_score_Nagano_total,
                                        interval_score_Gifu_total, interval_score_Shizuoka_total,
                                        interval_score_Aichi_total, interval_score_Mie_total,
                                        interval_score_Shiga_total, interval_score_Kyoto_total,
                                        interval_score_Osaka_total, interval_score_Hyogo_total,
                                        interval_score_Nara_total, interval_score_Wakayama_total,
                                        interval_score_Tottori_total, interval_score_Shimane_total,
                                        interval_score_Okayama_total, interval_score_Hiroshima_total,
                                        interval_score_Yamaguchi_total, interval_score_Tokushima_total,
                                        interval_score_Kagawa_total, interval_score_Ehime_total,
                                        interval_score_Kochi_total, interval_score_Fukuoka_total,
                                        interval_score_Saga_total, interval_score_Nagasaki_total,
                                        interval_score_Kumamoto_total, interval_score_Oita_total,
                                        interval_score_Miyazaki_total, interval_score_Kagoshima_total,
                                        interval_score_Okinawa_total))

# Japan prefecture (female + male)

interval_score_Level_5 = rowMeans(cbind(interval_score_Hokkaido_female, interval_score_Aomori_female,
                                        interval_score_Iwate_female, interval_score_Miyagi_female,
                                        interval_score_Akita_female, interval_score_Yamagata_female,
                                        interval_score_Fukushima_female, interval_score_Ibaraki_female,
                                        interval_score_Tochigi_female, interval_score_Gunma_female,
                                        interval_score_Saitama_female, interval_score_Chiba_female,
                                        interval_score_Tokyo_female, interval_score_Kanagawa_female,
                                        interval_score_Niigata_female, interval_score_Toyama_female,
                                        interval_score_Ishikawa_female, interval_score_Fukui_female,
                                        interval_score_Yamanashi_female, interval_score_Nagano_female,
                                        interval_score_Gifu_female, interval_score_Shizuoka_female,
                                        interval_score_Aichi_female, interval_score_Mie_female,
                                        interval_score_Shiga_female, interval_score_Kyoto_female,
                                        interval_score_Osaka_female, interval_score_Hyogo_female,
                                        interval_score_Nara_female, interval_score_Wakayama_female,
                                        interval_score_Tottori_female, interval_score_Shimane_female,
                                        interval_score_Okayama_female, interval_score_Hiroshima_female,
                                        interval_score_Yamaguchi_female, interval_score_Tokushima_female,
                                        interval_score_Kagawa_female, interval_score_Ehime_female,
                                        interval_score_Kochi_female, interval_score_Fukuoka_female,
                                        interval_score_Saga_female, interval_score_Nagasaki_female,
                                        interval_score_Kumamoto_female, interval_score_Oita_female,
                                        interval_score_Miyazaki_female, interval_score_Kagoshima_female,
                                        interval_score_Okinawa_female,
                                        interval_score_Hokkaido_male, interval_score_Aomori_male,
                                        interval_score_Iwate_male, interval_score_Miyagi_male,
                                        interval_score_Akita_male, interval_score_Yamagata_male,
                                        interval_score_Fukushima_male, interval_score_Ibaraki_male,
                                        interval_score_Tochigi_male, interval_score_Gunma_male,
                                        interval_score_Saitama_male, interval_score_Chiba_male,
                                        interval_score_Tokyo_male, interval_score_Kanagawa_male,
                                        interval_score_Niigata_male, interval_score_Toyama_male,
                                        interval_score_Ishikawa_male, interval_score_Fukui_male,
                                        interval_score_Yamanashi_male, interval_score_Nagano_male,
                                        interval_score_Gifu_male, interval_score_Shizuoka_male,
                                        interval_score_Aichi_male, interval_score_Mie_male,
                                        interval_score_Shiga_male, interval_score_Kyoto_male,
                                        interval_score_Osaka_male, interval_score_Hyogo_male,
                                        interval_score_Nara_male, interval_score_Wakayama_male,
                                        interval_score_Tottori_male, interval_score_Shimane_male,
                                        interval_score_Okayama_male, interval_score_Hiroshima_male,
                                        interval_score_Yamaguchi_male, interval_score_Tokushima_male,
                                        interval_score_Kagawa_male, interval_score_Ehime_male,
                                        interval_score_Kochi_male, interval_score_Fukuoka_male,
                                        interval_score_Saga_male, interval_score_Nagasaki_male,
                                        interval_score_Kumamoto_male, interval_score_Oita_male,
                                        interval_score_Miyazaki_male, interval_score_Kagoshima_male,
                                        interval_score_Okinawa_male))

interval_score_all = cbind(interval_score_Level_0, interval_score_Level_1, interval_score_Level_2, interval_score_Level_3,
                           interval_score_Level_4, interval_score_Level_5)
interval_score_all_stats = rbind(interval_score_all, colMeans(interval_score_all), apply(interval_score_all, 2, median))
colnames(interval_score_all_stats) = c("Level 0", "Level 1", "Level 2", "Level 3", "Level 4", "Level 5")
rownames(interval_score_all_stats) = c(1:15,"Mean","Median")

#########################################################
# construct prediction interval for multiple populations
#########################################################

require(gtools)

find_enlarge_val_mfts <- function(smooth_data, raw_data, series, fh, var_prop = 0.9,
                                  alpha = 0.8, transformation = c("log", "logit"))
{
    transformation = match.arg(transformation)
    decenter_object = rowmeans_object = sd_object = list()
    if(transformation == "log")
    {
        log_object = list()
        for(ik in 1:2)
        {
            log_object[[ik]] = log(smooth_data$rate[[ik]])
            # compute mean and standard deviation functions
            rowmeans_object[[ik]] = rowMeans(log(smooth_data$rate[[ik]]), na.rm = TRUE)
            sd_object[[ik]] = apply(log(smooth_data$rate[[ik]]), 1, sd, na.rm = TRUE)
            
            # de-center functional data
            decenter_object[[ik]] = t(scale(t(log(smooth_data$rate[[ik]])), center = TRUE, scale = TRUE))
        }
        rm(log_object)
    }
    if(transformation == "logit")
    {
        logit_object = list()
        for(ik in 1:2)
        {
            logit_object[[ik]] = logit(smooth_data$rate[[ik]])
            # compute mean and standard deviation functions
            rowmeans_object[[ik]] = rowMeans(logit(smooth_data$rate[[ik]]), na.rm=TRUE)
            sd_object[[ik]] = apply(logit(smooth_data$rate[[ik]]), 1, sd, na.rm=TRUE)
        
            # de-center functional data
            decenter_object[[ik]] = t(scale(t(logit(smooth_data$rate[[ik]])), center = TRUE, scale = TRUE))
        }
        rm(logit_object)
    }
    comb_object = do.call(rbind, decenter_object)
    ncomp_comb = head(which(cumsum(ftsm(fts(1:nrow(comb_object), comb_object), order = 20)$varprop) >= var_prop), 1)
    ftsm_obj = ftsm(fts(1:nrow(comb_object), comb_object), order = ncomp_comb)
    
    # calculate in-sample forecast curves
    fore_curve_dum = matrix(NA, length(smooth_data$age) * 2, length(smooth_data$year) - ncomp_comb - fh + 1)
    for(ij in 1:(length(smooth_data$year) - ncomp_comb - fh + 1))
    {
        fore_coef = matrix(NA, ncomp_comb, 1)
        for(ik in 2:(ncomp_comb + 1))
        {
            fore_coef[ik-1,1] = forecast(auto.arima(ftsm_obj$coeff[1:(ij+ncomp_comb-1), ik]), h = fh)$mean[fh]
        }
        fore_curve_dum[,ij] = (as.matrix(ftsm_obj$basis[,1]) + as.matrix(ftsm_obj$basis[,2:(ncomp_comb+1)]) %*% fore_coef) * do.call(c,sd_object) + do.call(c, rowmeans_object)
    }
    
    if(series == "female")
    {
        fore_curve = fore_curve_dum[1:41,]
    }
    if(series == "male")
    {
        fore_curve = fore_curve_dum[42:82,]
    }
    
    # holdout data example
    true_dat = extract.years(raw_data, raw_data$year[(ncomp_comb + fh): length(raw_data$year)])
    if(series == "female")
    {
        if(transformation == "log")
        {
            holdout_val = log(true_dat$rate$female)
        }
        if(transformation == "logit")
        {
            holdout_val = logit(true_dat$rate$female)
        }
    }
    if(series == "male")
    {
        if(transformation == "log")
        {
            holdout_val = log(true_dat$rate$male)
        }
        if(transformation == "logit")
        {
            holdout_val = logit(true_dat$rate$male)
        }
    }
    if(length(which(!is.finite(holdout_val))) > 0)
    {
        warning("some holdout data have Inf.")
        index = which(!is.finite(holdout_val))
        holdout_mat = replace(holdout_val, index, NA)
        rm(holdout_val)
        holdout_val = matrix(NA, nrow(holdout_mat), ncol(holdout_mat))
        for(ik in 1:ncol(holdout_mat))
        {
            holdout_val[,ik] = na.interp(holdout_mat[,ik])
        }
    }
    
    # calculate in-sample forecast errors
    err = holdout_val - fore_curve
    
    # must correct (compute standard deviation)
    
    if(ncol(err) == 1)
    {
        prediction_err_sd = sd(err)
    }
    else
    {
        prediction_err_sd = apply(err, 1, sd)
    }
    
    select_pointwise_tuning_parameter <- function(tuning_parameter, nominal_coverage)
    {
        nB = ncol(err)
        lb = -1 * tuning_parameter * prediction_err_sd
        ub = tuning_parameter * prediction_err_sd
        out_number = vector("numeric", nB)
        for(ik in 1:nB)
        {
            holdout = err[,ik]
            out_number[ik] = length(union(which(lb > holdout), which(ub < holdout)))
        }
        empirical_coverage = 1 - (sum(out_number)/length(err))
        return(abs(empirical_coverage - nominal_coverage))
    }
    
    pointwise_tuning_parameter_PI = optimize(f = select_pointwise_tuning_parameter, interval = c(0.1, 5), nominal_coverage = alpha)$minimum
    
    # constructing PI
    fore_pca_dat = forecast(ftsm_obj, h = fh)$mean$y[,fh] * do.call(c,sd_object) + do.call(c, rowmeans_object)
    parametric_pointwise_out = cbind(fore_pca_dat - prediction_err_sd * pointwise_tuning_parameter_PI,
                                     fore_pca_dat + prediction_err_sd * pointwise_tuning_parameter_PI)
    colnames(parametric_pointwise_out) = c("lb", "ub")
    
    if(series == "female")
    {
        return(parametric_pointwise_out[1:41,])
    }
    if(series == "male")
    {
        return(parametric_pointwise_out[42:82,])
    }
}

PI_fh_mfts <- function(smooth_series, raw_series, series, fh, transform = c("log", "logit"))
{
    transform = match.arg(transform)
    PI_pointwise_res = array(NA, dim = c(41, 2, (16 - fh)))
    for(ij in 1:(16-fh))
    {
        PI_pointwise_res[,,ij] = find_enlarge_val_mfts(smooth_data = extract.years(smooth_series, 1975:(2000+ij)),
                                                       raw_data = extract.years(raw_series, 1975:(2000+ij)),
                                                       series = series, fh = fh, transformation = transform)
    }
    return(PI_pointwise_res)
}


########
# Japan
########

require(doMC)
registerDoMC(15)
Japan_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Japan_smooth, raw_series = Japan, series = "female", fh = ik)
Japan_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Japan_smooth, raw_series = Japan, series = "male", fh = ik)

###########
# Hokkaido
###########

Hokkaido_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Hokkaido_smooth, raw_series = Hokkaido, series = "female", fh = ik)
Hokkaido_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Hokkaido_smooth, raw_series = Hokkaido, series = "male", fh = ik)

#########
# Aomori
#########

Aomori_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Aomori_smooth, raw_series = Aomori, series = "female", fh = ik)
Aomori_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Aomori_smooth, raw_series = Aomori, series = "male", fh = ik)

########
# Iwate
########

Iwate_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Iwate_smooth, raw_series = Iwate, series = "female", fh = ik)
Iwate_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Iwate_smooth, raw_series = Iwate, series = "male", fh = ik)

#########
# Miyagi
#########

Miyagi_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Miyagi_smooth, raw_series = Miyagi, series = "female", fh = ik)
Miyagi_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Miyagi_smooth, raw_series = Miyagi, series = "male", fh = ik)

########
# Akita
########

Akita_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Akita_smooth, raw_series = Akita, series = "female", fh = ik)
Akita_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Akita_smooth, raw_series = Akita, series = "male", fh = ik)

###########
# Yamagata
###########

Yamagata_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Yamagata_smooth, raw_series = Yamagata, series = "female", fh = ik)
Yamagata_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Yamagata_smooth, raw_series = Yamagata, series = "male", fh = ik)

############
# Fukushima
############

Fukushima_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Fukushima_smooth, raw_series = Fukushima, series = "female", fh = ik)
Fukushima_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Fukushima_smooth, raw_series = Fukushima, series = "male", fh = ik)

##########
# Ibaraki
##########

Ibaraki_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Ibaraki_smooth, raw_series = Ibaraki, series = "female", fh = ik)
Ibaraki_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Ibaraki_smooth, raw_series = Ibaraki, series = "male", fh = ik)

##########
# Tochigi
##########

Tochigi_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Tochigi_smooth, raw_series = Tochigi, series = "female", fh = ik)
Tochigi_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Tochigi_smooth, raw_series = Tochigi, series = "male", fh = ik)

########
# Gunma
########

Gunma_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Gunma_smooth, raw_series = Gunma, series = "female", fh = ik)
Gunma_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Gunma_smooth, raw_series = Gunma, series = "male", fh = ik)

##########
# Saitama
##########

Saitama_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Saitama_smooth, raw_series = Saitama, series = "female", fh = ik)
Saitama_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Saitama_smooth, raw_series = Saitama, series = "male", fh = ik)

########
# Chiba
########

Chiba_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Chiba_smooth, raw_series = Chiba, series = "female", fh = ik)
Chiba_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Chiba_smooth, raw_series = Chiba, series = "male", fh = ik)

########
# Tokyo
########

Tokyo_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Tokyo_smooth, raw_series = Tokyo, series = "female", fh = ik)
Tokyo_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Tokyo_smooth, raw_series = Tokyo, series = "male", fh = ik)

###########
# Kanagawa
###########

Kanagawa_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Kanagawa_smooth, raw_series = Kanagawa, series = "female", fh = ik)
Kanagawa_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Kanagawa_smooth, raw_series = Kanagawa, series = "male", fh = ik)

##########
# Niigata
##########

Niigata_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Niigata_smooth, raw_series = Niigata, series = "female", fh = ik)
Niigata_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Niigata_smooth, raw_series = Niigata, series = "male", fh = ik)

#########
# Toyama
#########

Toyama_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Toyama_smooth, raw_series = Toyama, series = "female", fh = ik)
Toyama_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Toyama_smooth, raw_series = Toyama, series = "male", fh = ik)

###########
# Ishikawa
###########

Ishikawa_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Ishikawa_smooth, raw_series = Ishikawa, series = "female", fh = ik)
Ishikawa_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Ishikawa_smooth, raw_series = Ishikawa, series = "male", fh = ik)

########
# Fukui
########

Fukui_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Fukui_smooth, raw_series = Fukui, series = "female", fh = ik)
Fukui_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Fukui_smooth, raw_series = Fukui, series = "male", fh = ik)

############
# Yamanashi
############

Yamanashi_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Yamanashi_smooth, raw_series = Yamanashi, series = "female", fh = ik)
Yamanashi_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Yamanashi_smooth, raw_series = Yamanashi, series = "male", fh = ik)

#########
# Nagano
#########

Nagano_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Nagano_smooth, raw_series = Nagano, series = "female", fh = ik)
Nagano_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Nagano_smooth, raw_series = Nagano, series = "male", fh = ik)

#######
# Gifu
#######

Gifu_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Gifu_smooth, raw_series = Gifu, series = "female", fh = ik)
Gifu_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Gifu_smooth, raw_series = Gifu, series = "male", fh = ik)

###########
# Shizuoka
###########

Shizuoka_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Shizuoka_smooth, raw_series = Shizuoka, series = "female", fh = ik)
Shizuoka_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Shizuoka_smooth, raw_series = Shizuoka, series = "male", fh = ik)

########
# Aichi
########

Aichi_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Aichi_smooth, raw_series = Aichi, series = "female", fh = ik)
Aichi_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Aichi_smooth, raw_series = Aichi, series = "male", fh = ik)

######
# Mie
######

Mie_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Mie_smooth, raw_series = Mie, series = "female", fh = ik)
Mie_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Mie_smooth, raw_series = Mie, series = "male", fh = ik)

########
# Shiga
########

Shiga_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Shiga_smooth, raw_series = Shiga, series = "female", fh = ik)
Shiga_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Shiga_smooth, raw_series = Shiga, series = "male", fh = ik)

########
# Kyoto
########

Kyoto_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Kyoto_smooth, raw_series = Kyoto, series = "female", fh = ik)
Kyoto_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Kyoto_smooth, raw_series = Kyoto, series = "male", fh = ik)

########
# Osaka
########

Osaka_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Osaka_smooth, raw_series = Osaka, series = "female", fh = ik)
Osaka_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Osaka_smooth, raw_series = Osaka, series = "male", fh = ik)

########
# Hyogo
########

Hyogo_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Hyogo_smooth, raw_series = Hyogo, series = "female", fh = ik)
Hyogo_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Hyogo_smooth, raw_series = Hyogo, series = "male", fh = ik)

#######
# Nara
#######

Nara_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Nara_smooth, raw_series = Nara, series = "female", fh = ik)
Nara_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Nara_smooth, raw_series = Nara, series = "male", fh = ik)

###########
# Wakayama
###########

Wakayama_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Wakayama_smooth, raw_series = Wakayama, series = "female", fh = ik)
Wakayama_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Wakayama_smooth, raw_series = Wakayama, series = "male", fh = ik)

##########
# Tottori
##########

Tottori_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Tottori_smooth, raw_series = Tottori, series = "female", fh = ik)
Tottori_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Tottori_smooth, raw_series = Tottori, series = "male", fh = ik)

##########
# Shimane
##########

Shimane_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Shimane_smooth, raw_series = Shimane, series = "female", fh = ik)
Shimane_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Shimane_smooth, raw_series = Shimane, series = "male", fh = ik)

##########
# Okayama
##########

Okayama_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Okayama_smooth, raw_series = Okayama, series = "female", fh = ik)
Okayama_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Okayama_smooth, raw_series = Okayama, series = "male", fh = ik)

############
# Hiroshima
############

Hiroshima_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Hiroshima_smooth, raw_series = Hiroshima, series = "female", fh = ik)
Hiroshima_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Hiroshima_smooth, raw_series = Hiroshima, series = "male", fh = ik)

############
# Yamaguchi
############

Yamaguchi_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Yamaguchi_smooth, raw_series = Yamaguchi, series = "female", fh = ik)
Yamaguchi_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Yamaguchi_smooth, raw_series = Yamaguchi, series = "male", fh = ik)

############
# Tokushima
############

Tokushima_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Tokushima_smooth, raw_series = Tokushima, series = "female", fh = ik)
Tokushima_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Tokushima_smooth, raw_series = Tokushima, series = "male", fh = ik)

#########
# Kagawa
#########

Kagawa_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Kagawa_smooth, raw_series = Kagawa, series = "female", fh = ik)
Kagawa_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Kagawa_smooth, raw_series = Kagawa, series = "male", fh = ik)

########
# Ehime
########

Ehime_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Ehime_smooth, raw_series = Ehime, series = "female", fh = ik)
Ehime_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Ehime_smooth, raw_series = Ehime, series = "male", fh = ik)

########
# Kochi
########

Kochi_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Kochi_smooth, raw_series = Kochi, series = "female", fh = ik)
Kochi_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Kochi_smooth, raw_series = Kochi, series = "male", fh = ik)

##########
# Fukuoka
##########

Fukuoka_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Fukuoka_smooth, raw_series = Fukuoka, series = "female", fh = ik)
Fukuoka_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Fukuoka_smooth, raw_series = Fukuoka, series = "male", fh = ik)

#######
# Saga
#######

Saga_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Saga_smooth, raw_series = Saga, series = "female", fh = ik)
Saga_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Saga_smooth, raw_series = Saga, series = "male", fh = ik)

###########
# Nagasaki
###########

Nagasaki_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Nagasaki_smooth, raw_series = Nagasaki, series = "female", fh = ik)
Nagasaki_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Nagasaki_smooth, raw_series = Nagasaki, series = "male", fh = ik)

###########
# Kumamoto
###########

Kumamoto_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Kumamoto_smooth, raw_series = Kumamoto, series = "female", fh = ik)
Kumamoto_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Kumamoto_smooth, raw_series = Kumamoto, series = "male", fh = ik)

#######
# Oita
#######

Oita_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Oita_smooth, raw_series = Oita, series = "female", fh = ik)
Oita_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Oita_smooth, raw_series = Oita, series = "male", fh = ik)

###########
# Miyazaki
###########

Miyazaki_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Miyazaki_smooth, raw_series = Miyazaki, series = "female", fh = ik)
Miyazaki_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Miyazaki_smooth, raw_series = Miyazaki, series = "male", fh = ik)

############
# Kagoshima
############

Kagoshima_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Kagoshima_smooth, raw_series = Kagoshima, series = "female", fh = ik)
Kagoshima_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Kagoshima_smooth, raw_series = Kagoshima, series = "male", fh = ik)

##########
# Okinawa
##########

Okinawa_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Okinawa_smooth, raw_series = Okinawa, series = "female", fh = ik)
Okinawa_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = Okinawa_smooth, raw_series = Okinawa, series = "male", fh = ik)

###########
# Region 1
###########

R1_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = ind_R1_smooth, raw_series = ind_R1, series = "female", fh = ik)
R1_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = ind_R1_smooth, raw_series = ind_R1, series = "male", fh = ik)

###########
# Region 2
###########

R2_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = ind_R2_smooth, raw_series = ind_R2, series = "female", fh = ik)
R2_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = ind_R2_smooth, raw_series = ind_R2, series = "male", fh = ik)

###########
# Region 3
###########

R3_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = ind_R3_smooth, raw_series = ind_R3, series = "female", fh = ik)
R3_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = ind_R3_smooth, raw_series = ind_R3, series = "male", fh = ik)

###########
# Region 4
###########

R4_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = ind_R4_smooth, raw_series = ind_R4, series = "female", fh = ik)
R4_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = ind_R4_smooth, raw_series = ind_R4, series = "male", fh = ik)

###########
# Region 5
###########

R5_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = ind_R5_smooth, raw_series = ind_R5, series = "female", fh = ik)
R5_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = ind_R5_smooth, raw_series = ind_R5, series = "male", fh = ik)

###########
# Region 6
###########

R6_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = ind_R6_smooth, raw_series = ind_R6, series = "female", fh = ik)
R6_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = ind_R6_smooth, raw_series = ind_R6, series = "male", fh = ik)

###########
# Region 7
###########

R7_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = ind_R7_smooth, raw_series = ind_R7, series = "female", fh = ik)
R7_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = ind_R7_smooth, raw_series = ind_R7, series = "male", fh = ik)

###########
# Region 8
###########

R8_female_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = ind_R8_smooth, raw_series = ind_R8, series = "female", fh = ik)
R8_male_fh_PI_mfts   = foreach(ik = 1:15) %dopar% PI_fh_mfts(smooth_series = ind_R8_smooth, raw_series = ind_R8, series = "male", fh = ik)

#################
# Interval score
#################

# interval score based on logit

interval_score <- function(PI_val, data_series, series, fh, alpha = 0.8,
                           transformation = c("log", "logit"))
{
    transformation = match.arg(transformation)
    if(series == "female")
    {
        test_val = extract.years(data_series, (2001+fh):2016)$rate$female
    }
    if(series == "male")
    {
        test_val = extract.years(data_series, (2001+fh):2016)$rate$male
    }
    if(series == "total")
    {
        test_val = extract.years(data_series, (2001+fh):2016)$rate$total
    }
    # transform back to the original scale
    if(transformation == "log")
    {
        boot_sample = exp(PI_val[[fh]])
    }
    else
    {
        boot_sample = inv.logit(PI_val[[fh]])
    }
    index = which(boot_sample > 1)
    if(length(index) > 0)
    {
        boot_sample_v1 = replace(boot_sample, index, 1)
    }
    else
    {
        boot_sample_v1 = boot_sample
    }
    index_below = which(boot_sample < 0)
    if(length(index_below) > 0)
    {
        boot_sample_v2 = replace(boot_sample_v1, index_below, 0)
    }
    else
    {
        boot_sample_v2 = boot_sample_v1
    }
    PI_lb_val = boot_sample_v2[,1,]
    PI_ub_val = boot_sample_v2[,2,]
    
    lb_ind = ifelse(test_val < PI_lb_val, 1, 0)
    ub_ind = ifelse(test_val > PI_ub_val, 1, 0)
    score = mean((PI_ub_val - PI_lb_val) + 2/(1 - alpha) * (PI_lb_val - test_val) * lb_ind + 2/(1 - alpha) * (test_val - PI_ub_val) * ub_ind, na.rm = TRUE)
    return(score)
}

# Japan

interval_score_Japan_female_mfts = interval_score_Japan_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Japan_female_mfts[ij] = interval_score(PI_val = Japan_female_fh_PI_mfts, data_series = Japan, series = "female", fh = ij)
    interval_score_Japan_male_mfts[ij]   = interval_score(PI_val = Japan_male_fh_PI_mfts, data_series = Japan, series = "male", fh = ij)
}

# Hokkaido

interval_score_Hokkaido_female_mfts = interval_score_Hokkaido_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Hokkaido_female_mfts[ij] = interval_score(PI_val = Hokkaido_female_fh_PI_mfts, data_series = Hokkaido, series = "female", fh = ij)
    interval_score_Hokkaido_male_mfts[ij]   = interval_score(PI_val = Hokkaido_male_fh_PI_mfts, data_series = Hokkaido, series = "male", fh = ij)
}

# Aomori

interval_score_Aomori_female_mfts = interval_score_Aomori_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Aomori_female_mfts[ij] = interval_score(PI_val = Aomori_female_fh_PI_mfts, data_series = Aomori, series = "female", fh = ij)
    interval_score_Aomori_male_mfts[ij]   = interval_score(PI_val = Aomori_male_fh_PI_mfts, data_series = Aomori, series = "male", fh = ij)
}

# Iwate

interval_score_Iwate_female_mfts = interval_score_Iwate_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Iwate_female_mfts[ij] = interval_score(PI_val = Iwate_female_fh_PI_mfts, data_series = Iwate, series = "female", fh = ij)
    interval_score_Iwate_male_mfts[ij]   = interval_score(PI_val = Iwate_male_fh_PI_mfts, data_series = Iwate, series = "male", fh = ij)
}

# Miyagi

interval_score_Miyagi_female_mfts = interval_score_Miyagi_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Miyagi_female_mfts[ij] = interval_score(PI_val = Miyagi_female_fh_PI_mfts, data_series = Miyagi, series = "female", fh = ij)
    interval_score_Miyagi_male_mfts[ij]   = interval_score(PI_val = Miyagi_male_fh_PI_mfts, data_series = Miyagi, series = "male", fh = ij)
}

# Akita

interval_score_Akita_female_mfts = interval_score_Akita_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Akita_female_mfts[ij] = interval_score(PI_val = Akita_female_fh_PI_mfts, data_series = Akita, series = "female", fh = ij)
    interval_score_Akita_male_mfts[ij]   = interval_score(PI_val = Akita_male_fh_PI_mfts, data_series = Akita, series = "male", fh = ij)
}

# Yamagata

interval_score_Yamagata_female_mfts = interval_score_Yamagata_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Yamagata_female_mfts[ij] = interval_score(PI_val = Yamagata_female_fh_PI_mfts, data_series = Yamagata, series = "female", fh = ij)
    interval_score_Yamagata_male_mfts[ij]   = interval_score(PI_val = Yamagata_male_fh_PI_mfts, data_series = Yamagata, series = "male", fh = ij)
}

# Fukushima

interval_score_Fukushima_female_mfts = interval_score_Fukushima_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Fukushima_female_mfts[ij] = interval_score(PI_val = Fukushima_female_fh_PI_mfts, data_series = Fukushima, series = "female", fh = ij)
    interval_score_Fukushima_male_mfts[ij]   = interval_score(PI_val = Fukushima_male_fh_PI_mfts, data_series = Fukushima, series = "male", fh = ij)
}

# Ibaraki

interval_score_Ibaraki_female_mfts = interval_score_Ibaraki_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Ibaraki_female_mfts[ij] = interval_score(PI_val = Ibaraki_female_fh_PI_mfts, data_series = Ibaraki, series = "female", fh = ij)
    interval_score_Ibaraki_male_mfts[ij]   = interval_score(PI_val = Ibaraki_male_fh_PI_mfts, data_series = Ibaraki, series = "male", fh = ij)
}

# Tochigi

interval_score_Tochigi_female_mfts = interval_score_Tochigi_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Tochigi_female_mfts[ij] = interval_score(PI_val = Tochigi_female_fh_PI_mfts, data_series = Tochigi, series = "female", fh = ij)
    interval_score_Tochigi_male_mfts[ij]   = interval_score(PI_val = Tochigi_male_fh_PI_mfts, data_series = Tochigi, series = "male", fh = ij)
}

# Gunma

interval_score_Gunma_female_mfts = interval_score_Gunma_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Gunma_female_mfts[ij] = interval_score(PI_val = Gunma_female_fh_PI_mfts, data_series = Gunma, series = "female", fh = ij)
    interval_score_Gunma_male_mfts[ij]   = interval_score(PI_val = Gunma_male_fh_PI_mfts, data_series = Gunma, series = "male", fh = ij)
}

# Saitama

interval_score_Saitama_female_mfts = interval_score_Saitama_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Saitama_female_mfts[ij] = interval_score(PI_val = Saitama_female_fh_PI_mfts, data_series = Saitama, series = "female", fh = ij)
    interval_score_Saitama_male_mfts[ij]   = interval_score(PI_val = Saitama_male_fh_PI_mfts, data_series = Saitama, series = "male", fh = ij)
}

# Chiba

interval_score_Chiba_female_mfts = interval_score_Chiba_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Chiba_female_mfts[ij] = interval_score(PI_val = Chiba_female_fh_PI_mfts, data_series = Chiba, series = "female", fh = ij)
    interval_score_Chiba_male_mfts[ij]   = interval_score(PI_val = Chiba_male_fh_PI_mfts, data_series = Chiba, series = "male", fh = ij)
}

# Tokyo

interval_score_Tokyo_female_mfts = interval_score_Tokyo_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Tokyo_female_mfts[ij] = interval_score(PI_val = Tokyo_female_fh_PI_mfts, data_series = Tokyo, series = "female", fh = ij)
    interval_score_Tokyo_male_mfts[ij]   = interval_score(PI_val = Tokyo_male_fh_PI_mfts, data_series = Tokyo, series = "male", fh = ij)
}

# Kanagawa

interval_score_Kanagawa_female_mfts = interval_score_Kanagawa_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Kanagawa_female_mfts[ij] = interval_score(PI_val = Kanagawa_female_fh_PI_mfts, data_series = Kanagawa, series = "female", fh = ij)
    interval_score_Kanagawa_male_mfts[ij]   = interval_score(PI_val = Kanagawa_male_fh_PI_mfts, data_series = Kanagawa, series = "male", fh = ij)
}

# Niigata

interval_score_Niigata_female_mfts = interval_score_Niigata_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Niigata_female_mfts[ij] = interval_score(PI_val = Niigata_female_fh_PI_mfts, data_series = Niigata, series = "female", fh = ij)
    interval_score_Niigata_male_mfts[ij]   = interval_score(PI_val = Niigata_male_fh_PI_mfts, data_series = Niigata, series = "male", fh = ij)
}

# Toyama

interval_score_Toyama_female_mfts = interval_score_Toyama_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Toyama_female_mfts[ij] = interval_score(PI_val = Toyama_female_fh_PI_mfts, data_series = Toyama, series = "female", fh = ij)
    interval_score_Toyama_male_mfts[ij]   = interval_score(PI_val = Toyama_male_fh_PI_mfts, data_series = Toyama, series = "male", fh = ij)
}

# Ishikawa

interval_score_Ishikawa_female_mfts = interval_score_Ishikawa_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Ishikawa_female_mfts[ij] = interval_score(PI_val = Ishikawa_female_fh_PI_mfts, data_series = Ishikawa, series = "female", fh = ij)
    interval_score_Ishikawa_male_mfts[ij]   = interval_score(PI_val = Ishikawa_male_fh_PI_mfts, data_series = Ishikawa, series = "male", fh = ij)
}

# Fukui

interval_score_Fukui_female_mfts = interval_score_Fukui_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Fukui_female_mfts[ij] = interval_score(PI_val = Fukui_female_fh_PI_mfts, data_series = Fukui, series = "female", fh = ij)
    interval_score_Fukui_male_mfts[ij]   = interval_score(PI_val = Fukui_male_fh_PI_mfts, data_series = Fukui, series = "male", fh = ij)
}

# Yamanashi

interval_score_Yamanashi_female_mfts = interval_score_Yamanashi_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Yamanashi_female_mfts[ij] = interval_score(PI_val = Yamanashi_female_fh_PI_mfts, data_series = Yamanashi, series = "female", fh = ij)
    interval_score_Yamanashi_male_mfts[ij]   = interval_score(PI_val = Yamanashi_male_fh_PI_mfts, data_series = Yamanashi, series = "male", fh = ij)
}

# Nagano

interval_score_Nagano_female_mfts = interval_score_Nagano_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Nagano_female_mfts[ij] = interval_score(PI_val = Nagano_female_fh_PI_mfts, data_series = Nagano, series = "female", fh = ij)
    interval_score_Nagano_male_mfts[ij]   = interval_score(PI_val = Nagano_male_fh_PI_mfts, data_series = Nagano, series = "male", fh = ij)
}

# Gifu

interval_score_Gifu_female_mfts = interval_score_Gifu_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Gifu_female_mfts[ij] = interval_score(PI_val = Gifu_female_fh_PI_mfts, data_series = Gifu, series = "female", fh = ij)
    interval_score_Gifu_male_mfts[ij]   = interval_score(PI_val = Gifu_male_fh_PI_mfts, data_series = Gifu, series = "male", fh = ij)
}

# Shizuoka

interval_score_Shizuoka_female_mfts = interval_score_Shizuoka_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Shizuoka_female_mfts[ij] = interval_score(PI_val = Shizuoka_female_fh_PI_mfts, data_series = Shizuoka, series = "female", fh = ij)
    interval_score_Shizuoka_male_mfts[ij]   = interval_score(PI_val = Shizuoka_male_fh_PI_mfts, data_series = Shizuoka, series = "male", fh = ij)
}

# Aichi

interval_score_Aichi_female_mfts = interval_score_Aichi_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Aichi_female_mfts[ij] = interval_score(PI_val = Aichi_female_fh_PI_mfts, data_series = Aichi, series = "female", fh = ij)
    interval_score_Aichi_male_mfts[ij]   = interval_score(PI_val = Aichi_male_fh_PI_mfts, data_series = Aichi, series = "male", fh = ij)
}

# Mie

interval_score_Mie_female_mfts = interval_score_Mie_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Mie_female_mfts[ij] = interval_score(PI_val = Mie_female_fh_PI_mfts, data_series = Mie, series = "female", fh = ij)
    interval_score_Mie_male_mfts[ij]   = interval_score(PI_val = Mie_male_fh_PI_mfts, data_series = Mie, series = "male", fh = ij)
}

# Shiga

interval_score_Shiga_female_mfts = interval_score_Shiga_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Shiga_female_mfts[ij] = interval_score(PI_val = Shiga_female_fh_PI_mfts, data_series = Shiga, series = "female", fh = ij)
    interval_score_Shiga_male_mfts[ij]   = interval_score(PI_val = Shiga_male_fh_PI_mfts, data_series = Shiga, series = "male", fh = ij)
}

# Kyoto

interval_score_Kyoto_female_mfts = interval_score_Kyoto_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Kyoto_female_mfts[ij] = interval_score(PI_val = Kyoto_female_fh_PI_mfts, data_series = Kyoto, series = "female", fh = ij)
    interval_score_Kyoto_male_mfts[ij]   = interval_score(PI_val = Kyoto_male_fh_PI_mfts, data_series = Kyoto, series = "male", fh = ij)
}

# Osaka

interval_score_Osaka_female_mfts = interval_score_Osaka_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Osaka_female_mfts[ij] = interval_score(PI_val = Osaka_female_fh_PI_mfts, data_series = Osaka, series = "female", fh = ij)
    interval_score_Osaka_male_mfts[ij]   = interval_score(PI_val = Osaka_male_fh_PI_mfts, data_series = Osaka, series = "male", fh = ij)
}

# Hyogo

interval_score_Hyogo_female_mfts = interval_score_Hyogo_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Hyogo_female_mfts[ij] = interval_score(PI_val = Hyogo_female_fh_PI_mfts, data_series = Hyogo, series = "female", fh = ij)
    interval_score_Hyogo_male_mfts[ij]   = interval_score(PI_val = Hyogo_male_fh_PI_mfts, data_series = Hyogo, series = "male", fh = ij)
}

# Nara

interval_score_Nara_female_mfts = interval_score_Nara_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Nara_female_mfts[ij] = interval_score(PI_val = Nara_female_fh_PI_mfts, data_series = Nara, series = "female", fh = ij)
    interval_score_Nara_male_mfts[ij]   = interval_score(PI_val = Nara_male_fh_PI_mfts, data_series = Nara, series = "male", fh = ij)
}

# Wakayama

interval_score_Wakayama_female_mfts = interval_score_Wakayama_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Wakayama_female_mfts[ij] = interval_score(PI_val = Wakayama_female_fh_PI_mfts, data_series = Wakayama, series = "female", fh = ij)
    interval_score_Wakayama_male_mfts[ij]   = interval_score(PI_val = Wakayama_male_fh_PI_mfts, data_series = Wakayama, series = "male", fh = ij)
}

# Tottori

interval_score_Tottori_female_mfts = interval_score_Tottori_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Tottori_female_mfts[ij] = interval_score(PI_val = Tottori_female_fh_PI_mfts, data_series = Tottori, series = "female", fh = ij)
    interval_score_Tottori_male_mfts[ij]   = interval_score(PI_val = Tottori_male_fh_PI_mfts, data_series = Tottori, series = "male", fh = ij)
}

# Shimane

interval_score_Shimane_female_mfts = interval_score_Shimane_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Shimane_female_mfts[ij] = interval_score(PI_val = Shimane_female_fh_PI_mfts, data_series = Shimane, series = "female", fh = ij)
    interval_score_Shimane_male_mfts[ij]   = interval_score(PI_val = Shimane_male_fh_PI_mfts, data_series = Shimane, series = "male", fh = ij)
}

# Okayama

interval_score_Okayama_female_mfts = interval_score_Okayama_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Okayama_female_mfts[ij] = interval_score(PI_val = Okayama_female_fh_PI_mfts, data_series = Okayama, series = "female", fh = ij)
    interval_score_Okayama_male_mfts[ij]   = interval_score(PI_val = Okayama_male_fh_PI_mfts, data_series = Okayama, series = "male", fh = ij)
}

# Hiroshima

interval_score_Hiroshima_female_mfts = interval_score_Hiroshima_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Hiroshima_female_mfts[ij] = interval_score(PI_val = Hiroshima_female_fh_PI_mfts, data_series = Hiroshima, series = "female", fh = ij)
    interval_score_Hiroshima_male_mfts[ij]   = interval_score(PI_val = Hiroshima_male_fh_PI_mfts, data_series = Hiroshima, series = "male", fh = ij)
}

# Yamaguchi

interval_score_Yamaguchi_female_mfts = interval_score_Yamaguchi_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Yamaguchi_female_mfts[ij] = interval_score(PI_val = Yamaguchi_female_fh_PI_mfts, data_series = Yamaguchi, series = "female", fh = ij)
    interval_score_Yamaguchi_male_mfts[ij]   = interval_score(PI_val = Yamaguchi_male_fh_PI_mfts, data_series = Yamaguchi, series = "male", fh = ij)
}

# Tokushima

interval_score_Tokushima_female_mfts = interval_score_Tokushima_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Tokushima_female_mfts[ij] = interval_score(PI_val = Tokushima_female_fh_PI_mfts, data_series = Tokushima, series = "female", fh = ij)
    interval_score_Tokushima_male_mfts[ij]   = interval_score(PI_val = Tokushima_male_fh_PI_mfts, data_series = Tokushima, series = "male", fh = ij)
}

# Kagawa

interval_score_Kagawa_female_mfts = interval_score_Kagawa_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Kagawa_female_mfts[ij] = interval_score(PI_val = Kagawa_female_fh_PI_mfts, data_series = Kagawa, series = "female", fh = ij)
    interval_score_Kagawa_male_mfts[ij]   = interval_score(PI_val = Kagawa_male_fh_PI_mfts, data_series = Kagawa, series = "male", fh = ij)
}

# Ehime

interval_score_Ehime_female_mfts = interval_score_Ehime_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Ehime_female_mfts[ij] = interval_score(PI_val = Ehime_female_fh_PI_mfts, data_series = Ehime, series = "female", fh = ij)
    interval_score_Ehime_male_mfts[ij]   = interval_score(PI_val = Ehime_male_fh_PI_mfts, data_series = Ehime, series = "male", fh = ij)
}

# Kochi

interval_score_Kochi_female_mfts = interval_score_Kochi_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Kochi_female_mfts[ij] = interval_score(PI_val = Kochi_female_fh_PI_mfts, data_series = Kochi, series = "female", fh = ij)
    interval_score_Kochi_male_mfts[ij]   = interval_score(PI_val = Kochi_male_fh_PI_mfts, data_series = Kochi, series = "male", fh = ij)
}

# Fukuoka

interval_score_Fukuoka_female_mfts = interval_score_Fukuoka_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Fukuoka_female_mfts[ij] = interval_score(PI_val = Fukuoka_female_fh_PI_mfts, data_series = Fukuoka, series = "female", fh = ij)
    interval_score_Fukuoka_male_mfts[ij]   = interval_score(PI_val = Fukuoka_male_fh_PI_mfts, data_series = Fukuoka, series = "male", fh = ij)
}

# Saga

interval_score_Saga_female_mfts = interval_score_Saga_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Saga_female_mfts[ij] = interval_score(PI_val = Saga_female_fh_PI_mfts, data_series = Saga, series = "female", fh = ij)
    interval_score_Saga_male_mfts[ij]   = interval_score(PI_val = Saga_male_fh_PI_mfts, data_series = Saga, series = "male", fh = ij)
}

# Nagasaki

interval_score_Nagasaki_female_mfts = interval_score_Nagasaki_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Nagasaki_female_mfts[ij] = interval_score(PI_val = Nagasaki_female_fh_PI_mfts, data_series = Nagasaki, series = "female", fh = ij)
    interval_score_Nagasaki_male_mfts[ij]   = interval_score(PI_val = Nagasaki_male_fh_PI_mfts, data_series = Nagasaki, series = "male", fh = ij)
}

# Kumamoto

interval_score_Kumamoto_female_mfts = interval_score_Kumamoto_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Kumamoto_female_mfts[ij] = interval_score(PI_val = Kumamoto_female_fh_PI_mfts, data_series = Kumamoto, series = "female", fh = ij)
    interval_score_Kumamoto_male_mfts[ij]   = interval_score(PI_val = Kumamoto_male_fh_PI_mfts, data_series = Kumamoto, series = "male", fh = ij)
}

# Oita

interval_score_Oita_female_mfts = interval_score_Oita_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Oita_female_mfts[ij] = interval_score(PI_val = Oita_female_fh_PI_mfts, data_series = Oita, series = "female", fh = ij)
    interval_score_Oita_male_mfts[ij]   = interval_score(PI_val = Oita_male_fh_PI_mfts, data_series = Oita, series = "male", fh = ij)
}

# Miyazaki

interval_score_Miyazaki_female_mfts = interval_score_Miyazaki_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Miyazaki_female_mfts[ij] = interval_score(PI_val = Miyazaki_female_fh_PI_mfts, data_series = Miyazaki, series = "female", fh = ij)
    interval_score_Miyazaki_male_mfts[ij]   = interval_score(PI_val = Miyazaki_male_fh_PI_mfts, data_series = Miyazaki, series = "male", fh = ij)
}

# Kagoshima

interval_score_Kagoshima_female_mfts = interval_score_Kagoshima_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Kagoshima_female_mfts[ij] = interval_score(PI_val = Kagoshima_female_fh_PI_mfts, data_series = Kagoshima, series = "female", fh = ij)
    interval_score_Kagoshima_male_mfts[ij] = interval_score(PI_val = Kagoshima_male_fh_PI_mfts, data_series = Kagoshima, series = "male", fh = ij)
}

# Okinawa

interval_score_Okinawa_female_mfts = interval_score_Okinawa_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_Okinawa_female_mfts[ij] = interval_score(PI_val = Okinawa_female_fh_PI_mfts, data_series = Okinawa, series = "female", fh = ij)
    interval_score_Okinawa_male_mfts[ij] = interval_score(PI_val = Okinawa_male_fh_PI_mfts, data_series = Okinawa, series = "male", fh = ij)
}

# R1

interval_score_R1_female_mfts = interval_score_R1_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_R1_female_mfts[ij] = interval_score(PI_val = R1_female_fh_PI_mfts, data_series = ind_R1, series = "female", fh = ij)
    interval_score_R1_male_mfts[ij]   = interval_score(PI_val = R1_male_fh_PI_mfts, data_series = ind_R1, series = "male", fh = ij)
}

# R2

interval_score_R2_female_mfts = interval_score_R2_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_R2_female_mfts[ij] = interval_score(PI_val = R2_female_fh_PI_mfts, data_series = ind_R2, series = "female", fh = ij)
    interval_score_R2_male_mfts[ij]   = interval_score(PI_val = R2_male_fh_PI_mfts, data_series = ind_R2, series = "male", fh = ij)
}

# R3

interval_score_R3_female_mfts = interval_score_R3_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_R3_female_mfts[ij] = interval_score(PI_val = R3_female_fh_PI_mfts, data_series = ind_R3, series = "female", fh = ij)
    interval_score_R3_male_mfts[ij]   = interval_score(PI_val = R3_male_fh_PI_mfts, data_series = ind_R3, series = "male", fh = ij)
}

# R4

interval_score_R4_female_mfts = interval_score_R4_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_R4_female_mfts[ij] = interval_score(PI_val = R4_female_fh_PI_mfts, data_series = ind_R4, series = "female", fh = ij)
    interval_score_R4_male_mfts[ij]   = interval_score(PI_val = R4_male_fh_PI_mfts, data_series = ind_R4, series = "male", fh = ij)
}

# R5

interval_score_R5_female_mfts = interval_score_R5_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_R5_female_mfts[ij] = interval_score(PI_val = R5_female_fh_PI_mfts, data_series = ind_R5, series = "female", fh = ij)
    interval_score_R5_male_mfts[ij]   = interval_score(PI_val = R5_male_fh_PI_mfts, data_series = ind_R5, series = "male", fh = ij)
}

# R6

interval_score_R6_female_mfts = interval_score_R6_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_R6_female_mfts[ij] = interval_score(PI_val = R6_female_fh_PI_mfts, data_series = ind_R6, series = "female", fh = ij)
    interval_score_R6_male_mfts[ij]   = interval_score(PI_val = R6_male_fh_PI_mfts, data_series = ind_R6, series = "male", fh = ij)
}

# R7

interval_score_R7_female_mfts = interval_score_R7_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_R7_female_mfts[ij] = interval_score(PI_val = R7_female_fh_PI_mfts, data_series = ind_R7, series = "female", fh = ij)
    interval_score_R7_male_mfts[ij]   = interval_score(PI_val = R7_male_fh_PI_mfts, data_series = ind_R7, series = "male", fh = ij)
}

# R8

interval_score_R8_female_mfts = interval_score_R8_male_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_R8_female_mfts[ij] = interval_score(PI_val = R8_female_fh_PI_mfts, data_series = ind_R8, series = "female", fh = ij)
    interval_score_R8_male_mfts[ij]   = interval_score(PI_val = R8_male_fh_PI_mfts, data_series = ind_R8, series = "male", fh = ij)
}

######################################################
# Interval score at different levels of the hierarchy
######################################################

# Japan (total)

interval_score_Level_0 = interval_score_Japan_total

# Japan (female + male)

interval_score_Level_1_mfts = rowMeans(cbind(interval_score_Japan_female_mfts, interval_score_Japan_male_mfts))

# Japan region (total)

interval_score_Level_2_mfts = rowMeans(cbind(interval_score_R1_total_mfts, interval_score_R2_total_mfts, interval_score_R3_total_mfts, interval_score_R4_total_mfts,
                                        interval_score_R5_total_mfts, interval_score_R6_total_mfts, interval_score_R7_total_mfts, interval_score_R8_total_mfts))

# Japan region (female + male)

interval_score_Level_3_mfts = rowMeans(cbind(interval_score_R1_female_mfts, interval_score_R2_female_mfts, interval_score_R3_female_mfts, interval_score_R4_female_mfts,
                                        interval_score_R5_female_mfts, interval_score_R6_female_mfts, interval_score_R7_female_mfts, interval_score_R8_female_mfts,
                                        interval_score_R1_male_mfts,   interval_score_R2_male_mfts,   interval_score_R3_male_mfts,   interval_score_R4_male_mfts,
                                        interval_score_R5_male_mfts,   interval_score_R6_male_mfts,   interval_score_R7_male_mfts,   interval_score_R8_male_mfts))

# Japan prefecture (total)

interval_score_Level_4_mfts = rowMeans(cbind(interval_score_P1_total_mfts, interval_score_P2_total_mfts, interval_score_P3_total_mfts, interval_score_P4_total_mfts,
                                             interval_score_P5_total_mfts, interval_score_P6_total_mfts, interval_score_P7_total_mfts, interval_score_P8_total_mfts,
                                             interval_score_P9_total_mfts, interval_score_P10_total_mfts, interval_score_P11_total_mfts, interval_score_P12_total_mfts,
                                             interval_score_P13_total_mfts, interval_score_P14_total_mfts, interval_score_P15_total_mfts, interval_score_P16_total_mfts,
                                             interval_score_P17_total_mfts, interval_score_P18_total_mfts, interval_score_P19_total_mfts, interval_score_P20_total_mfts,
                                             interval_score_P21_total_mfts, interval_score_P22_total_mfts, interval_score_P23_total_mfts, interval_score_P24_total_mfts,
                                             interval_score_P25_total_mfts, interval_score_P26_total_mfts, interval_score_P27_total_mfts, interval_score_P28_total_mfts,
                                             interval_score_P29_total_mfts, interval_score_P30_total_mfts, interval_score_P31_total_mfts, interval_score_P32_total_mfts,
                                             interval_score_P33_total_mfts, interval_score_P34_total_mfts, interval_score_P35_total_mfts, interval_score_P36_total_mfts,
                                             interval_score_P37_total_mfts, interval_score_P38_total_mfts, interval_score_P39_total_mfts, interval_score_P40_total_mfts,
                                             interval_score_P41_total_mfts, interval_score_P42_total_mfts, interval_score_P43_total_mfts, interval_score_P44_total_mfts,
                                             interval_score_P45_total_mfts, interval_score_P46_total_mfts, interval_score_P47_total_mfts))

# Japan prefecture (female + male)

interval_score_Level_5_mfts = rowMeans(cbind(interval_score_Hokkaido_female_mfts, interval_score_Aomori_female_mfts, interval_score_Iwate_female_mfts,
                                             interval_score_Miyagi_female_mfts, interval_score_Akita_female_mfts, interval_score_Yamagata_female_mfts,
                                             interval_score_Fukushima_female_mfts, interval_score_Ibaraki_female_mfts, interval_score_Tochigi_female_mfts,
                                             interval_score_Gunma_female_mfts, interval_score_Saitama_female_mfts, interval_score_Chiba_female_mfts,
                                             interval_score_Tokyo_female_mfts, interval_score_Kanagawa_female_mfts, interval_score_Niigata_female_mfts,
                                             interval_score_Toyama_female_mfts, interval_score_Ishikawa_female_mfts, interval_score_Fukui_female_mfts,
                                             interval_score_Yamanashi_female_mfts, interval_score_Nagano_female_mfts, interval_score_Gifu_female_mfts,
                                             interval_score_Shizuoka_female_mfts, interval_score_Aichi_female_mfts, interval_score_Mie_female_mfts,
                                             interval_score_Shiga_female_mfts, interval_score_Kyoto_female_mfts, interval_score_Osaka_female_mfts,
                                             interval_score_Hyogo_female_mfts, interval_score_Nara_female_mfts, interval_score_Wakayama_female_mfts,
                                             interval_score_Tottori_female_mfts, interval_score_Shimane_female_mfts, interval_score_Okayama_female_mfts,
                                             interval_score_Hiroshima_female_mfts, interval_score_Yamaguchi_female_mfts, interval_score_Tokushima_female_mfts,
                                             interval_score_Kagawa_female_mfts, interval_score_Ehime_female_mfts, interval_score_Kochi_female_mfts,
                                             interval_score_Fukuoka_female_mfts, interval_score_Saga_female_mfts, interval_score_Nagasaki_female_mfts,
                                             interval_score_Kumamoto_female_mfts, interval_score_Oita_female_mfts, interval_score_Miyazaki_female_mfts,
                                             interval_score_Kagoshima_female_mfts, interval_score_Okinawa_female_mfts,

                                             interval_score_Hokkaido_male_mfts, interval_score_Aomori_male_mfts, interval_score_Iwate_male_mfts,
                                             interval_score_Miyagi_male_mfts, interval_score_Akita_male_mfts, interval_score_Yamagata_male_mfts,
                                             interval_score_Fukushima_male_mfts, interval_score_Ibaraki_male_mfts, interval_score_Tochigi_male_mfts,
                                             interval_score_Gunma_male_mfts, interval_score_Saitama_male_mfts, interval_score_Chiba_male_mfts,
                                             interval_score_Tokyo_male_mfts, interval_score_Kanagawa_male_mfts, interval_score_Niigata_male_mfts,
                                             interval_score_Toyama_male_mfts, interval_score_Ishikawa_male_mfts, interval_score_Fukui_male_mfts,
                                             interval_score_Yamanashi_male_mfts, interval_score_Nagano_male_mfts, interval_score_Gifu_male_mfts,
                                             interval_score_Shizuoka_male_mfts, interval_score_Aichi_male_mfts, interval_score_Mie_male_mfts,
                                             interval_score_Shiga_male_mfts, interval_score_Kyoto_male_mfts, interval_score_Osaka_male_mfts,
                                             interval_score_Hyogo_male_mfts, interval_score_Nara_male_mfts, interval_score_Wakayama_male_mfts,
                                             interval_score_Tottori_male_mfts, interval_score_Shimane_male_mfts, interval_score_Okayama_male_mfts,
                                             interval_score_Hiroshima_male_mfts, interval_score_Yamaguchi_male_mfts, interval_score_Tokushima_male_mfts,
                                             interval_score_Kagawa_male_mfts, interval_score_Ehime_male_mfts, interval_score_Kochi_male_mfts,
                                             interval_score_Fukuoka_male_mfts, interval_score_Saga_male_mfts, interval_score_Nagasaki_male_mfts,
                                             interval_score_Kumamoto_male_mfts, interval_score_Oita_male_mfts, interval_score_Miyazaki_male_mfts,
                                             interval_score_Kagoshima_male_mfts, interval_score_Okinawa_male_mfts))

interval_score_all_mfts = cbind(interval_score_Level_0, interval_score_Level_1_mfts, interval_score_Level_2_mfts, interval_score_Level_3_mfts, interval_score_Level_4_mfts, interval_score_Level_5_mfts)
interval_score_all_mfts_stats = rbind(interval_score_all_mfts, colMeans(interval_score_all_mfts), apply(interval_score_all_mfts, 2, median))
colnames(interval_score_all_mfts_stats) = c("Level 0", "Level 1", "Level 2", "Level 3", "Level 4", "Level 5")
rownames(interval_score_all_mfts_stats) = c(1:15,"Mean","Median")

# comparison between univariate and multivariate functional time series methods

round(cbind(interval_score_all_stats[,1], interval_score_all_mfts_stats[,1],
            interval_score_all_stats[,2], interval_score_all_mfts_stats[,2],
            interval_score_all_stats[,3], interval_score_all_mfts_stats[,3],
            interval_score_all_stats[,4], interval_score_all_mfts_stats[,4],
            interval_score_all_stats[,5], interval_score_all_mfts_stats[,5],
            interval_score_all_stats[,6], interval_score_all_mfts_stats[,6]), 4)

######################################################
# construct prediction interval for total populations
######################################################

find_enlarge_val_mfts_region_total <- function(smooth_data, raw_data, series, fh,
                                               var_prop = 0.9, alpha = 0.8,
                                               transformation = c("log", "logit"))
{
    transformation = match.arg(transformation)
    n_pop = length(names(smooth_data$rate))
    rowmeans_object = sd_object = decenter_object = list()
    if(transformation == "log")
    {
        log_object = list()
        for(ik in 1:n_pop)
        {
            log_object[[ik]] = log(smooth_data$rate[[ik]])
            # compute mean and standard deviation functions
            rowmeans_object[[ik]] = rowMeans(log(smooth_data$rate[[ik]]), na.rm = TRUE)
            sd_object[[ik]] = apply(log(smooth_data$rate[[ik]]), 1, sd, na.rm = TRUE)
        
            # de-center functional data
            decenter_object[[ik]] = t(scale(t(log(smooth_data$rate[[ik]])), center = TRUE, scale = TRUE))
        }
        rm(log_object)
    }
    if(transformation == "logit")
    {
        logit_object = list()
        for(ik in 1:n_pop)
        {
            logit_object[[ik]] = logit(smooth_data$rate[[ik]])
            # compute mean and standard deviation functions
            rowmeans_object[[ik]] = rowMeans(logit(smooth_data$rate[[ik]]), na.rm = TRUE)
            sd_object[[ik]] = apply(logit(smooth_data$rate[[ik]]), 1, sd, na.rm = TRUE)
            
            # de-center functional data
            decenter_object[[ik]] = t(scale(t(logit(smooth_data$rate[[ik]])), center = TRUE, scale = TRUE))
        }
        rm(logit_object)
    }
    comb_object = do.call(rbind, decenter_object)
    ncomp_comb = head(which(cumsum(ftsm(fts(1:nrow(comb_object), comb_object), order = 20)$varprop) >= var_prop), 1)
    ftsm_obj = ftsm(fts(1:nrow(comb_object), comb_object), order = ncomp_comb)
    
    # calculate in-sample forecast curves
    fore_curve_dum = matrix(NA, length(smooth_data$age) * n_pop, length(smooth_data$year) - ncomp_comb - fh + 1)
    for(ij in 1:(length(smooth_data$year) - ncomp_comb - fh + 1))
    {
        fore_coef = matrix(NA, ncomp_comb, 1)
        for(ik in 2:(ncomp_comb + 1))
        {
            fore_coef[ik-1, 1] = forecast(auto.arima(ftsm_obj$coeff[1:(ij+ncomp_comb-1), ik]), h = fh)$mean[fh]
        }
        fore_curve_dum[,ij] = (as.matrix(ftsm_obj$basis[,1]) + as.matrix(ftsm_obj$basis[,2:(ncomp_comb+1)]) %*% fore_coef) * do.call(c,sd_object) + do.call(c, rowmeans_object)
    }
    
    index_1 = 1:41
    index_2 = 42:82
    index_3 = 83:123
    index_4 = 124:164
    index_5 = 165:205
    index_6 = 206:246
    index_7 = 247:287
    index_8 = 288:328
    if(series == "R1")
    {
        fore_curve = fore_curve_dum[index_1,]
    }
    if(series == "R2")
    {
        fore_curve = fore_curve_dum[index_2,]
    }
    if(series == "R3")
    {
        fore_curve = fore_curve_dum[index_3,]
    }
    if(series == "R4")
    {
        fore_curve = fore_curve_dum[index_4,]
    }
    if(series == "R5")
    {
        fore_curve = fore_curve_dum[index_5,]
    }
    if(series == "R6")
    {
        fore_curve = fore_curve_dum[index_6,]
    }
    if(series == "R7")
    {
        fore_curve = fore_curve_dum[index_7,]
    }
    if(series == "R8")
    {
        fore_curve = fore_curve_dum[index_8,]
    }
    
    # holdout data example
    true_dat = extract.years(raw_data, raw_data$year[(ncomp_comb + fh): length(raw_data$year)])
    if(transformation == "log")
    {
        holdout_val = log(true_dat$rate$total)
    }
    if(transformation == "logit")
    {
        holdout_val = logit(true_dat$rate$total)
    }
    if(length(which(!is.finite(holdout_val))) > 0)
    {
        warning("some holdout data have Inf.")
        index = which(!is.finite(holdout_val))
        holdout_mat = replace(holdout_val, index, NA)
        rm(holdout_val)
        holdout_val = matrix(NA, nrow(holdout_mat), ncol(holdout_mat))
        for(ik in 1:ncol(holdout_mat))
        {
            holdout_val[,ik] = na.interp(holdout_mat[,ik])
        }
    }
    
    # calculate in-sample forecast errors
    err = holdout_val - fore_curve
    
    # bootstrap error function
    
    if(ncol(err) == 1)
    {
        prediction_err_sd = sd(err)
    }
    else
    {
        prediction_err_sd = apply(err, 1, sd)
    }
    
    select_pointwise_tuning_parameter <- function(tuning_parameter, nominal_coverage)
    {
        nB = ncol(err)
        lb = -1 * tuning_parameter * prediction_err_sd
        ub = tuning_parameter * prediction_err_sd
        out_number = vector("numeric", nB)
        for(ik in 1:nB)
        {
            holdout = err[,ik]
            out_number[ik] = length(union(which(lb > holdout), which(ub < holdout)))
        }
        empirical_coverage = 1 - (sum(out_number)/length(err))
        return(abs(empirical_coverage - nominal_coverage))
    }
    
    pointwise_tuning_parameter_PI = optimize(f = select_pointwise_tuning_parameter, interval = c(0.1, 5), nominal_coverage = alpha)$minimum
    
    # constructing PI
    fore_pca_dat = forecast(ftsm_obj, h = fh)$mean$y[,fh] * do.call(c, sd_object) + do.call(c, rowmeans_object)
    parametric_pointwise_out = cbind(fore_pca_dat - prediction_err_sd * pointwise_tuning_parameter_PI,
                                     fore_pca_dat + prediction_err_sd * pointwise_tuning_parameter_PI)
    colnames(parametric_pointwise_out) = c("lb", "ub")
    
    if(series == "R1")
    {
        return(parametric_pointwise_out[index_1,])
    }
    if(series == "R2")
    {
        return(parametric_pointwise_out[index_2,])
    }
    if(series == "R3")
    {
        return(parametric_pointwise_out[index_3,])
    }
    if(series == "R4")
    {
        return(parametric_pointwise_out[index_4,])
    }
    if(series == "R5")
    {
        return(parametric_pointwise_out[index_5,])
    }
    if(series == "R6")
    {
        return(parametric_pointwise_out[index_6,])
    }
    if(series == "R7")
    {
        return(parametric_pointwise_out[index_7,])
    }
    if(series == "R8")
    {
        return(parametric_pointwise_out[index_8,])
    }
}

PI_fh_mfts_region_total <- function(smooth_series, raw_series, series, fh)
{
    PI_pointwise_res = array(NA, dim = c(41, 2, (16 - fh)))
    for(ij in 1:(16-fh))
    {
        PI_pointwise_res[,,ij] = find_enlarge_val_mfts_region_total(smooth_data = extract.years(smooth_series, 1975:(2000+ij)),
                                                                    raw_data = extract.years(raw_series, 1975:(2000+ij)),
                                                                    series = series, fh = fh)
    }
    return(PI_pointwise_res)
}

total_region_comb_demogdata = read.demogdata("total_region_comb.txt", "total_region_comb_pop.txt", type = "mortality", label = "total_region_comb", skip = 0)


install.packages("doMC")
require(doMC)
registerDoMC(15)
R1_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_region_total(smooth_series = total_region_comb_demogdata, raw_series = ind_R1, series = "R1", fh = ik)
R2_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_region_total(smooth_series = total_region_comb_demogdata, raw_series = ind_R2, series = "R2", fh = ik)
R3_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_region_total(smooth_series = total_region_comb_demogdata, raw_series = ind_R3, series = "R3", fh = ik)
R4_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_region_total(smooth_series = total_region_comb_demogdata, raw_series = ind_R4, series = "R4", fh = ik)
R5_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_region_total(smooth_series = total_region_comb_demogdata, raw_series = ind_R5, series = "R5", fh = ik)
R6_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_region_total(smooth_series = total_region_comb_demogdata, raw_series = ind_R6, series = "R6", fh = ik)
R7_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_region_total(smooth_series = total_region_comb_demogdata, raw_series = ind_R7, series = "R7", fh = ik)
R8_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_region_total(smooth_series = total_region_comb_demogdata, raw_series = ind_R8, series = "R8", fh = ik)

#################
# interval score
#################

interval_score_R1_total_mfts = interval_score_R2_total_mfts = interval_score_R3_total_mfts = interval_score_R4_total_mfts =
interval_score_R5_total_mfts = interval_score_R6_total_mfts = interval_score_R7_total_mfts = interval_score_R8_total_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_R1_total_mfts[ij] = interval_score(PI_val = R1_total_fh_PI_mfts, data_series = ind_R1, series = "total", fh = ij)
    interval_score_R2_total_mfts[ij] = interval_score(PI_val = R2_total_fh_PI_mfts, data_series = ind_R2, series = "total", fh = ij)
    interval_score_R3_total_mfts[ij] = interval_score(PI_val = R3_total_fh_PI_mfts, data_series = ind_R3, series = "total", fh = ij)
    interval_score_R4_total_mfts[ij] = interval_score(PI_val = R4_total_fh_PI_mfts, data_series = ind_R4, series = "total", fh = ij)
    interval_score_R5_total_mfts[ij] = interval_score(PI_val = R5_total_fh_PI_mfts, data_series = ind_R5, series = "total", fh = ij)
    interval_score_R6_total_mfts[ij] = interval_score(PI_val = R6_total_fh_PI_mfts, data_series = ind_R6, series = "total", fh = ij)
    interval_score_R7_total_mfts[ij] = interval_score(PI_val = R7_total_fh_PI_mfts, data_series = ind_R7, series = "total", fh = ij)
    interval_score_R8_total_mfts[ij] = interval_score(PI_val = R8_total_fh_PI_mfts, data_series = ind_R8, series = "total", fh = ij)
}


######################################################
# construct prediction interval for total populations
######################################################

find_enlarge_val_mfts_prefecture_total <- function(smooth_data, raw_data, series, fh,
                                                   var_prop = 0.9, alpha = 0.8,
                                                   transformation = c("log", "logit"))
{
    transformation = match.arg(transformation)
    n_pop = length(names(smooth_data$rate))
    rowmeans_object = sd_object = decenter_object = list()
    if(transformation == "log")
    {
        log_object = list()
        for(ik in 1:n_pop)
        {
            log_object[[ik]] = log(smooth_data$rate[[ik]])
            # compute mean and standard deviation functions
            rowmeans_object[[ik]] = rowMeans(log(smooth_data$rate[[ik]]), na.rm = TRUE)
            sd_object[[ik]] = apply(log(smooth_data$rate[[ik]]), 1, sd, na.rm = TRUE)
        
            # de-center functional data
            decenter_object[[ik]] = t(scale(t(log(smooth_data$rate[[ik]])), center = TRUE, scale = TRUE))
        }
        rm(log_object)
    }
    if(transformation == "logit")
    {
        logit_object = list()
        for(ik in 1:n_pop)
        {
            logit_object[[ik]] = logit(smooth_data$rate[[ik]])
            # compute mean and standard deviation functions
            rowmeans_object[[ik]] = rowMeans(logit(smooth_data$rate[[ik]]), na.rm = TRUE)
            sd_object[[ik]] = apply(logit(smooth_data$rate[[ik]]), 1, sd, na.rm = TRUE)
            
            # de-center functional data
            decenter_object[[ik]] = t(scale(t(logit(smooth_data$rate[[ik]])), center = TRUE, scale = TRUE))
        }
        rm(logit_object)
    }
    comb_object = do.call(rbind, decenter_object)
    ncomp_comb = head(which(cumsum(ftsm(fts(1:nrow(comb_object), comb_object), order = 20)$varprop) >= var_prop), 1)
    ftsm_obj = ftsm(fts(1:nrow(comb_object), comb_object), order = ncomp_comb)
    
    # calculate in-sample forecast curves
    fore_curve_dum = matrix(NA, length(smooth_data$age) * n_pop, length(smooth_data$year) - ncomp_comb - fh + 1)
    for(ij in 1:(length(smooth_data$year) - ncomp_comb - fh + 1))
    {
        fore_coef = matrix(NA, ncomp_comb, 1)
        for(ik in 2:(ncomp_comb + 1))
        {
            fore_coef[ik-1, 1] = forecast(auto.arima(ftsm_obj$coeff[1:(ij+ncomp_comb-1), ik]), h = fh)$mean[fh]
        }
        fore_curve_dum[,ij] = (as.matrix(ftsm_obj$basis[,1]) + as.matrix(ftsm_obj$basis[,2:(ncomp_comb+1)]) %*% fore_coef) * do.call(c,sd_object) + do.call(c, rowmeans_object)
    }
    
    index_all = c("index_1", "index_2", "index_3", "index_4", "index_5", "index_6", "index_7", "index_8", "index_9", "index_10",
                  "index_11", "index_12", "index_13", "index_14", "index_15", "index_16", "index_17", "index_18", "index_19",
                  "index_20", "index_21", "index_22", "index_23", "index_24", "index_25", "index_26", "index_27", "index_28",
                  "index_29", "index_30", "index_31", "index_32", "index_33", "index_34", "index_35", "index_36", "index_37",
                  "index_38", "index_39", "index_40", "index_41", "index_42", "index_43", "index_44", "index_45", "index_46",
                  "index_47")
                  
    for(ik in 1:47)
    {
        assign(index_all[ik], ((ik-1)*41+1):(ik*41))
    }
    
    if(series == "P1")
    {
        fore_curve = fore_curve_dum[index_1,]
    }
    if(series == "P2")
    {
        fore_curve = fore_curve_dum[index_2,]
    }
    if(series == "P3")
    {
        fore_curve = fore_curve_dum[index_3,]
    }
    if(series == "P4")
    {
        fore_curve = fore_curve_dum[index_4,]
    }
    if(series == "P5")
    {
        fore_curve = fore_curve_dum[index_5,]
    }
    if(series == "P6")
    {
        fore_curve = fore_curve_dum[index_6,]
    }
    if(series == "P7")
    {
        fore_curve = fore_curve_dum[index_7,]
    }
    if(series == "P8")
    {
        fore_curve = fore_curve_dum[index_8,]
    }
    if(series == "P9")
    {
        fore_curve = fore_curve_dum[index_9,]
    }
    if(series == "P10")
    {
        fore_curve = fore_curve_dum[index_10,]
    }
    if(series == "P11")
    {
        fore_curve = fore_curve_dum[index_11,]
    }
    if(series == "P12")
    {
        fore_curve = fore_curve_dum[index_12,]
    }
    if(series == "P13")
    {
        fore_curve = fore_curve_dum[index_13,]
    }
    if(series == "P14")
    {
        fore_curve = fore_curve_dum[index_14,]
    }
    if(series == "P15")
    {
        fore_curve = fore_curve_dum[index_15,]
    }
    if(series == "P16")
    {
        fore_curve = fore_curve_dum[index_16,]
    }
    if(series == "P17")
    {
        fore_curve = fore_curve_dum[index_17,]
    }
    if(series == "P18")
    {
        fore_curve = fore_curve_dum[index_18,]
    }
    if(series == "P19")
    {
        fore_curve = fore_curve_dum[index_19,]
    }
    if(series == "P20")
    {
        fore_curve = fore_curve_dum[index_20,]
    }
    if(series == "P21")
    {
        fore_curve = fore_curve_dum[index_21,]
    }
    if(series == "P22")
    {
        fore_curve = fore_curve_dum[index_22,]
    }
    if(series == "P23")
    {
        fore_curve = fore_curve_dum[index_23,]
    }
    if(series == "P24")
    {
        fore_curve = fore_curve_dum[index_24,]
    }
    if(series == "P25")
    {
        fore_curve = fore_curve_dum[index_25,]
    }
    if(series == "P26")
    {
        fore_curve = fore_curve_dum[index_26,]
    }
    if(series == "P27")
    {
        fore_curve = fore_curve_dum[index_27,]
    }
    if(series == "P28")
    {
        fore_curve = fore_curve_dum[index_28,]
    }
    if(series == "P29")
    {
        fore_curve = fore_curve_dum[index_29,]
    }
    if(series == "P30")
    {
        fore_curve = fore_curve_dum[index_30,]
    }
    if(series == "P31")
    {
        fore_curve = fore_curve_dum[index_31,]
    }
    if(series == "P32")
    {
        fore_curve = fore_curve_dum[index_32,]
    }
    if(series == "P33")
    {
        fore_curve = fore_curve_dum[index_33,]
    }
    if(series == "P34")
    {
        fore_curve = fore_curve_dum[index_34,]
    }
    if(series == "P35")
    {
        fore_curve = fore_curve_dum[index_35,]
    }
    if(series == "P36")
    {
        fore_curve = fore_curve_dum[index_36,]
    }
    if(series == "P37")
    {
        fore_curve = fore_curve_dum[index_37,]
    }
    if(series == "P38")
    {
        fore_curve = fore_curve_dum[index_38,]
    }
    if(series == "P39")
    {
        fore_curve = fore_curve_dum[index_39,]
    }
    if(series == "P40")
    {
        fore_curve = fore_curve_dum[index_40,]
    }
    if(series == "P41")
    {
        fore_curve = fore_curve_dum[index_41,]
    }
    if(series == "P42")
    {
        fore_curve = fore_curve_dum[index_42,]
    }
    if(series == "P43")
    {
        fore_curve = fore_curve_dum[index_43,]
    }
    if(series == "P44")
    {
        fore_curve = fore_curve_dum[index_44,]
    }
    if(series == "P45")
    {
        fore_curve = fore_curve_dum[index_45,]
    }
    if(series == "P46")
    {
        fore_curve = fore_curve_dum[index_46,]
    }
    if(series == "P47")
    {
        fore_curve = fore_curve_dum[index_47,]
    }

    # holdout data example
    true_dat = extract.years(raw_data, raw_data$year[(ncomp_comb + fh): length(raw_data$year)])
    if(transformation == "log")
    {
        holdout_val = log(true_dat$rate$total)
    }
    if(transformation == "logit")
    {
        holdout_val = logit(true_dat$rate$total)
    }
    if(length(which(!is.finite(holdout_val))) > 0)
    {
        print("some holdout data have Inf.")
        index = which(!is.finite(holdout_val))
        holdout_mat = replace(holdout_val, index, NA)
        rm(holdout_val)
        holdout_val = matrix(NA, nrow(holdout_mat), ncol(holdout_mat))
        for(ik in 1:ncol(holdout_mat))
        {
            holdout_val[,ik] = na.interp(holdout_mat[,ik])
        }
    }
    
    # calculate in-sample forecast errors
    # colnames(fore_curve) = colnames(holdout_val)
    err = holdout_val - fore_curve
    
    # bootstrap error function

    if(ncol(err) == 1)
    {
        prediction_err_sd = sd(err)
    }
    else
    {
        prediction_err_sd = apply(err, 1, sd)
    }
    
    select_pointwise_tuning_parameter <- function(tuning_parameter, nominal_coverage)
    {
        nB = ncol(err)
        lb = -1 * tuning_parameter * prediction_err_sd
        ub = tuning_parameter * prediction_err_sd
        out_number = vector("numeric", nB)
        for(ik in 1:nB)
        {
            holdout = err[,ik]
            out_number[ik] = length(union(which(lb > holdout), which(ub < holdout)))
        }
        empirical_coverage = 1 - (sum(out_number)/length(err))
        return(abs(empirical_coverage - nominal_coverage))
    }
    
    pointwise_tuning_parameter_PI = optimize(f = select_pointwise_tuning_parameter, interval = c(0.1, 5), nominal_coverage = alpha)$minimum
    
    # constructing PI
    fore_pca_dat = forecast(ftsm_obj, h = fh)$mean$y[,fh] * do.call(c, sd_object) + do.call(c, rowmeans_object)
    parametric_pointwise_out = cbind(fore_pca_dat - prediction_err_sd * pointwise_tuning_parameter_PI,
                                     fore_pca_dat + prediction_err_sd * pointwise_tuning_parameter_PI)
    colnames(parametric_pointwise_out) = c("lb", "ub")
    
    if(series == "P1")
    {
        return(parametric_pointwise_out[index_1,])
    }
    if(series == "P2")
    {
        return(parametric_pointwise_out[index_2,])
    }
    if(series == "P3")
    {
        return(parametric_pointwise_out[index_3,])
    }
    if(series == "P4")
    {
        return(parametric_pointwise_out[index_4,])
    }
    if(series == "P5")
    {
        return(parametric_pointwise_out[index_5,])
    }
    if(series == "P6")
    {
        return(parametric_pointwise_out[index_6,])
    }
    if(series == "P7")
    {
        return(parametric_pointwise_out[index_7,])
    }
    if(series == "P8")
    {
        return(parametric_pointwise_out[index_8,])
    }
    if(series == "P9")
    {
        return(parametric_pointwise_out[index_9,])
    }
    if(series == "P10")
    {
        return(parametric_pointwise_out[index_10,])
    }
    if(series == "P11")
    {
        return(parametric_pointwise_out[index_11,])
    }
    if(series == "P12")
    {
        return(parametric_pointwise_out[index_12,])
    }
    if(series == "P13")
    {
        return(parametric_pointwise_out[index_13,])
    }
    if(series == "P14")
    {
        return(parametric_pointwise_out[index_14,])
    }
    if(series == "P15")
    {
        return(parametric_pointwise_out[index_15,])
    }
    if(series == "P16")
    {
        return(parametric_pointwise_out[index_16,])
    }
    if(series == "P17")
    {
        return(parametric_pointwise_out[index_17,])
    }
    if(series == "P18")
    {
        return(parametric_pointwise_out[index_18,])
    }
    if(series == "P19")
    {
        return(parametric_pointwise_out[index_19,])
    }
    if(series == "P20")
    {
        return(parametric_pointwise_out[index_20,])
    }
    if(series == "P21")
    {
        return(parametric_pointwise_out[index_21,])
    }
    if(series == "P22")
    {
        return(parametric_pointwise_out[index_22,])
    }
    if(series == "P23")
    {
        return(parametric_pointwise_out[index_23,])
    }
    if(series == "P24")
    {
        return(parametric_pointwise_out[index_24,])
    }
    if(series == "P25")
    {
        return(parametric_pointwise_out[index_25,])
    }
    if(series == "P26")
    {
        return(parametric_pointwise_out[index_26,])
    }
    if(series == "P27")
    {
        return(parametric_pointwise_out[index_27,])
    }
    if(series == "P28")
    {
        return(parametric_pointwise_out[index_28,])
    }
    if(series == "P29")
    {
        return(parametric_pointwise_out[index_29,])
    }
    if(series == "P30")
    {
        return(parametric_pointwise_out[index_30,])
    }
    if(series == "P31")
    {
        return(parametric_pointwise_out[index_31,])
    }
    if(series == "P32")
    {
        return(parametric_pointwise_out[index_32,])
    }
    if(series == "P33")
    {
        return(parametric_pointwise_out[index_33,])
    }
    if(series == "P34")
    {
        return(parametric_pointwise_out[index_34,])
    }
    if(series == "P35")
    {
        return(parametric_pointwise_out[index_35,])
    }
    if(series == "P36")
    {
        return(parametric_pointwise_out[index_36,])
    }
    if(series == "P37")
    {
        return(parametric_pointwise_out[index_37,])
    }
    if(series == "P38")
    {
        return(parametric_pointwise_out[index_38,])
    }
    if(series == "P39")
    {
        return(parametric_pointwise_out[index_39,])
    }
    if(series == "P40")
    {
        return(parametric_pointwise_out[index_40,])
    }
    if(series == "P41")
    {
        return(parametric_pointwise_out[index_41,])
    }
    if(series == "P42")
    {
        return(parametric_pointwise_out[index_42,])
    }
    if(series == "P43")
    {
        return(parametric_pointwise_out[index_43,])
    }
    if(series == "P44")
    {
        return(parametric_pointwise_out[index_44,])
    }
    if(series == "P45")
    {
        return(parametric_pointwise_out[index_45,])
    }
    if(series == "P46")
    {
        return(parametric_pointwise_out[index_46,])
    }
    if(series == "P47")
    {
        return(parametric_pointwise_out[index_47,])
    }
    return(bootPI)
}

PI_fh_mfts_prefecture_total <- function(smooth_series, raw_series, series, fh)
{
    PI_pointwise_res = array(NA, dim = c(41, 2, (16 - fh)))
    for(ij in 1:(16 - fh))
    {
        PI_pointwise_res[,,ij] = find_enlarge_val_mfts_prefecture_total(smooth_data = extract.years(smooth_series, 1975:(2000+ij)),
                                                                        raw_data = extract.years(raw_series, 1975:(2000+ij)),
                                                                        series = series, fh = fh)
    }
    return(PI_pointwise_res)
}

total_comb_demogdata = read.demogdata("total_comb.txt", "total_comb_pop.txt", type = "mortality", label = "total_comb", skip = 0)

install.packages("doMC")
require(doMC)
registerDoMC(15)
P1_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Hokkaido, series = "P1", fh = ik)
P2_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Aomori, series = "P2", fh = ik)
P3_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Iwate, series = "P3", fh = ik)
P4_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Miyagi, series = "P4", fh = ik)
P5_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Akita, series = "P5", fh = ik)
P6_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Yamagata, series = "P6", fh = ik)
P7_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Fukushima, series = "P7", fh = ik)
P8_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Ibaraki, series = "P8", fh = ik)
P9_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Tochigi, series = "P9", fh = ik)
P10_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Gunma, series = "P10", fh = ik)
P11_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Saitama, series = "P11", fh = ik)
P12_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Chiba, series = "P12", fh = ik)
P13_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Tokyo, series = "P13", fh = ik)
P14_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Kanagawa, series = "P14", fh = ik)
P15_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Niigata, series = "P15", fh = ik)
P16_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Toyama, series = "P16", fh = ik)
P17_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Ishikawa, series = "P17", fh = ik)
P18_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Fukui, series = "P18", fh = ik)
P19_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Yamanashi, series = "P19", fh = ik)
P20_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Nagano, series = "P20", fh = ik)
P21_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Gifu, series = "P21", fh = ik)
P22_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Shizuoka, series = "P22", fh = ik)
P23_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Aichi, series = "P23", fh = ik)
P24_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Mie, series = "P24", fh = ik)
P25_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Shiga, series = "P25", fh = ik)
P26_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Kyoto, series = "P26", fh = ik)
P27_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Osaka, series = "P27", fh = ik)
P28_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Hyogo, series = "P28", fh = ik)
P29_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Nara, series = "P29", fh = ik)
P30_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Wakayama, series = "P30", fh = ik)
P31_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Tottori, series = "P31", fh = ik)
P32_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Shimane, series = "P32", fh = ik)
P33_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Okayama, series = "P33", fh = ik)
P34_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Hiroshima, series = "P34", fh = ik)
P35_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Yamaguchi, series = "P35", fh = ik)
P36_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Tokushima, series = "P36", fh = ik)
P37_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Kagawa, series = "P37", fh = ik)
P38_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Ehime, series = "P38", fh = ik)
P39_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Kochi, series = "P39", fh = ik)
P40_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Fukuoka, series = "P40", fh = ik)
P41_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Saga, series = "P41", fh = ik)
P42_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Nagasaki, series = "P42", fh = ik)
P43_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Kumamoto, series = "P43", fh = ik)
P44_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Oita, series = "P44", fh = ik)
P45_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Miyazaki, series = "P45", fh = ik)
P46_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Kagoshima, series = "P46", fh = ik)
P47_total_fh_PI_mfts = foreach(ik = 1:15) %dopar% PI_fh_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Okinawa, series = "P47", fh = ik)

#################
# interval score
#################

interval_score_P1_total_mfts = interval_score_P2_total_mfts = interval_score_P3_total_mfts = interval_score_P4_total_mfts = interval_score_P5_total_mfts =
interval_score_P6_total_mfts = interval_score_P7_total_mfts = interval_score_P8_total_mfts = interval_score_P9_total_mfts = interval_score_P10_total_mfts =
interval_score_P11_total_mfts = interval_score_P12_total_mfts = interval_score_P13_total_mfts = interval_score_P14_total_mfts = interval_score_P15_total_mfts =
interval_score_P16_total_mfts = interval_score_P17_total_mfts = interval_score_P18_total_mfts = interval_score_P19_total_mfts = interval_score_P20_total_mfts =
interval_score_P21_total_mfts = interval_score_P22_total_mfts = interval_score_P23_total_mfts = interval_score_P24_total_mfts = interval_score_P25_total_mfts =
interval_score_P26_total_mfts = interval_score_P27_total_mfts = interval_score_P28_total_mfts = interval_score_P29_total_mfts = interval_score_P30_total_mfts =
interval_score_P31_total_mfts = interval_score_P32_total_mfts = interval_score_P33_total_mfts = interval_score_P34_total_mfts = interval_score_P35_total_mfts =
interval_score_P36_total_mfts = interval_score_P37_total_mfts = interval_score_P38_total_mfts = interval_score_P39_total_mfts = interval_score_P40_total_mfts =
interval_score_P41_total_mfts = interval_score_P42_total_mfts = interval_score_P43_total_mfts = interval_score_P44_total_mfts = interval_score_P45_total_mfts =
interval_score_P46_total_mfts = interval_score_P47_total_mfts = vector("numeric", 15)
for(ij in 1:15)
{
    interval_score_P1_total_mfts[ij] = interval_score(PI_val = P1_total_fh_PI_mfts, data_series = Hokkaido, series = "total", fh = ij)
    interval_score_P2_total_mfts[ij] = interval_score(PI_val = P2_total_fh_PI_mfts, data_series = Aomori, series = "total", fh = ij)
    interval_score_P3_total_mfts[ij] = interval_score(PI_val = P3_total_fh_PI_mfts, data_series = Iwate, series = "total", fh = ij)
    interval_score_P4_total_mfts[ij] = interval_score(PI_val = P4_total_fh_PI_mfts, data_series = Miyagi, series = "total", fh = ij)
    interval_score_P5_total_mfts[ij] = interval_score(PI_val = P5_total_fh_PI_mfts, data_series = Akita, series = "total", fh = ij)
    interval_score_P6_total_mfts[ij] = interval_score(PI_val = P6_total_fh_PI_mfts, data_series = Yamagata, series = "total", fh = ij)
    interval_score_P7_total_mfts[ij] = interval_score(PI_val = P7_total_fh_PI_mfts, data_series = Fukushima, series = "total", fh = ij)
    interval_score_P8_total_mfts[ij] = interval_score(PI_val = P8_total_fh_PI_mfts, data_series = Ibaraki, series = "total", fh = ij)
    interval_score_P9_total_mfts[ij] = interval_score(PI_val = P9_total_fh_PI_mfts, data_series = Tochigi, series = "total", fh = ij)
    interval_score_P10_total_mfts[ij] = interval_score(PI_val = P10_total_fh_PI_mfts, data_series = Gunma, series = "total", fh = ij)
    interval_score_P11_total_mfts[ij] = interval_score(PI_val = P11_total_fh_PI_mfts, data_series = Saitama, series = "total", fh = ij)
    interval_score_P12_total_mfts[ij] = interval_score(PI_val = P12_total_fh_PI_mfts, data_series = Chiba, series = "total", fh = ij)
    interval_score_P13_total_mfts[ij] = interval_score(PI_val = P13_total_fh_PI_mfts, data_series = Tokyo, series = "total", fh = ij)
    interval_score_P14_total_mfts[ij] = interval_score(PI_val = P14_total_fh_PI_mfts, data_series = Kanagawa, series = "total", fh = ij)
    interval_score_P15_total_mfts[ij] = interval_score(PI_val = P15_total_fh_PI_mfts, data_series = Niigata, series = "total", fh = ij)
    interval_score_P16_total_mfts[ij] = interval_score(PI_val = P16_total_fh_PI_mfts, data_series = Toyama, series = "total", fh = ij)
    interval_score_P17_total_mfts[ij] = interval_score(PI_val = P17_total_fh_PI_mfts, data_series = Ishikawa, series = "total", fh = ij)
    interval_score_P18_total_mfts[ij] = interval_score(PI_val = P18_total_fh_PI_mfts, data_series = Fukui, series = "total", fh = ij)
    interval_score_P19_total_mfts[ij] = interval_score(PI_val = P19_total_fh_PI_mfts, data_series = Yamanashi, series = "total", fh = ij)
    interval_score_P20_total_mfts[ij] = interval_score(PI_val = P20_total_fh_PI_mfts, data_series = Nagano, series = "total", fh = ij)
    interval_score_P21_total_mfts[ij] = interval_score(PI_val = P21_total_fh_PI_mfts, data_series = Gifu, series = "total", fh = ij)
    interval_score_P22_total_mfts[ij] = interval_score(PI_val = P22_total_fh_PI_mfts, data_series = Shizuoka, series = "total", fh = ij)
    interval_score_P23_total_mfts[ij] = interval_score(PI_val = P23_total_fh_PI_mfts, data_series = Aichi, series = "total", fh = ij)
    interval_score_P24_total_mfts[ij] = interval_score(PI_val = P24_total_fh_PI_mfts, data_series = Mie, series = "total", fh = ij)
    interval_score_P25_total_mfts[ij] = interval_score(PI_val = P25_total_fh_PI_mfts, data_series = Shiga, series = "total", fh = ij)
    interval_score_P26_total_mfts[ij] = interval_score(PI_val = P26_total_fh_PI_mfts, data_series = Kyoto, series = "total", fh = ij)
    interval_score_P27_total_mfts[ij] = interval_score(PI_val = P27_total_fh_PI_mfts, data_series = Osaka, series = "total", fh = ij)
    interval_score_P28_total_mfts[ij] = interval_score(PI_val = P28_total_fh_PI_mfts, data_series = Hyogo, series = "total", fh = ij)
    interval_score_P29_total_mfts[ij] = interval_score(PI_val = P29_total_fh_PI_mfts, data_series = Nara, series = "total", fh = ij)
    interval_score_P30_total_mfts[ij] = interval_score(PI_val = P30_total_fh_PI_mfts, data_series = Wakayama, series = "total", fh = ij)
    interval_score_P31_total_mfts[ij] = interval_score(PI_val = P31_total_fh_PI_mfts, data_series = Tottori, series = "total", fh = ij)
    interval_score_P32_total_mfts[ij] = interval_score(PI_val = P32_total_fh_PI_mfts, data_series = Shimane, series = "total", fh = ij)
    interval_score_P33_total_mfts[ij] = interval_score(PI_val = P33_total_fh_PI_mfts, data_series = Okayama, series = "total", fh = ij)
    interval_score_P34_total_mfts[ij] = interval_score(PI_val = P34_total_fh_PI_mfts, data_series = Hiroshima, series = "total", fh = ij)
    interval_score_P35_total_mfts[ij] = interval_score(PI_val = P35_total_fh_PI_mfts, data_series = Yamaguchi, series = "total", fh = ij)
    interval_score_P36_total_mfts[ij] = interval_score(PI_val = P36_total_fh_PI_mfts, data_series = Tokushima, series = "total", fh = ij)
    interval_score_P37_total_mfts[ij] = interval_score(PI_val = P37_total_fh_PI_mfts, data_series = Kagawa, series = "total", fh = ij)
    interval_score_P38_total_mfts[ij] = interval_score(PI_val = P38_total_fh_PI_mfts, data_series = Ehime, series = "total", fh = ij)
    interval_score_P39_total_mfts[ij] = interval_score(PI_val = P39_total_fh_PI_mfts, data_series = Kochi, series = "total", fh = ij)
    interval_score_P40_total_mfts[ij] = interval_score(PI_val = P40_total_fh_PI_mfts, data_series = Fukuoka, series = "total", fh = ij)
    interval_score_P41_total_mfts[ij] = interval_score(PI_val = P41_total_fh_PI_mfts, data_series = Saga, series = "total", fh = ij)
    interval_score_P42_total_mfts[ij] = interval_score(PI_val = P42_total_fh_PI_mfts, data_series = Nagasaki, series = "total", fh = ij)
    interval_score_P43_total_mfts[ij] = interval_score(PI_val = P43_total_fh_PI_mfts, data_series = Kumamoto, series = "total", fh = ij)
    interval_score_P44_total_mfts[ij] = interval_score(PI_val = P44_total_fh_PI_mfts, data_series = Oita, series = "total", fh = ij)
    interval_score_P45_total_mfts[ij] = interval_score(PI_val = P45_total_fh_PI_mfts, data_series = Miyazaki, series = "total", fh = ij)
    interval_score_P46_total_mfts[ij] = interval_score(PI_val = P46_total_fh_PI_mfts, data_series = Kagoshima, series = "total", fh = ij)
    interval_score_P47_total_mfts[ij] = interval_score(PI_val = P47_total_fh_PI_mfts, data_series = Okinawa, series = "total", fh = ij)
}

####################################
# Bottom-level bootstrapped samples
####################################

PI_prefecture <- function(fh)
{
    prefecture_fh_PI = array(NA, dim = c(41, 2, (16 - fh), 168))
    for(ik in 1:2)
    {
        for(ij in 1:(16 - fh))
        {
            prefecture_fh_PI[,ik,ij,] = exp(cbind(Japan_total_fh_PI[[fh]][,ik,ij],
                                            
                                            Japan_female_fh_PI[[fh]][,ik,ij], Japan_male_fh_PI[[fh]][,ik,ij],
                                            
                                            R1_total_fh_PI[[fh]][,ik,ij], R2_total_fh_PI[[fh]][,ik,ij],
                                            R3_total_fh_PI[[fh]][,ik,ij], R4_total_fh_PI[[fh]][,ik,ij],
                                            R5_total_fh_PI[[fh]][,ik,ij], R6_total_fh_PI[[fh]][,ik,ij],
                                            R7_total_fh_PI[[fh]][,ik,ij], R8_total_fh_PI[[fh]][,ik,ij],
                                            
                                            R1_female_fh_PI[[fh]][,ik,ij], R2_female_fh_PI[[fh]][,ik,ij],
                                            R3_female_fh_PI[[fh]][,ik,ij], R4_female_fh_PI[[fh]][,ik,ij],
                                            R5_female_fh_PI[[fh]][,ik,ij], R6_female_fh_PI[[fh]][,ik,ij],
                                            R7_female_fh_PI[[fh]][,ik,ij], R8_female_fh_PI[[fh]][,ik,ij],
                                            
                                            R1_male_fh_PI[[fh]][,ik,ij], R2_male_fh_PI[[fh]][,ik,ij],
                                            R3_male_fh_PI[[fh]][,ik,ij], R4_male_fh_PI[[fh]][,ik,ij],
                                            R5_male_fh_PI[[fh]][,ik,ij], R6_male_fh_PI[[fh]][,ik,ij],
                                            R7_male_fh_PI[[fh]][,ik,ij], R8_male_fh_PI[[fh]][,ik,ij],
                                            
                                            Hokkaido_total_fh_PI[[fh]][,ik,ij],   Aomori_total_fh_PI[[fh]][,ik,ij],
                                            Iwate_total_fh_PI[[fh]][,ik,ij],      Miyagi_total_fh_PI[[fh]][,ik,ij],
                                            Akita_total_fh_PI[[fh]][,ik,ij],      Yamagata_total_fh_PI[[fh]][,ik,ij],
                                            Fukushima_total_fh_PI[[fh]][,ik,ij],  Ibaraki_total_fh_PI[[fh]][,ik,ij],
                                            Tochigi_total_fh_PI[[fh]][,ik,ij],    Gunma_total_fh_PI[[fh]][,ik,ij],
                                            Saitama_total_fh_PI[[fh]][,ik,ij],    Chiba_total_fh_PI[[fh]][,ik,ij],
                                            Tokyo_total_fh_PI[[fh]][,ik,ij],      Kanagawa_total_fh_PI[[fh]][,ik,ij],
                                            Niigata_total_fh_PI[[fh]][,ik,ij],    Toyama_total_fh_PI[[fh]][,ik,ij],
                                            Ishikawa_total_fh_PI[[fh]][,ik,ij],   Fukui_total_fh_PI[[fh]][,ik,ij],
                                            Yamanashi_total_fh_PI[[fh]][,ik,ij],  Nagano_total_fh_PI[[fh]][,ik,ij],
                                            Gifu_total_fh_PI[[fh]][,ik,ij],       Shizuoka_total_fh_PI[[fh]][,ik,ij],
                                            Aichi_total_fh_PI[[fh]][,ik,ij],      Mie_total_fh_PI[[fh]][,ik,ij],
                                            Shiga_total_fh_PI[[fh]][,ik,ij],      Kyoto_total_fh_PI[[fh]][,ik,ij],
                                            Osaka_total_fh_PI[[fh]][,ik,ij],      Hyogo_total_fh_PI[[fh]][,ik,ij],
                                            Nara_total_fh_PI[[fh]][,ik,ij],       Wakayama_total_fh_PI[[fh]][,ik,ij],
                                            Tottori_total_fh_PI[[fh]][,ik,ij],    Shimane_total_fh_PI[[fh]][,ik,ij],
                                            Okayama_total_fh_PI[[fh]][,ik,ij],    Hiroshima_total_fh_PI[[fh]][,ik,ij],
                                            Yamaguchi_total_fh_PI[[fh]][,ik,ij],  Tokushima_total_fh_PI[[fh]][,ik,ij],
                                            Kagawa_total_fh_PI[[fh]][,ik,ij],     Ehime_total_fh_PI[[fh]][,ik,ij],
                                            Kochi_total_fh_PI[[fh]][,ik,ij],      Fukuoka_total_fh_PI[[fh]][,ik,ij],
                                            Saga_total_fh_PI[[fh]][,ik,ij],       Nagasaki_total_fh_PI[[fh]][,ik,ij],
                                            Kumamoto_total_fh_PI[[fh]][,ik,ij],   Oita_total_fh_PI[[fh]][,ik,ij],
                                            Miyazaki_total_fh_PI[[fh]][,ik,ij],   Kagoshima_total_fh_PI[[fh]][,ik,ij],
                                            Okinawa_total_fh_PI[[fh]][,ik,ij],
                                            
                                            Hokkaido_female_fh_PI[[fh]][,ik,ij],  Hokkaido_male_fh_PI[[fh]][,ik,ij],
                                            Aomori_female_fh_PI[[fh]][,ik,ij],    Aomori_male_fh_PI[[fh]][,ik,ij],
                                            Iwate_female_fh_PI[[fh]][,ik,ij],     Iwate_male_fh_PI[[fh]][,ik,ij],
                                            Miyagi_female_fh_PI[[fh]][,ik,ij],    Miyagi_male_fh_PI[[fh]][,ik,ij],
                                            Akita_female_fh_PI[[fh]][,ik,ij],     Akita_male_fh_PI[[fh]][,ik,ij],
                                            Yamagata_female_fh_PI[[fh]][,ik,ij],  Yamagata_male_fh_PI[[fh]][,ik,ij],
                                            Fukushima_female_fh_PI[[fh]][,ik,ij], Fukushima_male_fh_PI[[fh]][,ik,ij],
                                            Ibaraki_female_fh_PI[[fh]][,ik,ij],   Ibaraki_male_fh_PI[[fh]][,ik,ij],
                                            Tochigi_female_fh_PI[[fh]][,ik,ij],   Tochigi_male_fh_PI[[fh]][,ik,ij],
                                            Gunma_female_fh_PI[[fh]][,ik,ij],     Gunma_male_fh_PI[[fh]][,ik,ij],
                                            Saitama_female_fh_PI[[fh]][,ik,ij],   Saitama_male_fh_PI[[fh]][,ik,ij],
                                            Chiba_female_fh_PI[[fh]][,ik,ij],     Chiba_male_fh_PI[[fh]][,ik,ij],
                                            Tokyo_female_fh_PI[[fh]][,ik,ij],     Tokyo_male_fh_PI[[fh]][,ik,ij],
                                            Kanagawa_female_fh_PI[[fh]][,ik,ij],  Kanagawa_male_fh_PI[[fh]][,ik,ij],
                                            Niigata_female_fh_PI[[fh]][,ik,ij],   Niigata_male_fh_PI[[fh]][,ik,ij],
                                            Toyama_female_fh_PI[[fh]][,ik,ij],    Toyama_male_fh_PI[[fh]][,ik,ij],
                                            Ishikawa_female_fh_PI[[fh]][,ik,ij],  Ishikawa_male_fh_PI[[fh]][,ik,ij],
                                            Fukui_female_fh_PI[[fh]][,ik,ij],     Fukui_male_fh_PI[[fh]][,ik,ij],
                                            Yamanashi_female_fh_PI[[fh]][,ik,ij], Yamanashi_male_fh_PI[[fh]][,ik,ij],
                                            Nagano_female_fh_PI[[fh]][,ik,ij],    Nagano_male_fh_PI[[fh]][,ik,ij],
                                            Gifu_female_fh_PI[[fh]][,ik,ij],      Gifu_male_fh_PI[[fh]][,ik,ij],
                                            Shizuoka_female_fh_PI[[fh]][,ik,ij],  Shizuoka_male_fh_PI[[fh]][,ik,ij],
                                            Aichi_female_fh_PI[[fh]][,ik,ij],     Aichi_male_fh_PI[[fh]][,ik,ij],
                                            Mie_female_fh_PI[[fh]][,ik,ij],       Mie_male_fh_PI[[fh]][,ik,ij],
                                            Shiga_female_fh_PI[[fh]][,ik,ij],     Shiga_male_fh_PI[[fh]][,ik,ij],
                                            Kyoto_female_fh_PI[[fh]][,ik,ij],     Kyoto_male_fh_PI[[fh]][,ik,ij],
                                            Osaka_female_fh_PI[[fh]][,ik,ij],     Osaka_male_fh_PI[[fh]][,ik,ij],
                                            Hyogo_female_fh_PI[[fh]][,ik,ij],     Hyogo_male_fh_PI[[fh]][,ik,ij],
                                            Nara_female_fh_PI[[fh]][,ik,ij],      Nara_male_fh_PI[[fh]][,ik,ij],
                                            Wakayama_female_fh_PI[[fh]][,ik,ij],  Wakayama_male_fh_PI[[fh]][,ik,ij],
                                            Tottori_female_fh_PI[[fh]][,ik,ij],   Tottori_male_fh_PI[[fh]][,ik,ij],
                                            Shimane_female_fh_PI[[fh]][,ik,ij],   Shimane_male_fh_PI[[fh]][,ik,ij],
                                            Okayama_female_fh_PI[[fh]][,ik,ij],   Okayama_male_fh_PI[[fh]][,ik,ij],
                                            Hiroshima_female_fh_PI[[fh]][,ik,ij], Hiroshima_male_fh_PI[[fh]][,ik,ij],
                                            Yamaguchi_female_fh_PI[[fh]][,ik,ij], Yamaguchi_male_fh_PI[[fh]][,ik,ij],
                                            Tokushima_female_fh_PI[[fh]][,ik,ij], Tokushima_male_fh_PI[[fh]][,ik,ij],
                                            Kagawa_female_fh_PI[[fh]][,ik,ij],    Kagawa_male_fh_PI[[fh]][,ik,ij],
                                            Ehime_female_fh_PI[[fh]][,ik,ij],     Ehime_male_fh_PI[[fh]][,ik,ij],
                                            Kochi_female_fh_PI[[fh]][,ik,ij],     Kochi_male_fh_PI[[fh]][,ik,ij],
                                            Fukuoka_female_fh_PI[[fh]][,ik,ij],   Fukuoka_male_fh_PI[[fh]][,ik,ij],
                                            Saga_female_fh_PI[[fh]][,ik,ij],      Saga_male_fh_PI[[fh]][,ik,ij],
                                            Nagasaki_female_fh_PI[[fh]][,ik,ij],  Nagasaki_male_fh_PI[[fh]][,ik,ij],
                                            Kumamoto_female_fh_PI[[fh]][,ik,ij],  Kumamoto_male_fh_PI[[fh]][,ik,ij],
                                            Oita_female_fh_PI[[fh]][,ik,ij],      Oita_male_fh_PI[[fh]][,ik,ij],
                                            Miyazaki_female_fh_PI[[fh]][,ik,ij],  Miyazaki_male_fh_PI[[fh]][,ik,ij],
                                            Kagoshima_female_fh_PI[[fh]][,ik,ij], Kagoshima_male_fh_PI[[fh]][,ik,ij],
                                            Okinawa_female_fh_PI[[fh]][,ik,ij],   Okinawa_male_fh_PI[[fh]][,ik,ij]))
        }
    }
    return(prefecture_fh_PI)
}

Japan_total_PI_indicator = Japan_female_PI_indicator = Japan_male_PI_indicator =
R1_total_PI_indicator = R2_total_PI_indicator = R3_total_PI_indicator = R4_total_PI_indicator =
R5_total_PI_indicator = R6_total_PI_indicator = R7_total_PI_indicator = R8_total_PI_indicator =
R1_female_PI_indicator = R2_female_PI_indicator = R3_female_PI_indicator = R4_female_PI_indicator =
R5_female_PI_indicator = R6_female_PI_indicator = R7_female_PI_indicator = R8_female_PI_indicator =
R1_male_PI_indicator = R2_male_PI_indicator = R3_male_PI_indicator = R4_male_PI_indicator =
R5_male_PI_indicator = R6_male_PI_indicator = R7_male_PI_indicator = R8_male_PI_indicator =

Hokkaido_total_PI_indicator = Aomori_total_PI_indicator = Iwate_total_PI_indicator = Miyagi_total_PI_indicator = Akita_total_PI_indicator =
Yamagata_total_PI_indicator = Fukushima_total_PI_indicator = Ibaraki_total_PI_indicator = Tochigi_total_PI_indicator = Gunma_total_PI_indicator =
Saitama_total_PI_indicator = Chiba_total_PI_indicator = Tokyo_total_PI_indicator = Kanagawa_total_PI_indicator = Niigata_total_PI_indicator =
Toyama_total_PI_indicator = Ishikawa_total_PI_indicator = Fukui_total_PI_indicator = Yamanashi_total_PI_indicator = Nagano_total_PI_indicator =
Gifu_total_PI_indicator = Shizuoka_total_PI_indicator = Aichi_total_PI_indicator = Mie_total_PI_indicator = Shiga_total_PI_indicator =
Kyoto_total_PI_indicator = Osaka_total_PI_indicator = Hyogo_total_PI_indicator = Nara_total_PI_indicator = Wakayama_total_PI_indicator =
Tottori_total_PI_indicator = Shimane_total_PI_indicator = Okayama_total_PI_indicator = Hiroshima_total_PI_indicator = Yamaguchi_total_PI_indicator =
Tokushima_total_PI_indicator = Kagawa_total_PI_indicator = Ehime_total_PI_indicator = Kochi_total_PI_indicator = Fukuoka_total_PI_indicator =
Saga_total_PI_indicator = Nagasaki_total_PI_indicator = Kumamoto_total_PI_indicator = Oita_total_PI_indicator = Miyazaki_total_PI_indicator =
Kagoshima_total_PI_indicator = Okinawa_total_PI_indicator =

Hokkaido_female_PI_indicator = Aomori_female_PI_indicator = Iwate_female_PI_indicator = Miyagi_female_PI_indicator = Akita_female_PI_indicator =
Yamagata_female_PI_indicator = Fukushima_female_PI_indicator = Ibaraki_female_PI_indicator = Tochigi_female_PI_indicator = Gunma_female_PI_indicator =
Saitama_female_PI_indicator = Chiba_female_PI_indicator = Tokyo_female_PI_indicator = Kanagawa_female_PI_indicator = Niigata_female_PI_indicator =
Toyama_female_PI_indicator = Ishikawa_female_PI_indicator = Fukui_female_PI_indicator = Yamanashi_female_PI_indicator = Nagano_female_PI_indicator =
Gifu_female_PI_indicator = Shizuoka_female_PI_indicator = Aichi_female_PI_indicator = Mie_female_PI_indicator = Shiga_female_PI_indicator =
Kyoto_female_PI_indicator = Osaka_female_PI_indicator = Hyogo_female_PI_indicator = Nara_female_PI_indicator = Wakayama_female_PI_indicator =
Tottori_female_PI_indicator = Shimane_female_PI_indicator = Okayama_female_PI_indicator = Hiroshima_female_PI_indicator = Yamaguchi_female_PI_indicator =
Tokushima_female_PI_indicator = Kagawa_female_PI_indicator = Ehime_female_PI_indicator = Kochi_female_PI_indicator = Fukuoka_female_PI_indicator =
Saga_female_PI_indicator = Nagasaki_female_PI_indicator = Kumamoto_female_PI_indicator = Oita_female_PI_indicator = Miyazaki_female_PI_indicator =
Kagoshima_female_PI_indicator = Okinawa_female_PI_indicator =

Hokkaido_male_PI_indicator = Aomori_male_PI_indicator = Iwate_male_PI_indicator = Miyagi_male_PI_indicator = Akita_male_PI_indicator =
Yamagata_male_PI_indicator = Fukushima_male_PI_indicator = Ibaraki_male_PI_indicator = Tochigi_male_PI_indicator = Gunma_male_PI_indicator =
Saitama_male_PI_indicator = Chiba_male_PI_indicator = Tokyo_male_PI_indicator = Kanagawa_male_PI_indicator = Niigata_male_PI_indicator =
Toyama_male_PI_indicator = Ishikawa_male_PI_indicator = Fukui_male_PI_indicator = Yamanashi_male_PI_indicator = Nagano_male_PI_indicator =
Gifu_male_PI_indicator = Shizuoka_male_PI_indicator = Aichi_male_PI_indicator = Mie_male_PI_indicator = Shiga_male_PI_indicator =
Kyoto_male_PI_indicator = Osaka_male_PI_indicator = Hyogo_male_PI_indicator = Nara_male_PI_indicator = Wakayama_male_PI_indicator =
Tottori_male_PI_indicator = Shimane_male_PI_indicator = Okayama_male_PI_indicator = Hiroshima_male_PI_indicator = Yamaguchi_male_PI_indicator =
Tokushima_male_PI_indicator = Kagawa_male_PI_indicator = Ehime_male_PI_indicator = Kochi_male_PI_indicator = Fukuoka_male_PI_indicator =
Saga_male_PI_indicator = Nagasaki_male_PI_indicator = Kumamoto_male_PI_indicator = Oita_male_PI_indicator = Miyazaki_male_PI_indicator =
Kagoshima_male_PI_indicator = Okinawa_male_PI_indicator = vector("numeric", 15)
for(ik in 1:15)
{
    Japan_total_PI_indicator[ik] = any(is.na(exp(Japan_total_fh_PI[[ik]])))
    Japan_female_PI_indicator[ik] = any(is.na(exp(Japan_female_fh_PI[[ik]])))
    Japan_male_PI_indicator[ik] = any(is.na(exp(Japan_male_fh_PI[[ik]])))
    
    R1_total_PI_indicator[ik] = any(is.na(exp(R1_total_fh_PI[[ik]])))
    R2_total_PI_indicator[ik] = any(is.na(exp(R2_total_fh_PI[[ik]])))
    R3_total_PI_indicator[ik] = any(is.na(exp(R3_total_fh_PI[[ik]])))
    R4_total_PI_indicator[ik] = any(is.na(exp(R4_total_fh_PI[[ik]])))
    R5_total_PI_indicator[ik] = any(is.na(exp(R5_total_fh_PI[[ik]])))
    R6_total_PI_indicator[ik] = any(is.na(exp(R6_total_fh_PI[[ik]])))
    R7_total_PI_indicator[ik] = any(is.na(exp(R7_total_fh_PI[[ik]])))
    R8_total_PI_indicator[ik] = any(is.na(exp(R8_total_fh_PI[[ik]])))
    
    R1_female_PI_indicator[ik] = any(is.na(exp(R1_female_fh_PI[[ik]])))
    R2_female_PI_indicator[ik] = any(is.na(exp(R2_female_fh_PI[[ik]])))
    R3_female_PI_indicator[ik] = any(is.na(exp(R3_female_fh_PI[[ik]])))
    R4_female_PI_indicator[ik] = any(is.na(exp(R4_female_fh_PI[[ik]])))
    R5_female_PI_indicator[ik] = any(is.na(exp(R5_female_fh_PI[[ik]])))
    R6_female_PI_indicator[ik] = any(is.na(exp(R6_female_fh_PI[[ik]])))
    R7_female_PI_indicator[ik] = any(is.na(exp(R7_female_fh_PI[[ik]])))
    R8_female_PI_indicator[ik] = any(is.na(exp(R8_female_fh_PI[[ik]])))
    
    R1_male_PI_indicator[ik] = any(is.na(exp(R1_male_fh_PI[[ik]])))
    R2_male_PI_indicator[ik] = any(is.na(exp(R2_male_fh_PI[[ik]])))
    R3_male_PI_indicator[ik] = any(is.na(exp(R3_male_fh_PI[[ik]])))
    R4_male_PI_indicator[ik] = any(is.na(exp(R4_male_fh_PI[[ik]])))
    R5_male_PI_indicator[ik] = any(is.na(exp(R5_male_fh_PI[[ik]])))
    R6_male_PI_indicator[ik] = any(is.na(exp(R6_male_fh_PI[[ik]])))
    R7_male_PI_indicator[ik] = any(is.na(exp(R7_male_fh_PI[[ik]])))
    R8_male_PI_indicator[ik] = any(is.na(exp(R8_male_fh_PI[[ik]])))
    
    Hokkaido_total_PI_indicator[ik] = any(is.na(exp(Hokkaido_total_fh_PI[[ik]])))
    Aomori_total_PI_indicator[ik] = any(is.na(exp(Aomori_total_fh_PI[[ik]])))
    Iwate_total_PI_indicator[ik] = any(is.na(exp(Iwate_total_fh_PI[[ik]])))
    Miyagi_total_PI_indicator[ik] = any(is.na(exp(Miyagi_total_fh_PI[[ik]])))
    Akita_total_PI_indicator[ik] = any(is.na(exp(Akita_total_fh_PI[[ik]])))
    Yamagata_total_PI_indicator[ik] = any(is.na(exp(Yamagata_total_fh_PI[[ik]])))
    Fukushima_total_PI_indicator[ik] = any(is.na(exp(Fukushima_total_fh_PI[[ik]])))
    Ibaraki_total_PI_indicator[ik] = any(is.na(exp(Ibaraki_total_fh_PI[[ik]])))
    Tochigi_total_PI_indicator[ik] = any(is.na(exp(Tochigi_total_fh_PI[[ik]])))
    Gunma_total_PI_indicator[ik] = any(is.na(exp(Gunma_total_fh_PI[[ik]])))
    Saitama_total_PI_indicator[ik] = any(is.na(exp(Saitama_total_fh_PI[[ik]])))
    Chiba_total_PI_indicator[ik] = any(is.na(exp(Chiba_total_fh_PI[[ik]])))
    Tokyo_total_PI_indicator[ik] = any(is.na(exp(Tokyo_total_fh_PI[[ik]])))
    Kanagawa_total_PI_indicator[ik] = any(is.na(exp(Kanagawa_total_fh_PI[[ik]])))
    Niigata_total_PI_indicator[ik] = any(is.na(exp(Niigata_total_fh_PI[[ik]])))
    Toyama_total_PI_indicator[ik] = any(is.na(exp(Toyama_total_fh_PI[[ik]])))
    Ishikawa_total_PI_indicator[ik] = any(is.na(exp(Ishikawa_total_fh_PI[[ik]])))
    Fukui_total_PI_indicator[ik] = any(is.na(exp(Fukui_total_fh_PI[[ik]])))
    Yamanashi_total_PI_indicator[ik] = any(is.na(exp(Yamanashi_total_fh_PI[[ik]])))
    Nagano_total_PI_indicator[ik] = any(is.na(exp(Nagano_total_fh_PI[[ik]])))
    Gifu_total_PI_indicator[ik] = any(is.na(exp(Gifu_total_fh_PI[[ik]])))
    Shizuoka_total_PI_indicator[ik] = any(is.na(exp(Shizuoka_total_fh_PI[[ik]])))
    Aichi_total_PI_indicator[ik] = any(is.na(exp(Aichi_total_fh_PI[[ik]])))
    Mie_total_PI_indicator[ik] = any(is.na(exp(Mie_total_fh_PI[[ik]])))
    Shiga_total_PI_indicator[ik] = any(is.na(exp(Shiga_total_fh_PI[[ik]])))
    Kyoto_total_PI_indicator[ik] = any(is.na(exp(Kyoto_total_fh_PI[[ik]])))
    Osaka_total_PI_indicator[ik] = any(is.na(exp(Osaka_total_fh_PI[[ik]])))
    Hyogo_total_PI_indicator[ik] = any(is.na(exp(Hyogo_total_fh_PI[[ik]])))
    Nara_total_PI_indicator[ik] = any(is.na(exp(Nara_total_fh_PI[[ik]])))
    Wakayama_total_PI_indicator[ik] = any(is.na(exp(Wakayama_total_fh_PI[[ik]])))
    Tottori_total_PI_indicator[ik] = any(is.na(exp(Tottori_total_fh_PI[[ik]])))
    Shimane_total_PI_indicator[ik] = any(is.na(exp(Shimane_total_fh_PI[[ik]])))
    Okayama_total_PI_indicator[ik] = any(is.na(exp(Okayama_total_fh_PI[[ik]])))
    Hiroshima_total_PI_indicator[ik] = any(is.na(exp(Hiroshima_total_fh_PI[[ik]])))
    Yamaguchi_total_PI_indicator[ik] = any(is.na(exp(Yamaguchi_total_fh_PI[[ik]])))
    Tokushima_total_PI_indicator[ik] = any(is.na(exp(Tokushima_total_fh_PI[[ik]])))
    Kagawa_total_PI_indicator[ik] = any(is.na(exp(Kagawa_total_fh_PI[[ik]])))
    Ehime_total_PI_indicator[ik] = any(is.na(exp(Ehime_total_fh_PI[[ik]])))
    Kochi_total_PI_indicator[ik] = any(is.na(exp(Kochi_total_fh_PI[[ik]])))
    Fukuoka_total_PI_indicator[ik] = any(is.na(exp(Fukuoka_total_fh_PI[[ik]])))
    Saga_total_PI_indicator[ik] = any(is.na(exp(Saga_total_fh_PI[[ik]])))
    Nagasaki_total_PI_indicator[ik] = any(is.na(exp(Nagasaki_total_fh_PI[[ik]])))
    Kumamoto_total_PI_indicator[ik] = any(is.na(exp(Kumamoto_total_fh_PI[[ik]])))
    Oita_total_PI_indicator[ik] = any(is.na(exp(Oita_total_fh_PI[[ik]])))
    Miyazaki_total_PI_indicator[ik] = any(is.na(exp(Miyazaki_total_fh_PI[[ik]])))
    Kagoshima_total_PI_indicator[ik] = any(is.na(exp(Kagoshima_total_fh_PI[[ik]])))
    Okinawa_total_PI_indicator[ik] = any(is.na(exp(Okinawa_total_fh_PI[[ik]])))
    
    Hokkaido_female_PI_indicator[ik] = any(is.na(exp(Hokkaido_female_fh_PI[[ik]])))
    Aomori_female_PI_indicator[ik] = any(is.na(exp(Aomori_female_fh_PI[[ik]])))
    Iwate_female_PI_indicator[ik] = any(is.na(exp(Iwate_female_fh_PI[[ik]])))
    Miyagi_female_PI_indicator[ik] = any(is.na(exp(Miyagi_female_fh_PI[[ik]])))
    Akita_female_PI_indicator[ik] = any(is.na(exp(Akita_female_fh_PI[[ik]])))
    Yamagata_female_PI_indicator[ik] = any(is.na(exp(Yamagata_female_fh_PI[[ik]])))
    Fukushima_female_PI_indicator[ik] = any(is.na(exp(Fukushima_female_fh_PI[[ik]])))
    Ibaraki_female_PI_indicator[ik] = any(is.na(exp(Ibaraki_female_fh_PI[[ik]])))
    Tochigi_female_PI_indicator[ik] = any(is.na(exp(Tochigi_female_fh_PI[[ik]])))
    Gunma_female_PI_indicator[ik] = any(is.na(exp(Gunma_female_fh_PI[[ik]])))
    Saitama_female_PI_indicator[ik] = any(is.na(exp(Saitama_female_fh_PI[[ik]])))
    Chiba_female_PI_indicator[ik] = any(is.na(exp(Chiba_female_fh_PI[[ik]])))
    Tokyo_female_PI_indicator[ik] = any(is.na(exp(Tokyo_female_fh_PI[[ik]])))
    Kanagawa_female_PI_indicator[ik] = any(is.na(exp(Kanagawa_female_fh_PI[[ik]])))
    Niigata_female_PI_indicator[ik] = any(is.na(exp(Niigata_female_fh_PI[[ik]])))
    Toyama_female_PI_indicator[ik] = any(is.na(exp(Toyama_female_fh_PI[[ik]])))
    Ishikawa_female_PI_indicator[ik] = any(is.na(exp(Ishikawa_female_fh_PI[[ik]])))
    Fukui_female_PI_indicator[ik] = any(is.na(exp(Fukui_female_fh_PI[[ik]])))
    Yamanashi_female_PI_indicator[ik] = any(is.na(exp(Yamanashi_female_fh_PI[[ik]])))
    Nagano_female_PI_indicator[ik] = any(is.na(exp(Nagano_female_fh_PI[[ik]])))
    Gifu_female_PI_indicator[ik] = any(is.na(exp(Gifu_female_fh_PI[[ik]])))
    Shizuoka_female_PI_indicator[ik] = any(is.na(exp(Shizuoka_female_fh_PI[[ik]])))
    Aichi_female_PI_indicator[ik] = any(is.na(exp(Aichi_female_fh_PI[[ik]])))
    Mie_female_PI_indicator[ik] = any(is.na(exp(Mie_female_fh_PI[[ik]])))
    Shiga_female_PI_indicator[ik] = any(is.na(exp(Shiga_female_fh_PI[[ik]])))
    Kyoto_female_PI_indicator[ik] = any(is.na(exp(Kyoto_female_fh_PI[[ik]])))
    Osaka_female_PI_indicator[ik] = any(is.na(exp(Osaka_female_fh_PI[[ik]])))
    Hyogo_female_PI_indicator[ik] = any(is.na(exp(Hyogo_female_fh_PI[[ik]])))
    Nara_female_PI_indicator[ik] = any(is.na(exp(Nara_female_fh_PI[[ik]])))
    Wakayama_female_PI_indicator[ik] = any(is.na(exp(Wakayama_female_fh_PI[[ik]])))
    Tottori_female_PI_indicator[ik] = any(is.na(exp(Tottori_female_fh_PI[[ik]])))
    Shimane_female_PI_indicator[ik] = any(is.na(exp(Shimane_female_fh_PI[[ik]])))
    Okayama_female_PI_indicator[ik] = any(is.na(exp(Okayama_female_fh_PI[[ik]])))
    Hiroshima_female_PI_indicator[ik] = any(is.na(exp(Hiroshima_female_fh_PI[[ik]])))
    Yamaguchi_female_PI_indicator[ik] = any(is.na(exp(Yamaguchi_female_fh_PI[[ik]])))
    Tokushima_female_PI_indicator[ik] = any(is.na(exp(Tokushima_female_fh_PI[[ik]])))
    Kagawa_female_PI_indicator[ik] = any(is.na(exp(Kagawa_female_fh_PI[[ik]])))
    Ehime_female_PI_indicator[ik] = any(is.na(exp(Ehime_female_fh_PI[[ik]])))
    Kochi_female_PI_indicator[ik] = any(is.na(exp(Kochi_female_fh_PI[[ik]])))
    Fukuoka_female_PI_indicator[ik] = any(is.na(exp(Fukuoka_female_fh_PI[[ik]])))
    Saga_female_PI_indicator[ik] = any(is.na(exp(Saga_female_fh_PI[[ik]])))
    Nagasaki_female_PI_indicator[ik] = any(is.na(exp(Nagasaki_female_fh_PI[[ik]])))
    Kumamoto_female_PI_indicator[ik] = any(is.na(exp(Kumamoto_female_fh_PI[[ik]])))
    Oita_female_PI_indicator[ik] = any(is.na(exp(Oita_female_fh_PI[[ik]])))
    Miyazaki_female_PI_indicator[ik] = any(is.na(exp(Miyazaki_female_fh_PI[[ik]])))
    Kagoshima_female_PI_indicator[ik] = any(is.na(exp(Kagoshima_female_fh_PI[[ik]])))
    Okinawa_female_PI_indicator[ik] = any(is.na(exp(Okinawa_female_fh_PI[[ik]])))
    
    Hokkaido_male_PI_indicator[ik] = any(is.na(exp(Hokkaido_male_fh_PI[[ik]])))
    Aomori_male_PI_indicator[ik] = any(is.na(exp(Aomori_male_fh_PI[[ik]])))
    Iwate_male_PI_indicator[ik] = any(is.na(exp(Iwate_male_fh_PI[[ik]])))
    Miyagi_male_PI_indicator[ik] = any(is.na(exp(Miyagi_male_fh_PI[[ik]])))
    Akita_male_PI_indicator[ik] = any(is.na(exp(Akita_male_fh_PI[[ik]])))
    Yamagata_male_PI_indicator[ik] = any(is.na(exp(Yamagata_male_fh_PI[[ik]])))
    Fukushima_male_PI_indicator[ik] = any(is.na(exp(Fukushima_male_fh_PI[[ik]])))
    Ibaraki_male_PI_indicator[ik] = any(is.na(exp(Ibaraki_male_fh_PI[[ik]])))
    Tochigi_male_PI_indicator[ik] = any(is.na(exp(Tochigi_male_fh_PI[[ik]])))
    Gunma_male_PI_indicator[ik] = any(is.na(exp(Gunma_male_fh_PI[[ik]])))
    Saitama_male_PI_indicator[ik] = any(is.na(exp(Saitama_male_fh_PI[[ik]])))
    Chiba_male_PI_indicator[ik] = any(is.na(exp(Chiba_male_fh_PI[[ik]])))
    Tokyo_male_PI_indicator[ik] = any(is.na(exp(Tokyo_male_fh_PI[[ik]])))
    Kanagawa_male_PI_indicator[ik] = any(is.na(exp(Kanagawa_male_fh_PI[[ik]])))
    Niigata_male_PI_indicator[ik] = any(is.na(exp(Niigata_male_fh_PI[[ik]])))
    Toyama_male_PI_indicator[ik] = any(is.na(exp(Toyama_male_fh_PI[[ik]])))
    Ishikawa_male_PI_indicator[ik] = any(is.na(exp(Ishikawa_male_fh_PI[[ik]])))
    Fukui_male_PI_indicator[ik] = any(is.na(exp(Fukui_male_fh_PI[[ik]])))
    Yamanashi_male_PI_indicator[ik] = any(is.na(exp(Yamanashi_male_fh_PI[[ik]])))
    Nagano_male_PI_indicator[ik] = any(is.na(exp(Nagano_male_fh_PI[[ik]])))
    Gifu_male_PI_indicator[ik] = any(is.na(exp(Gifu_male_fh_PI[[ik]])))
    Shizuoka_male_PI_indicator[ik] = any(is.na(exp(Shizuoka_male_fh_PI[[ik]])))
    Aichi_male_PI_indicator[ik] = any(is.na(exp(Aichi_male_fh_PI[[ik]])))
    Mie_male_PI_indicator[ik] = any(is.na(exp(Mie_male_fh_PI[[ik]])))
    Shiga_male_PI_indicator[ik] = any(is.na(exp(Shiga_male_fh_PI[[ik]])))
    Kyoto_male_PI_indicator[ik] = any(is.na(exp(Kyoto_male_fh_PI[[ik]])))
    Osaka_male_PI_indicator[ik] = any(is.na(exp(Osaka_male_fh_PI[[ik]])))
    Hyogo_male_PI_indicator[ik] = any(is.na(exp(Hyogo_male_fh_PI[[ik]])))
    Nara_male_PI_indicator[ik] = any(is.na(exp(Nara_male_fh_PI[[ik]])))
    Wakayama_male_PI_indicator[ik] = any(is.na(exp(Wakayama_male_fh_PI[[ik]])))
    Tottori_male_PI_indicator[ik] = any(is.na(exp(Tottori_male_fh_PI[[ik]])))
    Shimane_male_PI_indicator[ik] = any(is.na(exp(Shimane_male_fh_PI[[ik]])))
    Okayama_male_PI_indicator[ik] = any(is.na(exp(Okayama_male_fh_PI[[ik]])))
    Hiroshima_male_PI_indicator[ik] = any(is.na(exp(Hiroshima_male_fh_PI[[ik]])))
    Yamaguchi_male_PI_indicator[ik] = any(is.na(exp(Yamaguchi_male_fh_PI[[ik]])))
    Tokushima_male_PI_indicator[ik] = any(is.na(exp(Tokushima_male_fh_PI[[ik]])))
    Kagawa_male_PI_indicator[ik] = any(is.na(exp(Kagawa_male_fh_PI[[ik]])))
    Ehime_male_PI_indicator[ik] = any(is.na(exp(Ehime_male_fh_PI[[ik]])))
    Kochi_male_PI_indicator[ik] = any(is.na(exp(Kochi_male_fh_PI[[ik]])))
    Fukuoka_male_PI_indicator[ik] = any(is.na(exp(Fukuoka_male_fh_PI[[ik]])))
    Saga_male_PI_indicator[ik] = any(is.na(exp(Saga_male_fh_PI[[ik]])))
    Nagasaki_male_PI_indicator[ik] = any(is.na(exp(Nagasaki_male_fh_PI[[ik]])))
    Kumamoto_male_PI_indicator[ik] = any(is.na(exp(Kumamoto_male_fh_PI[[ik]])))
    Oita_male_PI_indicator[ik] = any(is.na(exp(Oita_male_fh_PI[[ik]])))
    Miyazaki_male_PI_indicator[ik] = any(is.na(exp(Miyazaki_male_fh_PI[[ik]])))
    Kagoshima_male_PI_indicator[ik] = any(is.na(exp(Kagoshima_male_fh_PI[[ik]])))
    Okinawa_male_PI_indicator[ik] = any(is.na(exp(Okinawa_male_fh_PI[[ik]])))
}

Japan_PI_indicator = cbind(Japan_total_PI_indicator, Japan_female_PI_indicator, Japan_male_PI_indicator,
                           R1_total_PI_indicator, R2_total_PI_indicator, R3_total_PI_indicator,
                           R4_total_PI_indicator, R5_total_PI_indicator, R6_total_PI_indicator, R7_total_PI_indicator, R8_total_PI_indicator,
                           R1_female_PI_indicator, R2_female_PI_indicator,
                           R3_female_PI_indicator, R4_female_PI_indicator, R5_female_PI_indicator, R6_female_PI_indicator, R7_female_PI_indicator, R8_female_PI_indicator,
                           R1_male_PI_indicator,
                           R2_male_PI_indicator, R3_male_PI_indicator, R4_male_PI_indicator, R5_male_PI_indicator, R6_male_PI_indicator, R7_male_PI_indicator, R8_male_PI_indicator, Hokkaido_total_PI_indicator, Aomori_total_PI_indicator, Iwate_total_PI_indicator, Miyagi_total_PI_indicator, Akita_total_PI_indicator,
                           Yamagata_total_PI_indicator, Fukushima_total_PI_indicator, Ibaraki_total_PI_indicator, Tochigi_total_PI_indicator, Gunma_total_PI_indicator,
                           Saitama_total_PI_indicator, Chiba_total_PI_indicator, Tokyo_total_PI_indicator, Kanagawa_total_PI_indicator, Niigata_total_PI_indicator,
                           Toyama_total_PI_indicator, Ishikawa_total_PI_indicator, Fukui_total_PI_indicator, Yamanashi_total_PI_indicator, Nagano_total_PI_indicator,
                           Gifu_total_PI_indicator, Shizuoka_total_PI_indicator, Aichi_total_PI_indicator, Mie_total_PI_indicator, Shiga_total_PI_indicator,
                           Kyoto_total_PI_indicator, Osaka_total_PI_indicator, Hyogo_total_PI_indicator, Nara_total_PI_indicator, Wakayama_total_PI_indicator,
                           Tottori_total_PI_indicator, Shimane_total_PI_indicator, Okayama_total_PI_indicator, Hiroshima_total_PI_indicator, Yamaguchi_total_PI_indicator,
                           Tokushima_total_PI_indicator, Kagawa_total_PI_indicator, Ehime_total_PI_indicator, Kochi_total_PI_indicator, Fukuoka_total_PI_indicator,
                           Saga_total_PI_indicator, Nagasaki_total_PI_indicator, Kumamoto_total_PI_indicator, Oita_total_PI_indicator, Miyazaki_total_PI_indicator,
                           Kagoshima_total_PI_indicator, Okinawa_total_PI_indicator, Hokkaido_female_PI_indicator, Aomori_female_PI_indicator, Iwate_female_PI_indicator, Miyagi_female_PI_indicator, Akita_female_PI_indicator,
                           Yamagata_female_PI_indicator, Fukushima_female_PI_indicator, Ibaraki_female_PI_indicator, Tochigi_female_PI_indicator, Gunma_female_PI_indicator,
                           Saitama_female_PI_indicator, Chiba_female_PI_indicator, Tokyo_female_PI_indicator, Kanagawa_female_PI_indicator, Niigata_female_PI_indicator,
                           Toyama_female_PI_indicator, Ishikawa_female_PI_indicator, Fukui_female_PI_indicator, Yamanashi_female_PI_indicator, Nagano_female_PI_indicator,
                           Gifu_female_PI_indicator, Shizuoka_female_PI_indicator, Aichi_female_PI_indicator, Mie_female_PI_indicator, Shiga_female_PI_indicator,
                           Kyoto_female_PI_indicator, Osaka_female_PI_indicator, Hyogo_female_PI_indicator, Nara_female_PI_indicator, Wakayama_female_PI_indicator,
                           Tottori_female_PI_indicator, Shimane_female_PI_indicator, Okayama_female_PI_indicator, Hiroshima_female_PI_indicator, Yamaguchi_female_PI_indicator,
                           Tokushima_female_PI_indicator, Kagawa_female_PI_indicator, Ehime_female_PI_indicator, Kochi_female_PI_indicator, Fukuoka_female_PI_indicator,
                           Saga_female_PI_indicator, Nagasaki_female_PI_indicator, Kumamoto_female_PI_indicator, Oita_female_PI_indicator, Miyazaki_female_PI_indicator,
                           Kagoshima_female_PI_indicator, Okinawa_female_PI_indicator, Hokkaido_male_PI_indicator, Aomori_male_PI_indicator, Iwate_male_PI_indicator, Miyagi_male_PI_indicator, Akita_male_PI_indicator,
                           Yamagata_male_PI_indicator, Fukushima_male_PI_indicator, Ibaraki_male_PI_indicator, Tochigi_male_PI_indicator, Gunma_male_PI_indicator,
                           Saitama_male_PI_indicator, Chiba_male_PI_indicator, Tokyo_male_PI_indicator, Kanagawa_male_PI_indicator, Niigata_male_PI_indicator,
                           Toyama_male_PI_indicator, Ishikawa_male_PI_indicator, Fukui_male_PI_indicator, Yamanashi_male_PI_indicator, Nagano_male_PI_indicator,
                           Gifu_male_PI_indicator, Shizuoka_male_PI_indicator, Aichi_male_PI_indicator, Mie_male_PI_indicator, Shiga_male_PI_indicator,
                           Kyoto_male_PI_indicator, Osaka_male_PI_indicator, Hyogo_male_PI_indicator, Nara_male_PI_indicator, Wakayama_male_PI_indicator,
                           Tottori_male_PI_indicator, Shimane_male_PI_indicator, Okayama_male_PI_indicator, Hiroshima_male_PI_indicator, Yamaguchi_male_PI_indicator,
                           Tokushima_male_PI_indicator, Kagawa_male_PI_indicator, Ehime_male_PI_indicator, Kochi_male_PI_indicator, Fukuoka_male_PI_indicator,
                           Saga_male_PI_indicator, Nagasaki_male_PI_indicator, Kumamoto_male_PI_indicator, Oita_male_PI_indicator, Miyazaki_male_PI_indicator,
                           Kagoshima_male_PI_indicator, Okinawa_male_PI_indicator)



##################################################################
# one- to 15-step-ahead bootstrapped mortality samples (B = 1000)
##################################################################

PI_prefecture_h1to15 = list()
for(ik in 1:15)
{
    PI_prefecture_h1to15[[ik]] = PI_prefecture(fh = ik)
    print(ik)
}

# kj: forecast horizon from h = 1 to 15
# age: age indexes from 1 to 41 (ages 60 to 100+)

BU_optim_hier_PI <- function(kj, age, hier_method = c("BU", "OLS"))
{
    hier_method = match.arg(hier_method)
    hier_fore = array(NA, dim = c(168, 2, (16 - kj)))
    
    summ_mat = Smat_fun(kj = kj, age = age)
    # ik: number of years in the forecasting period, it depends on kj
    for(ik in 1:(16 - kj))
    {
        hier = summ_mat[,,ik]
        if(hier_method == "BU")
        {
                for(ij in 1:2)
                {
                    hier_fore[,ij,ik] = hier %*% (PI_prefecture_h1to15[[kj]])[age, ij, ik, 75:168]
                }
        }
        if(hier_method == "OLS")
        {
            for(ij in 1:2)
            {
                hier_fore[,ij,ik] = hier %*% ginv(t(hier) %*% hier) %*% t(hier) %*% (PI_prefecture_h1to15[[kj]])[age, ij, ik, ]
            }
        }
    }
    return(hier_fore)
}

#####
# BU
#####

BU_fun <- function(kj)
{
    dum = array(NA, dim = c(41, 168, 2, (16 - kj)))
    for(ij in 1:41)
    {
        dum[ij,,,] = BU_optim_hier_PI(kj = kj, age = ij, hier_method = "BU")
    }
    return(dum)
}

require(doMC)
registerDoMC(15)
BU_optim_hier_comb = foreach(kj = 1:15) %dopar% BU_fun(kj = kj)

######
# OLS
######

OLS_fun <- function(kj)
{
    dum = array(NA, dim = c(41, 168, 2, (16 - kj)))
    for(ij in 1:41)
    {
        dum[ij,,,] = BU_optim_hier_PI(kj = kj, age = ij, hier_method = "OLS")
    }
    return(dum)
}

require(doMC); require(MASS)
registerDoMC(15)
OLS_hier_comb = foreach(kj = 1:15) %dopar% OLS_fun(kj = kj)

######################
# Comb (equal weight)
######################

comb_hier_comb = list()
for(ik in 1:15)
{
    comb_hier_comb[[ik]] = (BU_optim_hier_comb[[ik]] + OLS_hier_comb[[ik]])/2
}

##############################
# Comb (average of midpoints)
##############################

comb_hier_comb_midpoints = list()
for(ik in 1:15)
{
    comb_hier_comb_midpoints[[ik]] = (apply(BU_optim_hier_comb[[ik]], c(1, 2, 4), mean) +
                                      apply(OLS_hier_comb[[ik]], c(1, 2, 4), mean))/2
}

comb_hier_comb_int_midpoints = list()
for(ik in 1:15)
{
    dum_lb = BU_optim_hier_comb[[ik]]
    dum_lb[,,2,] = OLS_hier_comb[[ik]][,,1,]
    dum_lb_agg = apply(dum_lb, c(1, 2, 4), min)
    
    dum_ub = BU_optim_hier_comb[[ik]]
    dum_ub[,,1,] = OLS_hier_comb[[ik]][,,2,]
    dum_ub_agg = apply(dum_ub, c(1, 2, 4), max)
    
    dum_agg = array(NA, dim = c(dim(dum_lb_agg)[1], dim(dum_lb_agg)[2], 2, dim(dum_lb_agg)[3]))
    dum_agg[,,1,] = dum_lb_agg
    dum_agg[,,2,] = dum_ub_agg
    comb_hier_comb_int_midpoints[[ik]] = dum_agg
    rm(dum_lb); rm(dum_ub); rm(dum_lb_agg); rm(dum_ub_agg); rm(dum_agg)
}

################################
# Calculate mean interval score
################################

interval_score_BU_optim <- function(PI_val, data_series, series, fh, index, alpha = 0.8)
{
    if(series == "female")
    {
        test_val = extract.years(data_series, (2001+fh):2016)$rate$female
    }
    if(series == "male")
    {
        test_val = extract.years(data_series, (2001+fh):2016)$rate$male
    }
    if(series == "total")
    {
        test_val = extract.years(data_series, (2001+fh):2016)$rate$total
    }
    
    boot_sample = PI_val[[fh]]
    boot_index = which(boot_sample > 1)
    boot_index_below = which(boot_sample < 0)
    if(length(boot_index) > 0)
    {
        boot_sample_v1 = replace(boot_sample, boot_index, 1)
    }
    else
    {
        boot_sample_v1 = boot_sample
    }
    if(length(boot_index_below) > 0)
    {
        boot_sample_v2 = replace(boot_sample_v1, boot_index_below, 0)
    }
    else
    {
        boot_sample_v2 = boot_sample_v1
    }
    
    # lower and upper bounds
    
    # dummy = apply(boot_sample_v2, 1:3, quantile, c((1 - alpha)/2, (1 + alpha)/2), na.rm = TRUE)
    PI_lb_val = boot_sample_v2[,index,1,]
    PI_ub_val = boot_sample_v2[,index,2,]
    
    # which holdout samples lie outside lower and upper bounds
    
    lb_ind = ifelse(test_val < PI_lb_val, 1, 0)
    ub_ind = ifelse(test_val > PI_ub_val, 1, 0)
    
    score = mean((PI_ub_val - PI_lb_val) + 2/(1 - alpha) * (PI_lb_val - test_val) * lb_ind + 2/(1 - alpha) * (test_val - PI_ub_val) * ub_ind, na.rm = TRUE)
    return(score)
}

###############################################################################
# Interval forecasts produced by the bottom up and optimal-combination methods
###############################################################################

PI_prefecture_mfts <- function(fh)
{
    prefecture_fh_PI = array(NA, dim = c(41, 2, (16 - fh), 168))
    for(ik in 1:2)
    {
        for(ij in 1:(16 - fh))
        {
            prefecture_fh_PI[,ik,ij,] = exp(cbind(Japan_total_fh_PI[[fh]][,ik,ij],
                                                Japan_female_fh_PI_mfts[[fh]][,ik,ij], Japan_male_fh_PI_mfts[[fh]][,ik,ij],
                                                
                                                R1_total_fh_PI_mfts[[fh]][,ik,ij], R2_total_fh_PI_mfts[[fh]][,ik,ij],
                                                R3_total_fh_PI_mfts[[fh]][,ik,ij], R4_total_fh_PI_mfts[[fh]][,ik,ij],
                                                R5_total_fh_PI_mfts[[fh]][,ik,ij], R6_total_fh_PI_mfts[[fh]][,ik,ij],
                                                R7_total_fh_PI_mfts[[fh]][,ik,ij], R8_total_fh_PI_mfts[[fh]][,ik,ij],
                                                
                                                R1_female_fh_PI_mfts[[fh]][,ik,ij], R2_female_fh_PI_mfts[[fh]][,ik,ij],
                                                R3_female_fh_PI_mfts[[fh]][,ik,ij], R4_female_fh_PI_mfts[[fh]][,ik,ij],
                                                R5_female_fh_PI_mfts[[fh]][,ik,ij], R6_female_fh_PI_mfts[[fh]][,ik,ij],
                                                R7_female_fh_PI_mfts[[fh]][,ik,ij], R8_female_fh_PI_mfts[[fh]][,ik,ij],
                                                
                                                R1_male_fh_PI_mfts[[fh]][,ik,ij], R2_male_fh_PI_mfts[[fh]][,ik,ij],
                                                R3_male_fh_PI_mfts[[fh]][,ik,ij], R4_male_fh_PI_mfts[[fh]][,ik,ij],
                                                R5_male_fh_PI_mfts[[fh]][,ik,ij], R6_male_fh_PI_mfts[[fh]][,ik,ij],
                                                R7_male_fh_PI_mfts[[fh]][,ik,ij], R8_male_fh_PI_mfts[[fh]][,ik,ij],
                                                
                                                P1_total_fh_PI_mfts[[fh]][,ik,ij],   P2_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P3_total_fh_PI_mfts[[fh]][,ik,ij],   P4_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P5_total_fh_PI_mfts[[fh]][,ik,ij],   P6_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P7_total_fh_PI_mfts[[fh]][,ik,ij],   P8_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P9_total_fh_PI_mfts[[fh]][,ik,ij],   P10_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P11_total_fh_PI_mfts[[fh]][,ik,ij],  P12_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P13_total_fh_PI_mfts[[fh]][,ik,ij],  P14_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P15_total_fh_PI_mfts[[fh]][,ik,ij],  P16_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P17_total_fh_PI_mfts[[fh]][,ik,ij],  P18_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P19_total_fh_PI_mfts[[fh]][,ik,ij],  P20_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P21_total_fh_PI_mfts[[fh]][,ik,ij],  P22_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P23_total_fh_PI_mfts[[fh]][,ik,ij],  P24_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P25_total_fh_PI_mfts[[fh]][,ik,ij],  P26_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P27_total_fh_PI_mfts[[fh]][,ik,ij],  P28_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P29_total_fh_PI_mfts[[fh]][,ik,ij],  P30_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P31_total_fh_PI_mfts[[fh]][,ik,ij],  P32_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P33_total_fh_PI_mfts[[fh]][,ik,ij],  P34_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P35_total_fh_PI_mfts[[fh]][,ik,ij],  P36_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P37_total_fh_PI_mfts[[fh]][,ik,ij],  P38_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P39_total_fh_PI_mfts[[fh]][,ik,ij],  P40_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P41_total_fh_PI_mfts[[fh]][,ik,ij],  P42_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P43_total_fh_PI_mfts[[fh]][,ik,ij],  P44_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P45_total_fh_PI_mfts[[fh]][,ik,ij],  P46_total_fh_PI_mfts[[fh]][,ik,ij],
                                                P47_total_fh_PI_mfts[[fh]][,ik,ij],
                                                
                                                Hokkaido_female_fh_PI_mfts[[fh]][,ik,ij],  Hokkaido_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Aomori_female_fh_PI_mfts[[fh]][,ik,ij],    Aomori_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Iwate_female_fh_PI_mfts[[fh]][,ik,ij],     Iwate_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Miyagi_female_fh_PI_mfts[[fh]][,ik,ij],    Miyagi_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Akita_female_fh_PI_mfts[[fh]][,ik,ij],     Akita_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Yamagata_female_fh_PI_mfts[[fh]][,ik,ij],  Yamagata_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Fukushima_female_fh_PI_mfts[[fh]][,ik,ij], Fukushima_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Ibaraki_female_fh_PI_mfts[[fh]][,ik,ij],   Ibaraki_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Tochigi_female_fh_PI_mfts[[fh]][,ik,ij],   Tochigi_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Gunma_female_fh_PI_mfts[[fh]][,ik,ij],     Gunma_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Saitama_female_fh_PI_mfts[[fh]][,ik,ij],   Saitama_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Chiba_female_fh_PI_mfts[[fh]][,ik,ij],     Chiba_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Tokyo_female_fh_PI_mfts[[fh]][,ik,ij],     Tokyo_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Kanagawa_female_fh_PI_mfts[[fh]][,ik,ij],  Kanagawa_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Niigata_female_fh_PI_mfts[[fh]][,ik,ij],   Niigata_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Toyama_female_fh_PI_mfts[[fh]][,ik,ij],    Toyama_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Ishikawa_female_fh_PI_mfts[[fh]][,ik,ij],  Ishikawa_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Fukui_female_fh_PI_mfts[[fh]][,ik,ij],     Fukui_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Yamanashi_female_fh_PI_mfts[[fh]][,ik,ij], Yamanashi_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Nagano_female_fh_PI_mfts[[fh]][,ik,ij],    Nagano_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Gifu_female_fh_PI_mfts[[fh]][,ik,ij],      Gifu_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Shizuoka_female_fh_PI_mfts[[fh]][,ik,ij],  Shizuoka_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Aichi_female_fh_PI_mfts[[fh]][,ik,ij],     Aichi_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Mie_female_fh_PI_mfts[[fh]][,ik,ij],       Mie_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Shiga_female_fh_PI_mfts[[fh]][,ik,ij],     Shiga_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Kyoto_female_fh_PI_mfts[[fh]][,ik,ij],     Kyoto_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Osaka_female_fh_PI_mfts[[fh]][,ik,ij],     Osaka_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Hyogo_female_fh_PI_mfts[[fh]][,ik,ij],     Hyogo_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Nara_female_fh_PI_mfts[[fh]][,ik,ij],      Nara_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Wakayama_female_fh_PI_mfts[[fh]][,ik,ij],  Wakayama_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Tottori_female_fh_PI_mfts[[fh]][,ik,ij],   Tottori_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Shimane_female_fh_PI_mfts[[fh]][,ik,ij],   Shimane_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Okayama_female_fh_PI_mfts[[fh]][,ik,ij],   Okayama_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Hiroshima_female_fh_PI_mfts[[fh]][,ik,ij], Hiroshima_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Yamaguchi_female_fh_PI_mfts[[fh]][,ik,ij], Yamaguchi_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Tokushima_female_fh_PI_mfts[[fh]][,ik,ij], Tokushima_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Kagawa_female_fh_PI_mfts[[fh]][,ik,ij],    Kagawa_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Ehime_female_fh_PI_mfts[[fh]][,ik,ij],     Ehime_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Kochi_female_fh_PI_mfts[[fh]][,ik,ij],     Kochi_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Fukuoka_female_fh_PI_mfts[[fh]][,ik,ij],   Fukuoka_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Saga_female_fh_PI_mfts[[fh]][,ik,ij],      Saga_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Nagasaki_female_fh_PI_mfts[[fh]][,ik,ij],  Nagasaki_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Kumamoto_female_fh_PI_mfts[[fh]][,ik,ij],  Kumamoto_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Oita_female_fh_PI_mfts[[fh]][,ik,ij],      Oita_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Miyazaki_female_fh_PI_mfts[[fh]][,ik,ij],  Miyazaki_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Kagoshima_female_fh_PI_mfts[[fh]][,ik,ij], Kagoshima_male_fh_PI_mfts[[fh]][,ik,ij],
                                                Okinawa_female_fh_PI_mfts[[fh]][,ik,ij],   Okinawa_male_fh_PI_mfts[[fh]][,ik,ij]))
        }
    }
    return(prefecture_fh_PI)
}


Japan_total_PI_indicator_mfts = Japan_female_PI_indicator_mfts = Japan_male_PI_indicator_mfts =
R1_total_PI_indicator_mfts = R2_total_PI_indicator_mfts = R3_total_PI_indicator_mfts = R4_total_PI_indicator_mfts =
R5_total_PI_indicator_mfts = R6_total_PI_indicator_mfts = R7_total_PI_indicator_mfts = R8_total_PI_indicator_mfts =
R1_female_PI_indicator_mfts = R2_female_PI_indicator_mfts = R3_female_PI_indicator_mfts = R4_female_PI_indicator_mfts =
R5_female_PI_indicator_mfts = R6_female_PI_indicator_mfts = R7_female_PI_indicator_mfts = R8_female_PI_indicator_mfts =
R1_male_PI_indicator_mfts = R2_male_PI_indicator_mfts = R3_male_PI_indicator_mfts = R4_male_PI_indicator_mfts =
R5_male_PI_indicator_mfts = R6_male_PI_indicator_mfts = R7_male_PI_indicator_mfts = R8_male_PI_indicator_mfts =
    
Hokkaido_total_PI_indicator_mfts = Aomori_total_PI_indicator_mfts = Iwate_total_PI_indicator_mfts = Miyagi_total_PI_indicator_mfts = Akita_total_PI_indicator_mfts =
Yamagata_total_PI_indicator_mfts = Fukushima_total_PI_indicator_mfts = Ibaraki_total_PI_indicator_mfts = Tochigi_total_PI_indicator_mfts = Gunma_total_PI_indicator_mfts =
Saitama_total_PI_indicator_mfts = Chiba_total_PI_indicator_mfts = Tokyo_total_PI_indicator_mfts = Kanagawa_total_PI_indicator_mfts = Niigata_total_PI_indicator_mfts =
Toyama_total_PI_indicator_mfts = Ishikawa_total_PI_indicator_mfts = Fukui_total_PI_indicator_mfts = Yamanashi_total_PI_indicator_mfts = Nagano_total_PI_indicator_mfts =
Gifu_total_PI_indicator_mfts = Shizuoka_total_PI_indicator_mfts = Aichi_total_PI_indicator_mfts = Mie_total_PI_indicator_mfts = Shiga_total_PI_indicator_mfts =
Kyoto_total_PI_indicator_mfts = Osaka_total_PI_indicator_mfts = Hyogo_total_PI_indicator_mfts = Nara_total_PI_indicator_mfts = Wakayama_total_PI_indicator_mfts =
Tottori_total_PI_indicator_mfts = Shimane_total_PI_indicator_mfts = Okayama_total_PI_indicator_mfts = Hiroshima_total_PI_indicator_mfts = Yamaguchi_total_PI_indicator_mfts =
Tokushima_total_PI_indicator_mfts = Kagawa_total_PI_indicator_mfts = Ehime_total_PI_indicator_mfts = Kochi_total_PI_indicator_mfts = Fukuoka_total_PI_indicator_mfts =
Saga_total_PI_indicator_mfts = Nagasaki_total_PI_indicator_mfts = Kumamoto_total_PI_indicator_mfts = Oita_total_PI_indicator_mfts = Miyazaki_total_PI_indicator_mfts =
Kagoshima_total_PI_indicator_mfts = Okinawa_total_PI_indicator_mfts =
    
Hokkaido_female_PI_indicator_mfts = Aomori_female_PI_indicator_mfts = Iwate_female_PI_indicator_mfts = Miyagi_female_PI_indicator_mfts = Akita_female_PI_indicator_mfts =
Yamagata_female_PI_indicator_mfts = Fukushima_female_PI_indicator_mfts = Ibaraki_female_PI_indicator_mfts = Tochigi_female_PI_indicator_mfts = Gunma_female_PI_indicator_mfts =
Saitama_female_PI_indicator_mfts = Chiba_female_PI_indicator_mfts = Tokyo_female_PI_indicator_mfts = Kanagawa_female_PI_indicator_mfts = Niigata_female_PI_indicator_mfts =
Toyama_female_PI_indicator_mfts = Ishikawa_female_PI_indicator_mfts = Fukui_female_PI_indicator_mfts = Yamanashi_female_PI_indicator_mfts = Nagano_female_PI_indicator_mfts =
Gifu_female_PI_indicator_mfts = Shizuoka_female_PI_indicator_mfts = Aichi_female_PI_indicator_mfts = Mie_female_PI_indicator_mfts = Shiga_female_PI_indicator_mfts =
Kyoto_female_PI_indicator_mfts = Osaka_female_PI_indicator_mfts = Hyogo_female_PI_indicator_mfts = Nara_female_PI_indicator_mfts = Wakayama_female_PI_indicator_mfts =
Tottori_female_PI_indicator_mfts = Shimane_female_PI_indicator_mfts = Okayama_female_PI_indicator_mfts = Hiroshima_female_PI_indicator_mfts = Yamaguchi_female_PI_indicator_mfts =
Tokushima_female_PI_indicator_mfts = Kagawa_female_PI_indicator_mfts = Ehime_female_PI_indicator_mfts = Kochi_female_PI_indicator_mfts = Fukuoka_female_PI_indicator_mfts =
Saga_female_PI_indicator_mfts = Nagasaki_female_PI_indicator_mfts = Kumamoto_female_PI_indicator_mfts = Oita_female_PI_indicator_mfts = Miyazaki_female_PI_indicator_mfts =
Kagoshima_female_PI_indicator_mfts = Okinawa_female_PI_indicator_mfts =
    
Hokkaido_male_PI_indicator_mfts = Aomori_male_PI_indicator_mfts = Iwate_male_PI_indicator_mfts = Miyagi_male_PI_indicator_mfts = Akita_male_PI_indicator_mfts =
Yamagata_male_PI_indicator_mfts = Fukushima_male_PI_indicator_mfts = Ibaraki_male_PI_indicator_mfts = Tochigi_male_PI_indicator_mfts = Gunma_male_PI_indicator_mfts =
Saitama_male_PI_indicator_mfts = Chiba_male_PI_indicator_mfts = Tokyo_male_PI_indicator_mfts = Kanagawa_male_PI_indicator_mfts = Niigata_male_PI_indicator_mfts =
Toyama_male_PI_indicator_mfts = Ishikawa_male_PI_indicator_mfts = Fukui_male_PI_indicator_mfts = Yamanashi_male_PI_indicator_mfts = Nagano_male_PI_indicator_mfts =
Gifu_male_PI_indicator_mfts = Shizuoka_male_PI_indicator_mfts = Aichi_male_PI_indicator_mfts = Mie_male_PI_indicator_mfts = Shiga_male_PI_indicator_mfts =
Kyoto_male_PI_indicator_mfts = Osaka_male_PI_indicator_mfts = Hyogo_male_PI_indicator_mfts = Nara_male_PI_indicator_mfts = Wakayama_male_PI_indicator_mfts =
Tottori_male_PI_indicator_mfts = Shimane_male_PI_indicator_mfts = Okayama_male_PI_indicator_mfts = Hiroshima_male_PI_indicator_mfts = Yamaguchi_male_PI_indicator_mfts =
Tokushima_male_PI_indicator_mfts = Kagawa_male_PI_indicator_mfts = Ehime_male_PI_indicator_mfts = Kochi_male_PI_indicator_mfts = Fukuoka_male_PI_indicator_mfts =
Saga_male_PI_indicator_mfts = Nagasaki_male_PI_indicator_mfts = Kumamoto_male_PI_indicator_mfts = Oita_male_PI_indicator_mfts = Miyazaki_male_PI_indicator_mfts =
Kagoshima_male_PI_indicator_mfts = Okinawa_male_PI_indicator_mfts = vector("numeric", 15)
for(ik in 1:15)
{
    Japan_total_PI_indicator_mfts[ik] = any(is.na(exp(Japan_total_fh_PI_mfts[[ik]])))
    Japan_female_PI_indicator_mfts[ik] = any(is.na(exp(Japan_female_fh_PI_mfts[[ik]])))
    Japan_male_PI_indicator_mfts[ik] = any(is.na(exp(Japan_male_fh_PI_mfts[[ik]])))
    
    R1_total_PI_indicator_mfts[ik] = any(is.na(exp(R1_total_fh_PI_mfts[[ik]])))
    R2_total_PI_indicator_mfts[ik] = any(is.na(exp(R2_total_fh_PI_mfts[[ik]])))
    R3_total_PI_indicator_mfts[ik] = any(is.na(exp(R3_total_fh_PI_mfts[[ik]])))
    R4_total_PI_indicator_mfts[ik] = any(is.na(exp(R4_total_fh_PI_mfts[[ik]])))
    R5_total_PI_indicator_mfts[ik] = any(is.na(exp(R5_total_fh_PI_mfts[[ik]])))
    R6_total_PI_indicator_mfts[ik] = any(is.na(exp(R6_total_fh_PI_mfts[[ik]])))
    R7_total_PI_indicator_mfts[ik] = any(is.na(exp(R7_total_fh_PI_mfts[[ik]])))
    R8_total_PI_indicator_mfts[ik] = any(is.na(exp(R8_total_fh_PI_mfts[[ik]])))
    
    R1_female_PI_indicator_mfts[ik] = any(is.na(exp(R1_female_fh_PI_mfts[[ik]])))
    R2_female_PI_indicator_mfts[ik] = any(is.na(exp(R2_female_fh_PI_mfts[[ik]])))
    R3_female_PI_indicator_mfts[ik] = any(is.na(exp(R3_female_fh_PI_mfts[[ik]])))
    R4_female_PI_indicator_mfts[ik] = any(is.na(exp(R4_female_fh_PI_mfts[[ik]])))
    R5_female_PI_indicator_mfts[ik] = any(is.na(exp(R5_female_fh_PI_mfts[[ik]])))
    R6_female_PI_indicator_mfts[ik] = any(is.na(exp(R6_female_fh_PI_mfts[[ik]])))
    R7_female_PI_indicator_mfts[ik] = any(is.na(exp(R7_female_fh_PI_mfts[[ik]])))
    R8_female_PI_indicator_mfts[ik] = any(is.na(exp(R8_female_fh_PI_mfts[[ik]])))
    
    R1_male_PI_indicator_mfts[ik] = any(is.na(exp(R1_male_fh_PI_mfts[[ik]])))
    R2_male_PI_indicator_mfts[ik] = any(is.na(exp(R2_male_fh_PI_mfts[[ik]])))
    R3_male_PI_indicator_mfts[ik] = any(is.na(exp(R3_male_fh_PI_mfts[[ik]])))
    R4_male_PI_indicator_mfts[ik] = any(is.na(exp(R4_male_fh_PI_mfts[[ik]])))
    R5_male_PI_indicator_mfts[ik] = any(is.na(exp(R5_male_fh_PI_mfts[[ik]])))
    R6_male_PI_indicator_mfts[ik] = any(is.na(exp(R6_male_fh_PI_mfts[[ik]])))
    R7_male_PI_indicator_mfts[ik] = any(is.na(exp(R7_male_fh_PI_mfts[[ik]])))
    R8_male_PI_indicator_mfts[ik] = any(is.na(exp(R8_male_fh_PI_mfts[[ik]])))
    
    Hokkaido_total_PI_indicator_mfts[ik] = any(is.na(exp(Hokkaido_total_fh_PI_mfts[[ik]])))
    Aomori_total_PI_indicator_mfts[ik] = any(is.na(exp(Aomori_total_fh_PI_mfts[[ik]])))
    Iwate_total_PI_indicator_mfts[ik] = any(is.na(exp(Iwate_total_fh_PI_mfts[[ik]])))
    Miyagi_total_PI_indicator_mfts[ik] = any(is.na(exp(Miyagi_total_fh_PI_mfts[[ik]])))
    Akita_total_PI_indicator_mfts[ik] = any(is.na(exp(Akita_total_fh_PI_mfts[[ik]])))
    Yamagata_total_PI_indicator_mfts[ik] = any(is.na(exp(Yamagata_total_fh_PI_mfts[[ik]])))
    Fukushima_total_PI_indicator_mfts[ik] = any(is.na(exp(Fukushima_total_fh_PI_mfts[[ik]])))
    Ibaraki_total_PI_indicator_mfts[ik] = any(is.na(exp(Ibaraki_total_fh_PI_mfts[[ik]])))
    Tochigi_total_PI_indicator_mfts[ik] = any(is.na(exp(Tochigi_total_fh_PI_mfts[[ik]])))
    Gunma_total_PI_indicator_mfts[ik] = any(is.na(exp(Gunma_total_fh_PI_mfts[[ik]])))
    Saitama_total_PI_indicator_mfts[ik] = any(is.na(exp(Saitama_total_fh_PI_mfts[[ik]])))
    Chiba_total_PI_indicator_mfts[ik] = any(is.na(exp(Chiba_total_fh_PI_mfts[[ik]])))
    Tokyo_total_PI_indicator_mfts[ik] = any(is.na(exp(Tokyo_total_fh_PI_mfts[[ik]])))
    Kanagawa_total_PI_indicator_mfts[ik] = any(is.na(exp(Kanagawa_total_fh_PI_mfts[[ik]])))
    Niigata_total_PI_indicator_mfts[ik] = any(is.na(exp(Niigata_total_fh_PI_mfts[[ik]])))
    Toyama_total_PI_indicator_mfts[ik] = any(is.na(exp(Toyama_total_fh_PI_mfts[[ik]])))
    Ishikawa_total_PI_indicator_mfts[ik] = any(is.na(exp(Ishikawa_total_fh_PI_mfts[[ik]])))
    Fukui_total_PI_indicator_mfts[ik] = any(is.na(exp(Fukui_total_fh_PI_mfts[[ik]])))
    Yamanashi_total_PI_indicator_mfts[ik] = any(is.na(exp(Yamanashi_total_fh_PI_mfts[[ik]])))
    Nagano_total_PI_indicator_mfts[ik] = any(is.na(exp(Nagano_total_fh_PI_mfts[[ik]])))
    Gifu_total_PI_indicator_mfts[ik] = any(is.na(exp(Gifu_total_fh_PI_mfts[[ik]])))
    Shizuoka_total_PI_indicator_mfts[ik] = any(is.na(exp(Shizuoka_total_fh_PI_mfts[[ik]])))
    Aichi_total_PI_indicator_mfts[ik] = any(is.na(exp(Aichi_total_fh_PI_mfts[[ik]])))
    Mie_total_PI_indicator_mfts[ik] = any(is.na(exp(Mie_total_fh_PI_mfts[[ik]])))
    Shiga_total_PI_indicator_mfts[ik] = any(is.na(exp(Shiga_total_fh_PI_mfts[[ik]])))
    Kyoto_total_PI_indicator_mfts[ik] = any(is.na(exp(Kyoto_total_fh_PI_mfts[[ik]])))
    Osaka_total_PI_indicator_mfts[ik] = any(is.na(exp(Osaka_total_fh_PI_mfts[[ik]])))
    Hyogo_total_PI_indicator_mfts[ik] = any(is.na(exp(Hyogo_total_fh_PI_mfts[[ik]])))
    Nara_total_PI_indicator_mfts[ik] = any(is.na(exp(Nara_total_fh_PI_mfts[[ik]])))
    Wakayama_total_PI_indicator_mfts[ik] = any(is.na(exp(Wakayama_total_fh_PI_mfts[[ik]])))
    Tottori_total_PI_indicator_mfts[ik] = any(is.na(exp(Tottori_total_fh_PI_mfts[[ik]])))
    Shimane_total_PI_indicator_mfts[ik] = any(is.na(exp(Shimane_total_fh_PI_mfts[[ik]])))
    Okayama_total_PI_indicator_mfts[ik] = any(is.na(exp(Okayama_total_fh_PI_mfts[[ik]])))
    Hiroshima_total_PI_indicator_mfts[ik] = any(is.na(exp(Hiroshima_total_fh_PI_mfts[[ik]])))
    Yamaguchi_total_PI_indicator_mfts[ik] = any(is.na(exp(Yamaguchi_total_fh_PI_mfts[[ik]])))
    Tokushima_total_PI_indicator_mfts[ik] = any(is.na(exp(Tokushima_total_fh_PI_mfts[[ik]])))
    Kagawa_total_PI_indicator_mfts[ik] = any(is.na(exp(Kagawa_total_fh_PI_mfts[[ik]])))
    Ehime_total_PI_indicator_mfts[ik] = any(is.na(exp(Ehime_total_fh_PI_mfts[[ik]])))
    Kochi_total_PI_indicator_mfts[ik] = any(is.na(exp(Kochi_total_fh_PI_mfts[[ik]])))
    Fukuoka_total_PI_indicator_mfts[ik] = any(is.na(exp(Fukuoka_total_fh_PI_mfts[[ik]])))
    Saga_total_PI_indicator_mfts[ik] = any(is.na(exp(Saga_total_fh_PI_mfts[[ik]])))
    Nagasaki_total_PI_indicator_mfts[ik] = any(is.na(exp(Nagasaki_total_fh_PI_mfts[[ik]])))
    Kumamoto_total_PI_indicator_mfts[ik] = any(is.na(exp(Kumamoto_total_fh_PI_mfts[[ik]])))
    Oita_total_PI_indicator_mfts[ik] = any(is.na(exp(Oita_total_fh_PI_mfts[[ik]])))
    Miyazaki_total_PI_indicator_mfts[ik] = any(is.na(exp(Miyazaki_total_fh_PI_mfts[[ik]])))
    Kagoshima_total_PI_indicator_mfts[ik] = any(is.na(exp(Kagoshima_total_fh_PI_mfts[[ik]])))
    Okinawa_total_PI_indicator_mfts[ik] = any(is.na(exp(Okinawa_total_fh_PI_mfts[[ik]])))
    
    Hokkaido_female_PI_indicator_mfts[ik] = any(is.na(exp(Hokkaido_female_fh_PI_mfts[[ik]])))
    Aomori_female_PI_indicator_mfts[ik] = any(is.na(exp(Aomori_female_fh_PI_mfts[[ik]])))
    Iwate_female_PI_indicator_mfts[ik] = any(is.na(exp(Iwate_female_fh_PI_mfts[[ik]])))
    Miyagi_female_PI_indicator_mfts[ik] = any(is.na(exp(Miyagi_female_fh_PI_mfts[[ik]])))
    Akita_female_PI_indicator_mfts[ik] = any(is.na(exp(Akita_female_fh_PI_mfts[[ik]])))
    Yamagata_female_PI_indicator_mfts[ik] = any(is.na(exp(Yamagata_female_fh_PI_mfts[[ik]])))
    Fukushima_female_PI_indicator_mfts[ik] = any(is.na(exp(Fukushima_female_fh_PI_mfts[[ik]])))
    Ibaraki_female_PI_indicator_mfts[ik] = any(is.na(exp(Ibaraki_female_fh_PI_mfts[[ik]])))
    Tochigi_female_PI_indicator_mfts[ik] = any(is.na(exp(Tochigi_female_fh_PI_mfts[[ik]])))
    Gunma_female_PI_indicator_mfts[ik] = any(is.na(exp(Gunma_female_fh_PI_mfts[[ik]])))
    Saitama_female_PI_indicator_mfts[ik] = any(is.na(exp(Saitama_female_fh_PI_mfts[[ik]])))
    Chiba_female_PI_indicator_mfts[ik] = any(is.na(exp(Chiba_female_fh_PI_mfts[[ik]])))
    Tokyo_female_PI_indicator_mfts[ik] = any(is.na(exp(Tokyo_female_fh_PI_mfts[[ik]])))
    Kanagawa_female_PI_indicator_mfts[ik] = any(is.na(exp(Kanagawa_female_fh_PI_mfts[[ik]])))
    Niigata_female_PI_indicator_mfts[ik] = any(is.na(exp(Niigata_female_fh_PI_mfts[[ik]])))
    Toyama_female_PI_indicator_mfts[ik] = any(is.na(exp(Toyama_female_fh_PI_mfts[[ik]])))
    Ishikawa_female_PI_indicator_mfts[ik] = any(is.na(exp(Ishikawa_female_fh_PI_mfts[[ik]])))
    Fukui_female_PI_indicator_mfts[ik] = any(is.na(exp(Fukui_female_fh_PI_mfts[[ik]])))
    Yamanashi_female_PI_indicator_mfts[ik] = any(is.na(exp(Yamanashi_female_fh_PI_mfts[[ik]])))
    Nagano_female_PI_indicator_mfts[ik] = any(is.na(exp(Nagano_female_fh_PI_mfts[[ik]])))
    Gifu_female_PI_indicator_mfts[ik] = any(is.na(exp(Gifu_female_fh_PI_mfts[[ik]])))
    Shizuoka_female_PI_indicator_mfts[ik] = any(is.na(exp(Shizuoka_female_fh_PI_mfts[[ik]])))
    Aichi_female_PI_indicator_mfts[ik] = any(is.na(exp(Aichi_female_fh_PI_mfts[[ik]])))
    Mie_female_PI_indicator_mfts[ik] = any(is.na(exp(Mie_female_fh_PI_mfts[[ik]])))
    Shiga_female_PI_indicator_mfts[ik] = any(is.na(exp(Shiga_female_fh_PI_mfts[[ik]])))
    Kyoto_female_PI_indicator_mfts[ik] = any(is.na(exp(Kyoto_female_fh_PI_mfts[[ik]])))
    Osaka_female_PI_indicator_mfts[ik] = any(is.na(exp(Osaka_female_fh_PI_mfts[[ik]])))
    Hyogo_female_PI_indicator_mfts[ik] = any(is.na(exp(Hyogo_female_fh_PI_mfts[[ik]])))
    Nara_female_PI_indicator_mfts[ik] = any(is.na(exp(Nara_female_fh_PI_mfts[[ik]])))
    Wakayama_female_PI_indicator_mfts[ik] = any(is.na(exp(Wakayama_female_fh_PI_mfts[[ik]])))
    Tottori_female_PI_indicator_mfts[ik] = any(is.na(exp(Tottori_female_fh_PI_mfts[[ik]])))
    Shimane_female_PI_indicator_mfts[ik] = any(is.na(exp(Shimane_female_fh_PI_mfts[[ik]])))
    Okayama_female_PI_indicator_mfts[ik] = any(is.na(exp(Okayama_female_fh_PI_mfts[[ik]])))
    Hiroshima_female_PI_indicator_mfts[ik] = any(is.na(exp(Hiroshima_female_fh_PI_mfts[[ik]])))
    Yamaguchi_female_PI_indicator_mfts[ik] = any(is.na(exp(Yamaguchi_female_fh_PI_mfts[[ik]])))
    Tokushima_female_PI_indicator_mfts[ik] = any(is.na(exp(Tokushima_female_fh_PI_mfts[[ik]])))
    Kagawa_female_PI_indicator_mfts[ik] = any(is.na(exp(Kagawa_female_fh_PI_mfts[[ik]])))
    Ehime_female_PI_indicator_mfts[ik] = any(is.na(exp(Ehime_female_fh_PI_mfts[[ik]])))
    Kochi_female_PI_indicator_mfts[ik] = any(is.na(exp(Kochi_female_fh_PI_mfts[[ik]])))
    Fukuoka_female_PI_indicator_mfts[ik] = any(is.na(exp(Fukuoka_female_fh_PI_mfts[[ik]])))
    Saga_female_PI_indicator_mfts[ik] = any(is.na(exp(Saga_female_fh_PI_mfts[[ik]])))
    Nagasaki_female_PI_indicator_mfts[ik] = any(is.na(exp(Nagasaki_female_fh_PI_mfts[[ik]])))
    Kumamoto_female_PI_indicator_mfts[ik] = any(is.na(exp(Kumamoto_female_fh_PI_mfts[[ik]])))
    Oita_female_PI_indicator_mfts[ik] = any(is.na(exp(Oita_female_fh_PI_mfts[[ik]])))
    Miyazaki_female_PI_indicator_mfts[ik] = any(is.na(exp(Miyazaki_female_fh_PI_mfts[[ik]])))
    Kagoshima_female_PI_indicator_mfts[ik] = any(is.na(exp(Kagoshima_female_fh_PI_mfts[[ik]])))
    Okinawa_female_PI_indicator_mfts[ik] = any(is.na(exp(Okinawa_female_fh_PI_mfts[[ik]])))
    
    Hokkaido_male_PI_indicator_mfts[ik] = any(is.na(exp(Hokkaido_male_fh_PI_mfts[[ik]])))
    Aomori_male_PI_indicator_mfts[ik] = any(is.na(exp(Aomori_male_fh_PI_mfts[[ik]])))
    Iwate_male_PI_indicator_mfts[ik] = any(is.na(exp(Iwate_male_fh_PI_mfts[[ik]])))
    Miyagi_male_PI_indicator_mfts[ik] = any(is.na(exp(Miyagi_male_fh_PI_mfts[[ik]])))
    Akita_male_PI_indicator_mfts[ik] = any(is.na(exp(Akita_male_fh_PI_mfts[[ik]])))
    Yamagata_male_PI_indicator_mfts[ik] = any(is.na(exp(Yamagata_male_fh_PI_mfts[[ik]])))
    Fukushima_male_PI_indicator_mfts[ik] = any(is.na(exp(Fukushima_male_fh_PI_mfts[[ik]])))
    Ibaraki_male_PI_indicator_mfts[ik] = any(is.na(exp(Ibaraki_male_fh_PI_mfts[[ik]])))
    Tochigi_male_PI_indicator_mfts[ik] = any(is.na(exp(Tochigi_male_fh_PI_mfts[[ik]])))
    Gunma_male_PI_indicator_mfts[ik] = any(is.na(exp(Gunma_male_fh_PI_mfts[[ik]])))
    Saitama_male_PI_indicator_mfts[ik] = any(is.na(exp(Saitama_male_fh_PI_mfts[[ik]])))
    Chiba_male_PI_indicator_mfts[ik] = any(is.na(exp(Chiba_male_fh_PI_mfts[[ik]])))
    Tokyo_male_PI_indicator_mfts[ik] = any(is.na(exp(Tokyo_male_fh_PI_mfts[[ik]])))
    Kanagawa_male_PI_indicator_mfts[ik] = any(is.na(exp(Kanagawa_male_fh_PI_mfts[[ik]])))
    Niigata_male_PI_indicator_mfts[ik] = any(is.na(exp(Niigata_male_fh_PI_mfts[[ik]])))
    Toyama_male_PI_indicator_mfts[ik] = any(is.na(exp(Toyama_male_fh_PI_mfts[[ik]])))
    Ishikawa_male_PI_indicator_mfts[ik] = any(is.na(exp(Ishikawa_male_fh_PI_mfts[[ik]])))
    Fukui_male_PI_indicator_mfts[ik] = any(is.na(exp(Fukui_male_fh_PI_mfts[[ik]])))
    Yamanashi_male_PI_indicator_mfts[ik] = any(is.na(exp(Yamanashi_male_fh_PI_mfts[[ik]])))
    Nagano_male_PI_indicator_mfts[ik] = any(is.na(exp(Nagano_male_fh_PI_mfts[[ik]])))
    Gifu_male_PI_indicator_mfts[ik] = any(is.na(exp(Gifu_male_fh_PI_mfts[[ik]])))
    Shizuoka_male_PI_indicator_mfts[ik] = any(is.na(exp(Shizuoka_male_fh_PI_mfts[[ik]])))
    Aichi_male_PI_indicator_mfts[ik] = any(is.na(exp(Aichi_male_fh_PI_mfts[[ik]])))
    Mie_male_PI_indicator_mfts[ik] = any(is.na(exp(Mie_male_fh_PI_mfts[[ik]])))
    Shiga_male_PI_indicator_mfts[ik] = any(is.na(exp(Shiga_male_fh_PI_mfts[[ik]])))
    Kyoto_male_PI_indicator_mfts[ik] = any(is.na(exp(Kyoto_male_fh_PI_mfts[[ik]])))
    Osaka_male_PI_indicator_mfts[ik] = any(is.na(exp(Osaka_male_fh_PI_mfts[[ik]])))
    Hyogo_male_PI_indicator_mfts[ik] = any(is.na(exp(Hyogo_male_fh_PI_mfts[[ik]])))
    Nara_male_PI_indicator_mfts[ik] = any(is.na(exp(Nara_male_fh_PI_mfts[[ik]])))
    Wakayama_male_PI_indicator_mfts[ik] = any(is.na(exp(Wakayama_male_fh_PI_mfts[[ik]])))
    Tottori_male_PI_indicator_mfts[ik] = any(is.na(exp(Tottori_male_fh_PI_mfts[[ik]])))
    Shimane_male_PI_indicator_mfts[ik] = any(is.na(exp(Shimane_male_fh_PI_mfts[[ik]])))
    Okayama_male_PI_indicator_mfts[ik] = any(is.na(exp(Okayama_male_fh_PI_mfts[[ik]])))
    Hiroshima_male_PI_indicator_mfts[ik] = any(is.na(exp(Hiroshima_male_fh_PI_mfts[[ik]])))
    Yamaguchi_male_PI_indicator_mfts[ik] = any(is.na(exp(Yamaguchi_male_fh_PI_mfts[[ik]])))
    Tokushima_male_PI_indicator_mfts[ik] = any(is.na(exp(Tokushima_male_fh_PI_mfts[[ik]])))
    Kagawa_male_PI_indicator_mfts[ik] = any(is.na(exp(Kagawa_male_fh_PI_mfts[[ik]])))
    Ehime_male_PI_indicator_mfts[ik] = any(is.na(exp(Ehime_male_fh_PI_mfts[[ik]])))
    Kochi_male_PI_indicator_mfts[ik] = any(is.na(exp(Kochi_male_fh_PI_mfts[[ik]])))
    Fukuoka_male_PI_indicator_mfts[ik] = any(is.na(exp(Fukuoka_male_fh_PI_mfts[[ik]])))
    Saga_male_PI_indicator_mfts[ik] = any(is.na(exp(Saga_male_fh_PI_mfts[[ik]])))
    Nagasaki_male_PI_indicator_mfts[ik] = any(is.na(exp(Nagasaki_male_fh_PI_mfts[[ik]])))
    Kumamoto_male_PI_indicator_mfts[ik] = any(is.na(exp(Kumamoto_male_fh_PI_mfts[[ik]])))
    Oita_male_PI_indicator_mfts[ik] = any(is.na(exp(Oita_male_fh_PI_mfts[[ik]])))
    Miyazaki_male_PI_indicator_mfts[ik] = any(is.na(exp(Miyazaki_male_fh_PI_mfts[[ik]])))
    Kagoshima_male_PI_indicator_mfts[ik] = any(is.na(exp(Kagoshima_male_fh_PI_mfts[[ik]])))
    Okinawa_male_PI_indicator_mfts[ik] = any(is.na(exp(Okinawa_male_fh_PI_mfts[[ik]])))
}

Japan_PI_indicator_mfts = cbind(Japan_total_PI_indicator_mfts, Japan_female_PI_indicator_mfts, Japan_male_PI_indicator_mfts,
                                R1_total_PI_indicator_mfts, R2_total_PI_indicator_mfts, R3_total_PI_indicator_mfts,
                                R4_total_PI_indicator_mfts, R5_total_PI_indicator_mfts, R6_total_PI_indicator_mfts, R7_total_PI_indicator_mfts, R8_total_PI_indicator_mfts,
                                R1_female_PI_indicator_mfts, R2_female_PI_indicator_mfts,
                                R3_female_PI_indicator_mfts, R4_female_PI_indicator_mfts, R5_female_PI_indicator_mfts, R6_female_PI_indicator_mfts, R7_female_PI_indicator_mfts, R8_female_PI_indicator_mfts,
                                R1_male_PI_indicator_mfts,
                                R2_male_PI_indicator_mfts, R3_male_PI_indicator_mfts, R4_male_PI_indicator_mfts, R5_male_PI_indicator_mfts, R6_male_PI_indicator_mfts, R7_male_PI_indicator_mfts, R8_male_PI_indicator_mfts, Hokkaido_total_PI_indicator_mfts, Aomori_total_PI_indicator_mfts, Iwate_total_PI_indicator_mfts, Miyagi_total_PI_indicator_mfts, Akita_total_PI_indicator_mfts,
                                Yamagata_total_PI_indicator_mfts, Fukushima_total_PI_indicator_mfts, Ibaraki_total_PI_indicator_mfts, Tochigi_total_PI_indicator_mfts, Gunma_total_PI_indicator_mfts,
                                Saitama_total_PI_indicator_mfts, Chiba_total_PI_indicator_mfts, Tokyo_total_PI_indicator_mfts, Kanagawa_total_PI_indicator_mfts, Niigata_total_PI_indicator_mfts,
                                Toyama_total_PI_indicator_mfts, Ishikawa_total_PI_indicator_mfts, Fukui_total_PI_indicator_mfts, Yamanashi_total_PI_indicator_mfts, Nagano_total_PI_indicator_mfts,
                                Gifu_total_PI_indicator_mfts, Shizuoka_total_PI_indicator_mfts, Aichi_total_PI_indicator_mfts, Mie_total_PI_indicator_mfts, Shiga_total_PI_indicator_mfts,
                                Kyoto_total_PI_indicator_mfts, Osaka_total_PI_indicator_mfts, Hyogo_total_PI_indicator_mfts, Nara_total_PI_indicator_mfts, Wakayama_total_PI_indicator_mfts,
                                Tottori_total_PI_indicator_mfts, Shimane_total_PI_indicator_mfts, Okayama_total_PI_indicator_mfts, Hiroshima_total_PI_indicator_mfts, Yamaguchi_total_PI_indicator_mfts,
                                Tokushima_total_PI_indicator_mfts, Kagawa_total_PI_indicator_mfts, Ehime_total_PI_indicator_mfts, Kochi_total_PI_indicator_mfts, Fukuoka_total_PI_indicator_mfts,
                                Saga_total_PI_indicator_mfts, Nagasaki_total_PI_indicator_mfts, Kumamoto_total_PI_indicator_mfts, Oita_total_PI_indicator_mfts, Miyazaki_total_PI_indicator_mfts,
                                Kagoshima_total_PI_indicator_mfts, Okinawa_total_PI_indicator_mfts, Hokkaido_female_PI_indicator_mfts, Aomori_female_PI_indicator_mfts, Iwate_female_PI_indicator_mfts, Miyagi_female_PI_indicator_mfts, Akita_female_PI_indicator_mfts,
                                Yamagata_female_PI_indicator_mfts, Fukushima_female_PI_indicator_mfts, Ibaraki_female_PI_indicator_mfts, Tochigi_female_PI_indicator_mfts, Gunma_female_PI_indicator_mfts,
                                Saitama_female_PI_indicator_mfts, Chiba_female_PI_indicator_mfts, Tokyo_female_PI_indicator_mfts, Kanagawa_female_PI_indicator_mfts, Niigata_female_PI_indicator_mfts,
                                Toyama_female_PI_indicator_mfts, Ishikawa_female_PI_indicator_mfts, Fukui_female_PI_indicator_mfts, Yamanashi_female_PI_indicator_mfts, Nagano_female_PI_indicator_mfts,
                                Gifu_female_PI_indicator_mfts, Shizuoka_female_PI_indicator_mfts, Aichi_female_PI_indicator_mfts, Mie_female_PI_indicator_mfts, Shiga_female_PI_indicator_mfts,
                                Kyoto_female_PI_indicator_mfts, Osaka_female_PI_indicator_mfts, Hyogo_female_PI_indicator_mfts, Nara_female_PI_indicator_mfts, Wakayama_female_PI_indicator_mfts,
                                Tottori_female_PI_indicator_mfts, Shimane_female_PI_indicator_mfts, Okayama_female_PI_indicator_mfts, Hiroshima_female_PI_indicator_mfts, Yamaguchi_female_PI_indicator_mfts,
                                Tokushima_female_PI_indicator_mfts, Kagawa_female_PI_indicator_mfts, Ehime_female_PI_indicator_mfts, Kochi_female_PI_indicator_mfts, Fukuoka_female_PI_indicator_mfts,
                                Saga_female_PI_indicator_mfts, Nagasaki_female_PI_indicator_mfts, Kumamoto_female_PI_indicator_mfts, Oita_female_PI_indicator_mfts, Miyazaki_female_PI_indicator_mfts,
                                Kagoshima_female_PI_indicator_mfts, Okinawa_female_PI_indicator_mfts, Hokkaido_male_PI_indicator_mfts, Aomori_male_PI_indicator_mfts, Iwate_male_PI_indicator_mfts, Miyagi_male_PI_indicator_mfts, Akita_male_PI_indicator_mfts,
                                Yamagata_male_PI_indicator_mfts, Fukushima_male_PI_indicator_mfts, Ibaraki_male_PI_indicator_mfts, Tochigi_male_PI_indicator_mfts, Gunma_male_PI_indicator_mfts,
                                Saitama_male_PI_indicator_mfts, Chiba_male_PI_indicator_mfts, Tokyo_male_PI_indicator_mfts, Kanagawa_male_PI_indicator_mfts, Niigata_male_PI_indicator_mfts,
                                Toyama_male_PI_indicator_mfts, Ishikawa_male_PI_indicator_mfts, Fukui_male_PI_indicator_mfts, Yamanashi_male_PI_indicator_mfts, Nagano_male_PI_indicator_mfts,
                                Gifu_male_PI_indicator_mfts, Shizuoka_male_PI_indicator_mfts, Aichi_male_PI_indicator_mfts, Mie_male_PI_indicator_mfts, Shiga_male_PI_indicator_mfts,
                                Kyoto_male_PI_indicator_mfts, Osaka_male_PI_indicator_mfts, Hyogo_male_PI_indicator_mfts, Nara_male_PI_indicator_mfts, Wakayama_male_PI_indicator_mfts,
                                Tottori_male_PI_indicator_mfts, Shimane_male_PI_indicator_mfts, Okayama_male_PI_indicator_mfts, Hiroshima_male_PI_indicator_mfts, Yamaguchi_male_PI_indicator_mfts,
                                Tokushima_male_PI_indicator_mfts, Kagawa_male_PI_indicator_mfts, Ehime_male_PI_indicator_mfts, Kochi_male_PI_indicator_mfts, Fukuoka_male_PI_indicator_mfts,
                                Saga_male_PI_indicator_mfts, Nagasaki_male_PI_indicator_mfts, Kumamoto_male_PI_indicator_mfts, Oita_male_PI_indicator_mfts, Miyazaki_male_PI_indicator_mfts,
                                Kagoshima_male_PI_indicator_mfts, Okinawa_male_PI_indicator_mfts)


##################################################################
# one- to 15-step-ahead bootstrapped mortality samples (B = 1000)
##################################################################

PI_prefecture_h1to15_mfts = list()
for(ik in 1:15)
{
    PI_prefecture_h1to15_mfts[[ik]] = PI_prefecture_mfts(fh = ik)
    print(ik)
}

# kj: forecast horizon from h = 1 to 15
# age: age indexes from 1 to 41 (ages 60 to 100+)

BU_optim_hier_PI_mfts <- function(kj, age, hier_method = c("BU", "OLS"))
{
    hier_method = match.arg(hier_method)
    hier_fore = array(NA, dim = c(168, 2, (16 - kj)))
    
    summ_mat = Smat_fun(kj = kj, age = age)
    # ik: number of years in the forecasting period, it depends on kj
    for(ik in 1:(16 - kj))
    {
        hier = summ_mat[,,ik]
        if(hier_method == "BU")
        {
            for(ij in 1:2)
            {
                hier_fore[,ij,ik] = hier %*% (PI_prefecture_h1to15_mfts[[kj]])[age, ij, ik, 75:168]
            }
        }
        if(hier_method == "OLS")
        {
            for(ij in 1:2)
            {
                hier_fore[,ij,ik] = hier %*% ginv(t(hier) %*% hier) %*% t(hier) %*% (PI_prefecture_h1to15_mfts[[kj]])[age, ij, ik, ]
            }
        }
    }
    return(hier_fore)
}

#####
# BU
#####

BU_fun_mfts <- function(kj)
{
    dum = array(NA, dim = c(41, 168, 2, (16 - kj)))
    for(ij in 1:41)
    {
        dum[ij,,,] = BU_optim_hier_PI_mfts(kj = kj, age = ij, hier_method = "BU")
    }
    return(dum)
}

require(doMC)
registerDoMC(15)
BU_optim_hier_comb_mfts = foreach(kj = 1:15) %dopar% BU_fun_mfts(kj = kj)

######
# OLS
######

OLS_fun_mfts <- function(kj)
{
    dum = array(NA, dim = c(41, 168, 2, (16 - kj)))
    for(ij in 1:41)
    {
        dum[ij,,,] = BU_optim_hier_PI_mfts(kj = kj, age = ij, hier_method = "OLS")
    }
    return(dum)
}

OLS_hier_comb_mfts = list()
for(kjw in 1:15)
{
    OLS_hier_comb_mfts[[kjw]] = OLS_fun_mfts(kj = kjw)
    print(kjw)
}

######################
# Comb (equal weight)
######################

comb_hier_comb_mfts = list()
for(ik in 1:15)
{
    comb_hier_comb_mfts[[ik]] = (BU_optim_hier_comb_mfts[[ik]] + OLS_hier_comb_mfts[[ik]])/2
}

##############################
# Comb (average of midpoints)
##############################

comb_hier_comb_mfts_midpoints = list()
for(ik in 1:15)
{
    comb_hier_comb_mfts_midpoints[[ik]] = (apply(BU_optim_hier_comb_mfts[[ik]], c(1, 2, 4), mean) +
                                           apply(OLS_hier_comb_mfts[[ik]], c(1, 2, 4), mean))/2
}

comb_hier_comb_mfts_int_midpoints = list()
for(ik in 1:15)
{
    dum_lb = BU_optim_hier_comb_mfts[[ik]]
    dum_lb[,,2,] = OLS_hier_comb_mfts[[ik]][,,1,]
    dum_lb_agg = apply(dum_lb, c(1, 2, 4), min)
    
    dum_ub = BU_optim_hier_comb_mfts[[ik]]
    dum_ub[,,1,] = OLS_hier_comb_mfts[[ik]][,,2,]
    dum_ub_agg = apply(dum_ub, c(1, 2, 4), max)
    
    dum_agg = array(NA, dim = c(dim(dum_lb_agg)[1], dim(dum_lb_agg)[2], 2, dim(dum_lb_agg)[3]))
    dum_agg[,,1,] = dum_lb_agg
    dum_agg[,,2,] = dum_ub_agg
    comb_hier_comb_mfts_int_midpoints[[ik]] = dum_agg
    rm(dum_lb); rm(dum_ub); rm(dum_lb_agg); rm(dum_ub_agg); rm(dum_agg)
}

#########################################################################
# Calculate mean interval score for different levels of a hierarchy (BU)
#########################################################################

# Japan + Sex

BU_interval_score_Japan_total = BU_interval_score_Japan_female = BU_interval_score_Japan_male = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 0
    BU_interval_score_Japan_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Japan, series = "total",
                                                                fh = ik, index = 1)
    
    # Level 1
    BU_interval_score_Japan_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Japan, series = "female",
                                                                 fh = ik, index = 2)
    
    BU_interval_score_Japan_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Japan, series = "male",
                                                               fh = ik, index = 3)
    print(ik)
}

# Region (total)

BU_interval_score_R1_total = BU_interval_score_R2_total = BU_interval_score_R3_total = BU_interval_score_R4_total =
BU_interval_score_R5_total = BU_interval_score_R6_total = BU_interval_score_R7_total = BU_interval_score_R8_total = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 2
    BU_interval_score_R1_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R1, series = "total",
                                                             fh = ik, index = 4)
    
    BU_interval_score_R2_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R2, series = "total",
                                                             fh = ik, index = 5)
    
    BU_interval_score_R3_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R3, series = "total",
                                                             fh = ik, index = 6)
    
    BU_interval_score_R4_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R4, series = "total",
                                                             fh = ik, index = 7)
    
    BU_interval_score_R5_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R5, series = "total",
                                                             fh = ik, index = 8)
    
    BU_interval_score_R6_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R6, series = "total",
                                                             fh = ik, index = 9)
    
    BU_interval_score_R7_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R7, series = "total",
                                                             fh = ik, index = 10)
    
    BU_interval_score_R8_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R8, series = "total",
                                                             fh = ik, index = 11)
    print(ik)
}

# Region + Sex

BU_interval_score_R1_female = BU_interval_score_R2_female = BU_interval_score_R3_female = BU_interval_score_R4_female =
BU_interval_score_R5_female = BU_interval_score_R6_female = BU_interval_score_R7_female = BU_interval_score_R8_female =
BU_interval_score_R1_male   = BU_interval_score_R2_male   = BU_interval_score_R3_male   = BU_interval_score_R4_male   =
BU_interval_score_R5_male   = BU_interval_score_R6_male   = BU_interval_score_R7_male   = BU_interval_score_R8_male   = vector("numeric",15)
for(ik in 1:15)
{
    # Level 3 (female)
    BU_interval_score_R1_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R1, series = "female",
                                                              fh = ik, index = 12)
    
    BU_interval_score_R2_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R2, series = "female",
                                                              fh = ik, index = 13)
    
    BU_interval_score_R3_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R3, series = "female",
                                                              fh = ik, index = 14)
    
    BU_interval_score_R4_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R4, series = "female",
                                                              fh = ik, index = 15)
    
    BU_interval_score_R5_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R5, series = "female",
                                                              fh = ik, index = 16)
    
    BU_interval_score_R6_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R6, series = "female",
                                                              fh = ik, index = 17)
    
    BU_interval_score_R7_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R7, series = "female",
                                                              fh = ik, index = 18)
    
    BU_interval_score_R8_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R8, series = "female",
                                                              fh = ik, index = 19)
    
    # Level 3 (male)
    BU_interval_score_R1_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R1, series = "male",
                                                            fh = ik, index = 20)
    
    BU_interval_score_R2_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R2, series = "male",
                                                            fh = ik, index = 21)
    
    BU_interval_score_R3_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R3, series = "male",
                                                            fh = ik, index = 22)
    
    BU_interval_score_R4_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R4, series = "male",
                                                            fh = ik, index = 23)
    
    BU_interval_score_R5_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R5, series = "male",
                                                            fh = ik, index = 24)
    
    BU_interval_score_R6_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R6, series = "male",
                                                            fh = ik, index = 25)
    
    BU_interval_score_R7_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R7, series = "male",
                                                            fh = ik, index = 26)
    
    BU_interval_score_R8_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = ind_R8, series = "male",
                                                            fh = ik, index = 27)
    print(ik)
}

# Prefecture (total)

BU_interval_score_P1_total  = BU_interval_score_P2_total  = BU_interval_score_P3_total  = BU_interval_score_P4_total =
BU_interval_score_P5_total  = BU_interval_score_P6_total  = BU_interval_score_P7_total  = BU_interval_score_P8_total =
BU_interval_score_P9_total  = BU_interval_score_P10_total = BU_interval_score_P11_total = BU_interval_score_P12_total =
BU_interval_score_P13_total = BU_interval_score_P14_total = BU_interval_score_P15_total = BU_interval_score_P16_total =
BU_interval_score_P17_total = BU_interval_score_P18_total = BU_interval_score_P19_total = BU_interval_score_P20_total =
BU_interval_score_P21_total = BU_interval_score_P22_total = BU_interval_score_P23_total = BU_interval_score_P24_total =
BU_interval_score_P25_total = BU_interval_score_P26_total = BU_interval_score_P27_total = BU_interval_score_P28_total =
BU_interval_score_P29_total = BU_interval_score_P30_total = BU_interval_score_P31_total = BU_interval_score_P32_total =
BU_interval_score_P33_total = BU_interval_score_P34_total = BU_interval_score_P35_total = BU_interval_score_P36_total =
BU_interval_score_P37_total = BU_interval_score_P38_total = BU_interval_score_P39_total = BU_interval_score_P40_total =
BU_interval_score_P41_total = BU_interval_score_P42_total = BU_interval_score_P43_total = BU_interval_score_P44_total =
BU_interval_score_P45_total = BU_interval_score_P46_total = BU_interval_score_P47_total = vector("numeric",15)
for(ik in 1:15)
{
    BU_interval_score_P1_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Hokkaido, series = "total",
                                                             fh = ik, index = 28)
    
    BU_interval_score_P2_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Aomori, series = "total",
                                                             fh = ik, index = 29)
    
    BU_interval_score_P3_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Iwate, series = "total",
                                                             fh = ik, index = 30)
    
    BU_interval_score_P4_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Miyagi, series = "total",
                                                             fh = ik, index = 31)
    
    BU_interval_score_P5_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Akita, series = "total",
                                                             fh = ik, index = 32)
    
    BU_interval_score_P6_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Yamagata, series = "total",
                                                             fh = ik, index = 33)
    
    BU_interval_score_P7_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Fukushima, series = "total",
                                                             fh = ik, index = 34)
    
    BU_interval_score_P8_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Ibaraki, series = "total",
                                                             fh = ik, index = 35)
    
    BU_interval_score_P9_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Tochigi, series = "total",
                                                             fh = ik, index = 36)
    
    BU_interval_score_P10_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Gunma, series = "total",
                                                              fh = ik, index = 37)
    
    BU_interval_score_P11_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Saitama, series = "total",
                                                              fh = ik, index = 38)
    
    BU_interval_score_P12_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Chiba, series = "total",
                                                              fh = ik, index = 39)
    
    BU_interval_score_P13_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Tokyo, series = "total",
                                                              fh = ik, index = 40)
    
    BU_interval_score_P14_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kanagawa, series = "total",
                                                              fh = ik, index = 41)
    
    BU_interval_score_P15_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Niigata, series = "total",
                                                              fh = ik, index = 42)
    
    BU_interval_score_P16_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Toyama, series = "total",
                                                              fh = ik, index = 43)
    
    BU_interval_score_P17_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Ishikawa, series = "total",
                                                              fh = ik, index = 44)
    
    BU_interval_score_P18_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Fukui, series = "total",
                                                              fh = ik, index = 45)
    
    BU_interval_score_P19_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Yamanashi, series = "total",
                                                              fh = ik, index = 46)
    
    BU_interval_score_P20_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Nagano, series = "total",
                                                              fh = ik, index = 47)
    
    BU_interval_score_P21_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Gifu, series = "total",
                                                              fh = ik, index = 48)
    
    BU_interval_score_P22_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Shizuoka, series = "total",
                                                              fh = ik, index = 49)
    
    BU_interval_score_P23_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Aichi, series = "total",
                                                              fh = ik, index = 50)
    
    BU_interval_score_P24_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Mie, series = "total",
                                                              fh = ik, index = 51)
    
    BU_interval_score_P25_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Shiga, series = "total",
                                                              fh = ik, index = 52)
    
    BU_interval_score_P26_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kyoto, series = "total",
                                                              fh = ik, index = 53)
    
    BU_interval_score_P27_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Osaka, series = "total",
                                                              fh = ik, index = 54)
    
    BU_interval_score_P28_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Hyogo, series = "total",
                                                              fh = ik, index = 55)
    
    BU_interval_score_P29_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Nara, series = "total",
                                                              fh = ik, index = 56)
    
    BU_interval_score_P30_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Wakayama, series = "total",
                                                              fh = ik, index = 57)
    
    BU_interval_score_P31_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Tottori, series = "total",
                                                              fh = ik, index = 58)
    
    BU_interval_score_P32_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Shimane, series = "total",
                                                              fh = ik, index = 59)
    
    BU_interval_score_P33_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Okayama, series = "total",
                                                              fh = ik, index = 60)
    
    BU_interval_score_P34_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Hiroshima, series = "total",
                                                              fh = ik, index = 61)
    
    BU_interval_score_P35_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Yamaguchi, series = "total",
                                                              fh = ik, index = 62)
    
    BU_interval_score_P36_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Tokushima, series = "total",
                                                              fh = ik, index = 63)
    
    BU_interval_score_P37_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kagawa, series = "total",
                                                              fh = ik, index = 64)
    
    BU_interval_score_P38_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Ehime, series = "total",
                                                              fh = ik, index = 65)
    
    BU_interval_score_P39_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kochi, series = "total",
                                                              fh = ik, index = 66)
    
    BU_interval_score_P40_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Fukuoka, series = "total",
                                                              fh = ik, index = 67)
    
    BU_interval_score_P41_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Saga, series = "total",
                                                              fh = ik, index = 68)
    
    BU_interval_score_P42_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Nagasaki, series = "total",
                                                              fh = ik, index = 69)
    
    BU_interval_score_P43_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kumamoto, series = "total",
                                                              fh = ik, index = 70)
    
    BU_interval_score_P44_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Oita, series = "total",
                                                              fh = ik, index = 71)
    
    BU_interval_score_P45_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Miyazaki, series = "total",
                                                              fh = ik, index = 72)
    
    BU_interval_score_P46_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kagoshima, series = "total",
                                                              fh = ik, index = 73)
    
    BU_interval_score_P47_total[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Okinawa, series = "total",
                                                              fh = ik, index = 74)
    print(ik)
}

# Prefecture + Sex

BU_interval_score_P1_female  = BU_interval_score_P2_female  = BU_interval_score_P3_female  = BU_interval_score_P4_female =
BU_interval_score_P5_female  = BU_interval_score_P6_female  = BU_interval_score_P7_female  = BU_interval_score_P8_female =
BU_interval_score_P9_female  = BU_interval_score_P10_female = BU_interval_score_P11_female = BU_interval_score_P12_female =
BU_interval_score_P13_female = BU_interval_score_P14_female = BU_interval_score_P15_female = BU_interval_score_P16_female =
BU_interval_score_P17_female = BU_interval_score_P18_female = BU_interval_score_P19_female = BU_interval_score_P20_female =
BU_interval_score_P21_female = BU_interval_score_P22_female = BU_interval_score_P23_female = BU_interval_score_P24_female =
BU_interval_score_P25_female = BU_interval_score_P26_female = BU_interval_score_P27_female = BU_interval_score_P28_female =
BU_interval_score_P29_female = BU_interval_score_P30_female = BU_interval_score_P31_female = BU_interval_score_P32_female =
BU_interval_score_P33_female = BU_interval_score_P34_female = BU_interval_score_P35_female = BU_interval_score_P36_female =
BU_interval_score_P37_female = BU_interval_score_P38_female = BU_interval_score_P39_female = BU_interval_score_P40_female =
BU_interval_score_P41_female = BU_interval_score_P42_female = BU_interval_score_P43_female = BU_interval_score_P44_female =
BU_interval_score_P45_female = BU_interval_score_P46_female = BU_interval_score_P47_female = vector("numeric",15)
for(ik in 1:15)
{
    BU_interval_score_P1_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Hokkaido, series = "female",
                                                              fh = ik, index = 75)
    
    BU_interval_score_P2_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Aomori, series = "female",
                                                              fh = ik, index = 77)
    
    BU_interval_score_P3_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Iwate, series = "female",
                                                              fh = ik, index = 79)
    
    BU_interval_score_P4_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Miyagi, series = "female",
                                                              fh = ik, index = 81)
    
    BU_interval_score_P5_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Akita, series = "female",
                                                              fh = ik, index = 83)
    
    BU_interval_score_P6_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Yamagata, series = "female",
                                                              fh = ik, index = 85)
    
    BU_interval_score_P7_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Fukushima, series = "female",
                                                              fh = ik, index = 87)
    
    BU_interval_score_P8_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Ibaraki, series = "female",
                                                              fh = ik, index = 89)
    
    BU_interval_score_P9_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Tochigi, series = "female",
                                                              fh = ik, index = 91)
    
    BU_interval_score_P10_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Gunma, series = "female",
                                                               fh = ik, index = 93)
    
    BU_interval_score_P11_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Saitama, series = "female",
                                                               fh = ik, index = 95)
    
    BU_interval_score_P12_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Chiba, series = "female",
                                                               fh = ik, index = 97)
    
    BU_interval_score_P13_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Tokyo, series = "female",
                                                               fh = ik, index = 99)
    
    BU_interval_score_P14_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kanagawa, series = "female",
                                                               fh = ik, index = 101)
    
    BU_interval_score_P15_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Niigata, series = "female",
                                                               fh = ik, index = 103)
    
    BU_interval_score_P16_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Toyama, series = "female",
                                                               fh = ik, index = 105)
    
    BU_interval_score_P17_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Ishikawa, series = "female",
                                                               fh = ik, index = 107)
    
    BU_interval_score_P18_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Fukui, series = "female",
                                                               fh = ik, index = 109)
    
    BU_interval_score_P19_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Yamanashi, series = "female",
                                                               fh = ik, index = 111)
    
    BU_interval_score_P20_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Nagano, series = "female",
                                                               fh = ik, index = 113)
    
    BU_interval_score_P21_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Gifu, series = "female",
                                                               fh = ik, index = 115)
    
    BU_interval_score_P22_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Shizuoka, series = "female",
                                                               fh = ik, index = 117)
    
    BU_interval_score_P23_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Aichi, series = "female",
                                                               fh = ik, index = 119)
    
    BU_interval_score_P24_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Mie, series = "female",
                                                               fh = ik, index = 121)
    
    BU_interval_score_P25_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Shiga, series = "female",
                                                               fh = ik, index = 123)
    
    BU_interval_score_P26_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kyoto, series = "female",
                                                               fh = ik, index = 125)
    
    BU_interval_score_P27_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Osaka, series = "female",
                                                               fh = ik, index = 127)
    
    BU_interval_score_P28_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Hyogo, series = "female",
                                                               fh = ik, index = 129)
    
    BU_interval_score_P29_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Nara, series = "female",
                                                               fh = ik, index = 131)
    
    BU_interval_score_P30_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Wakayama, series = "female",
                                                               fh = ik, index = 133)
    
    BU_interval_score_P31_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Tottori, series = "female",
                                                               fh = ik, index = 135)
    
    BU_interval_score_P32_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Shimane, series = "female",
                                                               fh = ik, index = 137)
    
    BU_interval_score_P33_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Okayama, series = "female",
                                                               fh = ik, index = 139)
    
    BU_interval_score_P34_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Hiroshima, series = "female",
                                                               fh = ik, index = 141)
    
    BU_interval_score_P35_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Yamaguchi, series = "female",
                                                               fh = ik, index = 143)
    
    BU_interval_score_P36_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Tokushima, series = "female",
                                                               fh = ik, index = 145)
    
    BU_interval_score_P37_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kagawa, series = "female",
                                                               fh = ik, index = 147)
    
    BU_interval_score_P38_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Ehime, series = "female",
                                                               fh = ik, index = 149)
    
    BU_interval_score_P39_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kochi, series = "female",
                                                               fh = ik, index = 151)
    
    BU_interval_score_P40_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Fukuoka, series = "female",
                                                               fh = ik, index = 153)
    
    BU_interval_score_P41_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Saga, series = "female",
                                                               fh = ik, index = 155)
    
    BU_interval_score_P42_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Nagasaki, series = "female",
                                                               fh = ik, index = 157)
    
    BU_interval_score_P43_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kumamoto, series = "female",
                                                               fh = ik, index = 159)
    
    BU_interval_score_P44_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Oita, series = "female",
                                                               fh = ik, index = 161)
    
    BU_interval_score_P45_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Miyazaki, series = "female",
                                                               fh = ik, index = 163)
    
    BU_interval_score_P46_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kagoshima, series = "female",
                                                               fh = ik, index = 165)
    
    BU_interval_score_P47_female[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Okinawa, series = "female",
                                                               fh = ik, index = 167)
    print(ik)
}


BU_interval_score_P1_male  = BU_interval_score_P2_male  = BU_interval_score_P3_male  = BU_interval_score_P4_male =
BU_interval_score_P5_male  = BU_interval_score_P6_male  = BU_interval_score_P7_male  = BU_interval_score_P8_male =
BU_interval_score_P9_male  = BU_interval_score_P10_male = BU_interval_score_P11_male = BU_interval_score_P12_male =
BU_interval_score_P13_male = BU_interval_score_P14_male = BU_interval_score_P15_male = BU_interval_score_P16_male =
BU_interval_score_P17_male = BU_interval_score_P18_male = BU_interval_score_P19_male = BU_interval_score_P20_male =
BU_interval_score_P21_male = BU_interval_score_P22_male = BU_interval_score_P23_male = BU_interval_score_P24_male =
BU_interval_score_P25_male = BU_interval_score_P26_male = BU_interval_score_P27_male = BU_interval_score_P28_male =
BU_interval_score_P29_male = BU_interval_score_P30_male = BU_interval_score_P31_male = BU_interval_score_P32_male =
BU_interval_score_P33_male = BU_interval_score_P34_male = BU_interval_score_P35_male = BU_interval_score_P36_male =
BU_interval_score_P37_male = BU_interval_score_P38_male = BU_interval_score_P39_male = BU_interval_score_P40_male =
BU_interval_score_P41_male = BU_interval_score_P42_male = BU_interval_score_P43_male = BU_interval_score_P44_male =
BU_interval_score_P45_male = BU_interval_score_P46_male = BU_interval_score_P47_male = vector("numeric",15)
for(ik in 1:15)
{
    BU_interval_score_P1_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Hokkaido, series = "male",
                                                            fh = ik, index = 76)
    
    BU_interval_score_P2_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Aomori, series = "male",
                                                            fh = ik, index = 78)
    
    BU_interval_score_P3_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Iwate, series = "male",
                                                            fh = ik, index = 80)
    
    BU_interval_score_P4_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Miyagi, series = "male",
                                                            fh = ik, index = 82)
    
    BU_interval_score_P5_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Akita, series = "male",
                                                            fh = ik, index = 84)
    
    BU_interval_score_P6_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Yamagata, series = "male",
                                                            fh = ik, index = 86)
    
    BU_interval_score_P7_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Fukushima, series = "male",
                                                            fh = ik, index = 88)
    
    BU_interval_score_P8_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Ibaraki, series = "male",
                                                            fh = ik, index = 90)
    
    BU_interval_score_P9_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Tochigi, series = "male",
                                                            fh = ik, index = 92)
    
    BU_interval_score_P10_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Gunma, series = "male",
                                                             fh = ik, index = 94)
    
    BU_interval_score_P11_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Saitama, series = "male",
                                                             fh = ik, index = 96)
    
    BU_interval_score_P12_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Chiba, series = "male",
                                                             fh = ik, index = 98)
    
    BU_interval_score_P13_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Tokyo, series = "male",
                                                             fh = ik, index = 100)
    
    BU_interval_score_P14_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kanagawa, series = "male",
                                                             fh = ik, index = 102)
    
    BU_interval_score_P15_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Niigata, series = "male",
                                                             fh = ik, index = 104)
    
    BU_interval_score_P16_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Toyama, series = "male",
                                                             fh = ik, index = 106)
    
    BU_interval_score_P17_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Ishikawa, series = "male",
                                                             fh = ik, index = 108)
    
    BU_interval_score_P18_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Fukui, series = "male",
                                                             fh = ik, index = 110)
    
    BU_interval_score_P19_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Yamanashi, series = "male",
                                                             fh = ik, index = 112)
    
    BU_interval_score_P20_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Nagano, series = "male",
                                                             fh = ik, index = 114)
    
    BU_interval_score_P21_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Gifu, series = "male",
                                                             fh = ik, index = 116)
    
    BU_interval_score_P22_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Shizuoka, series = "male",
                                                             fh = ik, index = 118)
    
    BU_interval_score_P23_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Aichi, series = "male",
                                                             fh = ik, index = 120)
    
    BU_interval_score_P24_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Mie, series = "male",
                                                             fh = ik, index = 122)
    
    BU_interval_score_P25_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Shiga, series = "male",
                                                             fh = ik, index = 124)
    
    BU_interval_score_P26_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kyoto, series = "male",
                                                             fh = ik, index = 126)
    
    BU_interval_score_P27_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Osaka, series = "male",
                                                             fh = ik, index = 128)
    
    BU_interval_score_P28_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Hyogo, series = "male",
                                                             fh = ik, index = 130)
    
    BU_interval_score_P29_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Nara, series = "male",
                                                             fh = ik, index = 132)
    
    BU_interval_score_P30_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Wakayama, series = "male",
                                                             fh = ik, index = 134)
    
    BU_interval_score_P31_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Tottori, series = "male",
                                                             fh = ik, index = 136)
    
    BU_interval_score_P32_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Shimane, series = "male",
                                                             fh = ik, index = 138)
    
    BU_interval_score_P33_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Okayama, series = "male",
                                                             fh = ik, index = 140)
    
    BU_interval_score_P34_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Hiroshima, series = "male",
                                                             fh = ik, index = 142)
    
    BU_interval_score_P35_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Yamaguchi, series = "male",
                                                             fh = ik, index = 144)
    
    BU_interval_score_P36_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Tokushima, series = "male",
                                                             fh = ik, index = 146)
    
    BU_interval_score_P37_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kagawa, series = "male",
                                                             fh = ik, index = 148)
    
    BU_interval_score_P38_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Ehime, series = "male",
                                                             fh = ik, index = 150)
    
    BU_interval_score_P39_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kochi, series = "male",
                                                             fh = ik, index = 152)
    
    BU_interval_score_P40_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Fukuoka, series = "male",
                                                             fh = ik, index = 154)
    
    BU_interval_score_P41_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Saga, series = "male",
                                                             fh = ik, index = 156)
    
    BU_interval_score_P42_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Nagasaki, series = "male",
                                                             fh = ik, index = 158)
    
    BU_interval_score_P43_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kumamoto, series = "male",
                                                             fh = ik, index = 160)
    
    BU_interval_score_P44_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Oita, series = "male",
                                                             fh = ik, index = 162)
    
    BU_interval_score_P45_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Miyazaki, series = "male",
                                                             fh = ik, index = 164)
    
    BU_interval_score_P46_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Kagoshima, series = "male",
                                                             fh = ik, index = 166)
    
    BU_interval_score_P47_male[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb, data_series = Okinawa, series = "male",
                                                             fh = ik, index = 168)
}

BU_interval_score_Level_0 = BU_interval_score_Japan_total

BU_interval_score_Level_1 = rowMeans(cbind(BU_interval_score_Japan_female, BU_interval_score_Japan_male))

BU_interval_score_Level_2 = rowMeans(cbind(BU_interval_score_R1_total, BU_interval_score_R2_total, BU_interval_score_R3_total, BU_interval_score_R4_total,
                                           BU_interval_score_R5_total, BU_interval_score_R6_total, BU_interval_score_R7_total, BU_interval_score_R8_total))

BU_interval_score_Level_3 = rowMeans(cbind(BU_interval_score_R1_female, BU_interval_score_R2_female, BU_interval_score_R3_female, BU_interval_score_R4_female,
                                           BU_interval_score_R5_female, BU_interval_score_R6_female, BU_interval_score_R7_female, BU_interval_score_R8_female,
                                           BU_interval_score_R1_male, BU_interval_score_R2_male, BU_interval_score_R3_male, BU_interval_score_R4_male,
                                           BU_interval_score_R5_male, BU_interval_score_R6_male, BU_interval_score_R7_male, BU_interval_score_R8_male))

BU_interval_score_Level_4 = rowMeans(cbind(BU_interval_score_P1_total,  BU_interval_score_P2_total,  BU_interval_score_P3_total,  BU_interval_score_P4_total,  BU_interval_score_P5_total,
                                           BU_interval_score_P6_total,  BU_interval_score_P7_total,  BU_interval_score_P8_total,  BU_interval_score_P9_total,  BU_interval_score_P10_total,
                                           BU_interval_score_P11_total, BU_interval_score_P12_total, BU_interval_score_P13_total, BU_interval_score_P14_total, BU_interval_score_P15_total,
                                           BU_interval_score_P16_total, BU_interval_score_P17_total, BU_interval_score_P18_total, BU_interval_score_P19_total, BU_interval_score_P20_total,
                                           BU_interval_score_P21_total, BU_interval_score_P22_total, BU_interval_score_P23_total, BU_interval_score_P24_total, BU_interval_score_P25_total,
                                           BU_interval_score_P26_total, BU_interval_score_P27_total, BU_interval_score_P28_total, BU_interval_score_P29_total, BU_interval_score_P30_total,
                                           BU_interval_score_P31_total, BU_interval_score_P32_total, BU_interval_score_P33_total, BU_interval_score_P34_total, BU_interval_score_P35_total,
                                           BU_interval_score_P36_total, BU_interval_score_P37_total, BU_interval_score_P38_total, BU_interval_score_P39_total, BU_interval_score_P40_total,
                                           BU_interval_score_P41_total, BU_interval_score_P42_total, BU_interval_score_P43_total, BU_interval_score_P44_total, BU_interval_score_P45_total,
                                           BU_interval_score_P46_total, BU_interval_score_P47_total))

BU_interval_score_Level_5 = rowMeans(cbind(BU_interval_score_P1_female,  BU_interval_score_P2_female,  BU_interval_score_P3_female,  BU_interval_score_P4_female,  BU_interval_score_P5_female,
                                           BU_interval_score_P6_female,  BU_interval_score_P7_female,  BU_interval_score_P8_female,  BU_interval_score_P9_female,  BU_interval_score_P10_female,
                                           BU_interval_score_P11_female, BU_interval_score_P12_female, BU_interval_score_P13_female, BU_interval_score_P14_female, BU_interval_score_P15_female,
                                           BU_interval_score_P16_female, BU_interval_score_P17_female, BU_interval_score_P18_female, BU_interval_score_P19_female, BU_interval_score_P20_female,
                                           BU_interval_score_P21_female, BU_interval_score_P22_female, BU_interval_score_P23_female, BU_interval_score_P24_female, BU_interval_score_P25_female,
                                           BU_interval_score_P26_female, BU_interval_score_P27_female, BU_interval_score_P28_female, BU_interval_score_P29_female, BU_interval_score_P30_female,
                                           BU_interval_score_P31_female, BU_interval_score_P32_female, BU_interval_score_P33_female, BU_interval_score_P34_female, BU_interval_score_P35_female,
                                           BU_interval_score_P36_female, BU_interval_score_P37_female, BU_interval_score_P38_female, BU_interval_score_P39_female, BU_interval_score_P40_female,
                                           BU_interval_score_P41_female, BU_interval_score_P42_female, BU_interval_score_P43_female, BU_interval_score_P44_female, BU_interval_score_P45_female,
                                           BU_interval_score_P46_female, BU_interval_score_P47_female,
                                           BU_interval_score_P1_male,  BU_interval_score_P2_male,  BU_interval_score_P3_male,  BU_interval_score_P4_male,  BU_interval_score_P5_male,
                                           BU_interval_score_P6_male,  BU_interval_score_P7_male,  BU_interval_score_P8_male,  BU_interval_score_P9_male,  BU_interval_score_P10_male,
                                           BU_interval_score_P11_male, BU_interval_score_P12_male, BU_interval_score_P13_male, BU_interval_score_P14_male, BU_interval_score_P15_male,
                                           BU_interval_score_P16_male, BU_interval_score_P17_male, BU_interval_score_P18_male, BU_interval_score_P19_male, BU_interval_score_P20_male,
                                           BU_interval_score_P21_male, BU_interval_score_P22_male, BU_interval_score_P23_male, BU_interval_score_P24_male, BU_interval_score_P25_male,
                                           BU_interval_score_P26_male, BU_interval_score_P27_male, BU_interval_score_P28_male, BU_interval_score_P29_male, BU_interval_score_P30_male,
                                           BU_interval_score_P31_male, BU_interval_score_P32_male, BU_interval_score_P33_male, BU_interval_score_P34_male, BU_interval_score_P35_male,
                                           BU_interval_score_P36_male, BU_interval_score_P37_male, BU_interval_score_P38_male, BU_interval_score_P39_male, BU_interval_score_P40_male,
                                           BU_interval_score_P41_male, BU_interval_score_P42_male, BU_interval_score_P43_male, BU_interval_score_P44_male, BU_interval_score_P45_male,
                                           BU_interval_score_P46_male, BU_interval_score_P47_male))


BU_interval_score_all = cbind(BU_interval_score_Level_0, BU_interval_score_Level_1, BU_interval_score_Level_2, BU_interval_score_Level_3, BU_interval_score_Level_4, BU_interval_score_Level_5)
BU_interval_score_all_stats = rbind(BU_interval_score_all, colMeans(BU_interval_score_all), apply(BU_interval_score_all, 2, median))
colnames(BU_interval_score_all_stats) = c("Level 0", "Level 1", "Level 2", "Level 3", "Level 4", "Level 5")
rownames(BU_interval_score_all_stats) = c(1:15,"Mean","Median")

#########################################################################
# Calculate mean interval score for different levels of a hierarchy (BU)
#########################################################################

# Japan + Sex

BU_interval_score_Japan_total_mfts = BU_interval_score_Japan_female_mfts = BU_interval_score_Japan_male_mfts = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 0
    BU_interval_score_Japan_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Japan, series = "total",
                                                                     fh = ik, index = 1)
                                                                     
    # Level 1
    BU_interval_score_Japan_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Japan, series = "female",
                                                                      fh = ik, index = 2)

    BU_interval_score_Japan_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Japan, series = "male",
                                                                    fh = ik, index = 3)
    print(ik)
}

# Region (total)

BU_interval_score_R1_total_mfts = BU_interval_score_R2_total_mfts = BU_interval_score_R3_total_mfts = BU_interval_score_R4_total_mfts =
BU_interval_score_R5_total_mfts = BU_interval_score_R6_total_mfts = BU_interval_score_R7_total_mfts = BU_interval_score_R8_total_mfts = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 2
    BU_interval_score_R1_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R1, series = "total",
                                                                  fh = ik, index = 4)
                                                                  
    BU_interval_score_R2_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R2, series = "total",
                                                                  fh = ik, index = 5)
                                                                  
    BU_interval_score_R3_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R3, series = "total",
                                                                  fh = ik, index = 6)
    
    BU_interval_score_R4_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R4, series = "total",
                                                                  fh = ik, index = 7)

    BU_interval_score_R5_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R5, series = "total",
                                                                  fh = ik, index = 8)
                                                                  
    BU_interval_score_R6_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R6, series = "total",
                                                                  fh = ik, index = 9)

    BU_interval_score_R7_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R7, series = "total",
                                                                  fh = ik, index = 10)

    BU_interval_score_R8_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R8, series = "total",
                                                                  fh = ik, index = 11)
    print(ik)
}

# Region + Sex

BU_interval_score_R1_female_mfts = BU_interval_score_R2_female_mfts = BU_interval_score_R3_female_mfts = BU_interval_score_R4_female_mfts =
BU_interval_score_R5_female_mfts = BU_interval_score_R6_female_mfts = BU_interval_score_R7_female_mfts = BU_interval_score_R8_female_mfts =
BU_interval_score_R1_male_mfts = BU_interval_score_R2_male_mfts = BU_interval_score_R3_male_mfts = BU_interval_score_R4_male_mfts =
BU_interval_score_R5_male_mfts = BU_interval_score_R6_male_mfts = BU_interval_score_R7_male_mfts = BU_interval_score_R8_male_mfts = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 3 (female)
    BU_interval_score_R1_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R1, series = "female",
                                                                   fh = ik, index = 12)
                                                                   
    BU_interval_score_R2_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R2, series = "female",
                                                                   fh = ik, index = 13)
                                                                   
    BU_interval_score_R3_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R3, series = "female",
                                                                   fh = ik, index = 14)
                                                                   
    BU_interval_score_R4_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R4, series = "female",
                                                                   fh = ik, index = 15)
                                                                   
    BU_interval_score_R5_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R5, series = "female",
                                                                   fh = ik, index = 16)
                                                                   
    BU_interval_score_R6_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R6, series = "female",
                                                                   fh = ik, index = 17)
                                                                   
    BU_interval_score_R7_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R7, series = "female",
                                                                   fh = ik, index = 18)
                                                                   
    BU_interval_score_R8_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R8, series = "female",
                                                                   fh = ik, index = 19)

    # Level 3 (male)
    BU_interval_score_R1_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R1, series = "male",
                                                                 fh = ik, index = 20)
                                                                 
    BU_interval_score_R2_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R2, series = "male",
                                                                 fh = ik, index = 21)
                                                                 
    BU_interval_score_R3_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R3, series = "male",
                                                                 fh = ik, index = 22)
                                                                 
    BU_interval_score_R4_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R4, series = "male",
                                                                 fh = ik, index = 23)
                                                                 
    BU_interval_score_R5_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R5, series = "male",
                                                                 fh = ik, index = 24)
                                                                 
    BU_interval_score_R6_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R6, series = "male",
                                                                 fh = ik, index = 25)
                                                                 
    BU_interval_score_R7_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R7, series = "male",
                                                                 fh = ik, index = 26)
                                                                 
    BU_interval_score_R8_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = ind_R8, series = "male",
                                                                 fh = ik, index = 27)
    print(ik)
}

# prefecture (total)

BU_interval_score_P1_total_mfts  = BU_interval_score_P2_total_mfts  = BU_interval_score_P3_total_mfts  = BU_interval_score_P4_total_mfts =
BU_interval_score_P5_total_mfts  = BU_interval_score_P6_total_mfts  = BU_interval_score_P7_total_mfts  = BU_interval_score_P8_total_mfts =
BU_interval_score_P9_total_mfts  = BU_interval_score_P10_total_mfts = BU_interval_score_P11_total_mfts = BU_interval_score_P12_total_mfts =
BU_interval_score_P13_total_mfts = BU_interval_score_P14_total_mfts = BU_interval_score_P15_total_mfts = BU_interval_score_P16_total_mfts =
BU_interval_score_P17_total_mfts = BU_interval_score_P18_total_mfts = BU_interval_score_P19_total_mfts = BU_interval_score_P20_total_mfts =
BU_interval_score_P21_total_mfts = BU_interval_score_P22_total_mfts = BU_interval_score_P23_total_mfts = BU_interval_score_P24_total_mfts =
BU_interval_score_P25_total_mfts = BU_interval_score_P26_total_mfts = BU_interval_score_P27_total_mfts = BU_interval_score_P28_total_mfts =
BU_interval_score_P29_total_mfts = BU_interval_score_P30_total_mfts = BU_interval_score_P31_total_mfts = BU_interval_score_P32_total_mfts =
BU_interval_score_P33_total_mfts = BU_interval_score_P34_total_mfts = BU_interval_score_P35_total_mfts = BU_interval_score_P36_total_mfts =
BU_interval_score_P37_total_mfts = BU_interval_score_P38_total_mfts = BU_interval_score_P39_total_mfts = BU_interval_score_P40_total_mfts =
BU_interval_score_P41_total_mfts = BU_interval_score_P42_total_mfts = BU_interval_score_P43_total_mfts = BU_interval_score_P44_total_mfts =
BU_interval_score_P45_total_mfts = BU_interval_score_P46_total_mfts = BU_interval_score_P47_total_mfts = vector("numeric",15)
for(ik in 1:15)
{
    BU_interval_score_P1_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Hokkaido, series = "total",
                                                                  fh = ik, index = 28)
   
    BU_interval_score_P2_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Aomori, series = "total",
                                                                  fh = ik, index = 29)
                                                                  
    BU_interval_score_P3_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Iwate, series = "total",
                                                                  fh = ik, index = 30)
                                                                  
    BU_interval_score_P4_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Miyagi, series = "total",
                                                                  fh = ik, index = 31)
                                                                  
    BU_interval_score_P5_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Akita, series = "total",
                                                                  fh = ik, index = 32)
                                                                  
    BU_interval_score_P6_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Yamagata, series = "total",
                                                                  fh = ik, index = 33)
                                                                  
    BU_interval_score_P7_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Fukushima, series = "total",
                                                                  fh = ik, index = 34)
                                                                  
    BU_interval_score_P8_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Ibaraki, series = "total",
                                                                  fh = ik, index = 35)
                                                                  
    BU_interval_score_P9_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Tochigi, series = "total",
                                                                  fh = ik, index =  36)
    
    BU_interval_score_P10_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Gunma, series = "total",
                                                                   fh = ik, index = 37)
                                                                   
    BU_interval_score_P11_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Saitama, series = "total",
                                                                   fh = ik, index = 38)
                                                                   
    BU_interval_score_P12_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Chiba, series = "total",
                                                                   fh = ik, index = 39)

    BU_interval_score_P13_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Tokyo, series = "total",
                                                                   fh = ik, index = 40)
                                                                   
    BU_interval_score_P14_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kanagawa, series = "total",
                                                                   fh = ik, index = 41)
                                                                   
    BU_interval_score_P15_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Niigata, series = "total",
                                                                   fh = ik, index = 42)
                                                                   
    BU_interval_score_P16_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Toyama, series = "total",
                                                                   fh = ik, index = 43)
                                                                   
    BU_interval_score_P17_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Ishikawa, series = "total",
                                                                   fh = ik, index = 44)
                                                                   
    BU_interval_score_P18_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Fukui, series = "total",
                                                                   fh = ik, index = 45)
                                                                   
    BU_interval_score_P19_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Yamanashi, series = "total",
                                                                   fh = ik, index = 46)
                                                                   
    BU_interval_score_P20_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Nagano, series = "total",
                                                                   fh = ik, index = 47)
                                                                   
    BU_interval_score_P21_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Gifu, series = "total",
                                                                   fh = ik, index = 48)
                                                                   
    BU_interval_score_P22_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Shizuoka, series = "total",
                                                                   fh = ik, index = 49)

    BU_interval_score_P23_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Aichi, series = "total",
                                                                   fh = ik, index = 50)
                                                                   
    BU_interval_score_P24_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Mie, series = "total",
                                                                   fh = ik, index = 51)
                                                                   
    BU_interval_score_P25_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Shiga, series = "total",
                                                                   fh = ik, index = 52)
                                                                   
    BU_interval_score_P26_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kyoto, series = "total",
                                                                   fh = ik, index = 53)
                                                                   
    BU_interval_score_P27_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Osaka, series = "total",
                                                                   fh = ik, index = 54)
                                                                   
    BU_interval_score_P28_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Hyogo, series = "total",
                                                                   fh = ik, index = 55)
                                                                   
    BU_interval_score_P29_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Nara, series = "total",
                                                                   fh = ik, index = 56)
                                                                   
    BU_interval_score_P30_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Wakayama, series = "total",
                                                                   fh = ik, index = 57)
                                                                   
    BU_interval_score_P31_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Tottori, series = "total",
                                                                   fh = ik, index = 58)
                                                                   
    BU_interval_score_P32_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Shimane, series = "total",
                                                                   fh = ik, index = 59)
                                                                   
    BU_interval_score_P33_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Okayama, series = "total",
                                                                   fh = ik, index = 60)
                                                                   
    BU_interval_score_P34_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Hiroshima, series = "total",
                                                                   fh = ik, index = 61)
                                                                   
    BU_interval_score_P35_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Yamaguchi, series = "total",
                                                                   fh = ik, index = 62)
                                                                   
    BU_interval_score_P36_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Tokushima, series = "total",
                                                                   fh = ik, index = 63)
                                                                   
    BU_interval_score_P37_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kagawa, series = "total",
                                                                   fh = ik, index = 64)
                                                                   
    BU_interval_score_P38_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Ehime, series = "total",
                                                                   fh = ik, index = 65)
                                                                   
    BU_interval_score_P39_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kochi, series = "total",
                                                                   fh = ik, index = 66)
                                                                   
    BU_interval_score_P40_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Fukuoka, series = "total",
                                                                   fh = ik, index = 67)

    BU_interval_score_P41_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Saga, series = "total",
                                                                   fh = ik, index = 68)
                                                                   
    BU_interval_score_P42_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Nagasaki, series = "total",
                                                                   fh = ik, index = 69)
                                                                   
    BU_interval_score_P43_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kumamoto, series = "total",
                                                                   fh = ik, index = 70)
                                                                   
    BU_interval_score_P44_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Oita, series = "total",
                                                                   fh = ik, index = 71)
                                                                   
    BU_interval_score_P45_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Miyazaki, series = "total",
                                                                   fh = ik, index = 72)
                                                                   
    BU_interval_score_P46_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kagoshima, series = "total",
                                                                   fh = ik, index = 73)
                                                                   
    BU_interval_score_P47_total_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Okinawa, series = "total",
                                                                   fh = ik, index = 74)
    print(ik)
}
                                                                   
# prefecture + Sex

BU_interval_score_P1_female_mfts  = BU_interval_score_P2_female_mfts  = BU_interval_score_P3_female_mfts  = BU_interval_score_P4_female_mfts =
BU_interval_score_P5_female_mfts  = BU_interval_score_P6_female_mfts  = BU_interval_score_P7_female_mfts  = BU_interval_score_P8_female_mfts =
BU_interval_score_P9_female_mfts  = BU_interval_score_P10_female_mfts = BU_interval_score_P11_female_mfts = BU_interval_score_P12_female_mfts =
BU_interval_score_P13_female_mfts = BU_interval_score_P14_female_mfts = BU_interval_score_P15_female_mfts = BU_interval_score_P16_female_mfts =
BU_interval_score_P17_female_mfts = BU_interval_score_P18_female_mfts = BU_interval_score_P19_female_mfts = BU_interval_score_P20_female_mfts =
BU_interval_score_P21_female_mfts = BU_interval_score_P22_female_mfts = BU_interval_score_P23_female_mfts = BU_interval_score_P24_female_mfts =
BU_interval_score_P25_female_mfts = BU_interval_score_P26_female_mfts = BU_interval_score_P27_female_mfts = BU_interval_score_P28_female_mfts =
BU_interval_score_P29_female_mfts = BU_interval_score_P30_female_mfts = BU_interval_score_P31_female_mfts = BU_interval_score_P32_female_mfts =
BU_interval_score_P33_female_mfts = BU_interval_score_P34_female_mfts = BU_interval_score_P35_female_mfts = BU_interval_score_P36_female_mfts =
BU_interval_score_P37_female_mfts = BU_interval_score_P38_female_mfts = BU_interval_score_P39_female_mfts = BU_interval_score_P40_female_mfts =
BU_interval_score_P41_female_mfts = BU_interval_score_P42_female_mfts = BU_interval_score_P43_female_mfts = BU_interval_score_P44_female_mfts =
BU_interval_score_P45_female_mfts = BU_interval_score_P46_female_mfts = BU_interval_score_P47_female_mfts = vector("numeric",15)
for(ik in 1:15)
{
    BU_interval_score_P1_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Hokkaido, series = "female",
                                                                   fh = ik, index = 75)
                                                                   
    BU_interval_score_P2_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Aomori, series = "female",
                                                                   fh = ik, index = 77)
                                                                   
    BU_interval_score_P3_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Iwate, series = "female",
                                                                   fh = ik, index = 79)
                                                                   
    BU_interval_score_P4_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Miyagi, series = "female",
                                                                   fh = ik, index = 81)
                                                                   
    BU_interval_score_P5_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Akita, series = "female",
                                                                   fh = ik, index = 83)
                                                                   
    BU_interval_score_P6_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Yamagata, series = "female",
                                                                   fh = ik, index = 85)
                                                                   
    BU_interval_score_P7_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Fukushima, series = "female",
                                                                   fh = ik, index = 87)
                                                                   
    BU_interval_score_P8_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Ibaraki, series = "female",
                                                                   fh = ik, index = 89)
                                                                   
    BU_interval_score_P9_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Tochigi, series = "female",
                                                                   fh = ik, index = 91)
                                                                   
    BU_interval_score_P10_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Gunma, series = "female",
                                                                    fh = ik, index = 93)
                                                                    
    BU_interval_score_P11_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Saitama, series = "female",
                                                                    fh = ik, index = 95)

    BU_interval_score_P12_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Chiba, series = "female",
                                                                    fh = ik, index = 97)
                                                                    
    BU_interval_score_P13_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Tokyo, series = "female",
                                                                    fh = ik, index = 99)
                                                                    
    BU_interval_score_P14_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kanagawa, series = "female",
                                                                    fh = ik, index = 101)
                                                                    
    BU_interval_score_P15_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Niigata, series = "female",
                                                                    fh = ik, index = 103)
                                                                    
    BU_interval_score_P16_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Toyama, series = "female",
                                                                    fh = ik, index = 105)
                                                                    
    BU_interval_score_P17_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Ishikawa, series = "female",
                                                                    fh = ik, index = 107)
                                                                    
    BU_interval_score_P18_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Fukui, series = "female",
                                                                    fh = ik, index = 109)
                                                                    
    BU_interval_score_P19_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Yamanashi, series = "female",
                                                                    fh = ik, index = 111)
                                                                    
    BU_interval_score_P20_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Nagano, series = "female",
                                                                    fh = ik, index = 113)
                                                                    
    BU_interval_score_P21_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Gifu, series = "female",
                                                                    fh = ik, index = 115)
                                                                    
    BU_interval_score_P22_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Shizuoka, series = "female",
                                                                    fh = ik, index = 117)
                                                                    
    BU_interval_score_P23_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Aichi, series = "female",
                                                                    fh = ik, index = 119)
                                                                    
    BU_interval_score_P24_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Mie, series = "female",
                                                                    fh = ik, index = 121)
                                                                    
    BU_interval_score_P25_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Shiga, series = "female",
                                                                    fh = ik, index = 123)
                                                                    
    BU_interval_score_P26_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kyoto, series = "female",
                                                                    fh = ik, index = 125)
                                                                    
    BU_interval_score_P27_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Osaka, series = "female",
                                                                    fh = ik, index = 127)
                                                                    
    BU_interval_score_P28_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Hyogo, series = "female",
                                                                    fh = ik, index = 129)

    BU_interval_score_P29_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Nara, series = "female",
                                                                    fh = ik, index = 131)
                                                                    
    BU_interval_score_P30_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Wakayama, series = "female",
                                                                    fh = ik, index = 133)
                                                                    
    BU_interval_score_P31_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Tottori, series = "female",
                                                                    fh = ik, index = 135)
                                                                    
    BU_interval_score_P32_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Shimane, series = "female",
                                                                    fh = ik, index = 137)
                                                                    
    BU_interval_score_P33_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Okayama, series = "female",
                                                                    fh = ik, index = 139)
                                                                    
    BU_interval_score_P34_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Hiroshima, series = "female",
                                                                    fh = ik, index = 141)
                                                                    
    BU_interval_score_P35_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Yamaguchi, series = "female",
                                                                    fh = ik, index = 143)
                                                                    
    BU_interval_score_P36_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Tokushima, series = "female",
                                                                    fh = ik, index = 145)
                                                                    
    BU_interval_score_P37_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kagawa, series = "female",
                                                                    fh = ik, index = 147)
                                                                    
    BU_interval_score_P38_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Ehime, series = "female",
                                                                    fh = ik, index = 149)
                                                                    
    BU_interval_score_P39_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kochi, series = "female",
                                                                    fh = ik, index = 151)
                                                                    
    BU_interval_score_P40_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Fukuoka, series = "female",
                                                                    fh = ik, index = 153)
                                                                   
    BU_interval_score_P41_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Saga, series = "female",
                                                                    fh = ik, index = 155)
                                                                   
    BU_interval_score_P42_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Nagasaki, series = "female",
                                                                    fh = ik, index = 157)
                                                                    
    BU_interval_score_P43_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kumamoto, series = "female",
                                                                    fh = ik, index = 159)
                                                                    
    BU_interval_score_P44_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Oita, series = "female",
                                                                    fh = ik, index = 161)
                                                                    
    BU_interval_score_P45_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Miyazaki, series = "female",
                                                                    fh = ik, index = 163)
                                                                    
    BU_interval_score_P46_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kagoshima, series = "female",
                                                                    fh = ik, index = 165)
                                                                   
    BU_interval_score_P47_female_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Okinawa, series = "female",
                                                                    fh = ik, index = 167)
    print(ik)
}
                                                                   
# male

BU_interval_score_P1_male_mfts  = BU_interval_score_P2_male_mfts  = BU_interval_score_P3_male_mfts  = BU_interval_score_P4_male_mfts =
BU_interval_score_P5_male_mfts  = BU_interval_score_P6_male_mfts  = BU_interval_score_P7_male_mfts  = BU_interval_score_P8_male_mfts =
BU_interval_score_P9_male_mfts  = BU_interval_score_P10_male_mfts = BU_interval_score_P11_male_mfts = BU_interval_score_P12_male_mfts =
BU_interval_score_P13_male_mfts = BU_interval_score_P14_male_mfts = BU_interval_score_P15_male_mfts = BU_interval_score_P16_male_mfts =
BU_interval_score_P17_male_mfts = BU_interval_score_P18_male_mfts = BU_interval_score_P19_male_mfts = BU_interval_score_P20_male_mfts =
BU_interval_score_P21_male_mfts = BU_interval_score_P22_male_mfts = BU_interval_score_P23_male_mfts = BU_interval_score_P24_male_mfts =
BU_interval_score_P25_male_mfts = BU_interval_score_P26_male_mfts = BU_interval_score_P27_male_mfts = BU_interval_score_P28_male_mfts =
BU_interval_score_P29_male_mfts = BU_interval_score_P30_male_mfts = BU_interval_score_P31_male_mfts = BU_interval_score_P32_male_mfts =
BU_interval_score_P33_male_mfts = BU_interval_score_P34_male_mfts = BU_interval_score_P35_male_mfts = BU_interval_score_P36_male_mfts =
BU_interval_score_P37_male_mfts = BU_interval_score_P38_male_mfts = BU_interval_score_P39_male_mfts = BU_interval_score_P40_male_mfts =
BU_interval_score_P41_male_mfts = BU_interval_score_P42_male_mfts = BU_interval_score_P43_male_mfts = BU_interval_score_P44_male_mfts =
BU_interval_score_P45_male_mfts = BU_interval_score_P46_male_mfts = BU_interval_score_P47_male_mfts = vector("numeric",15)
for(ik in 1:15)
{
    BU_interval_score_P1_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Hokkaido, series = "male",
                                                                 fh = ik, index = 76)
    
    BU_interval_score_P2_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Aomori, series = "male",
                                                                 fh = ik, index = 78)
    
    BU_interval_score_P3_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Iwate, series = "male",
                                                                 fh = ik, index = 80)
    
    BU_interval_score_P4_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Miyagi, series = "male",
                                                                 fh = ik, index = 82)
    
    BU_interval_score_P5_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Akita, series = "male",
                                                                 fh = ik, index = 84)
    
    BU_interval_score_P6_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Yamagata, series = "male",
                                                                 fh = ik, index = 86)
    
    BU_interval_score_P7_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Fukushima, series = "male",
                                                                 fh = ik, index = 88)
    
    BU_interval_score_P8_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Ibaraki, series = "male",
                                                                 fh = ik, index = 90)
    
    BU_interval_score_P9_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Tochigi, series = "male",
                                                                 fh = ik, index = 92)
    
    BU_interval_score_P10_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Gunma, series = "male",
                                                                  fh = ik, index = 94)
    
    BU_interval_score_P11_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Saitama, series = "male",
                                                                  fh = ik, index = 96)
    
    BU_interval_score_P12_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Chiba, series = "male",
                                                                  fh = ik, index = 98)
    
    BU_interval_score_P13_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Tokyo, series = "male",
                                                                  fh = ik, index = 100)
    
    BU_interval_score_P14_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kanagawa, series = "male",
                                                                  fh = ik, index = 102)
    
    BU_interval_score_P15_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Niigata, series = "male",
                                                                  fh = ik, index = 104)
    
    BU_interval_score_P16_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Toyama, series = "male",
                                                                  fh = ik, index = 106)
    
    BU_interval_score_P17_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Ishikawa, series = "male",
                                                                  fh = ik, index = 108)
    
    BU_interval_score_P18_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Fukui, series = "male",
                                                                  fh = ik, index = 110)
    
    BU_interval_score_P19_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Yamanashi, series = "male",
                                                                  fh = ik, index = 112)
    
    BU_interval_score_P20_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Nagano, series = "male",
                                                                  fh = ik, index = 114)
    
    BU_interval_score_P21_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Gifu, series = "male",
                                                                  fh = ik, index = 116)
    
    BU_interval_score_P22_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Shizuoka, series = "male",
                                                                  fh = ik, index = 118)
    
    BU_interval_score_P23_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Aichi, series = "male",
                                                                  fh = ik, index = 120)
    
    BU_interval_score_P24_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Mie, series = "male",
                                                                  fh = ik, index = 122)
    
    BU_interval_score_P25_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Shiga, series = "male",
                                                                  fh = ik, index = 124)
    
    BU_interval_score_P26_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kyoto, series = "male",
                                                                  fh = ik, index = 126)
    
    BU_interval_score_P27_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Osaka, series = "male",
                                                                  fh = ik, index = 128)
    
    BU_interval_score_P28_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Hyogo, series = "male",
                                                                  fh = ik, index = 130)
    
    BU_interval_score_P29_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Nara, series = "male",
                                                                  fh = ik, index = 132)
    
    BU_interval_score_P30_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Wakayama, series = "male",
                                                                  fh = ik, index = 134)
    
    BU_interval_score_P31_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Tottori, series = "male",
                                                                  fh = ik, index = 136)
    
    BU_interval_score_P32_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Shimane, series = "male",
                                                                  fh = ik, index = 138)
    
    BU_interval_score_P33_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Okayama, series = "male",
                                                                  fh = ik, index = 140)
    
    BU_interval_score_P34_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Hiroshima, series = "male",
                                                                  fh = ik, index = 142)
    
    BU_interval_score_P35_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Yamaguchi, series = "male",
                                                                  fh = ik, index = 144)
    
    BU_interval_score_P36_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Tokushima, series = "male",
                                                                  fh = ik, index = 146)
    
    BU_interval_score_P37_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kagawa, series = "male",
                                                                  fh = ik, index = 148)
    
    BU_interval_score_P38_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Ehime, series = "male",
                                                                  fh = ik, index = 150)
    
    BU_interval_score_P39_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kochi, series = "male",
                                                                  fh = ik, index = 152)
    
    BU_interval_score_P40_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Fukuoka, series = "male",
                                                                  fh = ik, index = 154)
    
    BU_interval_score_P41_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Saga, series = "male",
                                                                  fh = ik, index = 156)
    
    BU_interval_score_P42_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Nagasaki, series = "male",
                                                                  fh = ik, index = 158)
    
    BU_interval_score_P43_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kumamoto, series = "male",
                                                                  fh = ik, index = 160)
    
    BU_interval_score_P44_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Oita, series = "male",
                                                                  fh = ik, index = 162)
    
    BU_interval_score_P45_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Miyazaki, series = "male",
                                                                  fh = ik, index = 164)
    
    BU_interval_score_P46_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Kagoshima, series = "male",
                                                                  fh = ik, index = 166)
    
    BU_interval_score_P47_male_mfts[ik] = interval_score_BU_optim(PI_val = BU_optim_hier_comb_mfts, data_series = Okinawa, series = "male",
                                                                  fh = ik, index = 168)
    print(ik)
}


BU_interval_score_Level_0_mfts = BU_interval_score_Japan_total_mfts

BU_interval_score_Level_1_mfts = rowMeans(cbind(BU_interval_score_Japan_female_mfts, BU_interval_score_Japan_male_mfts))

BU_interval_score_Level_2_mfts = rowMeans(cbind(BU_interval_score_R1_total_mfts, BU_interval_score_R2_total_mfts, BU_interval_score_R3_total_mfts,
                                                BU_interval_score_R4_total_mfts, BU_interval_score_R5_total_mfts, BU_interval_score_R6_total_mfts,
                                                BU_interval_score_R7_total_mfts, BU_interval_score_R8_total_mfts))

BU_interval_score_Level_3_mfts = rowMeans(cbind(BU_interval_score_R1_female_mfts, BU_interval_score_R2_female_mfts, BU_interval_score_R3_female_mfts,
                                                BU_interval_score_R4_female_mfts, BU_interval_score_R5_female_mfts, BU_interval_score_R6_female_mfts,
                                                BU_interval_score_R7_female_mfts, BU_interval_score_R8_female_mfts, BU_interval_score_R1_male_mfts,
                                                BU_interval_score_R2_male_mfts,   BU_interval_score_R3_male_mfts,   BU_interval_score_R4_male_mfts,
                                                BU_interval_score_R5_male_mfts,   BU_interval_score_R6_male_mfts,   BU_interval_score_R7_male_mfts,
                                                BU_interval_score_R8_male_mfts))

BU_interval_score_Level_4_mfts = rowMeans(cbind(BU_interval_score_P1_total_mfts,  BU_interval_score_P2_total_mfts,  BU_interval_score_P3_total_mfts,
                                                BU_interval_score_P4_total_mfts,  BU_interval_score_P5_total_mfts,  BU_interval_score_P6_total_mfts,
                                                BU_interval_score_P7_total_mfts,  BU_interval_score_P8_total_mfts,  BU_interval_score_P9_total_mfts,
                                                BU_interval_score_P10_total_mfts, BU_interval_score_P11_total_mfts, BU_interval_score_P12_total_mfts,
                                                BU_interval_score_P13_total_mfts, BU_interval_score_P14_total_mfts, BU_interval_score_P15_total_mfts,
                                                BU_interval_score_P16_total_mfts, BU_interval_score_P17_total_mfts, BU_interval_score_P18_total_mfts,
                                                BU_interval_score_P19_total_mfts, BU_interval_score_P20_total_mfts, BU_interval_score_P21_total_mfts,
                                                BU_interval_score_P22_total_mfts, BU_interval_score_P23_total_mfts, BU_interval_score_P24_total_mfts,
                                                BU_interval_score_P25_total_mfts, BU_interval_score_P26_total_mfts, BU_interval_score_P27_total_mfts,
                                                BU_interval_score_P28_total_mfts, BU_interval_score_P29_total_mfts, BU_interval_score_P30_total_mfts,
                                                BU_interval_score_P31_total_mfts, BU_interval_score_P32_total_mfts, BU_interval_score_P33_total_mfts,
                                                BU_interval_score_P34_total_mfts, BU_interval_score_P35_total_mfts, BU_interval_score_P36_total_mfts,
                                                BU_interval_score_P37_total_mfts, BU_interval_score_P38_total_mfts, BU_interval_score_P39_total_mfts,
                                                BU_interval_score_P40_total_mfts, BU_interval_score_P41_total_mfts, BU_interval_score_P42_total_mfts,
                                                BU_interval_score_P43_total_mfts, BU_interval_score_P44_total_mfts, BU_interval_score_P45_total_mfts,
                                                BU_interval_score_P46_total_mfts, BU_interval_score_P47_total_mfts))

BU_interval_score_Level_5_mfts = rowMeans(cbind(BU_interval_score_P1_female_mfts,  BU_interval_score_P2_female_mfts,  BU_interval_score_P3_female_mfts,
                                                BU_interval_score_P4_female_mfts,  BU_interval_score_P5_female_mfts,  BU_interval_score_P6_female_mfts,
                                                BU_interval_score_P7_female_mfts,  BU_interval_score_P8_female_mfts,  BU_interval_score_P9_female_mfts,
                                                BU_interval_score_P10_female_mfts, BU_interval_score_P11_female_mfts, BU_interval_score_P12_female_mfts,
                                                BU_interval_score_P13_female_mfts, BU_interval_score_P14_female_mfts, BU_interval_score_P15_female_mfts,
                                                BU_interval_score_P16_female_mfts, BU_interval_score_P17_female_mfts, BU_interval_score_P18_female_mfts,
                                                BU_interval_score_P19_female_mfts, BU_interval_score_P20_female_mfts, BU_interval_score_P21_female_mfts,
                                                BU_interval_score_P22_female_mfts, BU_interval_score_P23_female_mfts, BU_interval_score_P24_female_mfts,
                                                BU_interval_score_P25_female_mfts, BU_interval_score_P26_female_mfts, BU_interval_score_P27_female_mfts,
                                                BU_interval_score_P28_female_mfts, BU_interval_score_P29_female_mfts, BU_interval_score_P30_female_mfts,
                                                BU_interval_score_P31_female_mfts, BU_interval_score_P32_female_mfts, BU_interval_score_P33_female_mfts,
                                                BU_interval_score_P34_female_mfts, BU_interval_score_P35_female_mfts, BU_interval_score_P36_female_mfts,
                                                BU_interval_score_P37_female_mfts, BU_interval_score_P38_female_mfts, BU_interval_score_P39_female_mfts,
                                                BU_interval_score_P40_female_mfts, BU_interval_score_P41_female_mfts, BU_interval_score_P42_female_mfts,
                                                BU_interval_score_P43_female_mfts, BU_interval_score_P44_female_mfts, BU_interval_score_P45_female_mfts,
                                                BU_interval_score_P46_female_mfts, BU_interval_score_P47_female_mfts, BU_interval_score_P1_male_mfts,
                                                BU_interval_score_P2_male_mfts,  BU_interval_score_P3_male_mfts,  BU_interval_score_P4_male_mfts,
                                                BU_interval_score_P5_male_mfts,  BU_interval_score_P6_male_mfts,  BU_interval_score_P7_male_mfts,
                                                BU_interval_score_P8_male_mfts,  BU_interval_score_P9_male_mfts,  BU_interval_score_P10_male_mfts,
                                                BU_interval_score_P11_male_mfts, BU_interval_score_P12_male_mfts, BU_interval_score_P13_male_mfts,
                                                BU_interval_score_P14_male_mfts, BU_interval_score_P15_male_mfts, BU_interval_score_P16_male_mfts,
                                                BU_interval_score_P17_male_mfts, BU_interval_score_P18_male_mfts, BU_interval_score_P19_male_mfts,
                                                BU_interval_score_P20_male_mfts, BU_interval_score_P21_male_mfts, BU_interval_score_P22_male_mfts,
                                                BU_interval_score_P23_male_mfts, BU_interval_score_P24_male_mfts, BU_interval_score_P25_male_mfts,
                                                BU_interval_score_P26_male_mfts, BU_interval_score_P27_male_mfts, BU_interval_score_P28_male_mfts,
                                                BU_interval_score_P29_male_mfts, BU_interval_score_P30_male_mfts, BU_interval_score_P31_male_mfts,
                                                BU_interval_score_P32_male_mfts, BU_interval_score_P33_male_mfts, BU_interval_score_P34_male_mfts,
                                                BU_interval_score_P35_male_mfts, BU_interval_score_P36_male_mfts, BU_interval_score_P37_male_mfts,
                                                BU_interval_score_P38_male_mfts, BU_interval_score_P39_male_mfts, BU_interval_score_P40_male_mfts,
                                                BU_interval_score_P41_male_mfts, BU_interval_score_P42_male_mfts, BU_interval_score_P43_male_mfts,
                                                BU_interval_score_P44_male_mfts, BU_interval_score_P45_male_mfts, BU_interval_score_P46_male_mfts,
                                                BU_interval_score_P47_male_mfts))


BU_interval_score_all_mfts = cbind(BU_interval_score_Level_0_mfts, BU_interval_score_Level_1_mfts, BU_interval_score_Level_2_mfts, BU_interval_score_Level_3_mfts, BU_interval_score_Level_4_mfts, BU_interval_score_Level_5_mfts)
BU_interval_score_all_stats_mfts = rbind(BU_interval_score_all_mfts, colMeans(BU_interval_score_all_mfts), apply(BU_interval_score_all_mfts, 2, median))
colnames(BU_interval_score_all_stats_mfts) = c("Level 0", "Level 1", "Level 2", "Level 3", "Level 4", "Level 5")
rownames(BU_interval_score_all_stats_mfts) = c(1:15,"Mean","Median")

############################################################################
# Calculate mean interval score for different levels of a hierarchy (optim)
############################################################################

optim_interval_score_Japan_total = optim_interval_score_Japan_female = optim_interval_score_Japan_male = vector("numeric",15)
for(ik in 1:15)
{
    # Level 0
    
    optim_interval_score_Japan_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Japan, series = "total",
                                                                   fh = ik, index = 1)
    
    # Level 1
    
    optim_interval_score_Japan_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Japan, series = "female",
                                                                    fh = ik, index = 2)
    
    optim_interval_score_Japan_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Japan, series = "male",
                                                                  fh = ik, index = 3)
    print(ik)
}

optim_interval_score_R1_total = optim_interval_score_R2_total = optim_interval_score_R3_total = optim_interval_score_R4_total =
optim_interval_score_R5_total = optim_interval_score_R6_total = optim_interval_score_R7_total = optim_interval_score_R8_total = vector("numeric",15)
for(ik in 1:15)
{
    # Level 2
    
    optim_interval_score_R1_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R1, series = "total",
                                                                fh = ik, index = 4)
    
    optim_interval_score_R2_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R2, series = "total",
                                                                fh = ik, index = 5)
    
    optim_interval_score_R3_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R3, series = "total",
                                                                fh = ik, index = 6)
    
    optim_interval_score_R4_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R4, series = "total",
                                                                fh = ik, index = 7)
    
    optim_interval_score_R5_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R5, series = "total",
                                                                fh = ik, index = 8)
    
    optim_interval_score_R6_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R6, series = "total",
                                                                fh = ik, index = 9)
    
    optim_interval_score_R7_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R7, series = "total",
                                                                fh = ik, index = 10)
    
    optim_interval_score_R8_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R8, series = "total",
                                                                fh = ik, index = 11)
    print(ik)
}

optim_interval_score_R1_female = optim_interval_score_R2_female = optim_interval_score_R3_female = optim_interval_score_R4_female =
optim_interval_score_R5_female = optim_interval_score_R6_female = optim_interval_score_R7_female = optim_interval_score_R8_female =
optim_interval_score_R1_male   = optim_interval_score_R2_male   = optim_interval_score_R3_male   = optim_interval_score_R4_male   =
optim_interval_score_R5_male   = optim_interval_score_R6_male   = optim_interval_score_R7_male   = optim_interval_score_R8_male   = vector("numeric",15)
for(ik in 1:15)
{
    # Level 3 (female)
    
    optim_interval_score_R1_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R1, series = "female",
                                                                 fh = ik, index = 12)
    
    optim_interval_score_R2_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R2, series = "female",
                                                                 fh = ik, index = 13)
    
    optim_interval_score_R3_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R3, series = "female",
                                                                 fh = ik, index = 14)
    
    optim_interval_score_R4_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R4, series = "female",
                                                                 fh = ik, index = 15)
    
    optim_interval_score_R5_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R5, series = "female",
                                                                 fh = ik, index = 16)
    
    optim_interval_score_R6_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R6, series = "female",
                                                                 fh = ik, index = 17)
    
    optim_interval_score_R7_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R7, series = "female",
                                                                 fh = ik, index = 18)
    
    optim_interval_score_R8_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R8, series = "female",
                                                                 fh = ik, index = 19)
    
    # Level 3 (male)
    
    optim_interval_score_R1_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R1, series = "male",
                                                               fh = ik, index = 20)
    
    optim_interval_score_R2_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R2, series = "male",
                                                               fh = ik, index = 21)
    
    optim_interval_score_R3_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R3, series = "male",
                                                               fh = ik, index = 22)
    
    optim_interval_score_R4_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R4, series = "male",
                                                               fh = ik, index = 23)
    
    optim_interval_score_R5_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R5, series = "male",
                                                               fh = ik, index = 24)
    
    optim_interval_score_R6_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R6, series = "male",
                                                               fh = ik, index = 25)
    
    optim_interval_score_R7_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R7, series = "male",
                                                               fh = ik, index = 26)
    
    optim_interval_score_R8_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = ind_R8, series = "male",
                                                               fh = ik, index = 27)
    print(ik)
}

optim_interval_score_P1_total  = optim_interval_score_P2_total  = optim_interval_score_P3_total  = optim_interval_score_P4_total =
optim_interval_score_P5_total  = optim_interval_score_P6_total  = optim_interval_score_P7_total  = optim_interval_score_P8_total =
optim_interval_score_P9_total  = optim_interval_score_P15_total = optim_interval_score_P11_total = optim_interval_score_P12_total =
optim_interval_score_P13_total = optim_interval_score_P14_total = optim_interval_score_P15_total = optim_interval_score_P16_total =
optim_interval_score_P17_total = optim_interval_score_P18_total = optim_interval_score_P19_total = optim_interval_score_P20_total =
optim_interval_score_P21_total = optim_interval_score_P22_total = optim_interval_score_P23_total = optim_interval_score_P24_total =
optim_interval_score_P25_total = optim_interval_score_P26_total = optim_interval_score_P27_total = optim_interval_score_P28_total =
optim_interval_score_P29_total = optim_interval_score_P30_total = optim_interval_score_P31_total = optim_interval_score_P32_total =
optim_interval_score_P33_total = optim_interval_score_P34_total = optim_interval_score_P35_total = optim_interval_score_P36_total =
optim_interval_score_P37_total = optim_interval_score_P38_total = optim_interval_score_P39_total = optim_interval_score_P40_total =
optim_interval_score_P41_total = optim_interval_score_P42_total = optim_interval_score_P43_total = optim_interval_score_P44_total =
optim_interval_score_P45_total = optim_interval_score_P46_total = optim_interval_score_P47_total = vector("numeric",15)
for(ik in 1:15)
{
    optim_interval_score_P1_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Hokkaido, series = "total",
                                                                fh = ik, index = 28)
    
    optim_interval_score_P2_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Aomori, series = "total",
                                                                fh = ik, index = 29)
    
    optim_interval_score_P3_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Iwate, series = "total",
                                                                fh = ik, index = 30)
    
    optim_interval_score_P4_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Miyagi, series = "total",
                                                                fh = ik, index = 31)
    
    optim_interval_score_P5_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Akita, series = "total",
                                                                fh = ik, index = 32)
    
    optim_interval_score_P6_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Yamagata, series = "total",
                                                                fh = ik, index = 33)
    
    optim_interval_score_P7_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Fukushima, series = "total",
                                                                fh = ik, index = 34)
    
    optim_interval_score_P8_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Ibaraki, series = "total",
                                                                fh = ik, index = 35)
    
    optim_interval_score_P9_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Tochigi, series = "total",
                                                                fh = ik, index = 36)
    
    optim_interval_score_P15_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Gunma, series = "total",
                                                                 fh = ik, index = 37)
    
    optim_interval_score_P11_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Saitama, series = "total",
                                                                 fh = ik, index = 38)
    
    optim_interval_score_P12_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Chiba, series = "total",
                                                                 fh = ik, index = 39)
    
    optim_interval_score_P13_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Tokyo, series = "total",
                                                                 fh = ik, index = 40)
    
    optim_interval_score_P14_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kanagawa, series = "total",
                                                                 fh = ik, index = 41)
    
    optim_interval_score_P15_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Niigata, series = "total",
                                                                 fh = ik, index = 42)
    
    optim_interval_score_P16_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Toyama, series = "total",
                                                                 fh = ik, index = 43)
    
    optim_interval_score_P17_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Ishikawa, series = "total",
                                                                 fh = ik, index = 44)
    
    optim_interval_score_P18_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Fukui, series = "total",
                                                                 fh = ik, index = 45)
    
    optim_interval_score_P19_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Yamanashi, series = "total",
                                                                 fh = ik, index = 46)
    
    optim_interval_score_P20_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Nagano, series = "total",
                                                                 fh = ik, index = 47)
    
    optim_interval_score_P21_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Gifu, series = "total",
                                                                 fh = ik, index = 48)
    
    optim_interval_score_P22_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Shizuoka, series = "total",
                                                                 fh = ik, index = 49)
    
    optim_interval_score_P23_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Aichi, series = "total",
                                                                 fh = ik, index = 50)
    
    optim_interval_score_P24_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Mie, series = "total",
                                                                 fh = ik, index = 51)
    
    optim_interval_score_P25_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Shiga, series = "total",
                                                                 fh = ik, index = 52)
    
    optim_interval_score_P26_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kyoto, series = "total",
                                                                 fh = ik, index = 53)
    
    optim_interval_score_P27_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Osaka, series = "total",
                                                                 fh = ik, index = 54)
    
    optim_interval_score_P28_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Hyogo, series = "total",
                                                                 fh = ik, index = 55)
    
    optim_interval_score_P29_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Nara, series = "total",
                                                                 fh = ik, index = 56)
    
    optim_interval_score_P30_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Wakayama, series = "total",
                                                                 fh = ik, index = 57)
    
    optim_interval_score_P31_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Tottori, series = "total",
                                                                 fh = ik, index = 58)
    
    optim_interval_score_P32_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Shimane, series = "total",
                                                                 fh = ik, index = 59)
    
    optim_interval_score_P33_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Okayama, series = "total",
                                                                 fh = ik, index = 60)
    
    optim_interval_score_P34_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Hiroshima, series = "total",
                                                                 fh = ik, index = 61)
    
    optim_interval_score_P35_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Yamaguchi, series = "total",
                                                                 fh = ik, index = 62)
    
    optim_interval_score_P36_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Tokushima, series = "total",
                                                                 fh = ik, index = 63)
    
    optim_interval_score_P37_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kagawa, series = "total",
                                                                 fh = ik, index = 64)
    
    optim_interval_score_P38_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Ehime, series = "total",
                                                                 fh = ik, index = 65)
    
    optim_interval_score_P39_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kochi, series = "total",
                                                                 fh = ik, index = 66)
    
    optim_interval_score_P40_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Fukuoka, series = "total",
                                                                 fh = ik, index = 67)
    
    optim_interval_score_P41_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Saga, series = "total",
                                                                 fh = ik, index = 68)
    
    optim_interval_score_P42_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Nagasaki, series = "total",
                                                                 fh = ik, index = 69)
    
    optim_interval_score_P43_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kumamoto, series = "total",
                                                                 fh = ik, index = 70)
    
    optim_interval_score_P44_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Oita, series = "total",
                                                                 fh = ik, index = 71)
    
    optim_interval_score_P45_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Miyazaki, series = "total",
                                                                 fh = ik, index = 72)
    
    optim_interval_score_P46_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kagoshima, series = "total",
                                                                 fh = ik, index = 73)
    
    optim_interval_score_P47_total[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Okinawa, series = "total",
                                                                 fh = ik, index = 74)
    print(ik)
}


optim_interval_score_P1_female  = optim_interval_score_P2_female  = optim_interval_score_P3_female  = optim_interval_score_P4_female  =
optim_interval_score_P5_female  = optim_interval_score_P6_female  = optim_interval_score_P7_female  = optim_interval_score_P8_female  =
optim_interval_score_P9_female  = optim_interval_score_P15_female = optim_interval_score_P11_female = optim_interval_score_P12_female =
optim_interval_score_P13_female = optim_interval_score_P14_female = optim_interval_score_P15_female = optim_interval_score_P16_female =
optim_interval_score_P17_female = optim_interval_score_P18_female = optim_interval_score_P19_female = optim_interval_score_P20_female =
optim_interval_score_P21_female = optim_interval_score_P22_female = optim_interval_score_P23_female = optim_interval_score_P24_female =
optim_interval_score_P25_female = optim_interval_score_P26_female = optim_interval_score_P27_female = optim_interval_score_P28_female =
optim_interval_score_P29_female = optim_interval_score_P30_female = optim_interval_score_P31_female = optim_interval_score_P32_female =
optim_interval_score_P33_female = optim_interval_score_P34_female = optim_interval_score_P35_female = optim_interval_score_P36_female =
optim_interval_score_P37_female = optim_interval_score_P38_female = optim_interval_score_P39_female = optim_interval_score_P40_female =
optim_interval_score_P41_female = optim_interval_score_P42_female = optim_interval_score_P43_female = optim_interval_score_P44_female =
optim_interval_score_P45_female = optim_interval_score_P46_female = optim_interval_score_P47_female = vector("numeric",15)
for(ik in 1:15)
{
    optim_interval_score_P1_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Hokkaido, series = "female",
                                                                 fh = ik, index = 75)
    
    optim_interval_score_P2_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Aomori, series = "female",
                                                                 fh = ik, index = 77)
    
    optim_interval_score_P3_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Iwate, series = "female",
                                                                 fh = ik, index = 79)
    
    optim_interval_score_P4_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Miyagi, series = "female",
                                                                 fh = ik, index = 81)
    
    optim_interval_score_P5_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Akita, series = "female",
                                                                 fh = ik, index = 83)
    
    optim_interval_score_P6_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Yamagata, series = "female",
                                                                 fh = ik, index = 85)
    
    optim_interval_score_P7_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Fukushima, series = "female",
                                                                 fh = ik, index = 87)
    
    optim_interval_score_P8_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Ibaraki, series = "female",
                                                                 fh = ik, index = 89)
    
    optim_interval_score_P9_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Tochigi, series = "female",
                                                                 fh = ik, index = 91)
    
    optim_interval_score_P15_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Gunma, series = "female",
                                                                  fh = ik, index = 93)
    
    optim_interval_score_P11_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Saitama, series = "female",
                                                                  fh = ik, index = 95)
    
    optim_interval_score_P12_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Chiba, series = "female",
                                                                  fh = ik, index = 97)
    
    optim_interval_score_P13_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Tokyo, series = "female",
                                                                  fh = ik, index = 99)
    
    optim_interval_score_P14_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kanagawa, series = "female",
                                                                  fh = ik, index = 101)
    
    optim_interval_score_P15_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Niigata, series = "female",
                                                                  fh = ik, index = 103)
    
    optim_interval_score_P16_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Toyama, series = "female",
                                                                  fh = ik, index = 105)
    
    optim_interval_score_P17_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Ishikawa, series = "female",
                                                                  fh = ik, index = 107)
    
    optim_interval_score_P18_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Fukui, series = "female",
                                                                  fh = ik, index = 109)
    
    optim_interval_score_P19_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Yamanashi, series = "female",
                                                                  fh = ik, index = 111)
    
    optim_interval_score_P20_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Nagano, series = "female",
                                                                  fh = ik, index = 113)
    
    optim_interval_score_P21_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Gifu, series = "female",
                                                                  fh = ik, index = 115)
    
    optim_interval_score_P22_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Shizuoka, series = "female",
                                                                  fh = ik, index = 117)
    
    optim_interval_score_P23_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Aichi, series = "female",
                                                                  fh = ik, index = 119)
    
    optim_interval_score_P24_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Mie, series = "female",
                                                                  fh = ik, index = 121)
    
    optim_interval_score_P25_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Shiga, series = "female",
                                                                  fh = ik, index = 123)
    
    optim_interval_score_P26_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kyoto, series = "female",
                                                                  fh = ik, index = 125)
    
    optim_interval_score_P27_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Osaka, series = "female",
                                                                  fh = ik, index = 127)
    
    optim_interval_score_P28_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Hyogo, series = "female",
                                                                  fh = ik, index = 129)
    
    optim_interval_score_P29_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Nara, series = "female",
                                                                  fh = ik, index = 131)
    
    optim_interval_score_P30_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Wakayama, series = "female",
                                                                  fh = ik, index = 133)
    
    optim_interval_score_P31_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Tottori, series = "female",
                                                                  fh = ik, index = 135)
    
    optim_interval_score_P32_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Shimane, series = "female",
                                                                  fh = ik, index = 137)
    
    optim_interval_score_P33_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Okayama, series = "female",
                                                                  fh = ik, index = 139)
    
    optim_interval_score_P34_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Hiroshima, series = "female",
                                                                  fh = ik, index = 141)
    
    optim_interval_score_P35_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Yamaguchi, series = "female",
                                                                  fh = ik, index = 143)
    
    optim_interval_score_P36_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Tokushima, series = "female",
                                                                  fh = ik, index = 145)
    
    optim_interval_score_P37_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kagawa, series = "female",
                                                                  fh = ik, index = 147)
    
    optim_interval_score_P38_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Ehime, series = "female",
                                                                  fh = ik, index = 149)
    
    optim_interval_score_P39_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kochi, series = "female",
                                                                  fh = ik, index = 151)
    
    optim_interval_score_P40_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Fukuoka, series = "female",
                                                                  fh = ik, index = 153)
    
    optim_interval_score_P41_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Saga, series = "female",
                                                                  fh = ik, index = 155)
    
    optim_interval_score_P42_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Nagasaki, series = "female",
                                                                  fh = ik, index = 157)
    
    optim_interval_score_P43_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kumamoto, series = "female",
                                                                  fh = ik, index = 159)
    
    optim_interval_score_P44_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Oita, series = "female",
                                                                  fh = ik, index = 161)
    
    optim_interval_score_P45_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Miyazaki, series = "female",
                                                                  fh = ik, index = 163)
    
    optim_interval_score_P46_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kagoshima, series = "female",
                                                                  fh = ik, index = 165)
    
    optim_interval_score_P47_female[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Okinawa, series = "female",
                                                                  fh = ik, index = 167)
    print(ik)
}


optim_interval_score_P1_male  = optim_interval_score_P2_male  = optim_interval_score_P3_male  = optim_interval_score_P4_male  =
optim_interval_score_P5_male  = optim_interval_score_P6_male  = optim_interval_score_P7_male  = optim_interval_score_P8_male  =
optim_interval_score_P9_male  = optim_interval_score_P15_male = optim_interval_score_P11_male = optim_interval_score_P12_male =
optim_interval_score_P13_male = optim_interval_score_P14_male = optim_interval_score_P15_male = optim_interval_score_P16_male =
optim_interval_score_P17_male = optim_interval_score_P18_male = optim_interval_score_P19_male = optim_interval_score_P20_male =
optim_interval_score_P21_male = optim_interval_score_P22_male = optim_interval_score_P23_male = optim_interval_score_P24_male =
optim_interval_score_P25_male = optim_interval_score_P26_male = optim_interval_score_P27_male = optim_interval_score_P28_male =
optim_interval_score_P29_male = optim_interval_score_P30_male = optim_interval_score_P31_male = optim_interval_score_P32_male =
optim_interval_score_P33_male = optim_interval_score_P34_male = optim_interval_score_P35_male = optim_interval_score_P36_male =
optim_interval_score_P37_male = optim_interval_score_P38_male = optim_interval_score_P39_male = optim_interval_score_P40_male =
optim_interval_score_P41_male = optim_interval_score_P42_male = optim_interval_score_P43_male = optim_interval_score_P44_male =
optim_interval_score_P45_male = optim_interval_score_P46_male = optim_interval_score_P47_male = vector("numeric",15)
for(ik in 1:15)
{
    optim_interval_score_P1_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Hokkaido, series = "male",
                                                               fh = ik, index = 76)
    
    optim_interval_score_P2_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Aomori, series = "male",
                                                               fh = ik, index = 78)
    
    optim_interval_score_P3_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Iwate, series = "male",
                                                               fh = ik, index = 80)
    
    optim_interval_score_P4_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Miyagi, series = "male",
                                                               fh = ik, index = 82)
    
    optim_interval_score_P5_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Akita, series = "male",
                                                               fh = ik, index = 84)
    
    optim_interval_score_P6_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Yamagata, series = "male",
                                                               fh = ik, index = 86)
    
    optim_interval_score_P7_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Fukushima, series = "male",
                                                               fh = ik, index = 88)
    
    optim_interval_score_P8_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Ibaraki, series = "male",
                                                               fh = ik, index = 90)
    
    optim_interval_score_P9_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Tochigi, series = "male",
                                                               fh = ik, index = 92)
    
    optim_interval_score_P15_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Gunma, series = "male",
                                                                fh = ik, index = 94)
    
    optim_interval_score_P11_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Saitama, series = "male",
                                                                fh = ik, index = 96)
    
    optim_interval_score_P12_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Chiba, series = "male",
                                                                fh = ik, index = 98)
    
    optim_interval_score_P13_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Tokyo, series = "male",
                                                                fh = ik, index = 100)
    
    optim_interval_score_P14_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kanagawa, series = "male",
                                                                fh = ik, index = 102)
    
    optim_interval_score_P15_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Niigata, series = "male",
                                                                fh = ik, index = 104)
    
    optim_interval_score_P16_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Toyama, series = "male",
                                                                fh = ik, index = 106)
    
    optim_interval_score_P17_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Ishikawa, series = "male",
                                                                fh = ik, index = 108)
    
    optim_interval_score_P18_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Fukui, series = "male",
                                                                fh = ik, index = 110)
    
    optim_interval_score_P19_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Yamanashi, series = "male",
                                                                fh = ik, index = 112)
    
    optim_interval_score_P20_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Nagano, series = "male",
                                                                fh = ik, index = 114)
    
    optim_interval_score_P21_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Gifu, series = "male",
                                                                fh = ik, index = 116)
    
    optim_interval_score_P22_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Shizuoka, series = "male",
                                                                fh = ik, index = 118)
    
    optim_interval_score_P23_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Aichi, series = "male",
                                                                fh = ik, index = 120)
    
    optim_interval_score_P24_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Mie, series = "male",
                                                                fh = ik, index = 122)
    
    optim_interval_score_P25_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Shiga, series = "male",
                                                                fh = ik, index = 124)
    
    optim_interval_score_P26_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kyoto, series = "male",
                                                                fh = ik, index = 126)
    
    optim_interval_score_P27_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Osaka, series = "male",
                                                                fh = ik, index = 128)
    
    optim_interval_score_P28_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Hyogo, series = "male",
                                                                fh = ik, index = 130)
    
    optim_interval_score_P29_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Nara, series = "male",
                                                                fh = ik, index = 132)
    
    optim_interval_score_P30_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Wakayama, series = "male",
                                                                fh = ik, index = 134)
    
    optim_interval_score_P31_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Tottori, series = "male",
                                                                fh = ik, index = 136)
    
    optim_interval_score_P32_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Shimane, series = "male",
                                                                fh = ik, index = 138)
    
    optim_interval_score_P33_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Okayama, series = "male",
                                                                fh = ik, index = 140)
    
    optim_interval_score_P34_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Hiroshima, series = "male",
                                                                fh = ik, index = 142)
    
    optim_interval_score_P35_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Yamaguchi, series = "male",
                                                                fh = ik, index = 144)
    
    optim_interval_score_P36_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Tokushima, series = "male",
                                                                fh = ik, index = 146)
    
    optim_interval_score_P37_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kagawa, series = "male",
                                                                fh = ik, index = 148)
    
    optim_interval_score_P38_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Ehime, series = "male",
                                                                fh = ik, index = 150)
    
    optim_interval_score_P39_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kochi, series = "male",
                                                                fh = ik, index = 152)
    
    optim_interval_score_P40_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Fukuoka, series = "male",
                                                                fh = ik, index = 154)
    
    optim_interval_score_P41_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Saga, series = "male",
                                                                fh = ik, index = 156)
    
    optim_interval_score_P42_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Nagasaki, series = "male",
                                                                fh = ik, index = 158)
    
    optim_interval_score_P43_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kumamoto, series = "male",
                                                                fh = ik, index = 160)
    
    optim_interval_score_P44_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Oita, series = "male",
                                                                fh = ik, index = 162)
    
    optim_interval_score_P45_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Miyazaki, series = "male",
                                                                fh = ik, index = 164)
    
    optim_interval_score_P46_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Kagoshima, series = "male",
                                                                fh = ik, index = 166)
    
    optim_interval_score_P47_male[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb, data_series = Okinawa, series = "male",
                                                                fh = ik, index = 168)
    print(ik)
}

optim_interval_score_Level_0 = optim_interval_score_Japan_total

optim_interval_score_Level_1 = rowMeans(cbind(optim_interval_score_Japan_female, optim_interval_score_Japan_male))

optim_interval_score_Level_2 = rowMeans(cbind(optim_interval_score_R1_total, optim_interval_score_R2_total, optim_interval_score_R3_total, optim_interval_score_R4_total,
                                              optim_interval_score_R5_total, optim_interval_score_R6_total, optim_interval_score_R7_total, optim_interval_score_R8_total))

optim_interval_score_Level_3 = rowMeans(cbind(optim_interval_score_R1_female, optim_interval_score_R2_female, optim_interval_score_R3_female, optim_interval_score_R4_female,
                                              optim_interval_score_R5_female, optim_interval_score_R6_female, optim_interval_score_R7_female, optim_interval_score_R8_female,
                                              optim_interval_score_R1_male, optim_interval_score_R2_male, optim_interval_score_R3_male, optim_interval_score_R4_male,
                                              optim_interval_score_R5_male, optim_interval_score_R6_male, optim_interval_score_R7_male, optim_interval_score_R8_male))

optim_interval_score_Level_4 = rowMeans(cbind(optim_interval_score_P1_total,  optim_interval_score_P2_total,  optim_interval_score_P3_total,  optim_interval_score_P4_total,  optim_interval_score_P5_total,
                                              optim_interval_score_P6_total,  optim_interval_score_P7_total,  optim_interval_score_P8_total,  optim_interval_score_P9_total,  optim_interval_score_P15_total,
                                              optim_interval_score_P11_total, optim_interval_score_P12_total, optim_interval_score_P13_total, optim_interval_score_P14_total, optim_interval_score_P15_total,
                                              optim_interval_score_P16_total, optim_interval_score_P17_total, optim_interval_score_P18_total, optim_interval_score_P19_total, optim_interval_score_P20_total,
                                              optim_interval_score_P21_total, optim_interval_score_P22_total, optim_interval_score_P23_total, optim_interval_score_P24_total, optim_interval_score_P25_total,
                                              optim_interval_score_P26_total, optim_interval_score_P27_total, optim_interval_score_P28_total, optim_interval_score_P29_total, optim_interval_score_P30_total,
                                              optim_interval_score_P31_total, optim_interval_score_P32_total, optim_interval_score_P33_total, optim_interval_score_P34_total, optim_interval_score_P35_total,
                                              optim_interval_score_P36_total, optim_interval_score_P37_total, optim_interval_score_P38_total, optim_interval_score_P39_total, optim_interval_score_P40_total,
                                              optim_interval_score_P41_total, optim_interval_score_P42_total, optim_interval_score_P43_total, optim_interval_score_P44_total, optim_interval_score_P45_total,
                                              optim_interval_score_P46_total, optim_interval_score_P47_total))

optim_interval_score_Level_5 = rowMeans(cbind(optim_interval_score_P1_female,  optim_interval_score_P2_female,  optim_interval_score_P3_female,  optim_interval_score_P4_female,  optim_interval_score_P5_female,
                                              optim_interval_score_P6_female,  optim_interval_score_P7_female,  optim_interval_score_P8_female,  optim_interval_score_P9_female,  optim_interval_score_P15_female,
                                              optim_interval_score_P11_female, optim_interval_score_P12_female, optim_interval_score_P13_female, optim_interval_score_P14_female, optim_interval_score_P15_female,
                                              optim_interval_score_P16_female, optim_interval_score_P17_female, optim_interval_score_P18_female, optim_interval_score_P19_female, optim_interval_score_P20_female,
                                              optim_interval_score_P21_female, optim_interval_score_P22_female, optim_interval_score_P23_female, optim_interval_score_P24_female, optim_interval_score_P25_female,
                                              optim_interval_score_P26_female, optim_interval_score_P27_female, optim_interval_score_P28_female, optim_interval_score_P29_female, optim_interval_score_P30_female,
                                              optim_interval_score_P31_female, optim_interval_score_P32_female, optim_interval_score_P33_female, optim_interval_score_P34_female, optim_interval_score_P35_female,
                                              optim_interval_score_P36_female, optim_interval_score_P37_female, optim_interval_score_P38_female, optim_interval_score_P39_female, optim_interval_score_P40_female,
                                              optim_interval_score_P41_female, optim_interval_score_P42_female, optim_interval_score_P43_female, optim_interval_score_P44_female, optim_interval_score_P45_female,
                                              optim_interval_score_P46_female, optim_interval_score_P47_female,
                                              optim_interval_score_P1_male,  optim_interval_score_P2_male,  optim_interval_score_P3_male,  optim_interval_score_P4_male,  optim_interval_score_P5_male,
                                              optim_interval_score_P6_male,  optim_interval_score_P7_male,  optim_interval_score_P8_male,  optim_interval_score_P9_male,  optim_interval_score_P15_male,
                                              optim_interval_score_P11_male, optim_interval_score_P12_male, optim_interval_score_P13_male, optim_interval_score_P14_male, optim_interval_score_P15_male,
                                              optim_interval_score_P16_male, optim_interval_score_P17_male, optim_interval_score_P18_male, optim_interval_score_P19_male, optim_interval_score_P20_male,
                                              optim_interval_score_P21_male, optim_interval_score_P22_male, optim_interval_score_P23_male, optim_interval_score_P24_male, optim_interval_score_P25_male,
                                              optim_interval_score_P26_male, optim_interval_score_P27_male, optim_interval_score_P28_male, optim_interval_score_P29_male, optim_interval_score_P30_male,
                                              optim_interval_score_P31_male, optim_interval_score_P32_male, optim_interval_score_P33_male, optim_interval_score_P34_male, optim_interval_score_P35_male,
                                              optim_interval_score_P36_male, optim_interval_score_P37_male, optim_interval_score_P38_male, optim_interval_score_P39_male, optim_interval_score_P40_male,
                                              optim_interval_score_P41_male, optim_interval_score_P42_male, optim_interval_score_P43_male, optim_interval_score_P44_male, optim_interval_score_P45_male,
                                              optim_interval_score_P46_male, optim_interval_score_P47_male))


optim_interval_score_all = cbind(optim_interval_score_Level_0, optim_interval_score_Level_1, optim_interval_score_Level_2, optim_interval_score_Level_3, optim_interval_score_Level_4, optim_interval_score_Level_5)
optim_interval_score_all_stats = rbind(optim_interval_score_all, colMeans(optim_interval_score_all), apply(optim_interval_score_all, 2, median))
colnames(optim_interval_score_all_stats) = c("Level 0", "Level 1", "Level 2", "Level 3", "Level 4", "Level 5")
rownames(optim_interval_score_all_stats) = c(1:15,"Mean","Median")

require(stargazer)
stargazer(t((cbind(interval_score_all_stats[,1], BU_interval_score_all_stats[,1], optim_interval_score_all_stats[,1],
                   interval_score_all_stats[,2], BU_interval_score_all_stats[,2], optim_interval_score_all_stats[,2],
                   interval_score_all_stats[,3], BU_interval_score_all_stats[,3], optim_interval_score_all_stats[,3],
                   interval_score_all_stats[,4], BU_interval_score_all_stats[,4], optim_interval_score_all_stats[,4],
                   interval_score_all_stats[,5], BU_interval_score_all_stats[,5], optim_interval_score_all_stats[,5],
                   interval_score_all_stats[,6], BU_interval_score_all_stats[,6], optim_interval_score_all_stats[,6]) * 100)[c(1,5,10,15,16,17),]),
          digits = 2)


#########################################################################
# Calculate mean interval score for different levels of a hierarchy (BU)
#########################################################################

# Japan + Sex

optim_interval_score_Japan_total_mfts = optim_interval_score_Japan_female_mfts = optim_interval_score_Japan_male_mfts = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 0
    optim_interval_score_Japan_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Japan, series = "total",
                                                                     fh = ik, index = 1)
                                                                     
    # Level 1
    optim_interval_score_Japan_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Japan, series = "female",
                                                                      fh = ik, index = 2)

    optim_interval_score_Japan_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Japan, series = "male",
                                                                    fh = ik, index = 3)
    print(ik)
}

# Region (total)

optim_interval_score_R1_total_mfts = optim_interval_score_R2_total_mfts = optim_interval_score_R3_total_mfts = optim_interval_score_R4_total_mfts =
optim_interval_score_R5_total_mfts = optim_interval_score_R6_total_mfts = optim_interval_score_R7_total_mfts = optim_interval_score_R8_total_mfts = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 2
    optim_interval_score_R1_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R1, series = "total",
                                                                  fh = ik, index = 4)
                                                                  
    optim_interval_score_R2_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R2, series = "total",
                                                                  fh = ik, index = 5)
                                                                  
    optim_interval_score_R3_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R3, series = "total",
                                                                  fh = ik, index = 6)
    
    optim_interval_score_R4_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R4, series = "total",
                                                                  fh = ik, index = 7)

    optim_interval_score_R5_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R5, series = "total",
                                                                  fh = ik, index = 8)
                                                                  
    optim_interval_score_R6_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R6, series = "total",
                                                                  fh = ik, index = 9)

    optim_interval_score_R7_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R7, series = "total",
                                                                  fh = ik, index = 10)

    optim_interval_score_R8_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R8, series = "total",
                                                                  fh = ik, index = 11)
    print(ik)
}

# Region + Sex

optim_interval_score_R1_female_mfts = optim_interval_score_R2_female_mfts = optim_interval_score_R3_female_mfts = optim_interval_score_R4_female_mfts =
optim_interval_score_R5_female_mfts = optim_interval_score_R6_female_mfts = optim_interval_score_R7_female_mfts = optim_interval_score_R8_female_mfts =
optim_interval_score_R1_male_mfts = optim_interval_score_R2_male_mfts = optim_interval_score_R3_male_mfts = optim_interval_score_R4_male_mfts =
optim_interval_score_R5_male_mfts = optim_interval_score_R6_male_mfts = optim_interval_score_R7_male_mfts = optim_interval_score_R8_male_mfts = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 3 (female)
    optim_interval_score_R1_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R1, series = "female",
                                                                   fh = ik, index = 12)
                                                                   
    optim_interval_score_R2_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R2, series = "female",
                                                                   fh = ik, index = 13)
                                                                   
    optim_interval_score_R3_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R3, series = "female",
                                                                   fh = ik, index = 14)
                                                                   
    optim_interval_score_R4_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R4, series = "female",
                                                                   fh = ik, index = 15)
                                                                   
    optim_interval_score_R5_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R5, series = "female",
                                                                   fh = ik, index = 16)
                                                                   
    optim_interval_score_R6_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R6, series = "female",
                                                                   fh = ik, index = 17)
                                                                   
    optim_interval_score_R7_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R7, series = "female",
                                                                   fh = ik, index = 18)
                                                                   
    optim_interval_score_R8_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R8, series = "female",
                                                                   fh = ik, index = 19)

    # Level 3 (male)
    optim_interval_score_R1_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R1, series = "male",
                                                                 fh = ik, index = 20)
                                                                 
    optim_interval_score_R2_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R2, series = "male",
                                                                 fh = ik, index = 21)
                                                                 
    optim_interval_score_R3_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R3, series = "male",
                                                                 fh = ik, index = 22)
                                                                 
    optim_interval_score_R4_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R4, series = "male",
                                                                 fh = ik, index = 23)
                                                                 
    optim_interval_score_R5_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R5, series = "male",
                                                                 fh = ik, index = 24)
                                                                 
    optim_interval_score_R6_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R6, series = "male",
                                                                 fh = ik, index = 25)
                                                                 
    optim_interval_score_R7_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R7, series = "male",
                                                                 fh = ik, index = 26)
                                                                 
    optim_interval_score_R8_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = ind_R8, series = "male",
                                                                 fh = ik, index = 27)
    print(ik)
}

# prefecture (total)

optim_interval_score_P1_total_mfts  = optim_interval_score_P2_total_mfts  = optim_interval_score_P3_total_mfts  = optim_interval_score_P4_total_mfts =
optim_interval_score_P5_total_mfts  = optim_interval_score_P6_total_mfts  = optim_interval_score_P7_total_mfts  = optim_interval_score_P8_total_mfts =
optim_interval_score_P9_total_mfts  = optim_interval_score_P10_total_mfts = optim_interval_score_P11_total_mfts = optim_interval_score_P12_total_mfts =
optim_interval_score_P13_total_mfts = optim_interval_score_P14_total_mfts = optim_interval_score_P15_total_mfts = optim_interval_score_P16_total_mfts =
optim_interval_score_P17_total_mfts = optim_interval_score_P18_total_mfts = optim_interval_score_P19_total_mfts = optim_interval_score_P20_total_mfts =
optim_interval_score_P21_total_mfts = optim_interval_score_P22_total_mfts = optim_interval_score_P23_total_mfts = optim_interval_score_P24_total_mfts =
optim_interval_score_P25_total_mfts = optim_interval_score_P26_total_mfts = optim_interval_score_P27_total_mfts = optim_interval_score_P28_total_mfts =
optim_interval_score_P29_total_mfts = optim_interval_score_P30_total_mfts = optim_interval_score_P31_total_mfts = optim_interval_score_P32_total_mfts =
optim_interval_score_P33_total_mfts = optim_interval_score_P34_total_mfts = optim_interval_score_P35_total_mfts = optim_interval_score_P36_total_mfts =
optim_interval_score_P37_total_mfts = optim_interval_score_P38_total_mfts = optim_interval_score_P39_total_mfts = optim_interval_score_P40_total_mfts =
optim_interval_score_P41_total_mfts = optim_interval_score_P42_total_mfts = optim_interval_score_P43_total_mfts = optim_interval_score_P44_total_mfts =
optim_interval_score_P45_total_mfts = optim_interval_score_P46_total_mfts = optim_interval_score_P47_total_mfts = vector("numeric",15)
for(ik in 1:15)
{
    optim_interval_score_P1_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Hokkaido, series = "total",
                                                                  fh = ik, index = 28)
   
    optim_interval_score_P2_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Aomori, series = "total",
                                                                  fh = ik, index = 29)
                                                                  
    optim_interval_score_P3_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Iwate, series = "total",
                                                                  fh = ik, index = 30)
                                                                  
    optim_interval_score_P4_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Miyagi, series = "total",
                                                                  fh = ik, index = 31)
                                                                  
    optim_interval_score_P5_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Akita, series = "total",
                                                                  fh = ik, index = 32)
                                                                  
    optim_interval_score_P6_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Yamagata, series = "total",
                                                                  fh = ik, index = 33)
                                                                  
    optim_interval_score_P7_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Fukushima, series = "total",
                                                                  fh = ik, index = 34)
                                                                  
    optim_interval_score_P8_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Ibaraki, series = "total",
                                                                  fh = ik, index = 35)
                                                                  
    optim_interval_score_P9_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Tochigi, series = "total",
                                                                  fh = ik, index =  36)
    
    optim_interval_score_P10_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Gunma, series = "total",
                                                                   fh = ik, index = 37)
                                                                   
    optim_interval_score_P11_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Saitama, series = "total",
                                                                   fh = ik, index = 38)
                                                                   
    optim_interval_score_P12_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Chiba, series = "total",
                                                                   fh = ik, index = 39)

    optim_interval_score_P13_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Tokyo, series = "total",
                                                                   fh = ik, index = 40)
                                                                   
    optim_interval_score_P14_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kanagawa, series = "total",
                                                                   fh = ik, index = 41)
                                                                   
    optim_interval_score_P15_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Niigata, series = "total",
                                                                   fh = ik, index = 42)
                                                                   
    optim_interval_score_P16_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Toyama, series = "total",
                                                                   fh = ik, index = 43)
                                                                   
    optim_interval_score_P17_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Ishikawa, series = "total",
                                                                   fh = ik, index = 44)
                                                                   
    optim_interval_score_P18_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Fukui, series = "total",
                                                                   fh = ik, index = 45)
                                                                   
    optim_interval_score_P19_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Yamanashi, series = "total",
                                                                   fh = ik, index = 46)
                                                                   
    optim_interval_score_P20_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Nagano, series = "total",
                                                                   fh = ik, index = 47)
                                                                   
    optim_interval_score_P21_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Gifu, series = "total",
                                                                   fh = ik, index = 48)
                                                                   
    optim_interval_score_P22_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Shizuoka, series = "total",
                                                                   fh = ik, index = 49)

    optim_interval_score_P23_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Aichi, series = "total",
                                                                   fh = ik, index = 50)
                                                                   
    optim_interval_score_P24_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Mie, series = "total",
                                                                   fh = ik, index = 51)
                                                                   
    optim_interval_score_P25_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Shiga, series = "total",
                                                                   fh = ik, index = 52)
                                                                   
    optim_interval_score_P26_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kyoto, series = "total",
                                                                   fh = ik, index = 53)
                                                                   
    optim_interval_score_P27_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Osaka, series = "total",
                                                                   fh = ik, index = 54)
                                                                   
    optim_interval_score_P28_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Hyogo, series = "total",
                                                                   fh = ik, index = 55)
                                                                   
    optim_interval_score_P29_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Nara, series = "total",
                                                                   fh = ik, index = 56)
                                                                   
    optim_interval_score_P30_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Wakayama, series = "total",
                                                                   fh = ik, index = 57)
                                                                   
    optim_interval_score_P31_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Tottori, series = "total",
                                                                   fh = ik, index = 58)
                                                                   
    optim_interval_score_P32_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Shimane, series = "total",
                                                                   fh = ik, index = 59)
                                                                   
    optim_interval_score_P33_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Okayama, series = "total",
                                                                   fh = ik, index = 60)
                                                                   
    optim_interval_score_P34_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Hiroshima, series = "total",
                                                                   fh = ik, index = 61)
                                                                   
    optim_interval_score_P35_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Yamaguchi, series = "total",
                                                                   fh = ik, index = 62)
                                                                   
    optim_interval_score_P36_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Tokushima, series = "total",
                                                                   fh = ik, index = 63)
                                                                   
    optim_interval_score_P37_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kagawa, series = "total",
                                                                   fh = ik, index = 64)
                                                                   
    optim_interval_score_P38_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Ehime, series = "total",
                                                                   fh = ik, index = 65)
                                                                   
    optim_interval_score_P39_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kochi, series = "total",
                                                                   fh = ik, index = 66)
                                                                   
    optim_interval_score_P40_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Fukuoka, series = "total",
                                                                   fh = ik, index = 67)

    optim_interval_score_P41_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Saga, series = "total",
                                                                   fh = ik, index = 68)
                                                                   
    optim_interval_score_P42_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Nagasaki, series = "total",
                                                                   fh = ik, index = 69)
                                                                   
    optim_interval_score_P43_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kumamoto, series = "total",
                                                                   fh = ik, index = 70)
                                                                   
    optim_interval_score_P44_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Oita, series = "total",
                                                                   fh = ik, index = 71)
                                                                   
    optim_interval_score_P45_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Miyazaki, series = "total",
                                                                   fh = ik, index = 72)
                                                                   
    optim_interval_score_P46_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kagoshima, series = "total",
                                                                   fh = ik, index = 73)
                                                                   
    optim_interval_score_P47_total_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Okinawa, series = "total",
                                                                   fh = ik, index = 74)
    print(ik)
}
                                                                   
# prefecture + Sex

optim_interval_score_P1_female_mfts  = optim_interval_score_P2_female_mfts  = optim_interval_score_P3_female_mfts  = optim_interval_score_P4_female_mfts =
optim_interval_score_P5_female_mfts  = optim_interval_score_P6_female_mfts  = optim_interval_score_P7_female_mfts  = optim_interval_score_P8_female_mfts =
optim_interval_score_P9_female_mfts  = optim_interval_score_P10_female_mfts = optim_interval_score_P11_female_mfts = optim_interval_score_P12_female_mfts =
optim_interval_score_P13_female_mfts = optim_interval_score_P14_female_mfts = optim_interval_score_P15_female_mfts = optim_interval_score_P16_female_mfts =
optim_interval_score_P17_female_mfts = optim_interval_score_P18_female_mfts = optim_interval_score_P19_female_mfts = optim_interval_score_P20_female_mfts =
optim_interval_score_P21_female_mfts = optim_interval_score_P22_female_mfts = optim_interval_score_P23_female_mfts = optim_interval_score_P24_female_mfts =
optim_interval_score_P25_female_mfts = optim_interval_score_P26_female_mfts = optim_interval_score_P27_female_mfts = optim_interval_score_P28_female_mfts =
optim_interval_score_P29_female_mfts = optim_interval_score_P30_female_mfts = optim_interval_score_P31_female_mfts = optim_interval_score_P32_female_mfts =
optim_interval_score_P33_female_mfts = optim_interval_score_P34_female_mfts = optim_interval_score_P35_female_mfts = optim_interval_score_P36_female_mfts =
optim_interval_score_P37_female_mfts = optim_interval_score_P38_female_mfts = optim_interval_score_P39_female_mfts = optim_interval_score_P40_female_mfts =
optim_interval_score_P41_female_mfts = optim_interval_score_P42_female_mfts = optim_interval_score_P43_female_mfts = optim_interval_score_P44_female_mfts =
optim_interval_score_P45_female_mfts = optim_interval_score_P46_female_mfts = optim_interval_score_P47_female_mfts = vector("numeric",15)
for(ik in 1:15)
{
    optim_interval_score_P1_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Hokkaido, series = "female",
                                                                   fh = ik, index = 75)
                                                                   
    optim_interval_score_P2_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Aomori, series = "female",
                                                                   fh = ik, index = 77)
                                                                   
    optim_interval_score_P3_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Iwate, series = "female",
                                                                   fh = ik, index = 79)
                                                                   
    optim_interval_score_P4_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Miyagi, series = "female",
                                                                   fh = ik, index = 81)
                                                                   
    optim_interval_score_P5_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Akita, series = "female",
                                                                   fh = ik, index = 83)
                                                                   
    optim_interval_score_P6_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Yamagata, series = "female",
                                                                   fh = ik, index = 85)
                                                                   
    optim_interval_score_P7_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Fukushima, series = "female",
                                                                   fh = ik, index = 87)
                                                                   
    optim_interval_score_P8_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Ibaraki, series = "female",
                                                                   fh = ik, index = 89)
                                                                   
    optim_interval_score_P9_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Tochigi, series = "female",
                                                                   fh = ik, index = 91)
                                                                   
    optim_interval_score_P10_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Gunma, series = "female",
                                                                    fh = ik, index = 93)
                                                                    
    optim_interval_score_P11_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Saitama, series = "female",
                                                                    fh = ik, index = 95)

    optim_interval_score_P12_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Chiba, series = "female",
                                                                    fh = ik, index = 97)
                                                                    
    optim_interval_score_P13_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Tokyo, series = "female",
                                                                    fh = ik, index = 99)
                                                                    
    optim_interval_score_P14_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kanagawa, series = "female",
                                                                    fh = ik, index = 101)
                                                                    
    optim_interval_score_P15_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Niigata, series = "female",
                                                                    fh = ik, index = 103)
                                                                    
    optim_interval_score_P16_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Toyama, series = "female",
                                                                    fh = ik, index = 105)
                                                                    
    optim_interval_score_P17_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Ishikawa, series = "female",
                                                                    fh = ik, index = 107)
                                                                    
    optim_interval_score_P18_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Fukui, series = "female",
                                                                    fh = ik, index = 109)
                                                                    
    optim_interval_score_P19_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Yamanashi, series = "female",
                                                                    fh = ik, index = 111)
                                                                    
    optim_interval_score_P20_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Nagano, series = "female",
                                                                    fh = ik, index = 113)
                                                                    
    optim_interval_score_P21_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Gifu, series = "female",
                                                                    fh = ik, index = 115)
                                                                    
    optim_interval_score_P22_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Shizuoka, series = "female",
                                                                    fh = ik, index = 117)
                                                                    
    optim_interval_score_P23_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Aichi, series = "female",
                                                                    fh = ik, index = 119)
                                                                    
    optim_interval_score_P24_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Mie, series = "female",
                                                                    fh = ik, index = 121)
                                                                    
    optim_interval_score_P25_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Shiga, series = "female",
                                                                    fh = ik, index = 123)
                                                                    
    optim_interval_score_P26_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kyoto, series = "female",
                                                                    fh = ik, index = 125)
                                                                    
    optim_interval_score_P27_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Osaka, series = "female",
                                                                    fh = ik, index = 127)
                                                                    
    optim_interval_score_P28_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Hyogo, series = "female",
                                                                    fh = ik, index = 129)

    optim_interval_score_P29_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Nara, series = "female",
                                                                    fh = ik, index = 131)
                                                                    
    optim_interval_score_P30_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Wakayama, series = "female",
                                                                    fh = ik, index = 133)
                                                                    
    optim_interval_score_P31_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Tottori, series = "female",
                                                                    fh = ik, index = 135)
                                                                    
    optim_interval_score_P32_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Shimane, series = "female",
                                                                    fh = ik, index = 137)
                                                                    
    optim_interval_score_P33_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Okayama, series = "female",
                                                                    fh = ik, index = 139)
                                                                    
    optim_interval_score_P34_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Hiroshima, series = "female",
                                                                    fh = ik, index = 141)
                                                                    
    optim_interval_score_P35_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Yamaguchi, series = "female",
                                                                    fh = ik, index = 143)
                                                                    
    optim_interval_score_P36_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Tokushima, series = "female",
                                                                    fh = ik, index = 145)
                                                                    
    optim_interval_score_P37_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kagawa, series = "female",
                                                                    fh = ik, index = 147)
                                                                    
    optim_interval_score_P38_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Ehime, series = "female",
                                                                    fh = ik, index = 149)
                                                                    
    optim_interval_score_P39_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kochi, series = "female",
                                                                    fh = ik, index = 151)
                                                                    
    optim_interval_score_P40_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Fukuoka, series = "female",
                                                                    fh = ik, index = 153)
                                                                   
    optim_interval_score_P41_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Saga, series = "female",
                                                                    fh = ik, index = 155)
                                                                   
    optim_interval_score_P42_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Nagasaki, series = "female",
                                                                    fh = ik, index = 157)
                                                                    
    optim_interval_score_P43_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kumamoto, series = "female",
                                                                    fh = ik, index = 159)
                                                                    
    optim_interval_score_P44_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Oita, series = "female",
                                                                    fh = ik, index = 161)
                                                                    
    optim_interval_score_P45_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Miyazaki, series = "female",
                                                                    fh = ik, index = 163)
                                                                    
    optim_interval_score_P46_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kagoshima, series = "female",
                                                                    fh = ik, index = 165)
                                                                   
    optim_interval_score_P47_female_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Okinawa, series = "female",
                                                                    fh = ik, index = 167)
    print(ik)
}
                                                                   
# male

optim_interval_score_P1_male_mfts  = optim_interval_score_P2_male_mfts  = optim_interval_score_P3_male_mfts  = optim_interval_score_P4_male_mfts =
optim_interval_score_P5_male_mfts  = optim_interval_score_P6_male_mfts  = optim_interval_score_P7_male_mfts  = optim_interval_score_P8_male_mfts =
optim_interval_score_P9_male_mfts  = optim_interval_score_P10_male_mfts = optim_interval_score_P11_male_mfts = optim_interval_score_P12_male_mfts =
optim_interval_score_P13_male_mfts = optim_interval_score_P14_male_mfts = optim_interval_score_P15_male_mfts = optim_interval_score_P16_male_mfts =
optim_interval_score_P17_male_mfts = optim_interval_score_P18_male_mfts = optim_interval_score_P19_male_mfts = optim_interval_score_P20_male_mfts =
optim_interval_score_P21_male_mfts = optim_interval_score_P22_male_mfts = optim_interval_score_P23_male_mfts = optim_interval_score_P24_male_mfts =
optim_interval_score_P25_male_mfts = optim_interval_score_P26_male_mfts = optim_interval_score_P27_male_mfts = optim_interval_score_P28_male_mfts =
optim_interval_score_P29_male_mfts = optim_interval_score_P30_male_mfts = optim_interval_score_P31_male_mfts = optim_interval_score_P32_male_mfts =
optim_interval_score_P33_male_mfts = optim_interval_score_P34_male_mfts = optim_interval_score_P35_male_mfts = optim_interval_score_P36_male_mfts =
optim_interval_score_P37_male_mfts = optim_interval_score_P38_male_mfts = optim_interval_score_P39_male_mfts = optim_interval_score_P40_male_mfts =
optim_interval_score_P41_male_mfts = optim_interval_score_P42_male_mfts = optim_interval_score_P43_male_mfts = optim_interval_score_P44_male_mfts =
optim_interval_score_P45_male_mfts = optim_interval_score_P46_male_mfts = optim_interval_score_P47_male_mfts = vector("numeric",15)
for(ik in 1:15)
{
    optim_interval_score_P1_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Hokkaido, series = "male",
                                                                 fh = ik, index = 76)
    
    optim_interval_score_P2_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Aomori, series = "male",
                                                                 fh = ik, index = 78)
    
    optim_interval_score_P3_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Iwate, series = "male",
                                                                 fh = ik, index = 80)
    
    optim_interval_score_P4_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Miyagi, series = "male",
                                                                 fh = ik, index = 82)
    
    optim_interval_score_P5_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Akita, series = "male",
                                                                 fh = ik, index = 84)
    
    optim_interval_score_P6_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Yamagata, series = "male",
                                                                 fh = ik, index = 86)
    
    optim_interval_score_P7_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Fukushima, series = "male",
                                                                 fh = ik, index = 88)
    
    optim_interval_score_P8_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Ibaraki, series = "male",
                                                                 fh = ik, index = 90)
    
    optim_interval_score_P9_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Tochigi, series = "male",
                                                                 fh = ik, index = 92)
    
    optim_interval_score_P10_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Gunma, series = "male",
                                                                  fh = ik, index = 94)
    
    optim_interval_score_P11_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Saitama, series = "male",
                                                                  fh = ik, index = 96)
    
    optim_interval_score_P12_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Chiba, series = "male",
                                                                  fh = ik, index = 98)
    
    optim_interval_score_P13_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Tokyo, series = "male",
                                                                  fh = ik, index = 100)
    
    optim_interval_score_P14_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kanagawa, series = "male",
                                                                  fh = ik, index = 102)
    
    optim_interval_score_P15_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Niigata, series = "male",
                                                                  fh = ik, index = 104)
    
    optim_interval_score_P16_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Toyama, series = "male",
                                                                  fh = ik, index = 106)
    
    optim_interval_score_P17_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Ishikawa, series = "male",
                                                                  fh = ik, index = 108)
    
    optim_interval_score_P18_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Fukui, series = "male",
                                                                  fh = ik, index = 110)
    
    optim_interval_score_P19_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Yamanashi, series = "male",
                                                                  fh = ik, index = 112)
    
    optim_interval_score_P20_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Nagano, series = "male",
                                                                  fh = ik, index = 114)
    
    optim_interval_score_P21_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Gifu, series = "male",
                                                                  fh = ik, index = 116)
    
    optim_interval_score_P22_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Shizuoka, series = "male",
                                                                  fh = ik, index = 118)
    
    optim_interval_score_P23_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Aichi, series = "male",
                                                                  fh = ik, index = 120)
    
    optim_interval_score_P24_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Mie, series = "male",
                                                                  fh = ik, index = 122)
    
    optim_interval_score_P25_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Shiga, series = "male",
                                                                  fh = ik, index = 124)
    
    optim_interval_score_P26_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kyoto, series = "male",
                                                                  fh = ik, index = 126)
    
    optim_interval_score_P27_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Osaka, series = "male",
                                                                  fh = ik, index = 128)
    
    optim_interval_score_P28_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Hyogo, series = "male",
                                                                  fh = ik, index = 130)
    
    optim_interval_score_P29_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Nara, series = "male",
                                                                  fh = ik, index = 132)
    
    optim_interval_score_P30_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Wakayama, series = "male",
                                                                  fh = ik, index = 134)
    
    optim_interval_score_P31_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Tottori, series = "male",
                                                                  fh = ik, index = 136)
    
    optim_interval_score_P32_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Shimane, series = "male",
                                                                  fh = ik, index = 138)
    
    optim_interval_score_P33_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Okayama, series = "male",
                                                                  fh = ik, index = 140)
    
    optim_interval_score_P34_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Hiroshima, series = "male",
                                                                  fh = ik, index = 142)
    
    optim_interval_score_P35_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Yamaguchi, series = "male",
                                                                  fh = ik, index = 144)
    
    optim_interval_score_P36_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Tokushima, series = "male",
                                                                  fh = ik, index = 146)
    
    optim_interval_score_P37_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kagawa, series = "male",
                                                                  fh = ik, index = 148)
    
    optim_interval_score_P38_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Ehime, series = "male",
                                                                  fh = ik, index = 150)
    
    optim_interval_score_P39_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kochi, series = "male",
                                                                  fh = ik, index = 152)
    
    optim_interval_score_P40_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Fukuoka, series = "male",
                                                                  fh = ik, index = 154)
    
    optim_interval_score_P41_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Saga, series = "male",
                                                                  fh = ik, index = 156)
    
    optim_interval_score_P42_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Nagasaki, series = "male",
                                                                  fh = ik, index = 158)
    
    optim_interval_score_P43_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kumamoto, series = "male",
                                                                  fh = ik, index = 160)
    
    optim_interval_score_P44_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Oita, series = "male",
                                                                  fh = ik, index = 162)
    
    optim_interval_score_P45_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Miyazaki, series = "male",
                                                                  fh = ik, index = 164)
    
    optim_interval_score_P46_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Kagoshima, series = "male",
                                                                  fh = ik, index = 166)
    
    optim_interval_score_P47_male_mfts[ik] = interval_score_BU_optim(PI_val = OLS_hier_comb_mfts, data_series = Okinawa, series = "male",
                                                                  fh = ik, index = 168)
    print(ik)
}


optim_interval_score_Level_0_mfts = optim_interval_score_Japan_total_mfts

optim_interval_score_Level_1_mfts = rowMeans(cbind(optim_interval_score_Japan_female_mfts, optim_interval_score_Japan_male_mfts))

optim_interval_score_Level_2_mfts = rowMeans(cbind(optim_interval_score_R1_total_mfts, optim_interval_score_R2_total_mfts, optim_interval_score_R3_total_mfts,
                                                   optim_interval_score_R4_total_mfts, optim_interval_score_R5_total_mfts, optim_interval_score_R6_total_mfts,
                                                   optim_interval_score_R7_total_mfts, optim_interval_score_R8_total_mfts))

optim_interval_score_Level_3_mfts = rowMeans(cbind(optim_interval_score_R1_female_mfts, optim_interval_score_R2_female_mfts, optim_interval_score_R3_female_mfts,
                                                   optim_interval_score_R4_female_mfts, optim_interval_score_R5_female_mfts, optim_interval_score_R6_female_mfts,
                                                   optim_interval_score_R7_female_mfts, optim_interval_score_R8_female_mfts, optim_interval_score_R1_male_mfts,
                                                   optim_interval_score_R2_male_mfts,   optim_interval_score_R3_male_mfts,   optim_interval_score_R4_male_mfts,
                                                   optim_interval_score_R5_male_mfts,   optim_interval_score_R6_male_mfts,   optim_interval_score_R7_male_mfts,
                                                   optim_interval_score_R8_male_mfts))

optim_interval_score_Level_4_mfts = rowMeans(cbind(optim_interval_score_P1_total_mfts,  optim_interval_score_P2_total_mfts,  optim_interval_score_P3_total_mfts,
                                                   optim_interval_score_P4_total_mfts,  optim_interval_score_P5_total_mfts,  optim_interval_score_P6_total_mfts,
                                                   optim_interval_score_P7_total_mfts,  optim_interval_score_P8_total_mfts,  optim_interval_score_P9_total_mfts,
                                                   optim_interval_score_P10_total_mfts, optim_interval_score_P11_total_mfts, optim_interval_score_P12_total_mfts,
                                                   optim_interval_score_P13_total_mfts, optim_interval_score_P14_total_mfts, optim_interval_score_P15_total_mfts,
                                                   optim_interval_score_P16_total_mfts, optim_interval_score_P17_total_mfts, optim_interval_score_P18_total_mfts,
                                                   optim_interval_score_P19_total_mfts, optim_interval_score_P20_total_mfts, optim_interval_score_P21_total_mfts,
                                                   optim_interval_score_P22_total_mfts, optim_interval_score_P23_total_mfts, optim_interval_score_P24_total_mfts,
                                                   optim_interval_score_P25_total_mfts, optim_interval_score_P26_total_mfts, optim_interval_score_P27_total_mfts,
                                                   optim_interval_score_P28_total_mfts, optim_interval_score_P29_total_mfts, optim_interval_score_P30_total_mfts,
                                                   optim_interval_score_P31_total_mfts, optim_interval_score_P32_total_mfts, optim_interval_score_P33_total_mfts,
                                                   optim_interval_score_P34_total_mfts, optim_interval_score_P35_total_mfts, optim_interval_score_P36_total_mfts,
                                                   optim_interval_score_P37_total_mfts, optim_interval_score_P38_total_mfts, optim_interval_score_P39_total_mfts,
                                                   optim_interval_score_P40_total_mfts, optim_interval_score_P41_total_mfts, optim_interval_score_P42_total_mfts,
                                                   optim_interval_score_P43_total_mfts, optim_interval_score_P44_total_mfts, optim_interval_score_P45_total_mfts,
                                                   optim_interval_score_P46_total_mfts, optim_interval_score_P47_total_mfts))

optim_interval_score_Level_5_mfts = rowMeans(cbind(optim_interval_score_P1_female_mfts,  optim_interval_score_P2_female_mfts,  optim_interval_score_P3_female_mfts,
                                                   optim_interval_score_P4_female_mfts,  optim_interval_score_P5_female_mfts,  optim_interval_score_P6_female_mfts,
                                                   optim_interval_score_P7_female_mfts,  optim_interval_score_P8_female_mfts,  optim_interval_score_P9_female_mfts,
                                                   optim_interval_score_P10_female_mfts, optim_interval_score_P11_female_mfts, optim_interval_score_P12_female_mfts,
                                                   optim_interval_score_P13_female_mfts, optim_interval_score_P14_female_mfts, optim_interval_score_P15_female_mfts,
                                                   optim_interval_score_P16_female_mfts, optim_interval_score_P17_female_mfts, optim_interval_score_P18_female_mfts,
                                                   optim_interval_score_P19_female_mfts, optim_interval_score_P20_female_mfts, optim_interval_score_P21_female_mfts,
                                                   optim_interval_score_P22_female_mfts, optim_interval_score_P23_female_mfts, optim_interval_score_P24_female_mfts,
                                                   optim_interval_score_P25_female_mfts, optim_interval_score_P26_female_mfts, optim_interval_score_P27_female_mfts,
                                                   optim_interval_score_P28_female_mfts, optim_interval_score_P29_female_mfts, optim_interval_score_P30_female_mfts,
                                                   optim_interval_score_P31_female_mfts, optim_interval_score_P32_female_mfts, optim_interval_score_P33_female_mfts,
                                                   optim_interval_score_P34_female_mfts, optim_interval_score_P35_female_mfts, optim_interval_score_P36_female_mfts,
                                                   optim_interval_score_P37_female_mfts, optim_interval_score_P38_female_mfts, optim_interval_score_P39_female_mfts,
                                                   optim_interval_score_P40_female_mfts, optim_interval_score_P41_female_mfts, optim_interval_score_P42_female_mfts,
                                                   optim_interval_score_P43_female_mfts, optim_interval_score_P44_female_mfts, optim_interval_score_P45_female_mfts,
                                                   optim_interval_score_P46_female_mfts, optim_interval_score_P47_female_mfts, optim_interval_score_P1_male_mfts,
                                                   optim_interval_score_P2_male_mfts,  optim_interval_score_P3_male_mfts,  optim_interval_score_P4_male_mfts,
                                                   optim_interval_score_P5_male_mfts,  optim_interval_score_P6_male_mfts,  optim_interval_score_P7_male_mfts,
                                                   optim_interval_score_P8_male_mfts,  optim_interval_score_P9_male_mfts,  optim_interval_score_P10_male_mfts,
                                                   optim_interval_score_P11_male_mfts, optim_interval_score_P12_male_mfts, optim_interval_score_P13_male_mfts,
                                                   optim_interval_score_P14_male_mfts, optim_interval_score_P15_male_mfts, optim_interval_score_P16_male_mfts,
                                                   optim_interval_score_P17_male_mfts, optim_interval_score_P18_male_mfts, optim_interval_score_P19_male_mfts,
                                                   optim_interval_score_P20_male_mfts, optim_interval_score_P21_male_mfts, optim_interval_score_P22_male_mfts,
                                                   optim_interval_score_P23_male_mfts, optim_interval_score_P24_male_mfts, optim_interval_score_P25_male_mfts,
                                                   optim_interval_score_P26_male_mfts, optim_interval_score_P27_male_mfts, optim_interval_score_P28_male_mfts,
                                                   optim_interval_score_P29_male_mfts, optim_interval_score_P30_male_mfts, optim_interval_score_P31_male_mfts,
                                                   optim_interval_score_P32_male_mfts, optim_interval_score_P33_male_mfts, optim_interval_score_P34_male_mfts,
                                                   optim_interval_score_P35_male_mfts, optim_interval_score_P36_male_mfts, optim_interval_score_P37_male_mfts,
                                                   optim_interval_score_P38_male_mfts, optim_interval_score_P39_male_mfts, optim_interval_score_P40_male_mfts,
                                                   optim_interval_score_P41_male_mfts, optim_interval_score_P42_male_mfts, optim_interval_score_P43_male_mfts,
                                                   optim_interval_score_P44_male_mfts, optim_interval_score_P45_male_mfts, optim_interval_score_P46_male_mfts,
                                                   optim_interval_score_P47_male_mfts))


optim_interval_score_all_mfts = cbind(optim_interval_score_Level_0_mfts, optim_interval_score_Level_1_mfts, optim_interval_score_Level_2_mfts,
                                      optim_interval_score_Level_3_mfts, optim_interval_score_Level_4_mfts, optim_interval_score_Level_5_mfts)
optim_interval_score_all_stats_mfts = rbind(optim_interval_score_all_mfts, colMeans(optim_interval_score_all_mfts), apply(optim_interval_score_all_mfts, 2, median))
colnames(optim_interval_score_all_stats_mfts) = c("Level 0", "Level 1", "Level 2", "Level 3", "Level 4", "Level 5")
rownames(optim_interval_score_all_stats_mfts) = c(1:15,"Mean","Median")

#########################################################################
# Calculate mean interval score for different levels of a hierarchy (Comb)
#########################################################################

# Japan + Sex

Comb_interval_score_Japan_total = Comb_interval_score_Japan_female = Comb_interval_score_Japan_male = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 0
    Comb_interval_score_Japan_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Japan, series = "total",
                                                                fh = ik, index = 1)
    
    # Level 1
    Comb_interval_score_Japan_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Japan, series = "female",
                                                                 fh = ik, index = 2)
    
    Comb_interval_score_Japan_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Japan, series = "male",
                                                               fh = ik, index = 3)
    print(ik)
}

# Region (total)

Comb_interval_score_R1_total = Comb_interval_score_R2_total = Comb_interval_score_R3_total = Comb_interval_score_R4_total =
Comb_interval_score_R5_total = Comb_interval_score_R6_total = Comb_interval_score_R7_total = Comb_interval_score_R8_total = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 2
    Comb_interval_score_R1_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R1, series = "total",
                                                             fh = ik, index = 4)
    
    Comb_interval_score_R2_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R2, series = "total",
                                                             fh = ik, index = 5)
    
    Comb_interval_score_R3_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R3, series = "total",
                                                             fh = ik, index = 6)
    
    Comb_interval_score_R4_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R4, series = "total",
                                                             fh = ik, index = 7)
    
    Comb_interval_score_R5_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R5, series = "total",
                                                             fh = ik, index = 8)
    
    Comb_interval_score_R6_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R6, series = "total",
                                                             fh = ik, index = 9)
    
    Comb_interval_score_R7_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R7, series = "total",
                                                             fh = ik, index = 10)
    
    Comb_interval_score_R8_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R8, series = "total",
                                                             fh = ik, index = 11)
    print(ik)
}

# Region + Sex

Comb_interval_score_R1_female = Comb_interval_score_R2_female = Comb_interval_score_R3_female = Comb_interval_score_R4_female =
Comb_interval_score_R5_female = Comb_interval_score_R6_female = Comb_interval_score_R7_female = Comb_interval_score_R8_female =
Comb_interval_score_R1_male   = Comb_interval_score_R2_male   = Comb_interval_score_R3_male   = Comb_interval_score_R4_male   =
Comb_interval_score_R5_male   = Comb_interval_score_R6_male   = Comb_interval_score_R7_male   = Comb_interval_score_R8_male   = vector("numeric",15)
for(ik in 1:15)
{
    # Level 3 (female)
    Comb_interval_score_R1_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R1, series = "female",
                                                              fh = ik, index = 12)
    
    Comb_interval_score_R2_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R2, series = "female",
                                                              fh = ik, index = 13)
    
    Comb_interval_score_R3_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R3, series = "female",
                                                              fh = ik, index = 14)
    
    Comb_interval_score_R4_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R4, series = "female",
                                                              fh = ik, index = 15)
    
    Comb_interval_score_R5_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R5, series = "female",
                                                              fh = ik, index = 16)
    
    Comb_interval_score_R6_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R6, series = "female",
                                                              fh = ik, index = 17)
    
    Comb_interval_score_R7_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R7, series = "female",
                                                              fh = ik, index = 18)
    
    Comb_interval_score_R8_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R8, series = "female",
                                                              fh = ik, index = 19)
    
    # Level 3 (male)
    Comb_interval_score_R1_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R1, series = "male",
                                                            fh = ik, index = 20)
    
    Comb_interval_score_R2_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R2, series = "male",
                                                            fh = ik, index = 21)
    
    Comb_interval_score_R3_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R3, series = "male",
                                                            fh = ik, index = 22)
    
    Comb_interval_score_R4_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R4, series = "male",
                                                            fh = ik, index = 23)
    
    Comb_interval_score_R5_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R5, series = "male",
                                                            fh = ik, index = 24)
    
    Comb_interval_score_R6_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R6, series = "male",
                                                            fh = ik, index = 25)
    
    Comb_interval_score_R7_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R7, series = "male",
                                                            fh = ik, index = 26)
    
    Comb_interval_score_R8_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = ind_R8, series = "male",
                                                            fh = ik, index = 27)
    print(ik)
}

# Prefecture (total)

Comb_interval_score_P1_total  = Comb_interval_score_P2_total  = Comb_interval_score_P3_total  = Comb_interval_score_P4_total =
Comb_interval_score_P5_total  = Comb_interval_score_P6_total  = Comb_interval_score_P7_total  = Comb_interval_score_P8_total =
Comb_interval_score_P9_total  = Comb_interval_score_P10_total = Comb_interval_score_P11_total = Comb_interval_score_P12_total =
Comb_interval_score_P13_total = Comb_interval_score_P14_total = Comb_interval_score_P15_total = Comb_interval_score_P16_total =
Comb_interval_score_P17_total = Comb_interval_score_P18_total = Comb_interval_score_P19_total = Comb_interval_score_P20_total =
Comb_interval_score_P21_total = Comb_interval_score_P22_total = Comb_interval_score_P23_total = Comb_interval_score_P24_total =
Comb_interval_score_P25_total = Comb_interval_score_P26_total = Comb_interval_score_P27_total = Comb_interval_score_P28_total =
Comb_interval_score_P29_total = Comb_interval_score_P30_total = Comb_interval_score_P31_total = Comb_interval_score_P32_total =
Comb_interval_score_P33_total = Comb_interval_score_P34_total = Comb_interval_score_P35_total = Comb_interval_score_P36_total =
Comb_interval_score_P37_total = Comb_interval_score_P38_total = Comb_interval_score_P39_total = Comb_interval_score_P40_total =
Comb_interval_score_P41_total = Comb_interval_score_P42_total = Comb_interval_score_P43_total = Comb_interval_score_P44_total =
Comb_interval_score_P45_total = Comb_interval_score_P46_total = Comb_interval_score_P47_total = vector("numeric",15)
for(ik in 1:15)
{
    Comb_interval_score_P1_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Hokkaido, series = "total",
                                                             fh = ik, index = 28)
    
    Comb_interval_score_P2_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Aomori, series = "total",
                                                             fh = ik, index = 29)
    
    Comb_interval_score_P3_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Iwate, series = "total",
                                                             fh = ik, index = 30)
    
    Comb_interval_score_P4_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Miyagi, series = "total",
                                                             fh = ik, index = 31)
    
    Comb_interval_score_P5_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Akita, series = "total",
                                                             fh = ik, index = 32)
    
    Comb_interval_score_P6_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Yamagata, series = "total",
                                                             fh = ik, index = 33)
    
    Comb_interval_score_P7_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Fukushima, series = "total",
                                                             fh = ik, index = 34)
    
    Comb_interval_score_P8_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Ibaraki, series = "total",
                                                             fh = ik, index = 35)
    
    Comb_interval_score_P9_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Tochigi, series = "total",
                                                             fh = ik, index = 36)
    
    Comb_interval_score_P10_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Gunma, series = "total",
                                                              fh = ik, index = 37)
    
    Comb_interval_score_P11_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Saitama, series = "total",
                                                              fh = ik, index = 38)
    
    Comb_interval_score_P12_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Chiba, series = "total",
                                                              fh = ik, index = 39)
    
    Comb_interval_score_P13_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Tokyo, series = "total",
                                                              fh = ik, index = 40)
    
    Comb_interval_score_P14_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kanagawa, series = "total",
                                                              fh = ik, index = 41)
    
    Comb_interval_score_P15_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Niigata, series = "total",
                                                              fh = ik, index = 42)
    
    Comb_interval_score_P16_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Toyama, series = "total",
                                                              fh = ik, index = 43)
    
    Comb_interval_score_P17_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Ishikawa, series = "total",
                                                              fh = ik, index = 44)
    
    Comb_interval_score_P18_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Fukui, series = "total",
                                                              fh = ik, index = 45)
    
    Comb_interval_score_P19_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Yamanashi, series = "total",
                                                              fh = ik, index = 46)
    
    Comb_interval_score_P20_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Nagano, series = "total",
                                                              fh = ik, index = 47)
    
    Comb_interval_score_P21_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Gifu, series = "total",
                                                              fh = ik, index = 48)
    
    Comb_interval_score_P22_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Shizuoka, series = "total",
                                                              fh = ik, index = 49)
    
    Comb_interval_score_P23_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Aichi, series = "total",
                                                              fh = ik, index = 50)
    
    Comb_interval_score_P24_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Mie, series = "total",
                                                              fh = ik, index = 51)
    
    Comb_interval_score_P25_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Shiga, series = "total",
                                                              fh = ik, index = 52)
    
    Comb_interval_score_P26_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kyoto, series = "total",
                                                              fh = ik, index = 53)
    
    Comb_interval_score_P27_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Osaka, series = "total",
                                                              fh = ik, index = 54)
    
    Comb_interval_score_P28_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Hyogo, series = "total",
                                                              fh = ik, index = 55)
    
    Comb_interval_score_P29_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Nara, series = "total",
                                                              fh = ik, index = 56)
    
    Comb_interval_score_P30_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Wakayama, series = "total",
                                                              fh = ik, index = 57)
    
    Comb_interval_score_P31_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Tottori, series = "total",
                                                              fh = ik, index = 58)
    
    Comb_interval_score_P32_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Shimane, series = "total",
                                                              fh = ik, index = 59)
    
    Comb_interval_score_P33_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Okayama, series = "total",
                                                              fh = ik, index = 60)
    
    Comb_interval_score_P34_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Hiroshima, series = "total",
                                                              fh = ik, index = 61)
    
    Comb_interval_score_P35_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Yamaguchi, series = "total",
                                                              fh = ik, index = 62)
    
    Comb_interval_score_P36_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Tokushima, series = "total",
                                                              fh = ik, index = 63)
    
    Comb_interval_score_P37_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kagawa, series = "total",
                                                              fh = ik, index = 64)
    
    Comb_interval_score_P38_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Ehime, series = "total",
                                                              fh = ik, index = 65)
    
    Comb_interval_score_P39_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kochi, series = "total",
                                                              fh = ik, index = 66)
    
    Comb_interval_score_P40_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Fukuoka, series = "total",
                                                              fh = ik, index = 67)
    
    Comb_interval_score_P41_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Saga, series = "total",
                                                              fh = ik, index = 68)
    
    Comb_interval_score_P42_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Nagasaki, series = "total",
                                                              fh = ik, index = 69)
    
    Comb_interval_score_P43_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kumamoto, series = "total",
                                                              fh = ik, index = 70)
    
    Comb_interval_score_P44_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Oita, series = "total",
                                                              fh = ik, index = 71)
    
    Comb_interval_score_P45_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Miyazaki, series = "total",
                                                              fh = ik, index = 72)
    
    Comb_interval_score_P46_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kagoshima, series = "total",
                                                              fh = ik, index = 73)
    
    Comb_interval_score_P47_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Okinawa, series = "total",
                                                              fh = ik, index = 74)
    print(ik)
}

# Prefecture + Sex

Comb_interval_score_P1_female  = Comb_interval_score_P2_female  = Comb_interval_score_P3_female  = Comb_interval_score_P4_female =
Comb_interval_score_P5_female  = Comb_interval_score_P6_female  = Comb_interval_score_P7_female  = Comb_interval_score_P8_female =
Comb_interval_score_P9_female  = Comb_interval_score_P10_female = Comb_interval_score_P11_female = Comb_interval_score_P12_female =
Comb_interval_score_P13_female = Comb_interval_score_P14_female = Comb_interval_score_P15_female = Comb_interval_score_P16_female =
Comb_interval_score_P17_female = Comb_interval_score_P18_female = Comb_interval_score_P19_female = Comb_interval_score_P20_female =
Comb_interval_score_P21_female = Comb_interval_score_P22_female = Comb_interval_score_P23_female = Comb_interval_score_P24_female =
Comb_interval_score_P25_female = Comb_interval_score_P26_female = Comb_interval_score_P27_female = Comb_interval_score_P28_female =
Comb_interval_score_P29_female = Comb_interval_score_P30_female = Comb_interval_score_P31_female = Comb_interval_score_P32_female =
Comb_interval_score_P33_female = Comb_interval_score_P34_female = Comb_interval_score_P35_female = Comb_interval_score_P36_female =
Comb_interval_score_P37_female = Comb_interval_score_P38_female = Comb_interval_score_P39_female = Comb_interval_score_P40_female =
Comb_interval_score_P41_female = Comb_interval_score_P42_female = Comb_interval_score_P43_female = Comb_interval_score_P44_female =
Comb_interval_score_P45_female = Comb_interval_score_P46_female = Comb_interval_score_P47_female = vector("numeric",15)
for(ik in 1:15)
{
    Comb_interval_score_P1_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Hokkaido, series = "female",
                                                              fh = ik, index = 75)
    
    Comb_interval_score_P2_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Aomori, series = "female",
                                                              fh = ik, index = 77)
    
    Comb_interval_score_P3_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Iwate, series = "female",
                                                              fh = ik, index = 79)
    
    Comb_interval_score_P4_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Miyagi, series = "female",
                                                              fh = ik, index = 81)
    
    Comb_interval_score_P5_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Akita, series = "female",
                                                              fh = ik, index = 83)
    
    Comb_interval_score_P6_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Yamagata, series = "female",
                                                              fh = ik, index = 85)
    
    Comb_interval_score_P7_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Fukushima, series = "female",
                                                              fh = ik, index = 87)
    
    Comb_interval_score_P8_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Ibaraki, series = "female",
                                                              fh = ik, index = 89)
    
    Comb_interval_score_P9_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Tochigi, series = "female",
                                                              fh = ik, index = 91)
    
    Comb_interval_score_P10_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Gunma, series = "female",
                                                               fh = ik, index = 93)
    
    Comb_interval_score_P11_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Saitama, series = "female",
                                                               fh = ik, index = 95)
    
    Comb_interval_score_P12_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Chiba, series = "female",
                                                               fh = ik, index = 97)
    
    Comb_interval_score_P13_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Tokyo, series = "female",
                                                               fh = ik, index = 99)
    
    Comb_interval_score_P14_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kanagawa, series = "female",
                                                               fh = ik, index = 101)
    
    Comb_interval_score_P15_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Niigata, series = "female",
                                                               fh = ik, index = 103)
    
    Comb_interval_score_P16_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Toyama, series = "female",
                                                               fh = ik, index = 105)
    
    Comb_interval_score_P17_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Ishikawa, series = "female",
                                                               fh = ik, index = 107)
    
    Comb_interval_score_P18_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Fukui, series = "female",
                                                               fh = ik, index = 109)
    
    Comb_interval_score_P19_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Yamanashi, series = "female",
                                                               fh = ik, index = 111)
    
    Comb_interval_score_P20_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Nagano, series = "female",
                                                               fh = ik, index = 113)
    
    Comb_interval_score_P21_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Gifu, series = "female",
                                                               fh = ik, index = 115)
    
    Comb_interval_score_P22_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Shizuoka, series = "female",
                                                               fh = ik, index = 117)
    
    Comb_interval_score_P23_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Aichi, series = "female",
                                                               fh = ik, index = 119)
    
    Comb_interval_score_P24_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Mie, series = "female",
                                                               fh = ik, index = 121)
    
    Comb_interval_score_P25_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Shiga, series = "female",
                                                               fh = ik, index = 123)
    
    Comb_interval_score_P26_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kyoto, series = "female",
                                                               fh = ik, index = 125)
    
    Comb_interval_score_P27_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Osaka, series = "female",
                                                               fh = ik, index = 127)
    
    Comb_interval_score_P28_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Hyogo, series = "female",
                                                               fh = ik, index = 129)
    
    Comb_interval_score_P29_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Nara, series = "female",
                                                               fh = ik, index = 131)
    
    Comb_interval_score_P30_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Wakayama, series = "female",
                                                               fh = ik, index = 133)
    
    Comb_interval_score_P31_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Tottori, series = "female",
                                                               fh = ik, index = 135)
    
    Comb_interval_score_P32_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Shimane, series = "female",
                                                               fh = ik, index = 137)
    
    Comb_interval_score_P33_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Okayama, series = "female",
                                                               fh = ik, index = 139)
    
    Comb_interval_score_P34_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Hiroshima, series = "female",
                                                               fh = ik, index = 141)
    
    Comb_interval_score_P35_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Yamaguchi, series = "female",
                                                               fh = ik, index = 143)
    
    Comb_interval_score_P36_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Tokushima, series = "female",
                                                               fh = ik, index = 145)
    
    Comb_interval_score_P37_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kagawa, series = "female",
                                                               fh = ik, index = 147)
    
    Comb_interval_score_P38_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Ehime, series = "female",
                                                               fh = ik, index = 149)
    
    Comb_interval_score_P39_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kochi, series = "female",
                                                               fh = ik, index = 151)
    
    Comb_interval_score_P40_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Fukuoka, series = "female",
                                                               fh = ik, index = 153)
    
    Comb_interval_score_P41_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Saga, series = "female",
                                                               fh = ik, index = 155)
    
    Comb_interval_score_P42_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Nagasaki, series = "female",
                                                               fh = ik, index = 157)
    
    Comb_interval_score_P43_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kumamoto, series = "female",
                                                               fh = ik, index = 159)
    
    Comb_interval_score_P44_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Oita, series = "female",
                                                               fh = ik, index = 161)
    
    Comb_interval_score_P45_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Miyazaki, series = "female",
                                                               fh = ik, index = 163)
    
    Comb_interval_score_P46_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kagoshima, series = "female",
                                                               fh = ik, index = 165)
    
    Comb_interval_score_P47_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Okinawa, series = "female",
                                                               fh = ik, index = 167)
    print(ik)
}


Comb_interval_score_P1_male  = Comb_interval_score_P2_male  = Comb_interval_score_P3_male  = Comb_interval_score_P4_male =
Comb_interval_score_P5_male  = Comb_interval_score_P6_male  = Comb_interval_score_P7_male  = Comb_interval_score_P8_male =
Comb_interval_score_P9_male  = Comb_interval_score_P10_male = Comb_interval_score_P11_male = Comb_interval_score_P12_male =
Comb_interval_score_P13_male = Comb_interval_score_P14_male = Comb_interval_score_P15_male = Comb_interval_score_P16_male =
Comb_interval_score_P17_male = Comb_interval_score_P18_male = Comb_interval_score_P19_male = Comb_interval_score_P20_male =
Comb_interval_score_P21_male = Comb_interval_score_P22_male = Comb_interval_score_P23_male = Comb_interval_score_P24_male =
Comb_interval_score_P25_male = Comb_interval_score_P26_male = Comb_interval_score_P27_male = Comb_interval_score_P28_male =
Comb_interval_score_P29_male = Comb_interval_score_P30_male = Comb_interval_score_P31_male = Comb_interval_score_P32_male =
Comb_interval_score_P33_male = Comb_interval_score_P34_male = Comb_interval_score_P35_male = Comb_interval_score_P36_male =
Comb_interval_score_P37_male = Comb_interval_score_P38_male = Comb_interval_score_P39_male = Comb_interval_score_P40_male =
Comb_interval_score_P41_male = Comb_interval_score_P42_male = Comb_interval_score_P43_male = Comb_interval_score_P44_male =
Comb_interval_score_P45_male = Comb_interval_score_P46_male = Comb_interval_score_P47_male = vector("numeric",15)
for(ik in 1:15)
{
    Comb_interval_score_P1_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Hokkaido, series = "male",
                                                            fh = ik, index = 76)
    
    Comb_interval_score_P2_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Aomori, series = "male",
                                                            fh = ik, index = 78)
    
    Comb_interval_score_P3_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Iwate, series = "male",
                                                            fh = ik, index = 80)
    
    Comb_interval_score_P4_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Miyagi, series = "male",
                                                            fh = ik, index = 82)
    
    Comb_interval_score_P5_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Akita, series = "male",
                                                            fh = ik, index = 84)
    
    Comb_interval_score_P6_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Yamagata, series = "male",
                                                            fh = ik, index = 86)
    
    Comb_interval_score_P7_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Fukushima, series = "male",
                                                            fh = ik, index = 88)
    
    Comb_interval_score_P8_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Ibaraki, series = "male",
                                                            fh = ik, index = 90)
    
    Comb_interval_score_P9_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Tochigi, series = "male",
                                                            fh = ik, index = 92)
    
    Comb_interval_score_P10_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Gunma, series = "male",
                                                             fh = ik, index = 94)
    
    Comb_interval_score_P11_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Saitama, series = "male",
                                                             fh = ik, index = 96)
    
    Comb_interval_score_P12_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Chiba, series = "male",
                                                             fh = ik, index = 98)
    
    Comb_interval_score_P13_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Tokyo, series = "male",
                                                             fh = ik, index = 100)
    
    Comb_interval_score_P14_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kanagawa, series = "male",
                                                             fh = ik, index = 102)
    
    Comb_interval_score_P15_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Niigata, series = "male",
                                                             fh = ik, index = 104)
    
    Comb_interval_score_P16_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Toyama, series = "male",
                                                             fh = ik, index = 106)
    
    Comb_interval_score_P17_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Ishikawa, series = "male",
                                                             fh = ik, index = 108)
    
    Comb_interval_score_P18_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Fukui, series = "male",
                                                             fh = ik, index = 110)
    
    Comb_interval_score_P19_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Yamanashi, series = "male",
                                                             fh = ik, index = 112)
    
    Comb_interval_score_P20_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Nagano, series = "male",
                                                             fh = ik, index = 114)
    
    Comb_interval_score_P21_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Gifu, series = "male",
                                                             fh = ik, index = 116)
    
    Comb_interval_score_P22_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Shizuoka, series = "male",
                                                             fh = ik, index = 118)
    
    Comb_interval_score_P23_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Aichi, series = "male",
                                                             fh = ik, index = 120)
    
    Comb_interval_score_P24_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Mie, series = "male",
                                                             fh = ik, index = 122)
    
    Comb_interval_score_P25_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Shiga, series = "male",
                                                             fh = ik, index = 124)
    
    Comb_interval_score_P26_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kyoto, series = "male",
                                                             fh = ik, index = 126)
    
    Comb_interval_score_P27_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Osaka, series = "male",
                                                             fh = ik, index = 128)
    
    Comb_interval_score_P28_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Hyogo, series = "male",
                                                             fh = ik, index = 130)
    
    Comb_interval_score_P29_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Nara, series = "male",
                                                             fh = ik, index = 132)
    
    Comb_interval_score_P30_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Wakayama, series = "male",
                                                             fh = ik, index = 134)
    
    Comb_interval_score_P31_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Tottori, series = "male",
                                                             fh = ik, index = 136)
    
    Comb_interval_score_P32_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Shimane, series = "male",
                                                             fh = ik, index = 138)
    
    Comb_interval_score_P33_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Okayama, series = "male",
                                                             fh = ik, index = 140)
    
    Comb_interval_score_P34_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Hiroshima, series = "male",
                                                             fh = ik, index = 142)
    
    Comb_interval_score_P35_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Yamaguchi, series = "male",
                                                             fh = ik, index = 144)
    
    Comb_interval_score_P36_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Tokushima, series = "male",
                                                             fh = ik, index = 146)
    
    Comb_interval_score_P37_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kagawa, series = "male",
                                                             fh = ik, index = 148)
    
    Comb_interval_score_P38_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Ehime, series = "male",
                                                             fh = ik, index = 150)
    
    Comb_interval_score_P39_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kochi, series = "male",
                                                             fh = ik, index = 152)
    
    Comb_interval_score_P40_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Fukuoka, series = "male",
                                                             fh = ik, index = 154)
    
    Comb_interval_score_P41_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Saga, series = "male",
                                                             fh = ik, index = 156)
    
    Comb_interval_score_P42_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Nagasaki, series = "male",
                                                             fh = ik, index = 158)
    
    Comb_interval_score_P43_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kumamoto, series = "male",
                                                             fh = ik, index = 160)
    
    Comb_interval_score_P44_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Oita, series = "male",
                                                             fh = ik, index = 162)
    
    Comb_interval_score_P45_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Miyazaki, series = "male",
                                                             fh = ik, index = 164)
    
    Comb_interval_score_P46_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Kagoshima, series = "male",
                                                             fh = ik, index = 166)
    
    Comb_interval_score_P47_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb, data_series = Okinawa, series = "male",
                                                             fh = ik, index = 168)
}

Comb_interval_score_Level_0 = Comb_interval_score_Japan_total

Comb_interval_score_Level_1 = rowMeans(cbind(Comb_interval_score_Japan_female, Comb_interval_score_Japan_male))

Comb_interval_score_Level_2 = rowMeans(cbind(Comb_interval_score_R1_total, Comb_interval_score_R2_total, Comb_interval_score_R3_total, Comb_interval_score_R4_total,
                                           Comb_interval_score_R5_total, Comb_interval_score_R6_total, Comb_interval_score_R7_total, Comb_interval_score_R8_total))

Comb_interval_score_Level_3 = rowMeans(cbind(Comb_interval_score_R1_female, Comb_interval_score_R2_female, Comb_interval_score_R3_female, Comb_interval_score_R4_female,
                                           Comb_interval_score_R5_female, Comb_interval_score_R6_female, Comb_interval_score_R7_female, Comb_interval_score_R8_female,
                                           Comb_interval_score_R1_male, Comb_interval_score_R2_male, Comb_interval_score_R3_male, Comb_interval_score_R4_male,
                                           Comb_interval_score_R5_male, Comb_interval_score_R6_male, Comb_interval_score_R7_male, Comb_interval_score_R8_male))

Comb_interval_score_Level_4 = rowMeans(cbind(Comb_interval_score_P1_total,  Comb_interval_score_P2_total,  Comb_interval_score_P3_total,  Comb_interval_score_P4_total,  Comb_interval_score_P5_total,
                                           Comb_interval_score_P6_total,  Comb_interval_score_P7_total,  Comb_interval_score_P8_total,  Comb_interval_score_P9_total,  Comb_interval_score_P10_total,
                                           Comb_interval_score_P11_total, Comb_interval_score_P12_total, Comb_interval_score_P13_total, Comb_interval_score_P14_total, Comb_interval_score_P15_total,
                                           Comb_interval_score_P16_total, Comb_interval_score_P17_total, Comb_interval_score_P18_total, Comb_interval_score_P19_total, Comb_interval_score_P20_total,
                                           Comb_interval_score_P21_total, Comb_interval_score_P22_total, Comb_interval_score_P23_total, Comb_interval_score_P24_total, Comb_interval_score_P25_total,
                                           Comb_interval_score_P26_total, Comb_interval_score_P27_total, Comb_interval_score_P28_total, Comb_interval_score_P29_total, Comb_interval_score_P30_total,
                                           Comb_interval_score_P31_total, Comb_interval_score_P32_total, Comb_interval_score_P33_total, Comb_interval_score_P34_total, Comb_interval_score_P35_total,
                                           Comb_interval_score_P36_total, Comb_interval_score_P37_total, Comb_interval_score_P38_total, Comb_interval_score_P39_total, Comb_interval_score_P40_total,
                                           Comb_interval_score_P41_total, Comb_interval_score_P42_total, Comb_interval_score_P43_total, Comb_interval_score_P44_total, Comb_interval_score_P45_total,
                                           Comb_interval_score_P46_total, Comb_interval_score_P47_total))

Comb_interval_score_Level_5 = rowMeans(cbind(Comb_interval_score_P1_female,  Comb_interval_score_P2_female,  Comb_interval_score_P3_female,  Comb_interval_score_P4_female,  Comb_interval_score_P5_female,
                                           Comb_interval_score_P6_female,  Comb_interval_score_P7_female,  Comb_interval_score_P8_female,  Comb_interval_score_P9_female,  Comb_interval_score_P10_female,
                                           Comb_interval_score_P11_female, Comb_interval_score_P12_female, Comb_interval_score_P13_female, Comb_interval_score_P14_female, Comb_interval_score_P15_female,
                                           Comb_interval_score_P16_female, Comb_interval_score_P17_female, Comb_interval_score_P18_female, Comb_interval_score_P19_female, Comb_interval_score_P20_female,
                                           Comb_interval_score_P21_female, Comb_interval_score_P22_female, Comb_interval_score_P23_female, Comb_interval_score_P24_female, Comb_interval_score_P25_female,
                                           Comb_interval_score_P26_female, Comb_interval_score_P27_female, Comb_interval_score_P28_female, Comb_interval_score_P29_female, Comb_interval_score_P30_female,
                                           Comb_interval_score_P31_female, Comb_interval_score_P32_female, Comb_interval_score_P33_female, Comb_interval_score_P34_female, Comb_interval_score_P35_female,
                                           Comb_interval_score_P36_female, Comb_interval_score_P37_female, Comb_interval_score_P38_female, Comb_interval_score_P39_female, Comb_interval_score_P40_female,
                                           Comb_interval_score_P41_female, Comb_interval_score_P42_female, Comb_interval_score_P43_female, Comb_interval_score_P44_female, Comb_interval_score_P45_female,
                                           Comb_interval_score_P46_female, Comb_interval_score_P47_female,
                                           Comb_interval_score_P1_male,  Comb_interval_score_P2_male,  Comb_interval_score_P3_male,  Comb_interval_score_P4_male,  Comb_interval_score_P5_male,
                                           Comb_interval_score_P6_male,  Comb_interval_score_P7_male,  Comb_interval_score_P8_male,  Comb_interval_score_P9_male,  Comb_interval_score_P10_male,
                                           Comb_interval_score_P11_male, Comb_interval_score_P12_male, Comb_interval_score_P13_male, Comb_interval_score_P14_male, Comb_interval_score_P15_male,
                                           Comb_interval_score_P16_male, Comb_interval_score_P17_male, Comb_interval_score_P18_male, Comb_interval_score_P19_male, Comb_interval_score_P20_male,
                                           Comb_interval_score_P21_male, Comb_interval_score_P22_male, Comb_interval_score_P23_male, Comb_interval_score_P24_male, Comb_interval_score_P25_male,
                                           Comb_interval_score_P26_male, Comb_interval_score_P27_male, Comb_interval_score_P28_male, Comb_interval_score_P29_male, Comb_interval_score_P30_male,
                                           Comb_interval_score_P31_male, Comb_interval_score_P32_male, Comb_interval_score_P33_male, Comb_interval_score_P34_male, Comb_interval_score_P35_male,
                                           Comb_interval_score_P36_male, Comb_interval_score_P37_male, Comb_interval_score_P38_male, Comb_interval_score_P39_male, Comb_interval_score_P40_male,
                                           Comb_interval_score_P41_male, Comb_interval_score_P42_male, Comb_interval_score_P43_male, Comb_interval_score_P44_male, Comb_interval_score_P45_male,
                                           Comb_interval_score_P46_male, Comb_interval_score_P47_male))


Comb_interval_score_all = cbind(Comb_interval_score_Level_0, Comb_interval_score_Level_1, Comb_interval_score_Level_2, Comb_interval_score_Level_3, Comb_interval_score_Level_4, Comb_interval_score_Level_5)
Comb_interval_score_all_stats = rbind(Comb_interval_score_all, colMeans(Comb_interval_score_all), apply(Comb_interval_score_all, 2, median))
colnames(Comb_interval_score_all_stats) = c("Level 0", "Level 1", "Level 2", "Level 3", "Level 4", "Level 5")
rownames(Comb_interval_score_all_stats) = c(1:15,"Mean","Median")

#########################################################################
# Calculate mean interval score for different levels of a hierarchy (BU)
#########################################################################

# Japan + Sex

Comb_interval_score_Japan_total_mfts = Comb_interval_score_Japan_female_mfts = Comb_interval_score_Japan_male_mfts = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 0
    Comb_interval_score_Japan_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Japan, series = "total",
                                                                     fh = ik, index = 1)
    
    # Level 1
    Comb_interval_score_Japan_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Japan, series = "female",
                                                                      fh = ik, index = 2)
    
    Comb_interval_score_Japan_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Japan, series = "male",
                                                                    fh = ik, index = 3)
    print(ik)
}

# Region (total)

Comb_interval_score_R1_total_mfts = Comb_interval_score_R2_total_mfts = Comb_interval_score_R3_total_mfts = Comb_interval_score_R4_total_mfts =
Comb_interval_score_R5_total_mfts = Comb_interval_score_R6_total_mfts = Comb_interval_score_R7_total_mfts = Comb_interval_score_R8_total_mfts = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 2
    Comb_interval_score_R1_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R1, series = "total",
                                                                  fh = ik, index = 4)
    
    Comb_interval_score_R2_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R2, series = "total",
                                                                  fh = ik, index = 5)
    
    Comb_interval_score_R3_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R3, series = "total",
                                                                  fh = ik, index = 6)
    
    Comb_interval_score_R4_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R4, series = "total",
                                                                  fh = ik, index = 7)
    
    Comb_interval_score_R5_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R5, series = "total",
                                                                  fh = ik, index = 8)
    
    Comb_interval_score_R6_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R6, series = "total",
                                                                  fh = ik, index = 9)
    
    Comb_interval_score_R7_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R7, series = "total",
                                                                  fh = ik, index = 10)
    
    Comb_interval_score_R8_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R8, series = "total",
                                                                  fh = ik, index = 11)
    print(ik)
}

# Region + Sex

Comb_interval_score_R1_female_mfts = Comb_interval_score_R2_female_mfts = Comb_interval_score_R3_female_mfts = Comb_interval_score_R4_female_mfts =
Comb_interval_score_R5_female_mfts = Comb_interval_score_R6_female_mfts = Comb_interval_score_R7_female_mfts = Comb_interval_score_R8_female_mfts =
Comb_interval_score_R1_male_mfts = Comb_interval_score_R2_male_mfts = Comb_interval_score_R3_male_mfts = Comb_interval_score_R4_male_mfts =
Comb_interval_score_R5_male_mfts = Comb_interval_score_R6_male_mfts = Comb_interval_score_R7_male_mfts = Comb_interval_score_R8_male_mfts = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 3 (female)
    Comb_interval_score_R1_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R1, series = "female",
                                                                   fh = ik, index = 12)
    
    Comb_interval_score_R2_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R2, series = "female",
                                                                   fh = ik, index = 13)
    
    Comb_interval_score_R3_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R3, series = "female",
                                                                   fh = ik, index = 14)
    
    Comb_interval_score_R4_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R4, series = "female",
                                                                   fh = ik, index = 15)
    
    Comb_interval_score_R5_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R5, series = "female",
                                                                   fh = ik, index = 16)
    
    Comb_interval_score_R6_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R6, series = "female",
                                                                   fh = ik, index = 17)
    
    Comb_interval_score_R7_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R7, series = "female",
                                                                   fh = ik, index = 18)
    
    Comb_interval_score_R8_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R8, series = "female",
                                                                   fh = ik, index = 19)
    
    # Level 3 (male)
    Comb_interval_score_R1_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R1, series = "male",
                                                                 fh = ik, index = 20)
    
    Comb_interval_score_R2_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R2, series = "male",
                                                                 fh = ik, index = 21)
    
    Comb_interval_score_R3_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R3, series = "male",
                                                                 fh = ik, index = 22)
    
    Comb_interval_score_R4_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R4, series = "male",
                                                                 fh = ik, index = 23)
    
    Comb_interval_score_R5_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R5, series = "male",
                                                                 fh = ik, index = 24)
    
    Comb_interval_score_R6_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R6, series = "male",
                                                                 fh = ik, index = 25)
    
    Comb_interval_score_R7_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R7, series = "male",
                                                                 fh = ik, index = 26)
    
    Comb_interval_score_R8_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = ind_R8, series = "male",
                                                                 fh = ik, index = 27)
    print(ik)
}

# prefecture (total)

Comb_interval_score_P1_total_mfts  = Comb_interval_score_P2_total_mfts  = Comb_interval_score_P3_total_mfts  = Comb_interval_score_P4_total_mfts =
Comb_interval_score_P5_total_mfts  = Comb_interval_score_P6_total_mfts  = Comb_interval_score_P7_total_mfts  = Comb_interval_score_P8_total_mfts =
Comb_interval_score_P9_total_mfts  = Comb_interval_score_P10_total_mfts = Comb_interval_score_P11_total_mfts = Comb_interval_score_P12_total_mfts =
Comb_interval_score_P13_total_mfts = Comb_interval_score_P14_total_mfts = Comb_interval_score_P15_total_mfts = Comb_interval_score_P16_total_mfts =
Comb_interval_score_P17_total_mfts = Comb_interval_score_P18_total_mfts = Comb_interval_score_P19_total_mfts = Comb_interval_score_P20_total_mfts =
Comb_interval_score_P21_total_mfts = Comb_interval_score_P22_total_mfts = Comb_interval_score_P23_total_mfts = Comb_interval_score_P24_total_mfts =
Comb_interval_score_P25_total_mfts = Comb_interval_score_P26_total_mfts = Comb_interval_score_P27_total_mfts = Comb_interval_score_P28_total_mfts =
Comb_interval_score_P29_total_mfts = Comb_interval_score_P30_total_mfts = Comb_interval_score_P31_total_mfts = Comb_interval_score_P32_total_mfts =
Comb_interval_score_P33_total_mfts = Comb_interval_score_P34_total_mfts = Comb_interval_score_P35_total_mfts = Comb_interval_score_P36_total_mfts =
Comb_interval_score_P37_total_mfts = Comb_interval_score_P38_total_mfts = Comb_interval_score_P39_total_mfts = Comb_interval_score_P40_total_mfts =
Comb_interval_score_P41_total_mfts = Comb_interval_score_P42_total_mfts = Comb_interval_score_P43_total_mfts = Comb_interval_score_P44_total_mfts =
Comb_interval_score_P45_total_mfts = Comb_interval_score_P46_total_mfts = Comb_interval_score_P47_total_mfts = vector("numeric",15)
for(ik in 1:15)
{
    Comb_interval_score_P1_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Hokkaido, series = "total",
                                                                  fh = ik, index = 28)
    
    Comb_interval_score_P2_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Aomori, series = "total",
                                                                  fh = ik, index = 29)
    
    Comb_interval_score_P3_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Iwate, series = "total",
                                                                  fh = ik, index = 30)
    
    Comb_interval_score_P4_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Miyagi, series = "total",
                                                                  fh = ik, index = 31)
    
    Comb_interval_score_P5_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Akita, series = "total",
                                                                  fh = ik, index = 32)
    
    Comb_interval_score_P6_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Yamagata, series = "total",
                                                                  fh = ik, index = 33)
    
    Comb_interval_score_P7_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Fukushima, series = "total",
                                                                  fh = ik, index = 34)
    
    Comb_interval_score_P8_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Ibaraki, series = "total",
                                                                  fh = ik, index = 35)
    
    Comb_interval_score_P9_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Tochigi, series = "total",
                                                                  fh = ik, index =  36)
    
    Comb_interval_score_P10_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Gunma, series = "total",
                                                                   fh = ik, index = 37)
    
    Comb_interval_score_P11_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Saitama, series = "total",
                                                                   fh = ik, index = 38)
    
    Comb_interval_score_P12_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Chiba, series = "total",
                                                                   fh = ik, index = 39)
    
    Comb_interval_score_P13_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Tokyo, series = "total",
                                                                   fh = ik, index = 40)
    
    Comb_interval_score_P14_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kanagawa, series = "total",
                                                                   fh = ik, index = 41)
    
    Comb_interval_score_P15_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Niigata, series = "total",
                                                                   fh = ik, index = 42)
    
    Comb_interval_score_P16_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Toyama, series = "total",
                                                                   fh = ik, index = 43)
    
    Comb_interval_score_P17_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Ishikawa, series = "total",
                                                                   fh = ik, index = 44)
    
    Comb_interval_score_P18_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Fukui, series = "total",
                                                                   fh = ik, index = 45)
    
    Comb_interval_score_P19_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Yamanashi, series = "total",
                                                                   fh = ik, index = 46)
    
    Comb_interval_score_P20_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Nagano, series = "total",
                                                                   fh = ik, index = 47)
    
    Comb_interval_score_P21_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Gifu, series = "total",
                                                                   fh = ik, index = 48)
    
    Comb_interval_score_P22_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Shizuoka, series = "total",
                                                                   fh = ik, index = 49)
    
    Comb_interval_score_P23_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Aichi, series = "total",
                                                                   fh = ik, index = 50)
    
    Comb_interval_score_P24_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Mie, series = "total",
                                                                   fh = ik, index = 51)
    
    Comb_interval_score_P25_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Shiga, series = "total",
                                                                   fh = ik, index = 52)
    
    Comb_interval_score_P26_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kyoto, series = "total",
                                                                   fh = ik, index = 53)
    
    Comb_interval_score_P27_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Osaka, series = "total",
                                                                   fh = ik, index = 54)
    
    Comb_interval_score_P28_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Hyogo, series = "total",
                                                                   fh = ik, index = 55)
    
    Comb_interval_score_P29_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Nara, series = "total",
                                                                   fh = ik, index = 56)
    
    Comb_interval_score_P30_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Wakayama, series = "total",
                                                                   fh = ik, index = 57)
    
    Comb_interval_score_P31_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Tottori, series = "total",
                                                                   fh = ik, index = 58)
    
    Comb_interval_score_P32_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Shimane, series = "total",
                                                                   fh = ik, index = 59)
    
    Comb_interval_score_P33_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Okayama, series = "total",
                                                                   fh = ik, index = 60)
    
    Comb_interval_score_P34_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Hiroshima, series = "total",
                                                                   fh = ik, index = 61)
    
    Comb_interval_score_P35_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Yamaguchi, series = "total",
                                                                   fh = ik, index = 62)
    
    Comb_interval_score_P36_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Tokushima, series = "total",
                                                                   fh = ik, index = 63)
    
    Comb_interval_score_P37_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kagawa, series = "total",
                                                                   fh = ik, index = 64)
    
    Comb_interval_score_P38_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Ehime, series = "total",
                                                                   fh = ik, index = 65)
    
    Comb_interval_score_P39_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kochi, series = "total",
                                                                   fh = ik, index = 66)
    
    Comb_interval_score_P40_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Fukuoka, series = "total",
                                                                   fh = ik, index = 67)
    
    Comb_interval_score_P41_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Saga, series = "total",
                                                                   fh = ik, index = 68)
    
    Comb_interval_score_P42_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Nagasaki, series = "total",
                                                                   fh = ik, index = 69)
    
    Comb_interval_score_P43_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kumamoto, series = "total",
                                                                   fh = ik, index = 70)
    
    Comb_interval_score_P44_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Oita, series = "total",
                                                                   fh = ik, index = 71)
    
    Comb_interval_score_P45_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Miyazaki, series = "total",
                                                                   fh = ik, index = 72)
    
    Comb_interval_score_P46_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kagoshima, series = "total",
                                                                   fh = ik, index = 73)
    
    Comb_interval_score_P47_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Okinawa, series = "total",
                                                                   fh = ik, index = 74)
    print(ik)
}

# prefecture + Sex

Comb_interval_score_P1_female_mfts  = Comb_interval_score_P2_female_mfts  = Comb_interval_score_P3_female_mfts  = Comb_interval_score_P4_female_mfts =
Comb_interval_score_P5_female_mfts  = Comb_interval_score_P6_female_mfts  = Comb_interval_score_P7_female_mfts  = Comb_interval_score_P8_female_mfts =
Comb_interval_score_P9_female_mfts  = Comb_interval_score_P10_female_mfts = Comb_interval_score_P11_female_mfts = Comb_interval_score_P12_female_mfts =
Comb_interval_score_P13_female_mfts = Comb_interval_score_P14_female_mfts = Comb_interval_score_P15_female_mfts = Comb_interval_score_P16_female_mfts =
Comb_interval_score_P17_female_mfts = Comb_interval_score_P18_female_mfts = Comb_interval_score_P19_female_mfts = Comb_interval_score_P20_female_mfts =
Comb_interval_score_P21_female_mfts = Comb_interval_score_P22_female_mfts = Comb_interval_score_P23_female_mfts = Comb_interval_score_P24_female_mfts =
Comb_interval_score_P25_female_mfts = Comb_interval_score_P26_female_mfts = Comb_interval_score_P27_female_mfts = Comb_interval_score_P28_female_mfts =
Comb_interval_score_P29_female_mfts = Comb_interval_score_P30_female_mfts = Comb_interval_score_P31_female_mfts = Comb_interval_score_P32_female_mfts =
Comb_interval_score_P33_female_mfts = Comb_interval_score_P34_female_mfts = Comb_interval_score_P35_female_mfts = Comb_interval_score_P36_female_mfts =
Comb_interval_score_P37_female_mfts = Comb_interval_score_P38_female_mfts = Comb_interval_score_P39_female_mfts = Comb_interval_score_P40_female_mfts =
Comb_interval_score_P41_female_mfts = Comb_interval_score_P42_female_mfts = Comb_interval_score_P43_female_mfts = Comb_interval_score_P44_female_mfts =
Comb_interval_score_P45_female_mfts = Comb_interval_score_P46_female_mfts = Comb_interval_score_P47_female_mfts = vector("numeric",15)
for(ik in 1:15)
{
    Comb_interval_score_P1_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Hokkaido, series = "female",
                                                                   fh = ik, index = 75)
    
    Comb_interval_score_P2_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Aomori, series = "female",
                                                                   fh = ik, index = 77)
    
    Comb_interval_score_P3_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Iwate, series = "female",
                                                                   fh = ik, index = 79)
    
    Comb_interval_score_P4_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Miyagi, series = "female",
                                                                   fh = ik, index = 81)
    
    Comb_interval_score_P5_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Akita, series = "female",
                                                                   fh = ik, index = 83)
    
    Comb_interval_score_P6_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Yamagata, series = "female",
                                                                   fh = ik, index = 85)
    
    Comb_interval_score_P7_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Fukushima, series = "female",
                                                                   fh = ik, index = 87)
    
    Comb_interval_score_P8_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Ibaraki, series = "female",
                                                                   fh = ik, index = 89)
    
    Comb_interval_score_P9_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Tochigi, series = "female",
                                                                   fh = ik, index = 91)
    
    Comb_interval_score_P10_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Gunma, series = "female",
                                                                    fh = ik, index = 93)
    
    Comb_interval_score_P11_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Saitama, series = "female",
                                                                    fh = ik, index = 95)
    
    Comb_interval_score_P12_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Chiba, series = "female",
                                                                    fh = ik, index = 97)
    
    Comb_interval_score_P13_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Tokyo, series = "female",
                                                                    fh = ik, index = 99)
    
    Comb_interval_score_P14_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kanagawa, series = "female",
                                                                    fh = ik, index = 101)
    
    Comb_interval_score_P15_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Niigata, series = "female",
                                                                    fh = ik, index = 103)
    
    Comb_interval_score_P16_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Toyama, series = "female",
                                                                    fh = ik, index = 105)
    
    Comb_interval_score_P17_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Ishikawa, series = "female",
                                                                    fh = ik, index = 107)
    
    Comb_interval_score_P18_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Fukui, series = "female",
                                                                    fh = ik, index = 109)
    
    Comb_interval_score_P19_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Yamanashi, series = "female",
                                                                    fh = ik, index = 111)
    
    Comb_interval_score_P20_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Nagano, series = "female",
                                                                    fh = ik, index = 113)
    
    Comb_interval_score_P21_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Gifu, series = "female",
                                                                    fh = ik, index = 115)
    
    Comb_interval_score_P22_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Shizuoka, series = "female",
                                                                    fh = ik, index = 117)
    
    Comb_interval_score_P23_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Aichi, series = "female",
                                                                    fh = ik, index = 119)
    
    Comb_interval_score_P24_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Mie, series = "female",
                                                                    fh = ik, index = 121)
    
    Comb_interval_score_P25_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Shiga, series = "female",
                                                                    fh = ik, index = 123)
    
    Comb_interval_score_P26_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kyoto, series = "female",
                                                                    fh = ik, index = 125)
    
    Comb_interval_score_P27_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Osaka, series = "female",
                                                                    fh = ik, index = 127)
    
    Comb_interval_score_P28_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Hyogo, series = "female",
                                                                    fh = ik, index = 129)
    
    Comb_interval_score_P29_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Nara, series = "female",
                                                                    fh = ik, index = 131)
    
    Comb_interval_score_P30_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Wakayama, series = "female",
                                                                    fh = ik, index = 133)
    
    Comb_interval_score_P31_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Tottori, series = "female",
                                                                    fh = ik, index = 135)
    
    Comb_interval_score_P32_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Shimane, series = "female",
                                                                    fh = ik, index = 137)
    
    Comb_interval_score_P33_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Okayama, series = "female",
                                                                    fh = ik, index = 139)
    
    Comb_interval_score_P34_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Hiroshima, series = "female",
                                                                    fh = ik, index = 141)
    
    Comb_interval_score_P35_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Yamaguchi, series = "female",
                                                                    fh = ik, index = 143)
    
    Comb_interval_score_P36_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Tokushima, series = "female",
                                                                    fh = ik, index = 145)
    
    Comb_interval_score_P37_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kagawa, series = "female",
                                                                    fh = ik, index = 147)
    
    Comb_interval_score_P38_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Ehime, series = "female",
                                                                    fh = ik, index = 149)
    
    Comb_interval_score_P39_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kochi, series = "female",
                                                                    fh = ik, index = 151)
    
    Comb_interval_score_P40_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Fukuoka, series = "female",
                                                                    fh = ik, index = 153)
    
    Comb_interval_score_P41_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Saga, series = "female",
                                                                    fh = ik, index = 155)
    
    Comb_interval_score_P42_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Nagasaki, series = "female",
                                                                    fh = ik, index = 157)
    
    Comb_interval_score_P43_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kumamoto, series = "female",
                                                                    fh = ik, index = 159)
    
    Comb_interval_score_P44_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Oita, series = "female",
                                                                    fh = ik, index = 161)
    
    Comb_interval_score_P45_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Miyazaki, series = "female",
                                                                    fh = ik, index = 163)
    
    Comb_interval_score_P46_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kagoshima, series = "female",
                                                                    fh = ik, index = 165)
    
    Comb_interval_score_P47_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Okinawa, series = "female",
                                                                    fh = ik, index = 167)
    print(ik)
}

# male

Comb_interval_score_P1_male_mfts  = Comb_interval_score_P2_male_mfts  = Comb_interval_score_P3_male_mfts  = Comb_interval_score_P4_male_mfts =
Comb_interval_score_P5_male_mfts  = Comb_interval_score_P6_male_mfts  = Comb_interval_score_P7_male_mfts  = Comb_interval_score_P8_male_mfts =
Comb_interval_score_P9_male_mfts  = Comb_interval_score_P10_male_mfts = Comb_interval_score_P11_male_mfts = Comb_interval_score_P12_male_mfts =
Comb_interval_score_P13_male_mfts = Comb_interval_score_P14_male_mfts = Comb_interval_score_P15_male_mfts = Comb_interval_score_P16_male_mfts =
Comb_interval_score_P17_male_mfts = Comb_interval_score_P18_male_mfts = Comb_interval_score_P19_male_mfts = Comb_interval_score_P20_male_mfts =
Comb_interval_score_P21_male_mfts = Comb_interval_score_P22_male_mfts = Comb_interval_score_P23_male_mfts = Comb_interval_score_P24_male_mfts =
Comb_interval_score_P25_male_mfts = Comb_interval_score_P26_male_mfts = Comb_interval_score_P27_male_mfts = Comb_interval_score_P28_male_mfts =
Comb_interval_score_P29_male_mfts = Comb_interval_score_P30_male_mfts = Comb_interval_score_P31_male_mfts = Comb_interval_score_P32_male_mfts =
Comb_interval_score_P33_male_mfts = Comb_interval_score_P34_male_mfts = Comb_interval_score_P35_male_mfts = Comb_interval_score_P36_male_mfts =
Comb_interval_score_P37_male_mfts = Comb_interval_score_P38_male_mfts = Comb_interval_score_P39_male_mfts = Comb_interval_score_P40_male_mfts =
Comb_interval_score_P41_male_mfts = Comb_interval_score_P42_male_mfts = Comb_interval_score_P43_male_mfts = Comb_interval_score_P44_male_mfts =
Comb_interval_score_P45_male_mfts = Comb_interval_score_P46_male_mfts = Comb_interval_score_P47_male_mfts = vector("numeric",15)
for(ik in 1:15)
{
    Comb_interval_score_P1_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Hokkaido, series = "male",
                                                                 fh = ik, index = 76)
    
    Comb_interval_score_P2_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Aomori, series = "male",
                                                                 fh = ik, index = 78)
    
    Comb_interval_score_P3_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Iwate, series = "male",
                                                                 fh = ik, index = 80)
    
    Comb_interval_score_P4_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Miyagi, series = "male",
                                                                 fh = ik, index = 82)
    
    Comb_interval_score_P5_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Akita, series = "male",
                                                                 fh = ik, index = 84)
    
    Comb_interval_score_P6_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Yamagata, series = "male",
                                                                 fh = ik, index = 86)
    
    Comb_interval_score_P7_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Fukushima, series = "male",
                                                                 fh = ik, index = 88)
    
    Comb_interval_score_P8_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Ibaraki, series = "male",
                                                                 fh = ik, index = 90)
    
    Comb_interval_score_P9_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Tochigi, series = "male",
                                                                 fh = ik, index = 92)
    
    Comb_interval_score_P10_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Gunma, series = "male",
                                                                  fh = ik, index = 94)
    
    Comb_interval_score_P11_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Saitama, series = "male",
                                                                  fh = ik, index = 96)
    
    Comb_interval_score_P12_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Chiba, series = "male",
                                                                  fh = ik, index = 98)
    
    Comb_interval_score_P13_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Tokyo, series = "male",
                                                                  fh = ik, index = 100)
    
    Comb_interval_score_P14_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kanagawa, series = "male",
                                                                  fh = ik, index = 102)
    
    Comb_interval_score_P15_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Niigata, series = "male",
                                                                  fh = ik, index = 104)
    
    Comb_interval_score_P16_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Toyama, series = "male",
                                                                  fh = ik, index = 106)
    
    Comb_interval_score_P17_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Ishikawa, series = "male",
                                                                  fh = ik, index = 108)
    
    Comb_interval_score_P18_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Fukui, series = "male",
                                                                  fh = ik, index = 110)
    
    Comb_interval_score_P19_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Yamanashi, series = "male",
                                                                  fh = ik, index = 112)
    
    Comb_interval_score_P20_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Nagano, series = "male",
                                                                  fh = ik, index = 114)
    
    Comb_interval_score_P21_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Gifu, series = "male",
                                                                  fh = ik, index = 116)
    
    Comb_interval_score_P22_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Shizuoka, series = "male",
                                                                  fh = ik, index = 118)
    
    Comb_interval_score_P23_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Aichi, series = "male",
                                                                  fh = ik, index = 120)
    
    Comb_interval_score_P24_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Mie, series = "male",
                                                                  fh = ik, index = 122)
    
    Comb_interval_score_P25_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Shiga, series = "male",
                                                                  fh = ik, index = 124)
    
    Comb_interval_score_P26_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kyoto, series = "male",
                                                                  fh = ik, index = 126)
    
    Comb_interval_score_P27_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Osaka, series = "male",
                                                                  fh = ik, index = 128)
    
    Comb_interval_score_P28_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Hyogo, series = "male",
                                                                  fh = ik, index = 130)
    
    Comb_interval_score_P29_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Nara, series = "male",
                                                                  fh = ik, index = 132)
    
    Comb_interval_score_P30_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Wakayama, series = "male",
                                                                  fh = ik, index = 134)
    
    Comb_interval_score_P31_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Tottori, series = "male",
                                                                  fh = ik, index = 136)
    
    Comb_interval_score_P32_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Shimane, series = "male",
                                                                  fh = ik, index = 138)
    
    Comb_interval_score_P33_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Okayama, series = "male",
                                                                  fh = ik, index = 140)
    
    Comb_interval_score_P34_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Hiroshima, series = "male",
                                                                  fh = ik, index = 142)
    
    Comb_interval_score_P35_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Yamaguchi, series = "male",
                                                                  fh = ik, index = 144)
    
    Comb_interval_score_P36_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Tokushima, series = "male",
                                                                  fh = ik, index = 146)
    
    Comb_interval_score_P37_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kagawa, series = "male",
                                                                  fh = ik, index = 148)
    
    Comb_interval_score_P38_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Ehime, series = "male",
                                                                  fh = ik, index = 150)
    
    Comb_interval_score_P39_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kochi, series = "male",
                                                                  fh = ik, index = 152)
    
    Comb_interval_score_P40_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Fukuoka, series = "male",
                                                                  fh = ik, index = 154)
    
    Comb_interval_score_P41_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Saga, series = "male",
                                                                  fh = ik, index = 156)
    
    Comb_interval_score_P42_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Nagasaki, series = "male",
                                                                  fh = ik, index = 158)
    
    Comb_interval_score_P43_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kumamoto, series = "male",
                                                                  fh = ik, index = 160)
    
    Comb_interval_score_P44_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Oita, series = "male",
                                                                  fh = ik, index = 162)
    
    Comb_interval_score_P45_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Miyazaki, series = "male",
                                                                  fh = ik, index = 164)
    
    Comb_interval_score_P46_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Kagoshima, series = "male",
                                                                  fh = ik, index = 166)
    
    Comb_interval_score_P47_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts, data_series = Okinawa, series = "male",
                                                                  fh = ik, index = 168)
    print(ik)
}


Comb_interval_score_Level_0_mfts = Comb_interval_score_Japan_total_mfts

Comb_interval_score_Level_1_mfts = rowMeans(cbind(Comb_interval_score_Japan_female_mfts, Comb_interval_score_Japan_male_mfts))

Comb_interval_score_Level_2_mfts = rowMeans(cbind(Comb_interval_score_R1_total_mfts, Comb_interval_score_R2_total_mfts, Comb_interval_score_R3_total_mfts,
                                                Comb_interval_score_R4_total_mfts, Comb_interval_score_R5_total_mfts, Comb_interval_score_R6_total_mfts,
                                                Comb_interval_score_R7_total_mfts, Comb_interval_score_R8_total_mfts))

Comb_interval_score_Level_3_mfts = rowMeans(cbind(Comb_interval_score_R1_female_mfts, Comb_interval_score_R2_female_mfts, Comb_interval_score_R3_female_mfts,
                                                Comb_interval_score_R4_female_mfts, Comb_interval_score_R5_female_mfts, Comb_interval_score_R6_female_mfts,
                                                Comb_interval_score_R7_female_mfts, Comb_interval_score_R8_female_mfts, Comb_interval_score_R1_male_mfts,
                                                Comb_interval_score_R2_male_mfts,   Comb_interval_score_R3_male_mfts,   Comb_interval_score_R4_male_mfts,
                                                Comb_interval_score_R5_male_mfts,   Comb_interval_score_R6_male_mfts,   Comb_interval_score_R7_male_mfts,
                                                Comb_interval_score_R8_male_mfts))

Comb_interval_score_Level_4_mfts = rowMeans(cbind(Comb_interval_score_P1_total_mfts,  Comb_interval_score_P2_total_mfts,  Comb_interval_score_P3_total_mfts,
                                                Comb_interval_score_P4_total_mfts,  Comb_interval_score_P5_total_mfts,  Comb_interval_score_P6_total_mfts,
                                                Comb_interval_score_P7_total_mfts,  Comb_interval_score_P8_total_mfts,  Comb_interval_score_P9_total_mfts,
                                                Comb_interval_score_P10_total_mfts, Comb_interval_score_P11_total_mfts, Comb_interval_score_P12_total_mfts,
                                                Comb_interval_score_P13_total_mfts, Comb_interval_score_P14_total_mfts, Comb_interval_score_P15_total_mfts,
                                                Comb_interval_score_P16_total_mfts, Comb_interval_score_P17_total_mfts, Comb_interval_score_P18_total_mfts,
                                                Comb_interval_score_P19_total_mfts, Comb_interval_score_P20_total_mfts, Comb_interval_score_P21_total_mfts,
                                                Comb_interval_score_P22_total_mfts, Comb_interval_score_P23_total_mfts, Comb_interval_score_P24_total_mfts,
                                                Comb_interval_score_P25_total_mfts, Comb_interval_score_P26_total_mfts, Comb_interval_score_P27_total_mfts,
                                                Comb_interval_score_P28_total_mfts, Comb_interval_score_P29_total_mfts, Comb_interval_score_P30_total_mfts,
                                                Comb_interval_score_P31_total_mfts, Comb_interval_score_P32_total_mfts, Comb_interval_score_P33_total_mfts,
                                                Comb_interval_score_P34_total_mfts, Comb_interval_score_P35_total_mfts, Comb_interval_score_P36_total_mfts,
                                                Comb_interval_score_P37_total_mfts, Comb_interval_score_P38_total_mfts, Comb_interval_score_P39_total_mfts,
                                                Comb_interval_score_P40_total_mfts, Comb_interval_score_P41_total_mfts, Comb_interval_score_P42_total_mfts,
                                                Comb_interval_score_P43_total_mfts, Comb_interval_score_P44_total_mfts, Comb_interval_score_P45_total_mfts,
                                                Comb_interval_score_P46_total_mfts, Comb_interval_score_P47_total_mfts))

Comb_interval_score_Level_5_mfts = rowMeans(cbind(Comb_interval_score_P1_female_mfts,  Comb_interval_score_P2_female_mfts,  Comb_interval_score_P3_female_mfts,
                                                Comb_interval_score_P4_female_mfts,  Comb_interval_score_P5_female_mfts,  Comb_interval_score_P6_female_mfts,
                                                Comb_interval_score_P7_female_mfts,  Comb_interval_score_P8_female_mfts,  Comb_interval_score_P9_female_mfts,
                                                Comb_interval_score_P10_female_mfts, Comb_interval_score_P11_female_mfts, Comb_interval_score_P12_female_mfts,
                                                Comb_interval_score_P13_female_mfts, Comb_interval_score_P14_female_mfts, Comb_interval_score_P15_female_mfts,
                                                Comb_interval_score_P16_female_mfts, Comb_interval_score_P17_female_mfts, Comb_interval_score_P18_female_mfts,
                                                Comb_interval_score_P19_female_mfts, Comb_interval_score_P20_female_mfts, Comb_interval_score_P21_female_mfts,
                                                Comb_interval_score_P22_female_mfts, Comb_interval_score_P23_female_mfts, Comb_interval_score_P24_female_mfts,
                                                Comb_interval_score_P25_female_mfts, Comb_interval_score_P26_female_mfts, Comb_interval_score_P27_female_mfts,
                                                Comb_interval_score_P28_female_mfts, Comb_interval_score_P29_female_mfts, Comb_interval_score_P30_female_mfts,
                                                Comb_interval_score_P31_female_mfts, Comb_interval_score_P32_female_mfts, Comb_interval_score_P33_female_mfts,
                                                Comb_interval_score_P34_female_mfts, Comb_interval_score_P35_female_mfts, Comb_interval_score_P36_female_mfts,
                                                Comb_interval_score_P37_female_mfts, Comb_interval_score_P38_female_mfts, Comb_interval_score_P39_female_mfts,
                                                Comb_interval_score_P40_female_mfts, Comb_interval_score_P41_female_mfts, Comb_interval_score_P42_female_mfts,
                                                Comb_interval_score_P43_female_mfts, Comb_interval_score_P44_female_mfts, Comb_interval_score_P45_female_mfts,
                                                Comb_interval_score_P46_female_mfts, Comb_interval_score_P47_female_mfts, Comb_interval_score_P1_male_mfts,
                                                Comb_interval_score_P2_male_mfts,  Comb_interval_score_P3_male_mfts,  Comb_interval_score_P4_male_mfts,
                                                Comb_interval_score_P5_male_mfts,  Comb_interval_score_P6_male_mfts,  Comb_interval_score_P7_male_mfts,
                                                Comb_interval_score_P8_male_mfts,  Comb_interval_score_P9_male_mfts,  Comb_interval_score_P10_male_mfts,
                                                Comb_interval_score_P11_male_mfts, Comb_interval_score_P12_male_mfts, Comb_interval_score_P13_male_mfts,
                                                Comb_interval_score_P14_male_mfts, Comb_interval_score_P15_male_mfts, Comb_interval_score_P16_male_mfts,
                                                Comb_interval_score_P17_male_mfts, Comb_interval_score_P18_male_mfts, Comb_interval_score_P19_male_mfts,
                                                Comb_interval_score_P20_male_mfts, Comb_interval_score_P21_male_mfts, Comb_interval_score_P22_male_mfts,
                                                Comb_interval_score_P23_male_mfts, Comb_interval_score_P24_male_mfts, Comb_interval_score_P25_male_mfts,
                                                Comb_interval_score_P26_male_mfts, Comb_interval_score_P27_male_mfts, Comb_interval_score_P28_male_mfts,
                                                Comb_interval_score_P29_male_mfts, Comb_interval_score_P30_male_mfts, Comb_interval_score_P31_male_mfts,
                                                Comb_interval_score_P32_male_mfts, Comb_interval_score_P33_male_mfts, Comb_interval_score_P34_male_mfts,
                                                Comb_interval_score_P35_male_mfts, Comb_interval_score_P36_male_mfts, Comb_interval_score_P37_male_mfts,
                                                Comb_interval_score_P38_male_mfts, Comb_interval_score_P39_male_mfts, Comb_interval_score_P40_male_mfts,
                                                Comb_interval_score_P41_male_mfts, Comb_interval_score_P42_male_mfts, Comb_interval_score_P43_male_mfts,
                                                Comb_interval_score_P44_male_mfts, Comb_interval_score_P45_male_mfts, Comb_interval_score_P46_male_mfts,
                                                Comb_interval_score_P47_male_mfts))


Comb_interval_score_all_mfts = cbind(Comb_interval_score_Level_0_mfts, Comb_interval_score_Level_1_mfts, Comb_interval_score_Level_2_mfts, Comb_interval_score_Level_3_mfts, Comb_interval_score_Level_4_mfts, Comb_interval_score_Level_5_mfts)
Comb_interval_score_all_stats_mfts = rbind(Comb_interval_score_all_mfts, colMeans(Comb_interval_score_all_mfts), apply(Comb_interval_score_all_mfts, 2, median))
colnames(Comb_interval_score_all_stats_mfts) = c("Level 0", "Level 1", "Level 2", "Level 3", "Level 4", "Level 5")
rownames(Comb_interval_score_all_stats_mfts) = c(1:15,"Mean","Median")

#########################################################################
# Calculate mean interval score for different levels of a hierarchy (Comb)
#########################################################################

# Japan + Sex

Comb_AvInt_interval_score_Japan_total = Comb_AvInt_interval_score_Japan_female = Comb_AvInt_interval_score_Japan_male = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 0
    Comb_AvInt_interval_score_Japan_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Japan, series = "total",
                                                                  fh = ik, index = 1)
    
    # Level 1
    Comb_AvInt_interval_score_Japan_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Japan, series = "female",
                                                                   fh = ik, index = 2)
    
    Comb_AvInt_interval_score_Japan_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Japan, series = "male",
                                                                 fh = ik, index = 3)
    print(ik)
}

# Region (total)

Comb_AvInt_interval_score_R1_total = Comb_AvInt_interval_score_R2_total = Comb_AvInt_interval_score_R3_total = Comb_AvInt_interval_score_R4_total =
Comb_AvInt_interval_score_R5_total = Comb_AvInt_interval_score_R6_total = Comb_AvInt_interval_score_R7_total = Comb_AvInt_interval_score_R8_total = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 2
    Comb_AvInt_interval_score_R1_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R1, series = "total",
                                                               fh = ik, index = 4)
    
    Comb_AvInt_interval_score_R2_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R2, series = "total",
                                                               fh = ik, index = 5)
    
    Comb_AvInt_interval_score_R3_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R3, series = "total",
                                                               fh = ik, index = 6)
    
    Comb_AvInt_interval_score_R4_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R4, series = "total",
                                                               fh = ik, index = 7)
    
    Comb_AvInt_interval_score_R5_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R5, series = "total",
                                                               fh = ik, index = 8)
    
    Comb_AvInt_interval_score_R6_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R6, series = "total",
                                                               fh = ik, index = 9)
    
    Comb_AvInt_interval_score_R7_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R7, series = "total",
                                                               fh = ik, index = 10)
    
    Comb_AvInt_interval_score_R8_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R8, series = "total",
                                                               fh = ik, index = 11)
    print(ik)
}

# Region + Sex

Comb_AvInt_interval_score_R1_female = Comb_AvInt_interval_score_R2_female = Comb_AvInt_interval_score_R3_female = Comb_AvInt_interval_score_R4_female =
Comb_AvInt_interval_score_R5_female = Comb_AvInt_interval_score_R6_female = Comb_AvInt_interval_score_R7_female = Comb_AvInt_interval_score_R8_female =
Comb_AvInt_interval_score_R1_male   = Comb_AvInt_interval_score_R2_male   = Comb_AvInt_interval_score_R3_male   = Comb_AvInt_interval_score_R4_male   =
Comb_AvInt_interval_score_R5_male   = Comb_AvInt_interval_score_R6_male   = Comb_AvInt_interval_score_R7_male   = Comb_AvInt_interval_score_R8_male   = vector("numeric",15)
for(ik in 1:15)
{
    # Level 3 (female)
    Comb_AvInt_interval_score_R1_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R1, series = "female",
                                                                fh = ik, index = 12)
    
    Comb_AvInt_interval_score_R2_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R2, series = "female",
                                                                fh = ik, index = 13)
    
    Comb_AvInt_interval_score_R3_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R3, series = "female",
                                                                fh = ik, index = 14)
    
    Comb_AvInt_interval_score_R4_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R4, series = "female",
                                                                fh = ik, index = 15)
    
    Comb_AvInt_interval_score_R5_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R5, series = "female",
                                                                fh = ik, index = 16)
    
    Comb_AvInt_interval_score_R6_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R6, series = "female",
                                                                fh = ik, index = 17)
    
    Comb_AvInt_interval_score_R7_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R7, series = "female",
                                                                fh = ik, index = 18)
    
    Comb_AvInt_interval_score_R8_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R8, series = "female",
                                                                fh = ik, index = 19)
    
    # Level 3 (male)
    Comb_AvInt_interval_score_R1_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R1, series = "male",
                                                              fh = ik, index = 20)
    
    Comb_AvInt_interval_score_R2_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R2, series = "male",
                                                              fh = ik, index = 21)
    
    Comb_AvInt_interval_score_R3_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R3, series = "male",
                                                              fh = ik, index = 22)
    
    Comb_AvInt_interval_score_R4_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R4, series = "male",
                                                              fh = ik, index = 23)
    
    Comb_AvInt_interval_score_R5_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R5, series = "male",
                                                              fh = ik, index = 24)
    
    Comb_AvInt_interval_score_R6_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R6, series = "male",
                                                              fh = ik, index = 25)
    
    Comb_AvInt_interval_score_R7_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R7, series = "male",
                                                              fh = ik, index = 26)
    
    Comb_AvInt_interval_score_R8_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = ind_R8, series = "male",
                                                              fh = ik, index = 27)
    print(ik)
}

# Prefecture (total)

Comb_AvInt_interval_score_P1_total  = Comb_AvInt_interval_score_P2_total  = Comb_AvInt_interval_score_P3_total  = Comb_AvInt_interval_score_P4_total =
Comb_AvInt_interval_score_P5_total  = Comb_AvInt_interval_score_P6_total  = Comb_AvInt_interval_score_P7_total  = Comb_AvInt_interval_score_P8_total =
Comb_AvInt_interval_score_P9_total  = Comb_AvInt_interval_score_P10_total = Comb_AvInt_interval_score_P11_total = Comb_AvInt_interval_score_P12_total =
Comb_AvInt_interval_score_P13_total = Comb_AvInt_interval_score_P14_total = Comb_AvInt_interval_score_P15_total = Comb_AvInt_interval_score_P16_total =
Comb_AvInt_interval_score_P17_total = Comb_AvInt_interval_score_P18_total = Comb_AvInt_interval_score_P19_total = Comb_AvInt_interval_score_P20_total =
Comb_AvInt_interval_score_P21_total = Comb_AvInt_interval_score_P22_total = Comb_AvInt_interval_score_P23_total = Comb_AvInt_interval_score_P24_total =
Comb_AvInt_interval_score_P25_total = Comb_AvInt_interval_score_P26_total = Comb_AvInt_interval_score_P27_total = Comb_AvInt_interval_score_P28_total =
Comb_AvInt_interval_score_P29_total = Comb_AvInt_interval_score_P30_total = Comb_AvInt_interval_score_P31_total = Comb_AvInt_interval_score_P32_total =
Comb_AvInt_interval_score_P33_total = Comb_AvInt_interval_score_P34_total = Comb_AvInt_interval_score_P35_total = Comb_AvInt_interval_score_P36_total =
Comb_AvInt_interval_score_P37_total = Comb_AvInt_interval_score_P38_total = Comb_AvInt_interval_score_P39_total = Comb_AvInt_interval_score_P40_total =
Comb_AvInt_interval_score_P41_total = Comb_AvInt_interval_score_P42_total = Comb_AvInt_interval_score_P43_total = Comb_AvInt_interval_score_P44_total =
Comb_AvInt_interval_score_P45_total = Comb_AvInt_interval_score_P46_total = Comb_AvInt_interval_score_P47_total = vector("numeric",15)
for(ik in 1:15)
{
    Comb_AvInt_interval_score_P1_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Hokkaido, series = "total",
                                                               fh = ik, index = 28)
    
    Comb_AvInt_interval_score_P2_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Aomori, series = "total",
                                                               fh = ik, index = 29)
    
    Comb_AvInt_interval_score_P3_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Iwate, series = "total",
                                                               fh = ik, index = 30)
    
    Comb_AvInt_interval_score_P4_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Miyagi, series = "total",
                                                               fh = ik, index = 31)
    
    Comb_AvInt_interval_score_P5_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Akita, series = "total",
                                                               fh = ik, index = 32)
    
    Comb_AvInt_interval_score_P6_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Yamagata, series = "total",
                                                               fh = ik, index = 33)
    
    Comb_AvInt_interval_score_P7_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Fukushima, series = "total",
                                                               fh = ik, index = 34)
    
    Comb_AvInt_interval_score_P8_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Ibaraki, series = "total",
                                                               fh = ik, index = 35)
    
    Comb_AvInt_interval_score_P9_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Tochigi, series = "total",
                                                               fh = ik, index = 36)
    
    Comb_AvInt_interval_score_P10_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Gunma, series = "total",
                                                                fh = ik, index = 37)
    
    Comb_AvInt_interval_score_P11_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Saitama, series = "total",
                                                                fh = ik, index = 38)
    
    Comb_AvInt_interval_score_P12_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Chiba, series = "total",
                                                                fh = ik, index = 39)
    
    Comb_AvInt_interval_score_P13_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Tokyo, series = "total",
                                                                fh = ik, index = 40)
    
    Comb_AvInt_interval_score_P14_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kanagawa, series = "total",
                                                                fh = ik, index = 41)
    
    Comb_AvInt_interval_score_P15_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Niigata, series = "total",
                                                                fh = ik, index = 42)
    
    Comb_AvInt_interval_score_P16_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Toyama, series = "total",
                                                                fh = ik, index = 43)
    
    Comb_AvInt_interval_score_P17_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Ishikawa, series = "total",
                                                                fh = ik, index = 44)
    
    Comb_AvInt_interval_score_P18_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Fukui, series = "total",
                                                                fh = ik, index = 45)
    
    Comb_AvInt_interval_score_P19_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Yamanashi, series = "total",
                                                                fh = ik, index = 46)
    
    Comb_AvInt_interval_score_P20_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Nagano, series = "total",
                                                                fh = ik, index = 47)
    
    Comb_AvInt_interval_score_P21_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Gifu, series = "total",
                                                                fh = ik, index = 48)
    
    Comb_AvInt_interval_score_P22_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Shizuoka, series = "total",
                                                                fh = ik, index = 49)
    
    Comb_AvInt_interval_score_P23_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Aichi, series = "total",
                                                                fh = ik, index = 50)
    
    Comb_AvInt_interval_score_P24_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Mie, series = "total",
                                                                fh = ik, index = 51)
    
    Comb_AvInt_interval_score_P25_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Shiga, series = "total",
                                                                fh = ik, index = 52)
    
    Comb_AvInt_interval_score_P26_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kyoto, series = "total",
                                                                fh = ik, index = 53)
    
    Comb_AvInt_interval_score_P27_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Osaka, series = "total",
                                                                fh = ik, index = 54)
    
    Comb_AvInt_interval_score_P28_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Hyogo, series = "total",
                                                                fh = ik, index = 55)
    
    Comb_AvInt_interval_score_P29_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Nara, series = "total",
                                                                fh = ik, index = 56)
    
    Comb_AvInt_interval_score_P30_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Wakayama, series = "total",
                                                                fh = ik, index = 57)
    
    Comb_AvInt_interval_score_P31_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Tottori, series = "total",
                                                                fh = ik, index = 58)
    
    Comb_AvInt_interval_score_P32_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Shimane, series = "total",
                                                                fh = ik, index = 59)
    
    Comb_AvInt_interval_score_P33_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Okayama, series = "total",
                                                                fh = ik, index = 60)
    
    Comb_AvInt_interval_score_P34_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Hiroshima, series = "total",
                                                                fh = ik, index = 61)
    
    Comb_AvInt_interval_score_P35_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Yamaguchi, series = "total",
                                                                fh = ik, index = 62)
    
    Comb_AvInt_interval_score_P36_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Tokushima, series = "total",
                                                                fh = ik, index = 63)
    
    Comb_AvInt_interval_score_P37_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kagawa, series = "total",
                                                                fh = ik, index = 64)
    
    Comb_AvInt_interval_score_P38_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Ehime, series = "total",
                                                                fh = ik, index = 65)
    
    Comb_AvInt_interval_score_P39_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kochi, series = "total",
                                                                fh = ik, index = 66)
    
    Comb_AvInt_interval_score_P40_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Fukuoka, series = "total",
                                                                fh = ik, index = 67)
    
    Comb_AvInt_interval_score_P41_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Saga, series = "total",
                                                                fh = ik, index = 68)
    
    Comb_AvInt_interval_score_P42_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Nagasaki, series = "total",
                                                                fh = ik, index = 69)
    
    Comb_AvInt_interval_score_P43_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kumamoto, series = "total",
                                                                fh = ik, index = 70)
    
    Comb_AvInt_interval_score_P44_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Oita, series = "total",
                                                                fh = ik, index = 71)
    
    Comb_AvInt_interval_score_P45_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Miyazaki, series = "total",
                                                                fh = ik, index = 72)
    
    Comb_AvInt_interval_score_P46_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kagoshima, series = "total",
                                                                fh = ik, index = 73)
    
    Comb_AvInt_interval_score_P47_total[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Okinawa, series = "total",
                                                                fh = ik, index = 74)
    print(ik)
}

# Prefecture + Sex

Comb_AvInt_interval_score_P1_female  = Comb_AvInt_interval_score_P2_female  = Comb_AvInt_interval_score_P3_female  = Comb_AvInt_interval_score_P4_female =
Comb_AvInt_interval_score_P5_female  = Comb_AvInt_interval_score_P6_female  = Comb_AvInt_interval_score_P7_female  = Comb_AvInt_interval_score_P8_female =
Comb_AvInt_interval_score_P9_female  = Comb_AvInt_interval_score_P10_female = Comb_AvInt_interval_score_P11_female = Comb_AvInt_interval_score_P12_female =
Comb_AvInt_interval_score_P13_female = Comb_AvInt_interval_score_P14_female = Comb_AvInt_interval_score_P15_female = Comb_AvInt_interval_score_P16_female =
Comb_AvInt_interval_score_P17_female = Comb_AvInt_interval_score_P18_female = Comb_AvInt_interval_score_P19_female = Comb_AvInt_interval_score_P20_female =
Comb_AvInt_interval_score_P21_female = Comb_AvInt_interval_score_P22_female = Comb_AvInt_interval_score_P23_female = Comb_AvInt_interval_score_P24_female =
Comb_AvInt_interval_score_P25_female = Comb_AvInt_interval_score_P26_female = Comb_AvInt_interval_score_P27_female = Comb_AvInt_interval_score_P28_female =
Comb_AvInt_interval_score_P29_female = Comb_AvInt_interval_score_P30_female = Comb_AvInt_interval_score_P31_female = Comb_AvInt_interval_score_P32_female =
Comb_AvInt_interval_score_P33_female = Comb_AvInt_interval_score_P34_female = Comb_AvInt_interval_score_P35_female = Comb_AvInt_interval_score_P36_female =
Comb_AvInt_interval_score_P37_female = Comb_AvInt_interval_score_P38_female = Comb_AvInt_interval_score_P39_female = Comb_AvInt_interval_score_P40_female =
Comb_AvInt_interval_score_P41_female = Comb_AvInt_interval_score_P42_female = Comb_AvInt_interval_score_P43_female = Comb_AvInt_interval_score_P44_female =
Comb_AvInt_interval_score_P45_female = Comb_AvInt_interval_score_P46_female = Comb_AvInt_interval_score_P47_female = vector("numeric",15)
for(ik in 1:15)
{
    Comb_AvInt_interval_score_P1_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Hokkaido, series = "female",
                                                                fh = ik, index = 75)
    
    Comb_AvInt_interval_score_P2_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Aomori, series = "female",
                                                                fh = ik, index = 77)
    
    Comb_AvInt_interval_score_P3_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Iwate, series = "female",
                                                                fh = ik, index = 79)
    
    Comb_AvInt_interval_score_P4_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Miyagi, series = "female",
                                                                fh = ik, index = 81)
    
    Comb_AvInt_interval_score_P5_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Akita, series = "female",
                                                                fh = ik, index = 83)
    
    Comb_AvInt_interval_score_P6_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Yamagata, series = "female",
                                                                fh = ik, index = 85)
    
    Comb_AvInt_interval_score_P7_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Fukushima, series = "female",
                                                                fh = ik, index = 87)
    
    Comb_AvInt_interval_score_P8_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Ibaraki, series = "female",
                                                                fh = ik, index = 89)
    
    Comb_AvInt_interval_score_P9_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Tochigi, series = "female",
                                                                fh = ik, index = 91)
    
    Comb_AvInt_interval_score_P10_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Gunma, series = "female",
                                                                 fh = ik, index = 93)
    
    Comb_AvInt_interval_score_P11_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Saitama, series = "female",
                                                                 fh = ik, index = 95)
    
    Comb_AvInt_interval_score_P12_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Chiba, series = "female",
                                                                 fh = ik, index = 97)
    
    Comb_AvInt_interval_score_P13_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Tokyo, series = "female",
                                                                 fh = ik, index = 99)
    
    Comb_AvInt_interval_score_P14_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kanagawa, series = "female",
                                                                 fh = ik, index = 101)
    
    Comb_AvInt_interval_score_P15_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Niigata, series = "female",
                                                                 fh = ik, index = 103)
    
    Comb_AvInt_interval_score_P16_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Toyama, series = "female",
                                                                 fh = ik, index = 105)
    
    Comb_AvInt_interval_score_P17_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Ishikawa, series = "female",
                                                                 fh = ik, index = 107)
    
    Comb_AvInt_interval_score_P18_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Fukui, series = "female",
                                                                 fh = ik, index = 109)
    
    Comb_AvInt_interval_score_P19_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Yamanashi, series = "female",
                                                                 fh = ik, index = 111)
    
    Comb_AvInt_interval_score_P20_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Nagano, series = "female",
                                                                 fh = ik, index = 113)
    
    Comb_AvInt_interval_score_P21_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Gifu, series = "female",
                                                                 fh = ik, index = 115)
    
    Comb_AvInt_interval_score_P22_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Shizuoka, series = "female",
                                                                 fh = ik, index = 117)
    
    Comb_AvInt_interval_score_P23_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Aichi, series = "female",
                                                                 fh = ik, index = 119)
    
    Comb_AvInt_interval_score_P24_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Mie, series = "female",
                                                                 fh = ik, index = 121)
    
    Comb_AvInt_interval_score_P25_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Shiga, series = "female",
                                                                 fh = ik, index = 123)
    
    Comb_AvInt_interval_score_P26_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kyoto, series = "female",
                                                                 fh = ik, index = 125)
    
    Comb_AvInt_interval_score_P27_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Osaka, series = "female",
                                                                 fh = ik, index = 127)
    
    Comb_AvInt_interval_score_P28_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Hyogo, series = "female",
                                                                 fh = ik, index = 129)
    
    Comb_AvInt_interval_score_P29_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Nara, series = "female",
                                                                 fh = ik, index = 131)
    
    Comb_AvInt_interval_score_P30_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Wakayama, series = "female",
                                                                 fh = ik, index = 133)
    
    Comb_AvInt_interval_score_P31_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Tottori, series = "female",
                                                                 fh = ik, index = 135)
    
    Comb_AvInt_interval_score_P32_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Shimane, series = "female",
                                                                 fh = ik, index = 137)
    
    Comb_AvInt_interval_score_P33_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Okayama, series = "female",
                                                                 fh = ik, index = 139)
    
    Comb_AvInt_interval_score_P34_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Hiroshima, series = "female",
                                                                 fh = ik, index = 141)
    
    Comb_AvInt_interval_score_P35_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Yamaguchi, series = "female",
                                                                 fh = ik, index = 143)
    
    Comb_AvInt_interval_score_P36_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Tokushima, series = "female",
                                                                 fh = ik, index = 145)
    
    Comb_AvInt_interval_score_P37_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kagawa, series = "female",
                                                                 fh = ik, index = 147)
    
    Comb_AvInt_interval_score_P38_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Ehime, series = "female",
                                                                 fh = ik, index = 149)
    
    Comb_AvInt_interval_score_P39_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kochi, series = "female",
                                                                 fh = ik, index = 151)
    
    Comb_AvInt_interval_score_P40_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Fukuoka, series = "female",
                                                                 fh = ik, index = 153)
    
    Comb_AvInt_interval_score_P41_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Saga, series = "female",
                                                                 fh = ik, index = 155)
    
    Comb_AvInt_interval_score_P42_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Nagasaki, series = "female",
                                                                 fh = ik, index = 157)
    
    Comb_AvInt_interval_score_P43_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kumamoto, series = "female",
                                                                 fh = ik, index = 159)
    
    Comb_AvInt_interval_score_P44_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Oita, series = "female",
                                                                 fh = ik, index = 161)
    
    Comb_AvInt_interval_score_P45_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Miyazaki, series = "female",
                                                                 fh = ik, index = 163)
    
    Comb_AvInt_interval_score_P46_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kagoshima, series = "female",
                                                                 fh = ik, index = 165)
    
    Comb_AvInt_interval_score_P47_female[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Okinawa, series = "female",
                                                                 fh = ik, index = 167)
    print(ik)
}


Comb_AvInt_interval_score_P1_male  = Comb_AvInt_interval_score_P2_male  = Comb_AvInt_interval_score_P3_male  = Comb_AvInt_interval_score_P4_male =
Comb_AvInt_interval_score_P5_male  = Comb_AvInt_interval_score_P6_male  = Comb_AvInt_interval_score_P7_male  = Comb_AvInt_interval_score_P8_male =
Comb_AvInt_interval_score_P9_male  = Comb_AvInt_interval_score_P10_male = Comb_AvInt_interval_score_P11_male = Comb_AvInt_interval_score_P12_male =
Comb_AvInt_interval_score_P13_male = Comb_AvInt_interval_score_P14_male = Comb_AvInt_interval_score_P15_male = Comb_AvInt_interval_score_P16_male =
Comb_AvInt_interval_score_P17_male = Comb_AvInt_interval_score_P18_male = Comb_AvInt_interval_score_P19_male = Comb_AvInt_interval_score_P20_male =
Comb_AvInt_interval_score_P21_male = Comb_AvInt_interval_score_P22_male = Comb_AvInt_interval_score_P23_male = Comb_AvInt_interval_score_P24_male =
Comb_AvInt_interval_score_P25_male = Comb_AvInt_interval_score_P26_male = Comb_AvInt_interval_score_P27_male = Comb_AvInt_interval_score_P28_male =
Comb_AvInt_interval_score_P29_male = Comb_AvInt_interval_score_P30_male = Comb_AvInt_interval_score_P31_male = Comb_AvInt_interval_score_P32_male =
Comb_AvInt_interval_score_P33_male = Comb_AvInt_interval_score_P34_male = Comb_AvInt_interval_score_P35_male = Comb_AvInt_interval_score_P36_male =
Comb_AvInt_interval_score_P37_male = Comb_AvInt_interval_score_P38_male = Comb_AvInt_interval_score_P39_male = Comb_AvInt_interval_score_P40_male =
Comb_AvInt_interval_score_P41_male = Comb_AvInt_interval_score_P42_male = Comb_AvInt_interval_score_P43_male = Comb_AvInt_interval_score_P44_male =
Comb_AvInt_interval_score_P45_male = Comb_AvInt_interval_score_P46_male = Comb_AvInt_interval_score_P47_male = vector("numeric",15)
for(ik in 1:15)
{
    Comb_AvInt_interval_score_P1_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Hokkaido, series = "male",
                                                              fh = ik, index = 76)
    
    Comb_AvInt_interval_score_P2_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Aomori, series = "male",
                                                              fh = ik, index = 78)
    
    Comb_AvInt_interval_score_P3_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Iwate, series = "male",
                                                              fh = ik, index = 80)
    
    Comb_AvInt_interval_score_P4_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Miyagi, series = "male",
                                                              fh = ik, index = 82)
    
    Comb_AvInt_interval_score_P5_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Akita, series = "male",
                                                              fh = ik, index = 84)
    
    Comb_AvInt_interval_score_P6_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Yamagata, series = "male",
                                                              fh = ik, index = 86)
    
    Comb_AvInt_interval_score_P7_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Fukushima, series = "male",
                                                              fh = ik, index = 88)
    
    Comb_AvInt_interval_score_P8_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Ibaraki, series = "male",
                                                              fh = ik, index = 90)
    
    Comb_AvInt_interval_score_P9_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Tochigi, series = "male",
                                                              fh = ik, index = 92)
    
    Comb_AvInt_interval_score_P10_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Gunma, series = "male",
                                                               fh = ik, index = 94)
    
    Comb_AvInt_interval_score_P11_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Saitama, series = "male",
                                                               fh = ik, index = 96)
    
    Comb_AvInt_interval_score_P12_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Chiba, series = "male",
                                                               fh = ik, index = 98)
    
    Comb_AvInt_interval_score_P13_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Tokyo, series = "male",
                                                               fh = ik, index = 100)
    
    Comb_AvInt_interval_score_P14_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kanagawa, series = "male",
                                                               fh = ik, index = 102)
    
    Comb_AvInt_interval_score_P15_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Niigata, series = "male",
                                                               fh = ik, index = 104)
    
    Comb_AvInt_interval_score_P16_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Toyama, series = "male",
                                                               fh = ik, index = 106)
    
    Comb_AvInt_interval_score_P17_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Ishikawa, series = "male",
                                                               fh = ik, index = 108)
    
    Comb_AvInt_interval_score_P18_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Fukui, series = "male",
                                                               fh = ik, index = 110)
    
    Comb_AvInt_interval_score_P19_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Yamanashi, series = "male",
                                                               fh = ik, index = 112)
    
    Comb_AvInt_interval_score_P20_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Nagano, series = "male",
                                                               fh = ik, index = 114)
    
    Comb_AvInt_interval_score_P21_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Gifu, series = "male",
                                                               fh = ik, index = 116)
    
    Comb_AvInt_interval_score_P22_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Shizuoka, series = "male",
                                                               fh = ik, index = 118)
    
    Comb_AvInt_interval_score_P23_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Aichi, series = "male",
                                                               fh = ik, index = 120)
    
    Comb_AvInt_interval_score_P24_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Mie, series = "male",
                                                               fh = ik, index = 122)
    
    Comb_AvInt_interval_score_P25_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Shiga, series = "male",
                                                               fh = ik, index = 124)
    
    Comb_AvInt_interval_score_P26_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kyoto, series = "male",
                                                               fh = ik, index = 126)
    
    Comb_AvInt_interval_score_P27_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Osaka, series = "male",
                                                               fh = ik, index = 128)
    
    Comb_AvInt_interval_score_P28_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Hyogo, series = "male",
                                                               fh = ik, index = 130)
    
    Comb_AvInt_interval_score_P29_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Nara, series = "male",
                                                               fh = ik, index = 132)
    
    Comb_AvInt_interval_score_P30_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Wakayama, series = "male",
                                                               fh = ik, index = 134)
    
    Comb_AvInt_interval_score_P31_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Tottori, series = "male",
                                                               fh = ik, index = 136)
    
    Comb_AvInt_interval_score_P32_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Shimane, series = "male",
                                                               fh = ik, index = 138)
    
    Comb_AvInt_interval_score_P33_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Okayama, series = "male",
                                                               fh = ik, index = 140)
    
    Comb_AvInt_interval_score_P34_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Hiroshima, series = "male",
                                                               fh = ik, index = 142)
    
    Comb_AvInt_interval_score_P35_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Yamaguchi, series = "male",
                                                               fh = ik, index = 144)
    
    Comb_AvInt_interval_score_P36_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Tokushima, series = "male",
                                                               fh = ik, index = 146)
    
    Comb_AvInt_interval_score_P37_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kagawa, series = "male",
                                                               fh = ik, index = 148)
    
    Comb_AvInt_interval_score_P38_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Ehime, series = "male",
                                                               fh = ik, index = 150)
    
    Comb_AvInt_interval_score_P39_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kochi, series = "male",
                                                               fh = ik, index = 152)
    
    Comb_AvInt_interval_score_P40_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Fukuoka, series = "male",
                                                               fh = ik, index = 154)
    
    Comb_AvInt_interval_score_P41_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Saga, series = "male",
                                                               fh = ik, index = 156)
    
    Comb_AvInt_interval_score_P42_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Nagasaki, series = "male",
                                                               fh = ik, index = 158)
    
    Comb_AvInt_interval_score_P43_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kumamoto, series = "male",
                                                               fh = ik, index = 160)
    
    Comb_AvInt_interval_score_P44_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Oita, series = "male",
                                                               fh = ik, index = 162)
    
    Comb_AvInt_interval_score_P45_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Miyazaki, series = "male",
                                                               fh = ik, index = 164)
    
    Comb_AvInt_interval_score_P46_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Kagoshima, series = "male",
                                                               fh = ik, index = 166)
    
    Comb_AvInt_interval_score_P47_male[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_int_midpoints, data_series = Okinawa, series = "male",
                                                               fh = ik, index = 168)
}

Comb_AvInt_interval_score_Level_0 = Comb_AvInt_interval_score_Japan_total

Comb_AvInt_interval_score_Level_1 = rowMeans(cbind(Comb_AvInt_interval_score_Japan_female, Comb_AvInt_interval_score_Japan_male))

Comb_AvInt_interval_score_Level_2 = rowMeans(cbind(Comb_AvInt_interval_score_R1_total, Comb_AvInt_interval_score_R2_total, Comb_AvInt_interval_score_R3_total, Comb_AvInt_interval_score_R4_total,
                                             Comb_AvInt_interval_score_R5_total, Comb_AvInt_interval_score_R6_total, Comb_AvInt_interval_score_R7_total, Comb_AvInt_interval_score_R8_total))

Comb_AvInt_interval_score_Level_3 = rowMeans(cbind(Comb_AvInt_interval_score_R1_female, Comb_AvInt_interval_score_R2_female, Comb_AvInt_interval_score_R3_female, Comb_AvInt_interval_score_R4_female,
                                             Comb_AvInt_interval_score_R5_female, Comb_AvInt_interval_score_R6_female, Comb_AvInt_interval_score_R7_female, Comb_AvInt_interval_score_R8_female,
                                             Comb_AvInt_interval_score_R1_male, Comb_AvInt_interval_score_R2_male, Comb_AvInt_interval_score_R3_male, Comb_AvInt_interval_score_R4_male,
                                             Comb_AvInt_interval_score_R5_male, Comb_AvInt_interval_score_R6_male, Comb_AvInt_interval_score_R7_male, Comb_AvInt_interval_score_R8_male))

Comb_AvInt_interval_score_Level_4 = rowMeans(cbind(Comb_AvInt_interval_score_P1_total,  Comb_AvInt_interval_score_P2_total,  Comb_AvInt_interval_score_P3_total,  Comb_AvInt_interval_score_P4_total,  Comb_AvInt_interval_score_P5_total,
                                             Comb_AvInt_interval_score_P6_total,  Comb_AvInt_interval_score_P7_total,  Comb_AvInt_interval_score_P8_total,  Comb_AvInt_interval_score_P9_total,  Comb_AvInt_interval_score_P10_total,
                                             Comb_AvInt_interval_score_P11_total, Comb_AvInt_interval_score_P12_total, Comb_AvInt_interval_score_P13_total, Comb_AvInt_interval_score_P14_total, Comb_AvInt_interval_score_P15_total,
                                             Comb_AvInt_interval_score_P16_total, Comb_AvInt_interval_score_P17_total, Comb_AvInt_interval_score_P18_total, Comb_AvInt_interval_score_P19_total, Comb_AvInt_interval_score_P20_total,
                                             Comb_AvInt_interval_score_P21_total, Comb_AvInt_interval_score_P22_total, Comb_AvInt_interval_score_P23_total, Comb_AvInt_interval_score_P24_total, Comb_AvInt_interval_score_P25_total,
                                             Comb_AvInt_interval_score_P26_total, Comb_AvInt_interval_score_P27_total, Comb_AvInt_interval_score_P28_total, Comb_AvInt_interval_score_P29_total, Comb_AvInt_interval_score_P30_total,
                                             Comb_AvInt_interval_score_P31_total, Comb_AvInt_interval_score_P32_total, Comb_AvInt_interval_score_P33_total, Comb_AvInt_interval_score_P34_total, Comb_AvInt_interval_score_P35_total,
                                             Comb_AvInt_interval_score_P36_total, Comb_AvInt_interval_score_P37_total, Comb_AvInt_interval_score_P38_total, Comb_AvInt_interval_score_P39_total, Comb_AvInt_interval_score_P40_total,
                                             Comb_AvInt_interval_score_P41_total, Comb_AvInt_interval_score_P42_total, Comb_AvInt_interval_score_P43_total, Comb_AvInt_interval_score_P44_total, Comb_AvInt_interval_score_P45_total,
                                             Comb_AvInt_interval_score_P46_total, Comb_AvInt_interval_score_P47_total))

Comb_AvInt_interval_score_Level_5 = rowMeans(cbind(Comb_AvInt_interval_score_P1_female,  Comb_AvInt_interval_score_P2_female,  Comb_AvInt_interval_score_P3_female,  Comb_AvInt_interval_score_P4_female,  Comb_AvInt_interval_score_P5_female,
                                             Comb_AvInt_interval_score_P6_female,  Comb_AvInt_interval_score_P7_female,  Comb_AvInt_interval_score_P8_female,  Comb_AvInt_interval_score_P9_female,  Comb_AvInt_interval_score_P10_female,
                                             Comb_AvInt_interval_score_P11_female, Comb_AvInt_interval_score_P12_female, Comb_AvInt_interval_score_P13_female, Comb_AvInt_interval_score_P14_female, Comb_AvInt_interval_score_P15_female,
                                             Comb_AvInt_interval_score_P16_female, Comb_AvInt_interval_score_P17_female, Comb_AvInt_interval_score_P18_female, Comb_AvInt_interval_score_P19_female, Comb_AvInt_interval_score_P20_female,
                                             Comb_AvInt_interval_score_P21_female, Comb_AvInt_interval_score_P22_female, Comb_AvInt_interval_score_P23_female, Comb_AvInt_interval_score_P24_female, Comb_AvInt_interval_score_P25_female,
                                             Comb_AvInt_interval_score_P26_female, Comb_AvInt_interval_score_P27_female, Comb_AvInt_interval_score_P28_female, Comb_AvInt_interval_score_P29_female, Comb_AvInt_interval_score_P30_female,
                                             Comb_AvInt_interval_score_P31_female, Comb_AvInt_interval_score_P32_female, Comb_AvInt_interval_score_P33_female, Comb_AvInt_interval_score_P34_female, Comb_AvInt_interval_score_P35_female,
                                             Comb_AvInt_interval_score_P36_female, Comb_AvInt_interval_score_P37_female, Comb_AvInt_interval_score_P38_female, Comb_AvInt_interval_score_P39_female, Comb_AvInt_interval_score_P40_female,
                                             Comb_AvInt_interval_score_P41_female, Comb_AvInt_interval_score_P42_female, Comb_AvInt_interval_score_P43_female, Comb_AvInt_interval_score_P44_female, Comb_AvInt_interval_score_P45_female,
                                             Comb_AvInt_interval_score_P46_female, Comb_AvInt_interval_score_P47_female,
                                             Comb_AvInt_interval_score_P1_male,  Comb_AvInt_interval_score_P2_male,  Comb_AvInt_interval_score_P3_male,  Comb_AvInt_interval_score_P4_male,  Comb_AvInt_interval_score_P5_male,
                                             Comb_AvInt_interval_score_P6_male,  Comb_AvInt_interval_score_P7_male,  Comb_AvInt_interval_score_P8_male,  Comb_AvInt_interval_score_P9_male,  Comb_AvInt_interval_score_P10_male,
                                             Comb_AvInt_interval_score_P11_male, Comb_AvInt_interval_score_P12_male, Comb_AvInt_interval_score_P13_male, Comb_AvInt_interval_score_P14_male, Comb_AvInt_interval_score_P15_male,
                                             Comb_AvInt_interval_score_P16_male, Comb_AvInt_interval_score_P17_male, Comb_AvInt_interval_score_P18_male, Comb_AvInt_interval_score_P19_male, Comb_AvInt_interval_score_P20_male,
                                             Comb_AvInt_interval_score_P21_male, Comb_AvInt_interval_score_P22_male, Comb_AvInt_interval_score_P23_male, Comb_AvInt_interval_score_P24_male, Comb_AvInt_interval_score_P25_male,
                                             Comb_AvInt_interval_score_P26_male, Comb_AvInt_interval_score_P27_male, Comb_AvInt_interval_score_P28_male, Comb_AvInt_interval_score_P29_male, Comb_AvInt_interval_score_P30_male,
                                             Comb_AvInt_interval_score_P31_male, Comb_AvInt_interval_score_P32_male, Comb_AvInt_interval_score_P33_male, Comb_AvInt_interval_score_P34_male, Comb_AvInt_interval_score_P35_male,
                                             Comb_AvInt_interval_score_P36_male, Comb_AvInt_interval_score_P37_male, Comb_AvInt_interval_score_P38_male, Comb_AvInt_interval_score_P39_male, Comb_AvInt_interval_score_P40_male,
                                             Comb_AvInt_interval_score_P41_male, Comb_AvInt_interval_score_P42_male, Comb_AvInt_interval_score_P43_male, Comb_AvInt_interval_score_P44_male, Comb_AvInt_interval_score_P45_male,
                                             Comb_AvInt_interval_score_P46_male, Comb_AvInt_interval_score_P47_male))


Comb_AvInt_interval_score_all = cbind(Comb_AvInt_interval_score_Level_0, Comb_AvInt_interval_score_Level_1, Comb_AvInt_interval_score_Level_2, Comb_AvInt_interval_score_Level_3, Comb_AvInt_interval_score_Level_4, Comb_AvInt_interval_score_Level_5)
Comb_AvInt_interval_score_all_stats = rbind(Comb_AvInt_interval_score_all, colMeans(Comb_AvInt_interval_score_all), apply(Comb_AvInt_interval_score_all, 2, median))
colnames(Comb_AvInt_interval_score_all_stats) = c("Level 0", "Level 1", "Level 2", "Level 3", "Level 4", "Level 5")
rownames(Comb_AvInt_interval_score_all_stats) = c(1:15,"Mean","Median")

#########################################################################
# Calculate mean interval score for different levels of a hierarchy (BU)
#########################################################################

# Japan + Sex

Comb_AvInt_interval_score_Japan_total_mfts = Comb_AvInt_interval_score_Japan_female_mfts = Comb_AvInt_interval_score_Japan_male_mfts = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 0
    Comb_AvInt_interval_score_Japan_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Japan, series = "total",
                                                                       fh = ik, index = 1)
    
    # Level 1
    Comb_AvInt_interval_score_Japan_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Japan, series = "female",
                                                                        fh = ik, index = 2)
    
    Comb_AvInt_interval_score_Japan_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Japan, series = "male",
                                                                      fh = ik, index = 3)
    print(ik)
}

# Region (total)

Comb_AvInt_interval_score_R1_total_mfts = Comb_AvInt_interval_score_R2_total_mfts = Comb_AvInt_interval_score_R3_total_mfts = Comb_AvInt_interval_score_R4_total_mfts =
Comb_AvInt_interval_score_R5_total_mfts = Comb_AvInt_interval_score_R6_total_mfts = Comb_AvInt_interval_score_R7_total_mfts = Comb_AvInt_interval_score_R8_total_mfts = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 2
    Comb_AvInt_interval_score_R1_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R1, series = "total",
                                                                    fh = ik, index = 4)
    
    Comb_AvInt_interval_score_R2_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R2, series = "total",
                                                                    fh = ik, index = 5)
    
    Comb_AvInt_interval_score_R3_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R3, series = "total",
                                                                    fh = ik, index = 6)
    
    Comb_AvInt_interval_score_R4_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R4, series = "total",
                                                                    fh = ik, index = 7)
    
    Comb_AvInt_interval_score_R5_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R5, series = "total",
                                                                    fh = ik, index = 8)
    
    Comb_AvInt_interval_score_R6_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R6, series = "total",
                                                                    fh = ik, index = 9)
    
    Comb_AvInt_interval_score_R7_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R7, series = "total",
                                                                    fh = ik, index = 10)
    
    Comb_AvInt_interval_score_R8_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R8, series = "total",
                                                                    fh = ik, index = 11)
    print(ik)
}

# Region + Sex

Comb_AvInt_interval_score_R1_female_mfts = Comb_AvInt_interval_score_R2_female_mfts = Comb_AvInt_interval_score_R3_female_mfts = Comb_AvInt_interval_score_R4_female_mfts =
Comb_AvInt_interval_score_R5_female_mfts = Comb_AvInt_interval_score_R6_female_mfts = Comb_AvInt_interval_score_R7_female_mfts = Comb_AvInt_interval_score_R8_female_mfts =
Comb_AvInt_interval_score_R1_male_mfts = Comb_AvInt_interval_score_R2_male_mfts = Comb_AvInt_interval_score_R3_male_mfts = Comb_AvInt_interval_score_R4_male_mfts =
Comb_AvInt_interval_score_R5_male_mfts = Comb_AvInt_interval_score_R6_male_mfts = Comb_AvInt_interval_score_R7_male_mfts = Comb_AvInt_interval_score_R8_male_mfts = vector("numeric", 15)
for(ik in 1:15)
{
    # Level 3 (female)
    Comb_AvInt_interval_score_R1_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R1, series = "female",
                                                                     fh = ik, index = 12)
    
    Comb_AvInt_interval_score_R2_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R2, series = "female",
                                                                     fh = ik, index = 13)
    
    Comb_AvInt_interval_score_R3_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R3, series = "female",
                                                                     fh = ik, index = 14)
    
    Comb_AvInt_interval_score_R4_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R4, series = "female",
                                                                     fh = ik, index = 15)
    
    Comb_AvInt_interval_score_R5_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R5, series = "female",
                                                                     fh = ik, index = 16)
    
    Comb_AvInt_interval_score_R6_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R6, series = "female",
                                                                     fh = ik, index = 17)
    
    Comb_AvInt_interval_score_R7_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R7, series = "female",
                                                                     fh = ik, index = 18)
    
    Comb_AvInt_interval_score_R8_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R8, series = "female",
                                                                     fh = ik, index = 19)
    
    # Level 3 (male)
    Comb_AvInt_interval_score_R1_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R1, series = "male",
                                                                   fh = ik, index = 20)
    
    Comb_AvInt_interval_score_R2_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R2, series = "male",
                                                                   fh = ik, index = 21)
    
    Comb_AvInt_interval_score_R3_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R3, series = "male",
                                                                   fh = ik, index = 22)
    
    Comb_AvInt_interval_score_R4_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R4, series = "male",
                                                                   fh = ik, index = 23)
    
    Comb_AvInt_interval_score_R5_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R5, series = "male",
                                                                   fh = ik, index = 24)
    
    Comb_AvInt_interval_score_R6_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R6, series = "male",
                                                                   fh = ik, index = 25)
    
    Comb_AvInt_interval_score_R7_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R7, series = "male",
                                                                   fh = ik, index = 26)
    
    Comb_AvInt_interval_score_R8_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = ind_R8, series = "male",
                                                                   fh = ik, index = 27)
    print(ik)
}

# prefecture (total)

Comb_AvInt_interval_score_P1_total_mfts  = Comb_AvInt_interval_score_P2_total_mfts  = Comb_AvInt_interval_score_P3_total_mfts  = Comb_AvInt_interval_score_P4_total_mfts =
Comb_AvInt_interval_score_P5_total_mfts  = Comb_AvInt_interval_score_P6_total_mfts  = Comb_AvInt_interval_score_P7_total_mfts  = Comb_AvInt_interval_score_P8_total_mfts =
Comb_AvInt_interval_score_P9_total_mfts  = Comb_AvInt_interval_score_P10_total_mfts = Comb_AvInt_interval_score_P11_total_mfts = Comb_AvInt_interval_score_P12_total_mfts =
Comb_AvInt_interval_score_P13_total_mfts = Comb_AvInt_interval_score_P14_total_mfts = Comb_AvInt_interval_score_P15_total_mfts = Comb_AvInt_interval_score_P16_total_mfts =
Comb_AvInt_interval_score_P17_total_mfts = Comb_AvInt_interval_score_P18_total_mfts = Comb_AvInt_interval_score_P19_total_mfts = Comb_AvInt_interval_score_P20_total_mfts =
Comb_AvInt_interval_score_P21_total_mfts = Comb_AvInt_interval_score_P22_total_mfts = Comb_AvInt_interval_score_P23_total_mfts = Comb_AvInt_interval_score_P24_total_mfts =
Comb_AvInt_interval_score_P25_total_mfts = Comb_AvInt_interval_score_P26_total_mfts = Comb_AvInt_interval_score_P27_total_mfts = Comb_AvInt_interval_score_P28_total_mfts =
Comb_AvInt_interval_score_P29_total_mfts = Comb_AvInt_interval_score_P30_total_mfts = Comb_AvInt_interval_score_P31_total_mfts = Comb_AvInt_interval_score_P32_total_mfts =
Comb_AvInt_interval_score_P33_total_mfts = Comb_AvInt_interval_score_P34_total_mfts = Comb_AvInt_interval_score_P35_total_mfts = Comb_AvInt_interval_score_P36_total_mfts =
Comb_AvInt_interval_score_P37_total_mfts = Comb_AvInt_interval_score_P38_total_mfts = Comb_AvInt_interval_score_P39_total_mfts = Comb_AvInt_interval_score_P40_total_mfts =
Comb_AvInt_interval_score_P41_total_mfts = Comb_AvInt_interval_score_P42_total_mfts = Comb_AvInt_interval_score_P43_total_mfts = Comb_AvInt_interval_score_P44_total_mfts =
Comb_AvInt_interval_score_P45_total_mfts = Comb_AvInt_interval_score_P46_total_mfts = Comb_AvInt_interval_score_P47_total_mfts = vector("numeric",15)
for(ik in 1:15)
{
    Comb_AvInt_interval_score_P1_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Hokkaido, series = "total",
                                                                    fh = ik, index = 28)
    
    Comb_AvInt_interval_score_P2_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Aomori, series = "total",
                                                                    fh = ik, index = 29)
    
    Comb_AvInt_interval_score_P3_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Iwate, series = "total",
                                                                    fh = ik, index = 30)
    
    Comb_AvInt_interval_score_P4_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Miyagi, series = "total",
                                                                    fh = ik, index = 31)
    
    Comb_AvInt_interval_score_P5_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Akita, series = "total",
                                                                    fh = ik, index = 32)
    
    Comb_AvInt_interval_score_P6_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Yamagata, series = "total",
                                                                    fh = ik, index = 33)
    
    Comb_AvInt_interval_score_P7_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Fukushima, series = "total",
                                                                    fh = ik, index = 34)
    
    Comb_AvInt_interval_score_P8_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Ibaraki, series = "total",
                                                                    fh = ik, index = 35)
    
    Comb_AvInt_interval_score_P9_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Tochigi, series = "total",
                                                                    fh = ik, index =  36)
    
    Comb_AvInt_interval_score_P10_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Gunma, series = "total",
                                                                     fh = ik, index = 37)
    
    Comb_AvInt_interval_score_P11_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Saitama, series = "total",
                                                                     fh = ik, index = 38)
    
    Comb_AvInt_interval_score_P12_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Chiba, series = "total",
                                                                     fh = ik, index = 39)
    
    Comb_AvInt_interval_score_P13_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Tokyo, series = "total",
                                                                     fh = ik, index = 40)
    
    Comb_AvInt_interval_score_P14_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kanagawa, series = "total",
                                                                     fh = ik, index = 41)
    
    Comb_AvInt_interval_score_P15_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Niigata, series = "total",
                                                                     fh = ik, index = 42)
    
    Comb_AvInt_interval_score_P16_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Toyama, series = "total",
                                                                     fh = ik, index = 43)
    
    Comb_AvInt_interval_score_P17_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Ishikawa, series = "total",
                                                                     fh = ik, index = 44)
    
    Comb_AvInt_interval_score_P18_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Fukui, series = "total",
                                                                     fh = ik, index = 45)
    
    Comb_AvInt_interval_score_P19_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Yamanashi, series = "total",
                                                                     fh = ik, index = 46)
    
    Comb_AvInt_interval_score_P20_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Nagano, series = "total",
                                                                     fh = ik, index = 47)
    
    Comb_AvInt_interval_score_P21_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Gifu, series = "total",
                                                                     fh = ik, index = 48)
    
    Comb_AvInt_interval_score_P22_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Shizuoka, series = "total",
                                                                     fh = ik, index = 49)
    
    Comb_AvInt_interval_score_P23_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Aichi, series = "total",
                                                                     fh = ik, index = 50)
    
    Comb_AvInt_interval_score_P24_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Mie, series = "total",
                                                                     fh = ik, index = 51)
    
    Comb_AvInt_interval_score_P25_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Shiga, series = "total",
                                                                     fh = ik, index = 52)
    
    Comb_AvInt_interval_score_P26_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kyoto, series = "total",
                                                                     fh = ik, index = 53)
    
    Comb_AvInt_interval_score_P27_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Osaka, series = "total",
                                                                     fh = ik, index = 54)
    
    Comb_AvInt_interval_score_P28_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Hyogo, series = "total",
                                                                     fh = ik, index = 55)
    
    Comb_AvInt_interval_score_P29_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Nara, series = "total",
                                                                     fh = ik, index = 56)
    
    Comb_AvInt_interval_score_P30_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Wakayama, series = "total",
                                                                     fh = ik, index = 57)
    
    Comb_AvInt_interval_score_P31_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Tottori, series = "total",
                                                                     fh = ik, index = 58)
    
    Comb_AvInt_interval_score_P32_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Shimane, series = "total",
                                                                     fh = ik, index = 59)
    
    Comb_AvInt_interval_score_P33_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Okayama, series = "total",
                                                                     fh = ik, index = 60)
    
    Comb_AvInt_interval_score_P34_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Hiroshima, series = "total",
                                                                     fh = ik, index = 61)
    
    Comb_AvInt_interval_score_P35_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Yamaguchi, series = "total",
                                                                     fh = ik, index = 62)
    
    Comb_AvInt_interval_score_P36_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Tokushima, series = "total",
                                                                     fh = ik, index = 63)
    
    Comb_AvInt_interval_score_P37_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kagawa, series = "total",
                                                                     fh = ik, index = 64)
    
    Comb_AvInt_interval_score_P38_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Ehime, series = "total",
                                                                     fh = ik, index = 65)
    
    Comb_AvInt_interval_score_P39_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kochi, series = "total",
                                                                     fh = ik, index = 66)
    
    Comb_AvInt_interval_score_P40_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Fukuoka, series = "total",
                                                                     fh = ik, index = 67)
    
    Comb_AvInt_interval_score_P41_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Saga, series = "total",
                                                                     fh = ik, index = 68)
    
    Comb_AvInt_interval_score_P42_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Nagasaki, series = "total",
                                                                     fh = ik, index = 69)
    
    Comb_AvInt_interval_score_P43_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kumamoto, series = "total",
                                                                     fh = ik, index = 70)
    
    Comb_AvInt_interval_score_P44_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Oita, series = "total",
                                                                     fh = ik, index = 71)
    
    Comb_AvInt_interval_score_P45_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Miyazaki, series = "total",
                                                                     fh = ik, index = 72)
    
    Comb_AvInt_interval_score_P46_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kagoshima, series = "total",
                                                                     fh = ik, index = 73)
    
    Comb_AvInt_interval_score_P47_total_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Okinawa, series = "total",
                                                                     fh = ik, index = 74)
    print(ik)
}

# prefecture + Sex

Comb_AvInt_interval_score_P1_female_mfts  = Comb_AvInt_interval_score_P2_female_mfts  = Comb_AvInt_interval_score_P3_female_mfts  = Comb_AvInt_interval_score_P4_female_mfts =
Comb_AvInt_interval_score_P5_female_mfts  = Comb_AvInt_interval_score_P6_female_mfts  = Comb_AvInt_interval_score_P7_female_mfts  = Comb_AvInt_interval_score_P8_female_mfts =
Comb_AvInt_interval_score_P9_female_mfts  = Comb_AvInt_interval_score_P10_female_mfts = Comb_AvInt_interval_score_P11_female_mfts = Comb_AvInt_interval_score_P12_female_mfts =
Comb_AvInt_interval_score_P13_female_mfts = Comb_AvInt_interval_score_P14_female_mfts = Comb_AvInt_interval_score_P15_female_mfts = Comb_AvInt_interval_score_P16_female_mfts =
Comb_AvInt_interval_score_P17_female_mfts = Comb_AvInt_interval_score_P18_female_mfts = Comb_AvInt_interval_score_P19_female_mfts = Comb_AvInt_interval_score_P20_female_mfts =
Comb_AvInt_interval_score_P21_female_mfts = Comb_AvInt_interval_score_P22_female_mfts = Comb_AvInt_interval_score_P23_female_mfts = Comb_AvInt_interval_score_P24_female_mfts =
Comb_AvInt_interval_score_P25_female_mfts = Comb_AvInt_interval_score_P26_female_mfts = Comb_AvInt_interval_score_P27_female_mfts = Comb_AvInt_interval_score_P28_female_mfts =
Comb_AvInt_interval_score_P29_female_mfts = Comb_AvInt_interval_score_P30_female_mfts = Comb_AvInt_interval_score_P31_female_mfts = Comb_AvInt_interval_score_P32_female_mfts =
Comb_AvInt_interval_score_P33_female_mfts = Comb_AvInt_interval_score_P34_female_mfts = Comb_AvInt_interval_score_P35_female_mfts = Comb_AvInt_interval_score_P36_female_mfts =
Comb_AvInt_interval_score_P37_female_mfts = Comb_AvInt_interval_score_P38_female_mfts = Comb_AvInt_interval_score_P39_female_mfts = Comb_AvInt_interval_score_P40_female_mfts =
Comb_AvInt_interval_score_P41_female_mfts = Comb_AvInt_interval_score_P42_female_mfts = Comb_AvInt_interval_score_P43_female_mfts = Comb_AvInt_interval_score_P44_female_mfts =
Comb_AvInt_interval_score_P45_female_mfts = Comb_AvInt_interval_score_P46_female_mfts = Comb_AvInt_interval_score_P47_female_mfts = vector("numeric",15)
for(ik in 1:15)
{
    Comb_AvInt_interval_score_P1_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Hokkaido, series = "female",
                                                                     fh = ik, index = 75)
    
    Comb_AvInt_interval_score_P2_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Aomori, series = "female",
                                                                     fh = ik, index = 77)
    
    Comb_AvInt_interval_score_P3_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Iwate, series = "female",
                                                                     fh = ik, index = 79)
    
    Comb_AvInt_interval_score_P4_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Miyagi, series = "female",
                                                                     fh = ik, index = 81)
    
    Comb_AvInt_interval_score_P5_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Akita, series = "female",
                                                                     fh = ik, index = 83)
    
    Comb_AvInt_interval_score_P6_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Yamagata, series = "female",
                                                                     fh = ik, index = 85)
    
    Comb_AvInt_interval_score_P7_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Fukushima, series = "female",
                                                                     fh = ik, index = 87)
    
    Comb_AvInt_interval_score_P8_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Ibaraki, series = "female",
                                                                     fh = ik, index = 89)
    
    Comb_AvInt_interval_score_P9_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Tochigi, series = "female",
                                                                     fh = ik, index = 91)
    
    Comb_AvInt_interval_score_P10_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Gunma, series = "female",
                                                                      fh = ik, index = 93)
    
    Comb_AvInt_interval_score_P11_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Saitama, series = "female",
                                                                      fh = ik, index = 95)
    
    Comb_AvInt_interval_score_P12_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Chiba, series = "female",
                                                                      fh = ik, index = 97)
    
    Comb_AvInt_interval_score_P13_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Tokyo, series = "female",
                                                                      fh = ik, index = 99)
    
    Comb_AvInt_interval_score_P14_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kanagawa, series = "female",
                                                                      fh = ik, index = 101)
    
    Comb_AvInt_interval_score_P15_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Niigata, series = "female",
                                                                      fh = ik, index = 103)
    
    Comb_AvInt_interval_score_P16_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Toyama, series = "female",
                                                                      fh = ik, index = 105)
    
    Comb_AvInt_interval_score_P17_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Ishikawa, series = "female",
                                                                      fh = ik, index = 107)
    
    Comb_AvInt_interval_score_P18_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Fukui, series = "female",
                                                                      fh = ik, index = 109)
    
    Comb_AvInt_interval_score_P19_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Yamanashi, series = "female",
                                                                      fh = ik, index = 111)
    
    Comb_AvInt_interval_score_P20_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Nagano, series = "female",
                                                                      fh = ik, index = 113)
    
    Comb_AvInt_interval_score_P21_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Gifu, series = "female",
                                                                      fh = ik, index = 115)
    
    Comb_AvInt_interval_score_P22_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Shizuoka, series = "female",
                                                                      fh = ik, index = 117)
    
    Comb_AvInt_interval_score_P23_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Aichi, series = "female",
                                                                      fh = ik, index = 119)
    
    Comb_AvInt_interval_score_P24_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Mie, series = "female",
                                                                      fh = ik, index = 121)
    
    Comb_AvInt_interval_score_P25_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Shiga, series = "female",
                                                                      fh = ik, index = 123)
    
    Comb_AvInt_interval_score_P26_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kyoto, series = "female",
                                                                      fh = ik, index = 125)
    
    Comb_AvInt_interval_score_P27_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Osaka, series = "female",
                                                                      fh = ik, index = 127)
    
    Comb_AvInt_interval_score_P28_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Hyogo, series = "female",
                                                                      fh = ik, index = 129)
    
    Comb_AvInt_interval_score_P29_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Nara, series = "female",
                                                                      fh = ik, index = 131)
    
    Comb_AvInt_interval_score_P30_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Wakayama, series = "female",
                                                                      fh = ik, index = 133)
    
    Comb_AvInt_interval_score_P31_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Tottori, series = "female",
                                                                      fh = ik, index = 135)
    
    Comb_AvInt_interval_score_P32_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Shimane, series = "female",
                                                                      fh = ik, index = 137)
    
    Comb_AvInt_interval_score_P33_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Okayama, series = "female",
                                                                      fh = ik, index = 139)
    
    Comb_AvInt_interval_score_P34_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Hiroshima, series = "female",
                                                                      fh = ik, index = 141)
    
    Comb_AvInt_interval_score_P35_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Yamaguchi, series = "female",
                                                                      fh = ik, index = 143)
    
    Comb_AvInt_interval_score_P36_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Tokushima, series = "female",
                                                                      fh = ik, index = 145)
    
    Comb_AvInt_interval_score_P37_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kagawa, series = "female",
                                                                      fh = ik, index = 147)
    
    Comb_AvInt_interval_score_P38_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Ehime, series = "female",
                                                                      fh = ik, index = 149)
    
    Comb_AvInt_interval_score_P39_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kochi, series = "female",
                                                                      fh = ik, index = 151)
    
    Comb_AvInt_interval_score_P40_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Fukuoka, series = "female",
                                                                      fh = ik, index = 153)
    
    Comb_AvInt_interval_score_P41_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Saga, series = "female",
                                                                      fh = ik, index = 155)
    
    Comb_AvInt_interval_score_P42_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Nagasaki, series = "female",
                                                                      fh = ik, index = 157)
    
    Comb_AvInt_interval_score_P43_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kumamoto, series = "female",
                                                                      fh = ik, index = 159)
    
    Comb_AvInt_interval_score_P44_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Oita, series = "female",
                                                                      fh = ik, index = 161)
    
    Comb_AvInt_interval_score_P45_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Miyazaki, series = "female",
                                                                      fh = ik, index = 163)
    
    Comb_AvInt_interval_score_P46_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kagoshima, series = "female",
                                                                      fh = ik, index = 165)
    
    Comb_AvInt_interval_score_P47_female_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Okinawa, series = "female",
                                                                      fh = ik, index = 167)
    print(ik)
}

# male

Comb_AvInt_interval_score_P1_male_mfts  = Comb_AvInt_interval_score_P2_male_mfts  = Comb_AvInt_interval_score_P3_male_mfts  = Comb_AvInt_interval_score_P4_male_mfts =
Comb_AvInt_interval_score_P5_male_mfts  = Comb_AvInt_interval_score_P6_male_mfts  = Comb_AvInt_interval_score_P7_male_mfts  = Comb_AvInt_interval_score_P8_male_mfts =
Comb_AvInt_interval_score_P9_male_mfts  = Comb_AvInt_interval_score_P10_male_mfts = Comb_AvInt_interval_score_P11_male_mfts = Comb_AvInt_interval_score_P12_male_mfts =
Comb_AvInt_interval_score_P13_male_mfts = Comb_AvInt_interval_score_P14_male_mfts = Comb_AvInt_interval_score_P15_male_mfts = Comb_AvInt_interval_score_P16_male_mfts =
Comb_AvInt_interval_score_P17_male_mfts = Comb_AvInt_interval_score_P18_male_mfts = Comb_AvInt_interval_score_P19_male_mfts = Comb_AvInt_interval_score_P20_male_mfts =
Comb_AvInt_interval_score_P21_male_mfts = Comb_AvInt_interval_score_P22_male_mfts = Comb_AvInt_interval_score_P23_male_mfts = Comb_AvInt_interval_score_P24_male_mfts =
Comb_AvInt_interval_score_P25_male_mfts = Comb_AvInt_interval_score_P26_male_mfts = Comb_AvInt_interval_score_P27_male_mfts = Comb_AvInt_interval_score_P28_male_mfts =
Comb_AvInt_interval_score_P29_male_mfts = Comb_AvInt_interval_score_P30_male_mfts = Comb_AvInt_interval_score_P31_male_mfts = Comb_AvInt_interval_score_P32_male_mfts =
Comb_AvInt_interval_score_P33_male_mfts = Comb_AvInt_interval_score_P34_male_mfts = Comb_AvInt_interval_score_P35_male_mfts = Comb_AvInt_interval_score_P36_male_mfts =
Comb_AvInt_interval_score_P37_male_mfts = Comb_AvInt_interval_score_P38_male_mfts = Comb_AvInt_interval_score_P39_male_mfts = Comb_AvInt_interval_score_P40_male_mfts =
Comb_AvInt_interval_score_P41_male_mfts = Comb_AvInt_interval_score_P42_male_mfts = Comb_AvInt_interval_score_P43_male_mfts = Comb_AvInt_interval_score_P44_male_mfts =
Comb_AvInt_interval_score_P45_male_mfts = Comb_AvInt_interval_score_P46_male_mfts = Comb_AvInt_interval_score_P47_male_mfts = vector("numeric",15)
for(ik in 1:15)
{
    Comb_AvInt_interval_score_P1_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Hokkaido, series = "male",
                                                                   fh = ik, index = 76)
    
    Comb_AvInt_interval_score_P2_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Aomori, series = "male",
                                                                   fh = ik, index = 78)
    
    Comb_AvInt_interval_score_P3_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Iwate, series = "male",
                                                                   fh = ik, index = 80)
    
    Comb_AvInt_interval_score_P4_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Miyagi, series = "male",
                                                                   fh = ik, index = 82)
    
    Comb_AvInt_interval_score_P5_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Akita, series = "male",
                                                                   fh = ik, index = 84)
    
    Comb_AvInt_interval_score_P6_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Yamagata, series = "male",
                                                                   fh = ik, index = 86)
    
    Comb_AvInt_interval_score_P7_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Fukushima, series = "male",
                                                                   fh = ik, index = 88)
    
    Comb_AvInt_interval_score_P8_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Ibaraki, series = "male",
                                                                   fh = ik, index = 90)
    
    Comb_AvInt_interval_score_P9_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Tochigi, series = "male",
                                                                   fh = ik, index = 92)
    
    Comb_AvInt_interval_score_P10_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Gunma, series = "male",
                                                                    fh = ik, index = 94)
    
    Comb_AvInt_interval_score_P11_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Saitama, series = "male",
                                                                    fh = ik, index = 96)
    
    Comb_AvInt_interval_score_P12_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Chiba, series = "male",
                                                                    fh = ik, index = 98)
    
    Comb_AvInt_interval_score_P13_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Tokyo, series = "male",
                                                                    fh = ik, index = 100)
    
    Comb_AvInt_interval_score_P14_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kanagawa, series = "male",
                                                                    fh = ik, index = 102)
    
    Comb_AvInt_interval_score_P15_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Niigata, series = "male",
                                                                    fh = ik, index = 104)
    
    Comb_AvInt_interval_score_P16_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Toyama, series = "male",
                                                                    fh = ik, index = 106)
    
    Comb_AvInt_interval_score_P17_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Ishikawa, series = "male",
                                                                    fh = ik, index = 108)
    
    Comb_AvInt_interval_score_P18_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Fukui, series = "male",
                                                                    fh = ik, index = 110)
    
    Comb_AvInt_interval_score_P19_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Yamanashi, series = "male",
                                                                    fh = ik, index = 112)
    
    Comb_AvInt_interval_score_P20_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Nagano, series = "male",
                                                                    fh = ik, index = 114)
    
    Comb_AvInt_interval_score_P21_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Gifu, series = "male",
                                                                    fh = ik, index = 116)
    
    Comb_AvInt_interval_score_P22_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Shizuoka, series = "male",
                                                                    fh = ik, index = 118)
    
    Comb_AvInt_interval_score_P23_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Aichi, series = "male",
                                                                    fh = ik, index = 120)
    
    Comb_AvInt_interval_score_P24_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Mie, series = "male",
                                                                    fh = ik, index = 122)
    
    Comb_AvInt_interval_score_P25_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Shiga, series = "male",
                                                                    fh = ik, index = 124)
    
    Comb_AvInt_interval_score_P26_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kyoto, series = "male",
                                                                    fh = ik, index = 126)
    
    Comb_AvInt_interval_score_P27_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Osaka, series = "male",
                                                                    fh = ik, index = 128)
    
    Comb_AvInt_interval_score_P28_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Hyogo, series = "male",
                                                                    fh = ik, index = 130)
    
    Comb_AvInt_interval_score_P29_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Nara, series = "male",
                                                                    fh = ik, index = 132)
    
    Comb_AvInt_interval_score_P30_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Wakayama, series = "male",
                                                                    fh = ik, index = 134)
    
    Comb_AvInt_interval_score_P31_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Tottori, series = "male",
                                                                    fh = ik, index = 136)
    
    Comb_AvInt_interval_score_P32_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Shimane, series = "male",
                                                                    fh = ik, index = 138)
    
    Comb_AvInt_interval_score_P33_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Okayama, series = "male",
                                                                    fh = ik, index = 140)
    
    Comb_AvInt_interval_score_P34_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Hiroshima, series = "male",
                                                                    fh = ik, index = 142)
    
    Comb_AvInt_interval_score_P35_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Yamaguchi, series = "male",
                                                                    fh = ik, index = 144)
    
    Comb_AvInt_interval_score_P36_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Tokushima, series = "male",
                                                                    fh = ik, index = 146)
    
    Comb_AvInt_interval_score_P37_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kagawa, series = "male",
                                                                    fh = ik, index = 148)
    
    Comb_AvInt_interval_score_P38_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Ehime, series = "male",
                                                                    fh = ik, index = 150)
    
    Comb_AvInt_interval_score_P39_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kochi, series = "male",
                                                                    fh = ik, index = 152)
    
    Comb_AvInt_interval_score_P40_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Fukuoka, series = "male",
                                                                    fh = ik, index = 154)
    
    Comb_AvInt_interval_score_P41_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Saga, series = "male",
                                                                    fh = ik, index = 156)
    
    Comb_AvInt_interval_score_P42_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Nagasaki, series = "male",
                                                                    fh = ik, index = 158)
    
    Comb_AvInt_interval_score_P43_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kumamoto, series = "male",
                                                                    fh = ik, index = 160)
    
    Comb_AvInt_interval_score_P44_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Oita, series = "male",
                                                                    fh = ik, index = 162)
    
    Comb_AvInt_interval_score_P45_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Miyazaki, series = "male",
                                                                    fh = ik, index = 164)
    
    Comb_AvInt_interval_score_P46_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Kagoshima, series = "male",
                                                                    fh = ik, index = 166)
    
    Comb_AvInt_interval_score_P47_male_mfts[ik] = interval_score_BU_optim(PI_val = comb_hier_comb_mfts_int_midpoints, data_series = Okinawa, series = "male",
                                                                    fh = ik, index = 168)
    print(ik)
}


Comb_AvInt_interval_score_Level_0_mfts = Comb_AvInt_interval_score_Japan_total_mfts

Comb_AvInt_interval_score_Level_1_mfts = rowMeans(cbind(Comb_AvInt_interval_score_Japan_female_mfts, Comb_AvInt_interval_score_Japan_male_mfts))

Comb_AvInt_interval_score_Level_2_mfts = rowMeans(cbind(Comb_AvInt_interval_score_R1_total_mfts, Comb_AvInt_interval_score_R2_total_mfts, Comb_AvInt_interval_score_R3_total_mfts,
                                                  Comb_AvInt_interval_score_R4_total_mfts, Comb_AvInt_interval_score_R5_total_mfts, Comb_AvInt_interval_score_R6_total_mfts,
                                                  Comb_AvInt_interval_score_R7_total_mfts, Comb_AvInt_interval_score_R8_total_mfts))

Comb_AvInt_interval_score_Level_3_mfts = rowMeans(cbind(Comb_AvInt_interval_score_R1_female_mfts, Comb_AvInt_interval_score_R2_female_mfts, Comb_AvInt_interval_score_R3_female_mfts,
                                                  Comb_AvInt_interval_score_R4_female_mfts, Comb_AvInt_interval_score_R5_female_mfts, Comb_AvInt_interval_score_R6_female_mfts,
                                                  Comb_AvInt_interval_score_R7_female_mfts, Comb_AvInt_interval_score_R8_female_mfts, Comb_AvInt_interval_score_R1_male_mfts,
                                                  Comb_AvInt_interval_score_R2_male_mfts,   Comb_AvInt_interval_score_R3_male_mfts,   Comb_AvInt_interval_score_R4_male_mfts,
                                                  Comb_AvInt_interval_score_R5_male_mfts,   Comb_AvInt_interval_score_R6_male_mfts,   Comb_AvInt_interval_score_R7_male_mfts,
                                                  Comb_AvInt_interval_score_R8_male_mfts))

Comb_AvInt_interval_score_Level_4_mfts = rowMeans(cbind(Comb_AvInt_interval_score_P1_total_mfts,  Comb_AvInt_interval_score_P2_total_mfts,  Comb_AvInt_interval_score_P3_total_mfts,
                                                  Comb_AvInt_interval_score_P4_total_mfts,  Comb_AvInt_interval_score_P5_total_mfts,  Comb_AvInt_interval_score_P6_total_mfts,
                                                  Comb_AvInt_interval_score_P7_total_mfts,  Comb_AvInt_interval_score_P8_total_mfts,  Comb_AvInt_interval_score_P9_total_mfts,
                                                  Comb_AvInt_interval_score_P10_total_mfts, Comb_AvInt_interval_score_P11_total_mfts, Comb_AvInt_interval_score_P12_total_mfts,
                                                  Comb_AvInt_interval_score_P13_total_mfts, Comb_AvInt_interval_score_P14_total_mfts, Comb_AvInt_interval_score_P15_total_mfts,
                                                  Comb_AvInt_interval_score_P16_total_mfts, Comb_AvInt_interval_score_P17_total_mfts, Comb_AvInt_interval_score_P18_total_mfts,
                                                  Comb_AvInt_interval_score_P19_total_mfts, Comb_AvInt_interval_score_P20_total_mfts, Comb_AvInt_interval_score_P21_total_mfts,
                                                  Comb_AvInt_interval_score_P22_total_mfts, Comb_AvInt_interval_score_P23_total_mfts, Comb_AvInt_interval_score_P24_total_mfts,
                                                  Comb_AvInt_interval_score_P25_total_mfts, Comb_AvInt_interval_score_P26_total_mfts, Comb_AvInt_interval_score_P27_total_mfts,
                                                  Comb_AvInt_interval_score_P28_total_mfts, Comb_AvInt_interval_score_P29_total_mfts, Comb_AvInt_interval_score_P30_total_mfts,
                                                  Comb_AvInt_interval_score_P31_total_mfts, Comb_AvInt_interval_score_P32_total_mfts, Comb_AvInt_interval_score_P33_total_mfts,
                                                  Comb_AvInt_interval_score_P34_total_mfts, Comb_AvInt_interval_score_P35_total_mfts, Comb_AvInt_interval_score_P36_total_mfts,
                                                  Comb_AvInt_interval_score_P37_total_mfts, Comb_AvInt_interval_score_P38_total_mfts, Comb_AvInt_interval_score_P39_total_mfts,
                                                  Comb_AvInt_interval_score_P40_total_mfts, Comb_AvInt_interval_score_P41_total_mfts, Comb_AvInt_interval_score_P42_total_mfts,
                                                  Comb_AvInt_interval_score_P43_total_mfts, Comb_AvInt_interval_score_P44_total_mfts, Comb_AvInt_interval_score_P45_total_mfts,
                                                  Comb_AvInt_interval_score_P46_total_mfts, Comb_AvInt_interval_score_P47_total_mfts))

Comb_AvInt_interval_score_Level_5_mfts = rowMeans(cbind(Comb_AvInt_interval_score_P1_female_mfts,  Comb_AvInt_interval_score_P2_female_mfts,  Comb_AvInt_interval_score_P3_female_mfts,
                                                  Comb_AvInt_interval_score_P4_female_mfts,  Comb_AvInt_interval_score_P5_female_mfts,  Comb_AvInt_interval_score_P6_female_mfts,
                                                  Comb_AvInt_interval_score_P7_female_mfts,  Comb_AvInt_interval_score_P8_female_mfts,  Comb_AvInt_interval_score_P9_female_mfts,
                                                  Comb_AvInt_interval_score_P10_female_mfts, Comb_AvInt_interval_score_P11_female_mfts, Comb_AvInt_interval_score_P12_female_mfts,
                                                  Comb_AvInt_interval_score_P13_female_mfts, Comb_AvInt_interval_score_P14_female_mfts, Comb_AvInt_interval_score_P15_female_mfts,
                                                  Comb_AvInt_interval_score_P16_female_mfts, Comb_AvInt_interval_score_P17_female_mfts, Comb_AvInt_interval_score_P18_female_mfts,
                                                  Comb_AvInt_interval_score_P19_female_mfts, Comb_AvInt_interval_score_P20_female_mfts, Comb_AvInt_interval_score_P21_female_mfts,
                                                  Comb_AvInt_interval_score_P22_female_mfts, Comb_AvInt_interval_score_P23_female_mfts, Comb_AvInt_interval_score_P24_female_mfts,
                                                  Comb_AvInt_interval_score_P25_female_mfts, Comb_AvInt_interval_score_P26_female_mfts, Comb_AvInt_interval_score_P27_female_mfts,
                                                  Comb_AvInt_interval_score_P28_female_mfts, Comb_AvInt_interval_score_P29_female_mfts, Comb_AvInt_interval_score_P30_female_mfts,
                                                  Comb_AvInt_interval_score_P31_female_mfts, Comb_AvInt_interval_score_P32_female_mfts, Comb_AvInt_interval_score_P33_female_mfts,
                                                  Comb_AvInt_interval_score_P34_female_mfts, Comb_AvInt_interval_score_P35_female_mfts, Comb_AvInt_interval_score_P36_female_mfts,
                                                  Comb_AvInt_interval_score_P37_female_mfts, Comb_AvInt_interval_score_P38_female_mfts, Comb_AvInt_interval_score_P39_female_mfts,
                                                  Comb_AvInt_interval_score_P40_female_mfts, Comb_AvInt_interval_score_P41_female_mfts, Comb_AvInt_interval_score_P42_female_mfts,
                                                  Comb_AvInt_interval_score_P43_female_mfts, Comb_AvInt_interval_score_P44_female_mfts, Comb_AvInt_interval_score_P45_female_mfts,
                                                  Comb_AvInt_interval_score_P46_female_mfts, Comb_AvInt_interval_score_P47_female_mfts, Comb_AvInt_interval_score_P1_male_mfts,
                                                  Comb_AvInt_interval_score_P2_male_mfts,  Comb_AvInt_interval_score_P3_male_mfts,  Comb_AvInt_interval_score_P4_male_mfts,
                                                  Comb_AvInt_interval_score_P5_male_mfts,  Comb_AvInt_interval_score_P6_male_mfts,  Comb_AvInt_interval_score_P7_male_mfts,
                                                  Comb_AvInt_interval_score_P8_male_mfts,  Comb_AvInt_interval_score_P9_male_mfts,  Comb_AvInt_interval_score_P10_male_mfts,
                                                  Comb_AvInt_interval_score_P11_male_mfts, Comb_AvInt_interval_score_P12_male_mfts, Comb_AvInt_interval_score_P13_male_mfts,
                                                  Comb_AvInt_interval_score_P14_male_mfts, Comb_AvInt_interval_score_P15_male_mfts, Comb_AvInt_interval_score_P16_male_mfts,
                                                  Comb_AvInt_interval_score_P17_male_mfts, Comb_AvInt_interval_score_P18_male_mfts, Comb_AvInt_interval_score_P19_male_mfts,
                                                  Comb_AvInt_interval_score_P20_male_mfts, Comb_AvInt_interval_score_P21_male_mfts, Comb_AvInt_interval_score_P22_male_mfts,
                                                  Comb_AvInt_interval_score_P23_male_mfts, Comb_AvInt_interval_score_P24_male_mfts, Comb_AvInt_interval_score_P25_male_mfts,
                                                  Comb_AvInt_interval_score_P26_male_mfts, Comb_AvInt_interval_score_P27_male_mfts, Comb_AvInt_interval_score_P28_male_mfts,
                                                  Comb_AvInt_interval_score_P29_male_mfts, Comb_AvInt_interval_score_P30_male_mfts, Comb_AvInt_interval_score_P31_male_mfts,
                                                  Comb_AvInt_interval_score_P32_male_mfts, Comb_AvInt_interval_score_P33_male_mfts, Comb_AvInt_interval_score_P34_male_mfts,
                                                  Comb_AvInt_interval_score_P35_male_mfts, Comb_AvInt_interval_score_P36_male_mfts, Comb_AvInt_interval_score_P37_male_mfts,
                                                  Comb_AvInt_interval_score_P38_male_mfts, Comb_AvInt_interval_score_P39_male_mfts, Comb_AvInt_interval_score_P40_male_mfts,
                                                  Comb_AvInt_interval_score_P41_male_mfts, Comb_AvInt_interval_score_P42_male_mfts, Comb_AvInt_interval_score_P43_male_mfts,
                                                  Comb_AvInt_interval_score_P44_male_mfts, Comb_AvInt_interval_score_P45_male_mfts, Comb_AvInt_interval_score_P46_male_mfts,
                                                  Comb_AvInt_interval_score_P47_male_mfts))


Comb_AvInt_interval_score_all_mfts = cbind(Comb_AvInt_interval_score_Level_0_mfts, Comb_AvInt_interval_score_Level_1_mfts, Comb_AvInt_interval_score_Level_2_mfts, Comb_AvInt_interval_score_Level_3_mfts, Comb_AvInt_interval_score_Level_4_mfts, Comb_AvInt_interval_score_Level_5_mfts)
Comb_AvInt_interval_score_all_stats_mfts = rbind(Comb_AvInt_interval_score_all_mfts, colMeans(Comb_AvInt_interval_score_all_mfts), apply(Comb_AvInt_interval_score_all_mfts, 2, median))
colnames(Comb_AvInt_interval_score_all_stats_mfts) = c("Level 0", "Level 1", "Level 2", "Level 3", "Level 4", "Level 5")
rownames(Comb_AvInt_interval_score_all_stats_mfts) = c(1:15,"Mean","Median")

######################
# Mean interval score
######################

# FTS

xtable(rbind(t(interval_score_all_stats[c(1, 5, 10, 15:17),])[1,],
t(BU_interval_score_all_stats[c(1, 5, 10, 15:17),])[1,],
t(optim_interval_score_all_stats[c(1, 5, 10, 15:17),])[1,],
t(Comb_interval_score_all_stats[c(1, 5, 10, 15:17),])[1,],
t(Comb_AvInt_interval_score_all_stats[c(1, 5, 10, 15:17),])[1,],

t(interval_score_all_stats[c(1, 5, 10, 15:17),])[2,],
t(BU_interval_score_all_stats[c(1, 5, 10, 15:17),])[2,],
t(optim_interval_score_all_stats[c(1, 5, 10, 15:17),])[2,],
t(Comb_interval_score_all_stats[c(1, 5, 10, 15:17),])[2,],
t(Comb_AvInt_interval_score_all_stats[c(1, 5, 10, 15:17),])[2,],

t(interval_score_all_stats[c(1, 5, 10, 15:17),])[3,],
t(BU_interval_score_all_stats[c(1, 5, 10, 15:17),])[3,],
t(optim_interval_score_all_stats[c(1, 5, 10, 15:17),])[3,],
t(Comb_interval_score_all_stats[c(1, 5, 10, 15:17),])[3,],
t(Comb_AvInt_interval_score_all_stats[c(1, 5, 10, 15:17),])[3,],

t(interval_score_all_stats[c(1, 5, 10, 15:17),])[4,],
t(BU_interval_score_all_stats[c(1, 5, 10, 15:17),])[4,],
t(optim_interval_score_all_stats[c(1, 5, 10, 15:17),])[4,],
t(Comb_interval_score_all_stats[c(1, 5, 10, 15:17),])[4,],
t(Comb_AvInt_interval_score_all_stats[c(1, 5, 10, 15:17),])[4,],

t(interval_score_all_stats[c(1, 5, 10, 15:17),])[5,],
t(BU_interval_score_all_stats[c(1, 5, 10, 15:17),])[5,],
t(optim_interval_score_all_stats[c(1, 5, 10, 15:17),])[5,],
t(Comb_interval_score_all_stats[c(1, 5, 10, 15:17),])[5,],
t(Comb_AvInt_interval_score_all_stats[c(1, 5, 10, 15:17),])[5,],

t(interval_score_all_stats[c(1, 5, 10, 15:17),])[6,],
t(BU_interval_score_all_stats[c(1, 5, 10, 15:17),])[6,],
t(optim_interval_score_all_stats[c(1, 5, 10, 15:17),])[6,],
t(Comb_interval_score_all_stats[c(1, 5, 10, 15:17),])[6,],
t(Comb_AvInt_interval_score_all_stats[c(1, 5, 10, 15:17),])[6,]) * 100, digits = 2)

# MFTS

xtable(rbind(t(interval_score_all_mfts_stats[c(1, 5, 10, 15:17),])[1,],
t(BU_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[1,],
t(optim_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[1,],
t(Comb_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[1,],
t(Comb_AvInt_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[1,],

t(interval_score_all_mfts_stats[c(1, 5, 10, 15:17),])[2,],
t(BU_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[2,],
t(optim_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[2,],
t(Comb_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[2,],
t(Comb_AvInt_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[2,],

t(interval_score_all_mfts_stats[c(1, 5, 10, 15:17),])[3,],
t(BU_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[3,],
t(optim_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[3,],
t(Comb_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[3,],
t(Comb_AvInt_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[3,],

t(interval_score_all_mfts_stats[c(1, 5, 10, 15:17),])[4,],
t(BU_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[4,],
t(optim_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[4,],
t(Comb_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[4,],
t(Comb_AvInt_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[4,],

t(interval_score_all_mfts_stats[c(1, 5, 10, 15:17),])[5,],
t(BU_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[5,],
t(optim_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[5,],
t(Comb_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[5,],
t(Comb_AvInt_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[5,],

t(interval_score_all_mfts_stats[c(1, 5, 10, 15:17),])[6,],
t(BU_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[6,],
t(optim_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[6,],
t(Comb_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[6,],
t(Comb_AvInt_interval_score_all_stats_mfts[c(1, 5, 10, 15:17),])[6,]) * 100, digits = 2)

# Mention about na.interp for missing value imputation

data_series <- map2_dfr(.x = 1:6, .y = c("Total", "Sex", "Region", "Region + Sex", "Prefecture", "Prefecture + Sex"),
                        ~tibble(
                          variety = forcats::as_factor(rep(c("Ind", "BU", "OLS", "Comb_Av", "Comb_AvInt",
                                                             "Ind", "BU", "OLS", "Comb_Av", "Comb_AvInt"), each = 15)),
                          Method  = forcats::as_factor(rep(c("Univariate FTS", "Multivariate FTS"), each = 75)),
                          series = c(interval_score_all_mfts_stats[1:15, .x],
                                     BU_interval_score_all_stats_mfts[1:15, .x],
                                     optim_interval_score_all_stats_mfts[1:15, .x],
                                     Comb_interval_score_all_stats_mfts[1:15, .x],
                                     Comb_AvInt_interval_score_all_stats_mfts[1:15, .x],
                                     interval_score_all_stats[1:15, .x],
                                     BU_interval_score_all_stats[1:15, .x],
                                     optim_interval_score_all_stats[1:15, .x],
                                     Comb_interval_score_all_stats[1:15, .x],
                                     Comb_AvInt_interval_score_all_stats[1:15, .x]),
                          type = factor(paste(.y, "series"), levels = c("Total series", "Region series", "Prefecture series", "Sex series", "Region + Sex series", "Prefecture + Sex series"))
                        ))


ggplot(data_series, aes(x = variety, y = series, fill = Method)) +
  geom_boxplot() + ylab("Mean interval score") + xlab("") +
  facet_wrap(~type)
ggsave("score_plot.png")

#############
# Prefecture
#############

PI_fh_out_mfts <- function(smooth_series, raw_series, series, fh, transform = c("log", "logit"))
{
    transform = match.arg(transform)
    return(find_enlarge_val_mfts(smooth_data = smooth_series, raw_data = raw_series,
                                 series = series, fh = fh, transformation = transform))
}

Japan_female_fh_PI_out_mfts_logit = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Japan_smooth, raw_series = Japan,
                                                                              series = "female", fh = ik, transform = "logit")
Japan_male_fh_PI_out_mfts_logit = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Japan_smooth, raw_series = Japan,
                                                                            series = "male", fh = ik, transform = "logit")

########
# Japan
########

#install.packages("doMC")
require(doMC)
registerDoMC(15)
Japan_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Japan_smooth, raw_series = Japan,
                                                                        series = "female", fh = ik)
Japan_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Japan_smooth, raw_series = Japan,
                                                                      series = "male", fh = ik)

###########
# Hokkaido
###########

Hokkaido_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Hokkaido_smooth, raw_series = Hokkaido, series = "female", fh = ik)
Hokkaido_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Hokkaido_smooth, raw_series = Hokkaido, series = "male", fh = ik)

#########
# Aomori
#########

Aomori_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Aomori_smooth, raw_series = Aomori, series = "female", fh = ik)
Aomori_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Aomori_smooth, raw_series = Aomori, series = "male", fh = ik)

########
# Iwate
########

Iwate_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Iwate_smooth, raw_series = Iwate, series = "female", fh = ik)
Iwate_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Iwate_smooth, raw_series = Iwate, series = "male", fh = ik)

#########
# Miyagi
#########

Miyagi_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Miyagi_smooth, raw_series = Miyagi, series = "female", fh = ik)
Miyagi_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Miyagi_smooth, raw_series = Miyagi, series = "male", fh = ik)

########
# Akita
########

Akita_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Akita_smooth, raw_series = Akita, series = "female", fh = ik)
Akita_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Akita_smooth, raw_series = Akita, series = "male", fh = ik)

###########
# Yamagata
###########

Yamagata_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Yamagata_smooth, raw_series = Yamagata, series = "female", fh = ik)
Yamagata_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Yamagata_smooth, raw_series = Yamagata, series = "male", fh = ik)

############
# Fukushima
############

Fukushima_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Fukushima_smooth, raw_series = Fukushima, series = "female", fh = ik)
Fukushima_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Fukushima_smooth, raw_series = Fukushima, series = "male", fh = ik)

##########
# Ibaraki
##########

Ibaraki_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Ibaraki_smooth, raw_series = Ibaraki, series = "female", fh = ik)
Ibaraki_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Ibaraki_smooth, raw_series = Ibaraki, series = "male", fh = ik)

##########
# Tochigi
##########

Tochigi_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Tochigi_smooth, raw_series = Tochigi, series = "female", fh = ik)
Tochigi_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Tochigi_smooth, raw_series = Tochigi, series = "male", fh = ik)

########
# Gunma
########

Gunma_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Gunma_smooth, raw_series = Gunma, series = "female", fh = ik)
Gunma_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Gunma_smooth, raw_series = Gunma, series = "male", fh = ik)

##########
# Saitama
##########

Saitama_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Saitama_smooth, raw_series = Saitama, series = "female", fh = ik)
Saitama_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Saitama_smooth, raw_series = Saitama, series = "male", fh = ik)

########
# Chiba
########

Chiba_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Chiba_smooth, raw_series = Chiba, series = "female", fh = ik)
Chiba_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Chiba_smooth, raw_series = Chiba, series = "male", fh = ik)

########
# Tokyo
########

Tokyo_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Tokyo_smooth, raw_series = Tokyo, series = "female", fh = ik)
Tokyo_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Tokyo_smooth, raw_series = Tokyo, series = "male", fh = ik)

###########
# Kanagawa
###########

Kanagawa_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Kanagawa_smooth, raw_series = Kanagawa, series = "female", fh = ik)
Kanagawa_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Kanagawa_smooth, raw_series = Kanagawa, series = "male", fh = ik)

##########
# Niigata
##########

Niigata_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Niigata_smooth, raw_series = Niigata, series = "female", fh = ik)
Niigata_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Niigata_smooth, raw_series = Niigata, series = "male", fh = ik)

#########
# Toyama
#########

Toyama_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Toyama_smooth, raw_series = Toyama, series = "female", fh = ik)
Toyama_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Toyama_smooth, raw_series = Toyama, series = "male", fh = ik)

###########
# Ishikawa
###########

Ishikawa_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Ishikawa_smooth, raw_series = Ishikawa, series = "female", fh = ik)
Ishikawa_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Ishikawa_smooth, raw_series = Ishikawa, series = "male", fh = ik)

########
# Fukui
########

Fukui_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Fukui_smooth, raw_series = Fukui, series = "female", fh = ik)
Fukui_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Fukui_smooth, raw_series = Fukui, series = "male", fh = ik)

############
# Yamanashi
############

Yamanashi_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Yamanashi_smooth, raw_series = Yamanashi, series = "female", fh = ik)
Yamanashi_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Yamanashi_smooth, raw_series = Yamanashi, series = "male", fh = ik)

#########
# Nagano
#########

Nagano_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Nagano_smooth, raw_series = Nagano, series = "female", fh = ik)
Nagano_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Nagano_smooth, raw_series = Nagano, series = "male", fh = ik)

#######
# Gifu
#######

Gifu_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Gifu_smooth, raw_series = Gifu, series = "female", fh = ik)
Gifu_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Gifu_smooth, raw_series = Gifu, series = "male", fh = ik)

###########
# Shizuoka
###########

Shizuoka_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Shizuoka_smooth, raw_series = Shizuoka, series = "female", fh = ik)
Shizuoka_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Shizuoka_smooth, raw_series = Shizuoka, series = "male", fh = ik)

########
# Aichi
########

Aichi_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Aichi_smooth, raw_series = Aichi, series = "female", fh = ik)
Aichi_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Aichi_smooth, raw_series = Aichi, series = "male", fh = ik)

######
# Mie
######

Mie_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Mie_smooth, raw_series = Mie, series = "female", fh = ik)
Mie_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Mie_smooth, raw_series = Mie, series = "male", fh = ik)

########
# Shiga
########

Shiga_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Shiga_smooth, raw_series = Shiga, series = "female", fh = ik)
Shiga_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Shiga_smooth, raw_series = Shiga, series = "male", fh = ik)

########
# Kyoto
########

Kyoto_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Kyoto_smooth, raw_series = Kyoto, series = "female", fh = ik)
Kyoto_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Kyoto_smooth, raw_series = Kyoto, series = "male", fh = ik)

########
# Osaka
########

Osaka_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Osaka_smooth, raw_series = Osaka, series = "female", fh = ik)
Osaka_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Osaka_smooth, raw_series = Osaka, series = "male", fh = ik)

########
# Hyogo
########

Hyogo_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Hyogo_smooth, raw_series = Hyogo, series = "female", fh = ik)
Hyogo_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Hyogo_smooth, raw_series = Hyogo, series = "male", fh = ik)

#######
# Nara
#######

Nara_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Nara_smooth, raw_series = Nara, series = "female", fh = ik)
Nara_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Nara_smooth, raw_series = Nara, series = "male", fh = ik)

###########
# Wakayama
###########

Wakayama_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Wakayama_smooth, raw_series = Wakayama, series = "female", fh = ik)
Wakayama_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Wakayama_smooth, raw_series = Wakayama, series = "male", fh = ik)

##########
# Tottori
##########

Tottori_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Tottori_smooth, raw_series = Tottori, series = "female", fh = ik)
Tottori_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Tottori_smooth, raw_series = Tottori, series = "male", fh = ik)

##########
# Shimane
##########

Shimane_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Shimane_smooth, raw_series = Shimane, series = "female", fh = ik)
Shimane_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Shimane_smooth, raw_series = Shimane, series = "male", fh = ik)

##########
# Okayama
##########

Okayama_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Okayama_smooth, raw_series = Okayama, series = "female", fh = ik)
Okayama_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Okayama_smooth, raw_series = Okayama, series = "male", fh = ik)

############
# Hiroshima
############

Hiroshima_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Hiroshima_smooth, raw_series = Hiroshima, series = "female", fh = ik)
Hiroshima_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Hiroshima_smooth, raw_series = Hiroshima, series = "male", fh = ik)

############
# Yamaguchi
############

Yamaguchi_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Yamaguchi_smooth, raw_series = Yamaguchi, series = "female", fh = ik)
Yamaguchi_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Yamaguchi_smooth, raw_series = Yamaguchi, series = "male", fh = ik)

############
# Tokushima
############

Tokushima_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Tokushima_smooth, raw_series = Tokushima, series = "female", fh = ik)
Tokushima_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Tokushima_smooth, raw_series = Tokushima, series = "male", fh = ik)

#########
# Kagawa
#########

Kagawa_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Kagawa_smooth, raw_series = Kagawa, series = "female", fh = ik)
Kagawa_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Kagawa_smooth, raw_series = Kagawa, series = "male", fh = ik)

########
# Ehime
########

Ehime_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Ehime_smooth, raw_series = Ehime, series = "female", fh = ik)
Ehime_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Ehime_smooth, raw_series = Ehime, series = "male", fh = ik)

########
# Kochi
########

Kochi_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Kochi_smooth, raw_series = Kochi, series = "female", fh = ik)
Kochi_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Kochi_smooth, raw_series = Kochi, series = "male", fh = ik)

##########
# Fukuoka
##########

Fukuoka_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Fukuoka_smooth, raw_series = Fukuoka, series = "female", fh = ik)
Fukuoka_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Fukuoka_smooth, raw_series = Fukuoka, series = "male", fh = ik)

#######
# Saga
#######

Saga_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Saga_smooth, raw_series = Saga, series = "female", fh = ik)
Saga_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Saga_smooth, raw_series = Saga, series = "male", fh = ik)

###########
# Nagasaki
###########

Nagasaki_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Nagasaki_smooth, raw_series = Nagasaki, series = "female", fh = ik)
Nagasaki_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Nagasaki_smooth, raw_series = Nagasaki, series = "male", fh = ik)

###########
# Kumamoto
###########

Kumamoto_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Kumamoto_smooth, raw_series = Kumamoto, series = "female", fh = ik)
Kumamoto_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Kumamoto_smooth, raw_series = Kumamoto, series = "male", fh = ik)

#######
# Oita
#######

Oita_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Oita_smooth, raw_series = Oita, series = "female", fh = ik)
Oita_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Oita_smooth, raw_series = Oita, series = "male", fh = ik)

###########
# Miyazaki
###########

Miyazaki_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Miyazaki_smooth, raw_series = Miyazaki, series = "female", fh = ik)
Miyazaki_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Miyazaki_smooth, raw_series = Miyazaki, series = "male", fh = ik)

############
# Kagoshima
############

Kagoshima_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Kagoshima_smooth, raw_series = Kagoshima, series = "female", fh = ik)
Kagoshima_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Kagoshima_smooth, raw_series = Kagoshima, series = "male", fh = ik)

##########
# Okinawa
##########

Okinawa_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Okinawa_smooth, raw_series = Okinawa, series = "female", fh = ik)
Okinawa_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = Okinawa_smooth, raw_series = Okinawa, series = "male", fh = ik)

###########
# Region 1
###########

R1_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = ind_R1_smooth, raw_series = ind_R1, series = "female", fh = ik)
R1_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = ind_R1_smooth, raw_series = ind_R1, series = "male", fh = ik)

###########
# Region 2
###########

R2_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = ind_R2_smooth, raw_series = ind_R2, series = "female", fh = ik)
R2_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = ind_R2_smooth, raw_series = ind_R2, series = "male", fh = ik)

###########
# Region 3
###########

R3_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = ind_R3_smooth, raw_series = ind_R3, series = "female", fh = ik)
R3_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = ind_R3_smooth, raw_series = ind_R3, series = "male", fh = ik)

###########
# Region 4
###########

R4_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = ind_R4_smooth, raw_series = ind_R4, series = "female", fh = ik)
R4_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = ind_R4_smooth, raw_series = ind_R4, series = "male", fh = ik)

###########
# Region 5
###########

R5_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = ind_R5_smooth, raw_series = ind_R5, series = "female", fh = ik)
R5_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = ind_R5_smooth, raw_series = ind_R5, series = "male", fh = ik)

###########
# Region 6
###########

R6_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = ind_R6_smooth, raw_series = ind_R6, series = "female", fh = ik)
R6_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = ind_R6_smooth, raw_series = ind_R6, series = "male", fh = ik)

###########
# Region 7
###########

R7_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = ind_R7_smooth, raw_series = ind_R7, series = "female", fh = ik)
R7_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = ind_R7_smooth, raw_series = ind_R7, series = "male", fh = ik)

###########
# Region 8
###########

R8_female_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = ind_R8_smooth, raw_series = ind_R8, series = "female", fh = ik)
R8_male_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts(smooth_series = ind_R8_smooth, raw_series = ind_R8, series = "male", fh = ik)

#################
# Region (total)
#################

PI_fh_out_mfts_region_total <- function(smooth_series, raw_series, series, fh, transform = c("log", "logit"))
{
    transform = match.arg(transform)
    return(find_enlarge_val_mfts_region_total(smooth_data = smooth_series, raw_data = raw_series, series = series, fh = fh, transformation = transform))
}

require(doMC)
registerDoMC(15)
R1_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_region_total(smooth_series = total_region_comb_demogdata, raw_series = ind_R1,
series = "R1", fh = ik)

R2_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_region_total(smooth_series = total_region_comb_demogdata, raw_series = ind_R2,
series = "R2", fh = ik)

R3_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_region_total(smooth_series = total_region_comb_demogdata, raw_series = ind_R3,
series = "R3", fh = ik)

R4_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_region_total(smooth_series = total_region_comb_demogdata, raw_series = ind_R4,
series = "R4", fh = ik)

R5_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_region_total(smooth_series = total_region_comb_demogdata, raw_series = ind_R5,
series = "R5", fh = ik)

R6_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_region_total(smooth_series = total_region_comb_demogdata, raw_series = ind_R6,
series = "R6", fh = ik)

R7_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_region_total(smooth_series = total_region_comb_demogdata, raw_series = ind_R7,
series = "R7", fh = ik)

R8_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_region_total(smooth_series = total_region_comb_demogdata, raw_series = ind_R8,
series = "R8", fh = ik)


#####################
# Prefecture (total)
#####################

PI_fh_out_mfts_prefecture_total <- function(smooth_series, raw_series, series, fh, transform = c("log", "logit"))
{
    transform = match.arg(transform)
    return(find_enlarge_val_mfts_prefecture_total(smooth_data = smooth_series, raw_data = raw_series, series = series, fh = fh, transformation = transform))
}

total_comb_demogdata =  read.demogdata("total_comb.txt", "total_comb_pop.txt", type = "mortality", label="total_comb", skip = 0)

require(doMC)
registerDoMC(15)
P1_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Hokkaido, series = "P1", fh = ik)
P2_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Aomori, series = "P2", fh = ik)
P3_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Iwate, series = "P3", fh = ik)
P4_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Miyagi, series = "P4", fh = ik)
P5_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Akita, series = "P5", fh = ik)
P6_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Yamagata, series = "P6", fh = ik)
P7_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Fukushima, series = "P7", fh = ik)
P8_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Ibaraki, series = "P8", fh = ik)
P9_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Tochigi, series = "P9", fh = ik)
P10_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Gunma, series = "P10", fh = ik)
P11_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Saitama, series = "P11", fh = ik)
P12_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Chiba, series = "P12", fh = ik)
P13_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Tokyo, series = "P13", fh = ik)
P14_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Kanagawa, series = "P14", fh = ik)
P15_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Niigata, series = "P15", fh = ik)
P16_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Toyama, series = "P16", fh = ik)
P17_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Ishikawa, series = "P17", fh = ik)
P18_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Fukui, series = "P18", fh = ik)
P19_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Yamanashi, series = "P19", fh = ik)
P20_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Nagano, series = "P20", fh = ik)
P21_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Gifu, series = "P21", fh = ik)
P22_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Shizuoka, series = "P22", fh = ik)
P23_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Aichi, series = "P23", fh = ik)
P24_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Mie, series = "P24", fh = ik)
P25_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Shiga, series = "P25", fh = ik)
P26_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Kyoto, series = "P26", fh = ik)
P27_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Osaka, series = "P27", fh = ik)
P28_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Hyogo, series = "P28", fh = ik)
P29_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Nara, series = "P29", fh = ik)
P30_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Wakayama, series = "P30", fh = ik)
P31_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Tottori, series = "P31", fh = ik)
P32_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Shimane, series = "P32", fh = ik)
P33_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Okayama, series = "P33", fh = ik)
P34_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Hiroshima, series = "P34", fh = ik)
P35_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Yamaguchi, series = "P35", fh = ik)
P36_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Tokushima, series = "P36", fh = ik)
P37_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Kagawa, series = "P37", fh = ik)
P38_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Ehime, series = "P38", fh = ik)
P39_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Kochi, series = "P39", fh = ik)
P40_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Fukuoka, series = "P40", fh = ik)
P41_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Saga, series = "P41", fh = ik)
P42_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Nagasaki, series = "P42", fh = ik)
P43_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Kumamoto, series = "P43", fh = ik)
P44_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Oita, series = "P44", fh = ik)
P45_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Miyazaki, series = "P45", fh = ik)
P46_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Kagoshima, series = "P46", fh = ik)
P47_total_fh_PI_out_mfts = foreach(ik = 1:41) %dopar% PI_fh_out_mfts_prefecture_total(smooth_series = total_comb_demogdata, raw_series = Okinawa, series = "P47", fh = ik)

################
# Japan (total)
################

PI_fh_out <- function(smooth_series, raw_series, series, fh, transform = c("log", "logit"))
{
    transform = match.arg(transform)
    return(find_enlarge_val(smooth_data = smooth_series, raw_data = raw_series, series = series, fh = fh, transformation = transform))
}


Japan_total_fh_PI_out_mfts = Japan_total_fh_PI_mfts_out = foreach(ik = 1:41) %dopar% PI_fh_out(smooth_series = Japan_smooth, raw_series = Japan, series = "total", fh = ik)

############################################
# Bottom-up and optimal-combination methods
############################################

PI_prefecture_out_mfts <- function(fh)
{
    prefecture_fh_PI_mfts = array(NA, dim = c(41, 2, 168))
    for(ik in 1:2)
    {
        prefecture_fh_PI_mfts[,ik,] = exp(cbind(Japan_total_fh_PI_out_mfts[[fh]][,ik],
                                                   
                                                   Japan_female_fh_PI_out_mfts[[fh]][,ik], Japan_male_fh_PI_out_mfts[[fh]][,ik],
                                                   
                                                   R1_total_fh_PI_out_mfts[[fh]][,ik], R2_total_fh_PI_out_mfts[[fh]][,ik],
                                                   R3_total_fh_PI_out_mfts[[fh]][,ik], R4_total_fh_PI_out_mfts[[fh]][,ik],
                                                   R5_total_fh_PI_out_mfts[[fh]][,ik], R6_total_fh_PI_out_mfts[[fh]][,ik],
                                                   R7_total_fh_PI_out_mfts[[fh]][,ik], R8_total_fh_PI_out_mfts[[fh]][,ik],
                                                   
                                                   R1_female_fh_PI_out_mfts[[fh]][,ik], R2_female_fh_PI_out_mfts[[fh]][,ik],
                                                   R3_female_fh_PI_out_mfts[[fh]][,ik], R4_female_fh_PI_out_mfts[[fh]][,ik],
                                                   R5_female_fh_PI_out_mfts[[fh]][,ik], R6_female_fh_PI_out_mfts[[fh]][,ik],
                                                   R7_female_fh_PI_out_mfts[[fh]][,ik], R8_female_fh_PI_out_mfts[[fh]][,ik],
                                                   
                                                   R1_male_fh_PI_out_mfts[[fh]][,ik], R2_male_fh_PI_out_mfts[[fh]][,ik],
                                                   R3_male_fh_PI_out_mfts[[fh]][,ik], R4_male_fh_PI_out_mfts[[fh]][,ik],
                                                   R5_male_fh_PI_out_mfts[[fh]][,ik], R6_male_fh_PI_out_mfts[[fh]][,ik],
                                                   R7_male_fh_PI_out_mfts[[fh]][,ik], R8_male_fh_PI_out_mfts[[fh]][,ik],
                                                   
                                                   P1_total_fh_PI_out_mfts[[fh]][,ik],   P2_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P3_total_fh_PI_out_mfts[[fh]][,ik],   P4_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P5_total_fh_PI_out_mfts[[fh]][,ik],   P6_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P7_total_fh_PI_out_mfts[[fh]][,ik],   P8_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P9_total_fh_PI_out_mfts[[fh]][,ik],   P10_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P11_total_fh_PI_out_mfts[[fh]][,ik],  P12_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P13_total_fh_PI_out_mfts[[fh]][,ik],  P14_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P15_total_fh_PI_out_mfts[[fh]][,ik],  P16_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P17_total_fh_PI_out_mfts[[fh]][,ik],  P18_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P19_total_fh_PI_out_mfts[[fh]][,ik],  P20_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P21_total_fh_PI_out_mfts[[fh]][,ik],  P22_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P23_total_fh_PI_out_mfts[[fh]][,ik],  P24_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P25_total_fh_PI_out_mfts[[fh]][,ik],  P26_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P27_total_fh_PI_out_mfts[[fh]][,ik],  P28_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P29_total_fh_PI_out_mfts[[fh]][,ik],  P30_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P31_total_fh_PI_out_mfts[[fh]][,ik],  P32_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P33_total_fh_PI_out_mfts[[fh]][,ik],  P34_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P35_total_fh_PI_out_mfts[[fh]][,ik],  P36_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P37_total_fh_PI_out_mfts[[fh]][,ik],  P38_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P39_total_fh_PI_out_mfts[[fh]][,ik],  P40_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P41_total_fh_PI_out_mfts[[fh]][,ik],  P42_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P43_total_fh_PI_out_mfts[[fh]][,ik],  P44_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P45_total_fh_PI_out_mfts[[fh]][,ik],  P46_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P47_total_fh_PI_out_mfts[[fh]][,ik],
                                                   
                                                   Hokkaido_female_fh_PI_out_mfts[[fh]][,ik],  Hokkaido_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Aomori_female_fh_PI_out_mfts[[fh]][,ik],    Aomori_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Iwate_female_fh_PI_out_mfts[[fh]][,ik],     Iwate_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Miyagi_female_fh_PI_out_mfts[[fh]][,ik],    Miyagi_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Akita_female_fh_PI_out_mfts[[fh]][,ik],     Akita_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Yamagata_female_fh_PI_out_mfts[[fh]][,ik],  Yamagata_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Fukushima_female_fh_PI_out_mfts[[fh]][,ik], Fukushima_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Ibaraki_female_fh_PI_out_mfts[[fh]][,ik],   Ibaraki_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Tochigi_female_fh_PI_out_mfts[[fh]][,ik],   Tochigi_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Gunma_female_fh_PI_out_mfts[[fh]][,ik],     Gunma_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Saitama_female_fh_PI_out_mfts[[fh]][,ik],   Saitama_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Chiba_female_fh_PI_out_mfts[[fh]][,ik],     Chiba_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Tokyo_female_fh_PI_out_mfts[[fh]][,ik],     Tokyo_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Kanagawa_female_fh_PI_out_mfts[[fh]][,ik],  Kanagawa_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Niigata_female_fh_PI_out_mfts[[fh]][,ik],   Niigata_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Toyama_female_fh_PI_out_mfts[[fh]][,ik],    Toyama_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Ishikawa_female_fh_PI_out_mfts[[fh]][,ik],  Ishikawa_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Fukui_female_fh_PI_out_mfts[[fh]][,ik],     Fukui_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Yamanashi_female_fh_PI_out_mfts[[fh]][,ik], Yamanashi_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Nagano_female_fh_PI_out_mfts[[fh]][,ik],    Nagano_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Gifu_female_fh_PI_out_mfts[[fh]][,ik],      Gifu_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Shizuoka_female_fh_PI_out_mfts[[fh]][,ik],  Shizuoka_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Aichi_female_fh_PI_out_mfts[[fh]][,ik],     Aichi_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Mie_female_fh_PI_out_mfts[[fh]][,ik],       Mie_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Shiga_female_fh_PI_out_mfts[[fh]][,ik],     Shiga_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Kyoto_female_fh_PI_out_mfts[[fh]][,ik],     Kyoto_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Osaka_female_fh_PI_out_mfts[[fh]][,ik],     Osaka_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Hyogo_female_fh_PI_out_mfts[[fh]][,ik],     Hyogo_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Nara_female_fh_PI_out_mfts[[fh]][,ik],      Nara_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Wakayama_female_fh_PI_out_mfts[[fh]][,ik],  Wakayama_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Tottori_female_fh_PI_out_mfts[[fh]][,ik],   Tottori_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Shimane_female_fh_PI_out_mfts[[fh]][,ik],   Shimane_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Okayama_female_fh_PI_out_mfts[[fh]][,ik],   Okayama_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Hiroshima_female_fh_PI_out_mfts[[fh]][,ik], Hiroshima_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Yamaguchi_female_fh_PI_out_mfts[[fh]][,ik], Yamaguchi_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Tokushima_female_fh_PI_out_mfts[[fh]][,ik], Tokushima_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Kagawa_female_fh_PI_out_mfts[[fh]][,ik],    Kagawa_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Ehime_female_fh_PI_out_mfts[[fh]][,ik],     Ehime_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Kochi_female_fh_PI_out_mfts[[fh]][,ik],     Kochi_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Fukuoka_female_fh_PI_out_mfts[[fh]][,ik],   Fukuoka_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Saga_female_fh_PI_out_mfts[[fh]][,ik],      Saga_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Nagasaki_female_fh_PI_out_mfts[[fh]][,ik],  Nagasaki_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Kumamoto_female_fh_PI_out_mfts[[fh]][,ik],  Kumamoto_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Oita_female_fh_PI_out_mfts[[fh]][,ik],      Oita_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Miyazaki_female_fh_PI_out_mfts[[fh]][,ik],  Miyazaki_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Kagoshima_female_fh_PI_out_mfts[[fh]][,ik], Kagoshima_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Okinawa_female_fh_PI_out_mfts[[fh]][,ik],   Okinawa_male_fh_PI_out_mfts[[fh]][,ik]))
    }
    return(prefecture_fh_PI_mfts)
}

##################################################################
# one- to 15-step-ahead bootstrapped mortality samples (B = 1000)
##################################################################

PI_prefecture_h1to15_out_mfts = list()
for(ik in 1:41)
{
    PI_prefecture_h1to15_out_mfts[[ik]] = PI_prefecture_out_mfts(fh = ik)
    print(ik)
}


# kj: forecast horizon from h = 1 to 15
# age: age indexes from 1 to 41 (ages 60 to 100+)

BU_optim_hier_PI_out_mfts <- function(fh, age, hier_method = c("BU", "OLS"))
{
    hier_method = match.arg(hier_method)
    hier_fore = matrix(NA, 168, 2)
    
    # Summing matrix for kj horizon at a given age
    summing_out = Smat_fun_out(age = age, year_horizon = 41)
    hier = summing_out[,,fh]
    if(hier_method == "BU")
    {
        for(ij in 1:2)
        {
            hier_fore[,ij] = hier %*% (PI_prefecture_h1to15_out_mfts[[fh]])[age, ij, 75:168]
        }
    }
    if(hier_method == "OLS")
    {
        for(ij in 1:2)
        {
            hier_fore[,ij] = hier %*% ginv(t(hier) %*% hier) %*% t(hier) %*% (PI_prefecture_h1to15_out_mfts[[fh]])[age,ij,]
        }
    }
    return(hier_fore)
}

## hier_method = "BU" (output: h1 to h15 BU reconciled bootstrap sample) (debug here)

BU_fun_out_mfts <- function(kj)
{
    dum = array(NA, dim = c(41, 168, 2))
    for(ij in 1:41)
    {
        dum[ij,,] = BU_optim_hier_PI_out_mfts(fh = kj, age = ij, hier_method = "BU")
    }
    return(dum)
}

BU_optim_hier_comb_out_mfts = list()
for(kj in 1:41)
{
    BU_optim_hier_comb_out_mfts[[kj]] = BU_fun_out_mfts(kj = kj)
    print(kj)
}

## hier_method = "OLS" (output: h1 to h15 OLS reconciled bootstrap samples)

OLS_fun_out_mfts <- function(kj)
{
    dum = array(NA, dim = c(41, 168, 2))
    for(ij in 1:41)
    {
        dum[ij,,] = BU_optim_hier_PI_out_mfts(fh = kj, age = ij, hier_method = "OLS")
    }
    return(dum)
}

OLS_hier_comb_out_mfts = list()
for(kj in 1:41)
{
    OLS_hier_comb_out_mfts[[kj]] = OLS_fun_out_mfts(kj = kj)
    print(kj)
}

#########################################################
## bottom-up and optimal combination methods (to a list)
#########################################################

# bottom-up

BU_optim_hier_comb_out_arrange = array(NA, dim = c(41, 168, 2, 41))
for(ik in 1:41)
{
    BU_optim_hier_comb_out_arrange[,,,ik] = BU_optim_hier_comb_out_mfts[[ik]]
}

# OLS

OLS_hier_comb_out_arrange = array(NA, dim = c(41, 168, 2, 41))
for(ik in 1:41)
{
    OLS_hier_comb_out_arrange[,,,ik] = OLS_hier_comb_out_mfts[[ik]]
}

# Comb (equal weight)

Comb_optim_hier_comb_out_arrange = (BU_optim_hier_comb_out_arrange + OLS_hier_comb_out_arrange)/2

# Comb (AvInt)

Comb_AvInt_optim_hier_comb_out_arrange = (apply(BU_optim_hier_comb_out_arrange, c(1, 2, 4), mean) + apply(OLS_hier_comb_out_arrange, c(1, 2, 4), mean))/2


################################
# ind (R2) (as an illustration)
################################

R2_female_fh_PI_out_arrange = array(NA, dim = c(41, 2, 15))
for(ik in 1:15)
{
    R2_female_fh_PI_out_arrange[,,ik] = (R2_female_fh_PI_out_mfts[[ik]])
}

#################################################
# Construct S matrix by age and forecast horizon
#################################################

Smat_fun_out <- function(age, year_horizon, no_prefecture = 47)
{
    level_0 = level_1_a = level_1_b = matrix(NA, 2*no_prefecture, year_horizon)
    for(iw in 1:no_prefecture)
    {
        # Level 0
        
        level_0[(2*iw-1),] = get(pop_ratio_P_F_to_T_out[iw])[age,]
        level_0[(2*iw),]   = get(pop_ratio_P_M_to_T_out[iw])[age,]
        
        # Level 1 (disaggregate by sex)
        
        level_1_a[(2*iw-1),] = get(pop_ratio_P_F_to_F_out[iw])[age,]
        level_1_a[(2*iw),]   = rep(0,year_horizon)
        
        level_1_b[(2*iw-1),] = rep(0,year_horizon)
        level_1_b[(2*iw),]   = get(pop_ratio_P_M_to_M_out[iw])[age,]
    }
    
    level_2_a_1 = level_2_a_2 = level_2_a_3 = level_2_a_4 = level_2_a_5 =
    level_2_a_6 = level_2_a_7 = level_2_a_8 = matrix(NA, 2*no_prefecture, year_horizon)
  
    ###################################
    # Level 2 (disaggregate by region)
    ###################################
    
    # R1
    
    level_2_a_1[1,] = get(pop_ratio_P_F_to_R1_T_out[1])[age,]
    level_2_a_1[2,] = get(pop_ratio_P_M_to_R1_T_out[1])[age,]
    level_2_a_1[3:(2*no_prefecture),] = matrix(rep(0,year_horizon*92), ncol = year_horizon)
  
    # R2
    
    level_2_a_2[1:2, ] = matrix(rep(0,year_horizon*2), ncol=year_horizon)
    for(iw in 1:6)
    {
        level_2_a_2[(2*iw+1),] = get(pop_ratio_P_F_to_R2_T_out[iw])[age,1:year_horizon]
        level_2_a_2[(2*iw+2),] = get(pop_ratio_P_M_to_R2_T_out[iw])[age,1:year_horizon]
    }
    level_2_a_2[15:(2*no_prefecture),] = matrix(rep(0,year_horizon*80), ncol = year_horizon)
  
    # R3
    
    level_2_a_3[1:14,] = matrix(rep(0,year_horizon*14), ncol=year_horizon)
    for(iw in 1:7)
    {
        level_2_a_3[(2*(iw+6)+1),] = get(pop_ratio_P_F_to_R3_T_out[iw])[age,]
        level_2_a_3[(2*(iw+6)+2),] = get(pop_ratio_P_M_to_R3_T_out[iw])[age,]
    }
    level_2_a_3[29:(2*no_prefecture),] = matrix(rep(0,year_horizon*66), ncol = year_horizon)
    
    # R4
    
    level_2_a_4[1:28,] = matrix(rep(0,year_horizon*28), ncol=year_horizon)
    for(iw in 1:9)
    {
        level_2_a_4[(2*(iw+13)+1),] = get(pop_ratio_P_F_to_R4_T_out[iw])[age,]
        level_2_a_4[(2*(iw+13)+2),] = get(pop_ratio_P_M_to_R4_T_out[iw])[age,]
    }
    level_2_a_4[47:(2*no_prefecture),] = matrix(rep(0,year_horizon*48), ncol = year_horizon)
    
    # R5
    
    level_2_a_5[1:46,] = matrix(rep(0,year_horizon*46), ncol=year_horizon)
    for(iw in 1:7)
    {
        level_2_a_5[(2*(iw+22)+1),] = get(pop_ratio_P_F_to_R5_T_out[iw])[age,]
        level_2_a_5[(2*(iw+22)+2),] = get(pop_ratio_P_M_to_R5_T_out[iw])[age,]
    }
    level_2_a_5[61:(2*no_prefecture),] = matrix(rep(0,year_horizon*34), ncol = year_horizon)
    
    # R6
    
    level_2_a_6[1:60,] = matrix(rep(0,year_horizon*60), ncol=year_horizon)
    for(iw in 1:5)
    {
        level_2_a_6[(2*(iw+29)+1),] = get(pop_ratio_P_F_to_R6_T_out[iw])[age,]
        level_2_a_6[(2*(iw+29)+2),] = get(pop_ratio_P_M_to_R6_T_out[iw])[age,]
    }
    level_2_a_6[71:(2*no_prefecture),] = matrix(rep(0,year_horizon*24), ncol = year_horizon)
    
    # R7
    
    level_2_a_7[1:70,] = matrix(rep(0,year_horizon*70), ncol=year_horizon)
    for(iw in 1:4)
    {
        level_2_a_7[(2*(iw+34)+1),] = get(pop_ratio_P_F_to_R7_T_out[iw])[age,]
        level_2_a_7[(2*(iw+34)+2),] = get(pop_ratio_P_M_to_R7_T_out[iw])[age,]
    }
    level_2_a_7[79:(2*no_prefecture),] = matrix(rep(0,year_horizon*16), ncol = year_horizon)
    
    # R8
    
    level_2_a_8[1:78,] = matrix(rep(0,year_horizon*78), ncol=year_horizon)
    for(iw in 1:8)
    {
        level_2_a_8[(2*(iw+38)+1),] = get(pop_ratio_P_F_to_R8_T_out[iw])[age,]
        level_2_a_8[(2*(iw+38)+2),] = get(pop_ratio_P_M_to_R8_T_out[iw])[age,]
    }
    
    level_2_b_1 = level_2_b_2 = level_2_b_3 = level_2_b_4 = level_2_b_5 = level_2_b_6 =
    level_2_b_7 = level_2_b_8 = matrix(NA, (2*no_prefecture), year_horizon)
  
    ##################################################
    # Level 2 (disaggregate by region + sex (female))
    ##################################################
    
    # R1
    
    level_2_b_1[1,] = get(pop_ratio_P_F_to_R1_F_out[1])[age,]
    level_2_b_1[2:(2*no_prefecture),] = matrix(rep(0,year_horizon*93), ncol = year_horizon)
    
    # R2
    
    level_2_b_2[1:2, ] = matrix(rep(0,year_horizon*2), ncol=year_horizon)
    for(iw in 1:6)
    {
        level_2_b_2[(2*iw+1),] = get(pop_ratio_P_F_to_R2_F_out[iw])[age,]
        level_2_b_2[(2*iw+2),] = rep(0, year_horizon)
    }
    level_2_b_2[15:(2*no_prefecture),] = matrix(rep(0,year_horizon*80), ncol = year_horizon)
    
    # R3
    
    level_2_b_3[1:14,] = matrix(rep(0,year_horizon*14), ncol=year_horizon)
    for(iw in 1:7)
    {
        level_2_b_3[(2*(iw+6)+1),] = get(pop_ratio_P_F_to_R3_F_out[iw])[age,]
        level_2_b_3[(2*(iw+6)+2),] = rep(0, year_horizon)
    }
    level_2_b_3[29:(2*no_prefecture),] = matrix(rep(0,year_horizon*66), ncol = year_horizon)
    
    # R4
    
    level_2_b_4[1:28,] = matrix(rep(0,year_horizon*28), ncol=year_horizon)
    for(iw in 1:9)
    {
        level_2_b_4[(2*(iw+13)+1),] = get(pop_ratio_P_F_to_R4_F_out[iw])[age,]
        level_2_b_4[(2*(iw+13)+2),] = rep(0, year_horizon)
    }
    level_2_b_4[47:(2*no_prefecture),] = matrix(rep(0,year_horizon*48), ncol = year_horizon)
    
    # R5
    
    level_2_b_5[1:46,] = matrix(rep(0,year_horizon*46), ncol=year_horizon)
    for(iw in 1:7)
    {
        level_2_b_5[(2*(iw+22)+1),] = get(pop_ratio_P_F_to_R5_F_out[iw])[age,]
        level_2_b_5[(2*(iw+22)+2),] = rep(0, year_horizon)
    }
    level_2_b_5[61:(2*no_prefecture),] = matrix(rep(0,year_horizon*34), ncol = year_horizon)
    
    # R6
    
    level_2_b_6[1:60,] = matrix(rep(0,year_horizon*60), ncol=year_horizon)
    for(iw in 1:5)
    {
        level_2_b_6[(2*(iw+29)+1),] = get(pop_ratio_P_F_to_R6_F_out[iw])[age,]
        level_2_b_6[(2*(iw+29)+2),] = rep(0, year_horizon)
    }
    level_2_b_6[71:(2*no_prefecture),] = matrix(rep(0,year_horizon*24), ncol = year_horizon)
    
    # R7
    
    level_2_b_7[1:70,] = matrix(rep(0,year_horizon*70), ncol=year_horizon)
    for(iw in 1:4)
    {
        level_2_b_7[(2*(iw+34)+1),] = get(pop_ratio_P_F_to_R7_F_out[iw])[age,]
        level_2_b_7[(2*(iw+34)+2),] = rep(0, year_horizon)
    }
    level_2_b_7[79:(2*no_prefecture),] = matrix(rep(0,year_horizon*16), ncol = year_horizon)
    
    # R8
    
    level_2_b_8[1:78,] = matrix(rep(0,year_horizon*78), ncol=year_horizon)
    for(iw in 1:8)
    {
        level_2_b_8[(2*(iw+38)+1),] = get(pop_ratio_P_F_to_R8_F_out[iw])[age,]
        level_2_b_8[(2*(iw+38)+2),] = rep(0, year_horizon)
    }
    
    level_2_c_1 = level_2_c_2 = level_2_c_3 = level_2_c_4 = level_2_c_5 = level_2_c_6 =
    level_2_c_7 = level_2_c_8 = matrix(NA, (2*no_prefecture), year_horizon)
    
    ################################################
    # Level 2 (disaggregate by region + sex (male))
    ################################################
    
    # R1
    
    level_2_c_1[1,] = rep(0,year_horizon)
    level_2_c_1[2,] = get(pop_ratio_P_M_to_R1_M_out[1])[age,]
    level_2_c_1[3:(2*no_prefecture),] = matrix(rep(0,year_horizon*92), ncol = year_horizon)
    
    # R2
    
    level_2_c_2[1:2, ] = matrix(rep(0,year_horizon*2), ncol=year_horizon)
    for(iw in 1:6)
    {
        level_2_c_2[(2*iw+1),] = rep(0,year_horizon)
        level_2_c_2[(2*iw+2),] = get(pop_ratio_P_M_to_R2_M_out[iw])[age,]
    }
    level_2_c_2[15:(2*no_prefecture),] = matrix(rep(0,year_horizon*80), ncol = year_horizon)
    
    # R3
    
    level_2_c_3[1:14,] = matrix(rep(0,year_horizon*14), ncol=year_horizon)
    for(iw in 1:7)
    {
        level_2_c_3[(2*(iw+6)+1),] = rep(0,year_horizon)
        level_2_c_3[(2*(iw+6)+2),] = get(pop_ratio_P_M_to_R3_M_out[iw])[age,]
    }
    level_2_c_3[29:(2*no_prefecture),] = matrix(rep(0,year_horizon*66), ncol = year_horizon)
    
    # R4
    
    level_2_c_4[1:28,] = matrix(rep(0,year_horizon*28), ncol=year_horizon)
    for(iw in 1:9)
    {
        level_2_c_4[(2*(iw+13)+1),] = rep(0,year_horizon)
        level_2_c_4[(2*(iw+13)+2),] = get(pop_ratio_P_M_to_R4_M_out[iw])[age,]
    }
    level_2_c_4[47:(2*no_prefecture),] = matrix(rep(0,year_horizon*48), ncol = year_horizon)
    
    # R5
    
    level_2_c_5[1:46,] = matrix(rep(0,year_horizon*46), ncol=year_horizon)
    for(iw in 1:7)
    {
        level_2_c_5[(2*(iw+22)+1),] = rep(0,year_horizon)
        level_2_c_5[(2*(iw+22)+2),] = get(pop_ratio_P_M_to_R5_M_out[iw])[age,]
    }
    level_2_c_5[61:(2*no_prefecture),] = matrix(rep(0,year_horizon*34), ncol = year_horizon)
    
    # R6
    
    level_2_c_6[1:60,] = matrix(rep(0,year_horizon*60), ncol=year_horizon)
    for(iw in 1:5)
    {
        level_2_c_6[(2*(iw+29)+1),] = rep(0,year_horizon)
        level_2_c_6[(2*(iw+29)+2),] = get(pop_ratio_P_M_to_R6_M_out[iw])[age,]
    }
    level_2_c_6[71:(2*no_prefecture),] = matrix(rep(0,year_horizon*24), ncol = year_horizon)
    
    # R7
    
    level_2_c_7[1:70,] = matrix(rep(0,year_horizon*70), ncol=year_horizon)
    for(iw in 1:4)
    {
        level_2_c_7[(2*(iw+34)+1),] = rep(0,year_horizon)
        level_2_c_7[(2*(iw+34)+2),] = get(pop_ratio_P_M_to_R7_M_out[iw])[age,]
    }
    level_2_c_7[79:(2*no_prefecture),] = matrix(rep(0,year_horizon*16), ncol = year_horizon)
    
    # R8
    
    level_2_c_8[1:78,] = matrix(rep(0,year_horizon*78), ncol=year_horizon)
    for(iw in 1:8)
    {
        level_2_c_8[(2*(iw+38)+1),] = rep(0,year_horizon)
        level_2_c_8[(2*(iw+38)+2),] = get(pop_ratio_P_M_to_R8_M_out[iw])[age,]
    }
    
    ###################################################
    # Level 3 (disaggregate by prefecture + sex (male))
    ###################################################
    
    level_3 = array(0,dim = c((2*no_prefecture),year_horizon,47))
    for(iw in 1:47)
    {
        level_3[2*iw-1,,iw] = get(pop_ratio_P_F_to_P_T_out[iw])[age,]
        level_3[2*iw,,iw]   = get(pop_ratio_P_M_to_P_T_out[iw])[age,]
    }
    
    S_mat = array(NA, dim = c(168, (2*no_prefecture), year_horizon))
    for(ik in 1:year_horizon)
    {
        S_mat[,,ik] = rbind(level_0[,ik],     level_1_a[,ik],   level_1_b[,ik],   level_2_a_1[,ik],
                          level_2_a_2[,ik], level_2_a_3[,ik], level_2_a_4[,ik], level_2_a_5[,ik],
                          level_2_a_6[,ik], level_2_a_7[,ik], level_2_a_8[,ik], level_2_b_1[,ik],
                          level_2_b_2[,ik], level_2_b_3[,ik], level_2_b_4[,ik], level_2_b_5[,ik],
                          level_2_b_6[,ik], level_2_b_7[,ik], level_2_b_8[,ik], level_2_c_1[,ik],
                          level_2_c_2[,ik], level_2_c_3[,ik], level_2_c_4[,ik], level_2_c_5[,ik],
                          level_2_c_6[,ik], level_2_c_7[,ik], level_2_c_8[,ik], t(level_3[,ik,]),
                          diag(94))
    }
    return(S_mat)
}

######################################################################
# Exposure-to-risk at the bottom level
# Replace 41 by 15, 15 by 41 depending on point or interval forecasts
######################################################################

pop_fore_fun_out <- function(top, bottom, year_horizon)
{
    Japan_pop_fore = matrix(0, 41, year_horizon)
    Japan_pop_fore[2:41,1] = (top[,41]/bottom[,41])[1:40]
    ratio = top[1,]/bottom[1,]
    Japan_pop_fore[1,] = forecast(auto.arima(ratio), h = year_horizon)$mean
    for(ij in 2:year_horizon)
    {
        # x in year t is x+1 in year t+1
        Japan_pop_fore[2:41,ij] = Japan_pop_fore[1:40,ij-1]
    }
    return(Japan_pop_fore)
}

# Row 1

pop_ratio_P_F_to_T_out = c("pop_ratio_P1_F_to_T_out",  "pop_ratio_P2_F_to_T_out",  "pop_ratio_P3_F_to_T_out",
                           "pop_ratio_P4_F_to_T_out",  "pop_ratio_P5_F_to_T_out",  "pop_ratio_P6_F_to_T_out",
                           "pop_ratio_P7_F_to_T_out",  "pop_ratio_P8_F_to_T_out",  "pop_ratio_P9_F_to_T_out",
                           "pop_ratio_P10_F_to_T_out", "pop_ratio_P11_F_to_T_out", "pop_ratio_P12_F_to_T_out",
                           "pop_ratio_P13_F_to_T_out", "pop_ratio_P14_F_to_T_out", "pop_ratio_P15_F_to_T_out",
                           "pop_ratio_P16_F_to_T_out", "pop_ratio_P17_F_to_T_out", "pop_ratio_P18_F_to_T_out",
                           "pop_ratio_P19_F_to_T_out", "pop_ratio_P20_F_to_T_out", "pop_ratio_P21_F_to_T_out",
                           "pop_ratio_P22_F_to_T_out", "pop_ratio_P23_F_to_T_out", "pop_ratio_P24_F_to_T_out",
                           "pop_ratio_P25_F_to_T_out", "pop_ratio_P26_F_to_T_out", "pop_ratio_P27_F_to_T_out",
                           "pop_ratio_P28_F_to_T_out", "pop_ratio_P29_F_to_T_out", "pop_ratio_P30_F_to_T_out",
                           "pop_ratio_P31_F_to_T_out", "pop_ratio_P32_F_to_T_out", "pop_ratio_P33_F_to_T_out",
                           "pop_ratio_P34_F_to_T_out", "pop_ratio_P35_F_to_T_out", "pop_ratio_P36_F_to_T_out",
                           "pop_ratio_P37_F_to_T_out", "pop_ratio_P38_F_to_T_out", "pop_ratio_P39_F_to_T_out",
                           "pop_ratio_P40_F_to_T_out", "pop_ratio_P41_F_to_T_out", "pop_ratio_P42_F_to_T_out",
                           "pop_ratio_P43_F_to_T_out", "pop_ratio_P44_F_to_T_out", "pop_ratio_P45_F_to_T_out",
                           "pop_ratio_P46_F_to_T_out", "pop_ratio_P47_F_to_T_out")

pop_ratio_P_M_to_T_out = c("pop_ratio_P1_M_to_T_out",  "pop_ratio_P2_M_to_T_out",  "pop_ratio_P3_M_to_T_out",
                           "pop_ratio_P4_M_to_T_out",  "pop_ratio_P5_M_to_T_out",  "pop_ratio_P6_M_to_T_out",
                           "pop_ratio_P7_M_to_T_out",  "pop_ratio_P8_M_to_T_out",  "pop_ratio_P9_M_to_T_out",
                           "pop_ratio_P10_M_to_T_out", "pop_ratio_P11_M_to_T_out", "pop_ratio_P12_M_to_T_out",
                           "pop_ratio_P13_M_to_T_out", "pop_ratio_P14_M_to_T_out", "pop_ratio_P15_M_to_T_out",
                           "pop_ratio_P16_M_to_T_out", "pop_ratio_P17_M_to_T_out", "pop_ratio_P18_M_to_T_out",
                           "pop_ratio_P19_M_to_T_out", "pop_ratio_P20_M_to_T_out", "pop_ratio_P21_M_to_T_out",
                           "pop_ratio_P22_M_to_T_out", "pop_ratio_P23_M_to_T_out", "pop_ratio_P24_M_to_T_out",
                           "pop_ratio_P25_M_to_T_out", "pop_ratio_P26_M_to_T_out", "pop_ratio_P27_M_to_T_out",
                           "pop_ratio_P28_M_to_T_out", "pop_ratio_P29_M_to_T_out", "pop_ratio_P30_M_to_T_out",
                           "pop_ratio_P31_M_to_T_out", "pop_ratio_P32_M_to_T_out", "pop_ratio_P33_M_to_T_out",
                           "pop_ratio_P34_M_to_T_out", "pop_ratio_P35_M_to_T_out", "pop_ratio_P36_M_to_T_out",
                           "pop_ratio_P37_M_to_T_out", "pop_ratio_P38_M_to_T_out", "pop_ratio_P39_M_to_T_out",
                           "pop_ratio_P40_M_to_T_out", "pop_ratio_P41_M_to_T_out", "pop_ratio_P42_M_to_T_out",
                           "pop_ratio_P43_M_to_T_out", "pop_ratio_P44_M_to_T_out", "pop_ratio_P45_M_to_T_out",
                           "pop_ratio_P46_M_to_T_out", "pop_ratio_P47_M_to_T_out")

for(iw in 2:48)
{
    assign(pop_ratio_P_F_to_T_out[iw-1], pop_fore_fun_out(top = get(state[iw])$pop$female, bottom = Japan$pop$total, year_horizon = 41))
    assign(pop_ratio_P_M_to_T_out[iw-1], pop_fore_fun_out(top = get(state[iw])$pop$male,   bottom = Japan$pop$total, year_horizon = 41))
    print(iw)
}

# Row 2

pop_ratio_P_F_to_F_out = c("pop_ratio_P1_F_to_F_out",  "pop_ratio_P2_F_to_F_out",  "pop_ratio_P3_F_to_F_out",
                           "pop_ratio_P4_F_to_F_out",  "pop_ratio_P5_F_to_F_out",  "pop_ratio_P6_F_to_F_out",
                           "pop_ratio_P7_F_to_F_out",  "pop_ratio_P8_F_to_F_out",  "pop_ratio_P9_F_to_F_out",
                           "pop_ratio_P10_F_to_F_out", "pop_ratio_P11_F_to_F_out", "pop_ratio_P12_F_to_F_out",
                           "pop_ratio_P13_F_to_F_out", "pop_ratio_P14_F_to_F_out", "pop_ratio_P15_F_to_F_out",
                           "pop_ratio_P16_F_to_F_out", "pop_ratio_P17_F_to_F_out", "pop_ratio_P18_F_to_F_out",
                           "pop_ratio_P19_F_to_F_out", "pop_ratio_P20_F_to_F_out", "pop_ratio_P21_F_to_F_out",
                           "pop_ratio_P22_F_to_F_out", "pop_ratio_P23_F_to_F_out", "pop_ratio_P24_F_to_F_out",
                           "pop_ratio_P25_F_to_F_out", "pop_ratio_P26_F_to_F_out", "pop_ratio_P27_F_to_F_out",
                           "pop_ratio_P28_F_to_F_out", "pop_ratio_P29_F_to_F_out", "pop_ratio_P30_F_to_F_out",
                           "pop_ratio_P31_F_to_F_out", "pop_ratio_P32_F_to_F_out", "pop_ratio_P33_F_to_F_out",
                           "pop_ratio_P34_F_to_F_out", "pop_ratio_P35_F_to_F_out", "pop_ratio_P36_F_to_F_out",
                           "pop_ratio_P37_F_to_F_out", "pop_ratio_P38_F_to_F_out", "pop_ratio_P39_F_to_F_out",
                           "pop_ratio_P40_F_to_F_out", "pop_ratio_P41_F_to_F_out", "pop_ratio_P42_F_to_F_out",
                           "pop_ratio_P43_F_to_F_out", "pop_ratio_P44_F_to_F_out", "pop_ratio_P45_F_to_F_out",
                           "pop_ratio_P46_F_to_F_out", "pop_ratio_P47_F_to_F_out")

# Row 3

pop_ratio_P_M_to_M_out = c("pop_ratio_P1_M_to_M_out",  "pop_ratio_P2_M_to_M_out",  "pop_ratio_P3_M_to_M_out",
                           "pop_ratio_P4_M_to_M_out",  "pop_ratio_P5_M_to_M_out",  "pop_ratio_P6_M_to_M_out",
                           "pop_ratio_P7_M_to_M_out",  "pop_ratio_P8_M_to_M_out",  "pop_ratio_P9_M_to_M_out",
                           "pop_ratio_P10_M_to_M_out", "pop_ratio_P11_M_to_M_out", "pop_ratio_P12_M_to_M_out",
                           "pop_ratio_P13_M_to_M_out", "pop_ratio_P14_M_to_M_out", "pop_ratio_P15_M_to_M_out",
                           "pop_ratio_P16_M_to_M_out", "pop_ratio_P17_M_to_M_out", "pop_ratio_P18_M_to_M_out",
                           "pop_ratio_P19_M_to_M_out", "pop_ratio_P20_M_to_M_out", "pop_ratio_P21_M_to_M_out",
                           "pop_ratio_P22_M_to_M_out", "pop_ratio_P23_M_to_M_out", "pop_ratio_P24_M_to_M_out",
                           "pop_ratio_P25_M_to_M_out", "pop_ratio_P26_M_to_M_out", "pop_ratio_P27_M_to_M_out",
                           "pop_ratio_P28_M_to_M_out", "pop_ratio_P29_M_to_M_out", "pop_ratio_P30_M_to_M_out",
                           "pop_ratio_P31_M_to_M_out", "pop_ratio_P32_M_to_M_out", "pop_ratio_P33_M_to_M_out",
                           "pop_ratio_P34_M_to_M_out", "pop_ratio_P35_M_to_M_out", "pop_ratio_P36_M_to_M_out",
                           "pop_ratio_P37_M_to_M_out", "pop_ratio_P38_M_to_M_out", "pop_ratio_P39_M_to_M_out",
                           "pop_ratio_P40_M_to_M_out", "pop_ratio_P41_M_to_M_out", "pop_ratio_P42_M_to_M_out",
                           "pop_ratio_P43_M_to_M_out", "pop_ratio_P44_M_to_M_out", "pop_ratio_P45_M_to_M_out",
                           "pop_ratio_P46_M_to_M_out", "pop_ratio_P47_M_to_M_out")

for(iw in 2:48)
{
    assign(pop_ratio_P_F_to_F_out[iw-1], pop_fore_fun_out(top = get(state[iw])$pop$female,
           bottom = Japan$pop$female, year_horizon = 41))
    assign(pop_ratio_P_M_to_M_out[iw-1], pop_fore_fun_out(top = get(state[iw])$pop$male,
           bottom = Japan$pop$male, year_horizon = 41))
    print(iw)
}


# Row 4

pop_ratio_P_F_to_R1_T_out = "pop_ratio_P1_F_to_R1_T_out"
pop_ratio_P_F_to_R2_T_out = c("pop_ratio_P2_F_to_R2_T_out", "pop_ratio_P3_F_to_R2_T_out", "pop_ratio_P4_F_to_R2_T_out",
                              "pop_ratio_P5_F_to_R2_T_out", "pop_ratio_P6_F_to_R2_T_out", "pop_ratio_P7_F_to_R2_T_out")
pop_ratio_P_F_to_R3_T_out = c("pop_ratio_P8_F_to_R3_T_out",  "pop_ratio_P9_F_to_R3_T_out",  "pop_ratio_P10_F_to_R3_T_out",
                              "pop_ratio_P11_F_to_R3_T_out", "pop_ratio_P12_F_to_R3_T_out", "pop_ratio_P13_F_to_R3_T_out",
                              "pop_ratio_P14_F_to_R3_T_out")
pop_ratio_P_F_to_R4_T_out = c("pop_ratio_P15_F_to_R4_T_out", "pop_ratio_P16_F_to_R4_T_out", "pop_ratio_P17_F_to_R4_T_out",
                              "pop_ratio_P18_F_to_R4_T_out", "pop_ratio_P19_F_to_R4_T_out", "pop_ratio_P20_F_to_R4_T_out",
                              "pop_ratio_P21_F_to_R4_T_out", "pop_ratio_P22_F_to_R4_T_out", "pop_ratio_P23_F_to_R4_T_out")
pop_ratio_P_F_to_R5_T_out = c("pop_ratio_P24_F_to_R5_T_out", "pop_ratio_P25_F_to_R5_T_out", "pop_ratio_P26_F_to_R5_T_out",
                              "pop_ratio_P27_F_to_R5_T_out", "pop_ratio_P28_F_to_R5_T_out", "pop_ratio_P29_F_to_R5_T_out",
                              "pop_ratio_P30_F_to_R5_T_out")
pop_ratio_P_F_to_R6_T_out = c("pop_ratio_P31_F_to_R6_T_out", "pop_ratio_P32_F_to_R6_T_out", "pop_ratio_P33_F_to_R6_T_out",
                              "pop_ratio_P34_F_to_R6_T_out", "pop_ratio_P35_F_to_R6_T_out")
pop_ratio_P_F_to_R7_T_out = c("pop_ratio_P36_F_to_R7_T_out", "pop_ratio_P37_F_to_R7_T_out", "pop_ratio_P38_F_to_R7_T_out",
                              "pop_ratio_P39_F_to_R7_T_out")
pop_ratio_P_F_to_R8_T_out = c("pop_ratio_P40_F_to_R8_T_out", "pop_ratio_P41_F_to_R8_T_out", "pop_ratio_P42_F_to_R8_T_out",
                              "pop_ratio_P43_F_to_R8_T_out", "pop_ratio_P44_F_to_R8_T_out", "pop_ratio_P45_F_to_R8_T_out",
                              "pop_ratio_P46_F_to_R8_T_out", "pop_ratio_P47_F_to_R8_T_out")

assign(pop_ratio_P_F_to_R1_T_out, pop_fore_fun_out(top = get(state[2])$pop$female, bottom = ind_R1$pop$total, year_horizon = 41))
for(iw in 2:7)
{
    assign(pop_ratio_P_F_to_R2_T_out[iw-1], pop_fore_fun_out(top = get(state[(iw+1)])$pop$female, bottom = ind_R2$pop$total, year_horizon = 41))
    print(iw)
}
for(iw in 8:14)
{
    assign(pop_ratio_P_F_to_R3_T_out[iw-7], pop_fore_fun_out(top = get(state[(iw+1)])$pop$female, bottom = ind_R3$pop$total, year_horizon = 41))
    print(iw)
}
for(iw in 15:23)
{
    assign(pop_ratio_P_F_to_R4_T_out[iw-14], pop_fore_fun_out(top = get(state[(iw+1)])$pop$female, bottom = ind_R4$pop$total, year_horizon = 41))
    print(iw)
}
for(iw in 24:30)
{
    assign(pop_ratio_P_F_to_R5_T_out[iw-23], pop_fore_fun_out(top = get(state[(iw+1)])$pop$female, bottom = ind_R5$pop$total, year_horizon = 41))
    print(iw)
}
for(iw in 31:35)
{
    assign(pop_ratio_P_F_to_R6_T_out[iw-30], pop_fore_fun_out(top = get(state[(iw+1)])$pop$female, bottom = ind_R6$pop$total, year_horizon = 41))
    print(iw)
}
for(iw in 36:39)
{
    assign(pop_ratio_P_F_to_R7_T_out[iw-35], pop_fore_fun_out(top = get(state[(iw+1)])$pop$female, bottom = ind_R7$pop$total, year_horizon = 41))
    print(iw)
}
for(iw in 40:47)
{
    assign(pop_ratio_P_F_to_R8_T_out[iw-39], pop_fore_fun_out(top = get(state[(iw+1)])$pop$female, bottom = ind_R8$pop$total, year_horizon = 41))
    print(iw)
}


pop_ratio_P_M_to_R1_T_out = "pop_ratio_P1_M_to_R1_T_out"
pop_ratio_P_M_to_R2_T_out = c("pop_ratio_P2_M_to_R2_T_out", "pop_ratio_P3_M_to_R2_T_out", "pop_ratio_P4_M_to_R2_T_out",
                              "pop_ratio_P5_M_to_R2_T_out", "pop_ratio_P6_M_to_R2_T_out", "pop_ratio_P7_M_to_R2_T_out")
pop_ratio_P_M_to_R3_T_out = c("pop_ratio_P8_M_to_R3_T_out",  "pop_ratio_P9_M_to_R3_T_out",  "pop_ratio_P10_M_to_R3_T_out",
                              "pop_ratio_P11_M_to_R3_T_out", "pop_ratio_P12_M_to_R3_T_out", "pop_ratio_P13_M_to_R3_T_out",
                              "pop_ratio_P14_M_to_R3_T_out")
pop_ratio_P_M_to_R4_T_out = c("pop_ratio_P15_M_to_R4_T_out", "pop_ratio_P16_M_to_R4_T_out", "pop_ratio_P17_M_to_R4_T_out",
                              "pop_ratio_P18_M_to_R4_T_out", "pop_ratio_P19_M_to_R4_T_out", "pop_ratio_P20_M_to_R4_T_out",
                              "pop_ratio_P21_M_to_R4_T_out", "pop_ratio_P22_M_to_R4_T_out", "pop_ratio_P23_M_to_R4_T_out")
pop_ratio_P_M_to_R5_T_out = c("pop_ratio_P24_M_to_R5_T_out", "pop_ratio_P25_M_to_R5_T_out", "pop_ratio_P26_M_to_R5_T_out",
                              "pop_ratio_P27_M_to_R5_T_out", "pop_ratio_P28_M_to_R5_T_out", "pop_ratio_P29_M_to_R5_T_out",
                              "pop_ratio_P30_M_to_R5_T_out")
pop_ratio_P_M_to_R6_T_out = c("pop_ratio_P31_M_to_R6_T_out", "pop_ratio_P32_M_to_R6_T_out", "pop_ratio_P33_M_to_R6_T_out",
                              "pop_ratio_P34_M_to_R6_T_out", "pop_ratio_P35_M_to_R6_T_out")
pop_ratio_P_M_to_R7_T_out = c("pop_ratio_P36_M_to_R7_T_out", "pop_ratio_P37_M_to_R7_T_out", "pop_ratio_P38_M_to_R7_T_out",
                              "pop_ratio_P39_M_to_R7_T_out")
pop_ratio_P_M_to_R8_T_out = c("pop_ratio_P40_M_to_R8_T_out", "pop_ratio_P41_M_to_R8_T_out", "pop_ratio_P42_M_to_R8_T_out",
                              "pop_ratio_P43_M_to_R8_T_out", "pop_ratio_P44_M_to_R8_T_out", "pop_ratio_P45_M_to_R8_T_out",
                              "pop_ratio_P46_M_to_R8_T_out", "pop_ratio_P47_M_to_R8_T_out")

assign(pop_ratio_P_M_to_R1_T_out, pop_fore_fun_out(top = get(state[2])$pop$male, bottom = ind_R1$pop$total, year_horizon = 41))
for(iw in 2:7)
{
    assign(pop_ratio_P_M_to_R2_T_out[iw-1], pop_fore_fun_out(top = get(state[(iw+1)])$pop$male, bottom = ind_R2$pop$total, year_horizon = 41))
    print(iw)
}
for(iw in 8:14)
{
    assign(pop_ratio_P_M_to_R3_T_out[iw-7], pop_fore_fun_out(top = get(state[(iw+1)])$pop$male, bottom = ind_R3$pop$total, year_horizon = 41))
    print(iw)
}
for(iw in 15:23)
{
    assign(pop_ratio_P_M_to_R4_T_out[iw-14], pop_fore_fun_out(top = get(state[(iw+1)])$pop$male, bottom = ind_R4$pop$total, year_horizon = 41))
    print(iw)
}
for(iw in 24:30)
{
    assign(pop_ratio_P_M_to_R5_T_out[iw-23], pop_fore_fun_out(top = get(state[(iw+1)])$pop$male, bottom = ind_R5$pop$total, year_horizon = 41))
    print(iw)
}
for(iw in 31:35)
{
    assign(pop_ratio_P_M_to_R6_T_out[iw-30], pop_fore_fun_out(top = get(state[(iw+1)])$pop$male, bottom = ind_R6$pop$total, year_horizon = 41))
    print(iw)
}
for(iw in 36:39)
{
    assign(pop_ratio_P_M_to_R7_T_out[iw-35], pop_fore_fun_out(top = get(state[(iw+1)])$pop$male, bottom = ind_R7$pop$total, year_horizon = 41))
    print(iw)
}
for(iw in 40:47)
{
    assign(pop_ratio_P_M_to_R8_T_out[iw-39], pop_fore_fun_out(top = get(state[(iw+1)])$pop$male, bottom = ind_R8$pop$total, year_horizon = 41))
    print(iw)
}


# Row 5

pop_ratio_P_F_to_R1_F_out = "pop_ratio_P1_F_to_R1_F_out"
pop_ratio_P_F_to_R2_F_out = c("pop_ratio_P2_F_to_R2_F_out",  "pop_ratio_P3_F_to_R2_F_out",  "pop_ratio_P4_F_to_R2_F_out",
                              "pop_ratio_P5_F_to_R2_F_out",  "pop_ratio_P6_F_to_R2_F_out",  "pop_ratio_P7_F_to_R2_F_out")
pop_ratio_P_F_to_R3_F_out = c("pop_ratio_P8_F_to_R3_F_out",  "pop_ratio_P9_F_to_R3_F_out",  "pop_ratio_P10_F_to_R3_F_out",
                              "pop_ratio_P11_F_to_R3_F_out", "pop_ratio_P12_F_to_R3_F_out", "pop_ratio_P13_F_to_R3_F_out",
                              "pop_ratio_P14_F_to_R3_F_out")
pop_ratio_P_F_to_R4_F_out = c("pop_ratio_P15_F_to_R4_F_out", "pop_ratio_P16_F_to_R4_F_out", "pop_ratio_P17_F_to_R4_F_out",
                              "pop_ratio_P18_F_to_R4_F_out", "pop_ratio_P19_F_to_R4_F_out", "pop_ratio_P20_F_to_R4_F_out",
                              "pop_ratio_P21_F_to_R4_F_out", "pop_ratio_P22_F_to_R4_F_out", "pop_ratio_P23_F_to_R4_F_out")
pop_ratio_P_F_to_R5_F_out = c("pop_ratio_P24_F_to_R5_F_out", "pop_ratio_P25_F_to_R5_F_out", "pop_ratio_P26_F_to_R5_F_out",
                              "pop_ratio_P27_F_to_R5_F_out", "pop_ratio_P28_F_to_R5_F_out", "pop_ratio_P29_F_to_R5_F_out",
                              "pop_ratio_P30_F_to_R5_F_out")
pop_ratio_P_F_to_R6_F_out = c("pop_ratio_P31_F_to_R6_F_out", "pop_ratio_P32_F_to_R6_F_out", "pop_ratio_P33_F_to_R6_F_out",
                              "pop_ratio_P34_F_to_R6_F_out", "pop_ratio_P35_F_to_R6_F_out")
pop_ratio_P_F_to_R7_F_out = c("pop_ratio_P36_F_to_R7_F_out", "pop_ratio_P37_F_to_R7_F_out", "pop_ratio_P38_F_to_R7_F_out",
                              "pop_ratio_P39_F_to_R7_F_out")
pop_ratio_P_F_to_R8_F_out = c("pop_ratio_P40_F_to_R8_F_out", "pop_ratio_P41_F_to_R8_F_out", "pop_ratio_P42_F_to_R8_F_out",
                              "pop_ratio_P43_F_to_R8_F_out", "pop_ratio_P44_F_to_R8_F_out", "pop_ratio_P45_F_to_R8_F_out",
                              "pop_ratio_P46_F_to_R8_F_out", "pop_ratio_P47_F_to_R8_F_out")

assign(pop_ratio_P_F_to_R1_F_out, pop_fore_fun_out(top = get(state[2])$pop$female, bottom = ind_R1$pop$female, year_horizon = 41))
for(iw in 2:7)
{
    assign(pop_ratio_P_F_to_R2_F_out[iw-1], pop_fore_fun_out(top = get(state[(iw+1)])$pop$female, bottom = ind_R2$pop$female, year_horizon = 41))
    print(iw)
}
for(iw in 8:14)
{
    assign(pop_ratio_P_F_to_R3_F_out[iw-7], pop_fore_fun_out(top = get(state[(iw+1)])$pop$female, bottom = ind_R3$pop$female, year_horizon = 41))
    print(iw)
}
for(iw in 15:23)
{
    assign(pop_ratio_P_F_to_R4_F_out[iw-14], pop_fore_fun_out(top = get(state[(iw+1)])$pop$female, bottom = ind_R4$pop$female, year_horizon = 41))
    print(iw)
}
for(iw in 24:30)
{
    assign(pop_ratio_P_F_to_R5_F_out[iw-23], pop_fore_fun_out(top = get(state[(iw+1)])$pop$female, bottom = ind_R5$pop$female, year_horizon = 41))
    print(iw)
}
for(iw in 31:35)
{
    assign(pop_ratio_P_F_to_R6_F_out[iw-30], pop_fore_fun_out(top = get(state[(iw+1)])$pop$female, bottom = ind_R6$pop$female, year_horizon = 41))
    print(iw)
}
for(iw in 36:39)
{
    assign(pop_ratio_P_F_to_R7_F_out[iw-35], pop_fore_fun_out(top = get(state[(iw+1)])$pop$female, bottom = ind_R7$pop$female, year_horizon = 41))
    print(iw)
}
for(iw in 40:47)
{
    assign(pop_ratio_P_F_to_R8_F_out[iw-39], pop_fore_fun_out(top = get(state[(iw+1)])$pop$female, bottom = ind_R8$pop$female, year_horizon = 41))
    print(iw)
}


# Row 6

pop_ratio_P_M_to_R1_M_out = "pop_ratio_P1_M_to_R1_M_out"
pop_ratio_P_M_to_R2_M_out = c("pop_ratio_P2_M_to_R2_M_out",  "pop_ratio_P3_M_to_R2_M_out",  "pop_ratio_P4_M_to_R2_M_out",
                              "pop_ratio_P5_M_to_R2_M_out",  "pop_ratio_P6_M_to_R2_M_out",  "pop_ratio_P7_M_to_R2_M_out")
pop_ratio_P_M_to_R3_M_out = c("pop_ratio_P8_M_to_R3_M_out",  "pop_ratio_P9_M_to_R3_M_out",  "pop_ratio_P10_M_to_R3_M_out",
                              "pop_ratio_P11_M_to_R3_M_out", "pop_ratio_P12_M_to_R3_M_out", "pop_ratio_P13_M_to_R3_M_out",
                              "pop_ratio_P14_M_to_R3_M_out")
pop_ratio_P_M_to_R4_M_out = c("pop_ratio_P15_M_to_R4_M_out", "pop_ratio_P16_M_to_R4_M_out", "pop_ratio_P17_M_to_R4_M_out",
                              "pop_ratio_P18_M_to_R4_M_out", "pop_ratio_P19_M_to_R4_M_out", "pop_ratio_P20_M_to_R4_M_out",
                              "pop_ratio_P21_M_to_R4_M_out", "pop_ratio_P22_M_to_R4_M_out", "pop_ratio_P23_M_to_R4_M_out")
pop_ratio_P_M_to_R5_M_out = c("pop_ratio_P24_M_to_R5_M_out", "pop_ratio_P25_M_to_R5_M_out", "pop_ratio_P26_M_to_R5_M_out",
                              "pop_ratio_P27_M_to_R5_M_out", "pop_ratio_P28_M_to_R5_M_out", "pop_ratio_P29_M_to_R5_M_out",
                              "pop_ratio_P30_M_to_R5_M_out")
pop_ratio_P_M_to_R6_M_out = c("pop_ratio_P31_M_to_R6_M_out", "pop_ratio_P32_M_to_R6_M_out", "pop_ratio_P33_M_to_R6_M_out",
                              "pop_ratio_P34_M_to_R6_M_out", "pop_ratio_P35_M_to_R6_M_out")
pop_ratio_P_M_to_R7_M_out = c("pop_ratio_P36_M_to_R7_M_out", "pop_ratio_P37_M_to_R7_M_out", "pop_ratio_P38_M_to_R7_M_out",
                              "pop_ratio_P39_M_to_R7_M_out")
pop_ratio_P_M_to_R8_M_out = c("pop_ratio_P40_M_to_R8_M_out", "pop_ratio_P41_M_to_R8_M_out", "pop_ratio_P42_M_to_R8_M_out",
                              "pop_ratio_P43_M_to_R8_M_out", "pop_ratio_P44_M_to_R8_M_out", "pop_ratio_P45_M_to_R8_M_out",
                              "pop_ratio_P46_M_to_R8_M_out", "pop_ratio_P47_M_to_R8_M_out")

assign(pop_ratio_P_M_to_R1_M_out, pop_fore_fun_out(top = get(state[2])$pop$male, bottom = ind_R1$pop$male, year_horizon = 41))
for(iw in 2:7)
{
    assign(pop_ratio_P_M_to_R2_M_out[iw-1], pop_fore_fun_out(top = get(state[(iw+1)])$pop$male, bottom = ind_R2$pop$male, year_horizon = 41))
    print(iw)
}
for(iw in 8:14)
{
    assign(pop_ratio_P_M_to_R3_M_out[iw-7], pop_fore_fun_out(top = get(state[(iw+1)])$pop$male, bottom = ind_R3$pop$male, year_horizon = 41))
    print(iw)
}
for(iw in 15:23)
{
    assign(pop_ratio_P_M_to_R4_M_out[iw-14], pop_fore_fun_out(top = get(state[(iw+1)])$pop$male, bottom = ind_R4$pop$male, year_horizon = 41))
    print(iw)
}
for(iw in 24:30)
{
    assign(pop_ratio_P_M_to_R5_M_out[iw-23], pop_fore_fun_out(top = get(state[(iw+1)])$pop$male, bottom = ind_R5$pop$male, year_horizon = 41))
    print(iw)
}
for(iw in 31:35)
{
    assign(pop_ratio_P_M_to_R6_M_out[iw-30], pop_fore_fun_out(top = get(state[(iw+1)])$pop$male, bottom = ind_R6$pop$male, year_horizon = 41))
    print(iw)
}
for(iw in 36:39)
{
    assign(pop_ratio_P_M_to_R7_M_out[iw-35], pop_fore_fun_out(top = get(state[(iw+1)])$pop$male, bottom = ind_R7$pop$male, year_horizon = 41))
    print(iw)
}
for(iw in 40:47)
{
    assign(pop_ratio_P_M_to_R8_M_out[iw-39], pop_fore_fun_out(top = get(state[(iw+1)])$pop$male, bottom = ind_R8$pop$male, year_horizon = 41))
    print(iw)
}


# Row 7

pop_ratio_P_F_to_P_T_out = c("pop_ratio_P1_F_to_P1_T_out",   "pop_ratio_P2_F_to_P2_T_out",   "pop_ratio_P3_F_to_P3_T_out",
                             "pop_ratio_P4_F_to_P4_T_out",   "pop_ratio_P5_F_to_P5_T_out",   "pop_ratio_P6_F_to_P6_T_out",
                             "pop_ratio_P7_F_to_P7_T_out",   "pop_ratio_P8_F_to_P8_T_out",   "pop_ratio_P9_F_to_P9_T_out",
                             "pop_ratio_P10_F_to_P10_T_out", "pop_ratio_P11_F_to_P11_T_out", "pop_ratio_P12_F_to_P12_T_out",
                             "pop_ratio_P13_F_to_P13_T_out", "pop_ratio_P14_F_to_P14_T_out", "pop_ratio_P15_F_to_P15_T_out",
                             "pop_ratio_P16_F_to_P16_T_out", "pop_ratio_P17_F_to_P17_T_out",
                             "pop_ratio_P18_F_to_P18_T_out", "pop_ratio_P19_F_to_P19_T_out", "pop_ratio_P20_F_to_P20_T_out",
                             "pop_ratio_P21_F_to_P21_T_out", "pop_ratio_P22_F_to_P22_T_out", "pop_ratio_P23_F_to_P23_T_out",
                             "pop_ratio_P24_F_to_P24_T_out", "pop_ratio_P25_F_to_P25_T_out", "pop_ratio_P26_F_to_P26_T_out",
                             "pop_ratio_P27_F_to_P27_T_out", "pop_ratio_P28_F_to_P28_T_out", "pop_ratio_P29_F_to_P29_T_out",
                             "pop_ratio_P30_F_to_P30_T_out", "pop_ratio_P31_F_to_P31_T_out", "pop_ratio_P32_F_to_P32_T_out",
                             "pop_ratio_P33_F_to_P33_T_out", "pop_ratio_P34_F_to_P34_T_out", "pop_ratio_P35_F_to_P35_T_out",
                             "pop_ratio_P36_F_to_P36_T_out", "pop_ratio_P37_F_to_P37_T_out", "pop_ratio_P38_F_to_P38_T_out",
                             "pop_ratio_P39_F_to_P39_T_out", "pop_ratio_P40_F_to_P40_T_out", "pop_ratio_P41_F_to_P41_T_out",
                             "pop_ratio_P42_F_to_P42_T_out", "pop_ratio_P43_F_to_P43_T_out", "pop_ratio_P44_F_to_P44_T_out",
                             "pop_ratio_P45_F_to_P45_T_out", "pop_ratio_P46_F_to_P46_T_out", "pop_ratio_P47_F_to_P47_T_out")

pop_ratio_P_M_to_P_T_out = c("pop_ratio_P1_M_to_P1_T_out",   "pop_ratio_P2_M_to_P2_T_out",   "pop_ratio_P3_M_to_P3_T_out",
                             "pop_ratio_P4_M_to_P4_T_out",   "pop_ratio_P5_M_to_P5_T_out",   "pop_ratio_P6_M_to_P6_T_out",
                             "pop_ratio_P7_M_to_P7_T_out",   "pop_ratio_P8_M_to_P8_T_out",   "pop_ratio_P9_M_to_P9_T_out",
                             "pop_ratio_P10_M_to_P10_T_out", "pop_ratio_P11_M_to_P11_T_out", "pop_ratio_P12_M_to_P12_T_out",
                             "pop_ratio_P13_M_to_P13_T_out", "pop_ratio_P14_M_to_P14_T_out",
                             "pop_ratio_P15_M_to_P15_T_out", "pop_ratio_P16_M_to_P16_T_out", "pop_ratio_P17_M_to_P17_T_out",
                             "pop_ratio_P18_M_to_P18_T_out", "pop_ratio_P19_M_to_P19_T_out", "pop_ratio_P20_M_to_P20_T_out",
                             "pop_ratio_P21_M_to_P21_T_out", "pop_ratio_P22_M_to_P22_T_out", "pop_ratio_P23_M_to_P23_T_out",
                             "pop_ratio_P24_M_to_P24_T_out", "pop_ratio_P25_M_to_P25_T_out", "pop_ratio_P26_M_to_P26_T_out",
                             "pop_ratio_P27_M_to_P27_T_out", "pop_ratio_P28_M_to_P28_T_out", "pop_ratio_P29_M_to_P29_T_out",
                             "pop_ratio_P30_M_to_P30_T_out", "pop_ratio_P31_M_to_P31_T_out", "pop_ratio_P32_M_to_P32_T_out",
                             "pop_ratio_P33_M_to_P33_T_out", "pop_ratio_P34_M_to_P34_T_out", "pop_ratio_P35_M_to_P35_T_out",
                             "pop_ratio_P36_M_to_P36_T_out", "pop_ratio_P37_M_to_P37_T_out", "pop_ratio_P38_M_to_P38_T_out",
                             "pop_ratio_P39_M_to_P39_T_out", "pop_ratio_P40_M_to_P40_T_out", "pop_ratio_P41_M_to_P41_T_out",
                             "pop_ratio_P42_M_to_P42_T_out", "pop_ratio_P43_M_to_P43_T_out", "pop_ratio_P44_M_to_P44_T_out",
                             "pop_ratio_P45_M_to_P45_T_out", "pop_ratio_P46_M_to_P46_T_out", "pop_ratio_P47_M_to_P47_T_out")

for(iw in 2:48)
{
    assign(pop_ratio_P_F_to_P_T_out[iw-1], pop_fore_fun_out(top = get(state[iw])$pop$female, bottom = get(state[iw])$pop$total, year_horizon = 41))
    assign(pop_ratio_P_M_to_P_T_out[iw-1], pop_fore_fun_out(top = get(state[iw])$pop$male,   bottom = get(state[iw])$pop$total, year_horizon = 41))
    print(iw)
}

###############################################
# Point forecasts of mortality (out-of-sample)
###############################################

load("Forecast_summing_mat.R")

#######################################################
# Forecast mortality rates (Female & Male prefectures)
#######################################################

mfts_state_forc_female_annuity = c("mfts_Japan_forc_female_annuity", "mfts_Hokkaido_forc_female_annuity", "mfts_Aomori_forc_female_annuity",
                                  "mfts_Iwate_forc_female_annuity", "mfts_Miyagi_forc_female_annuity", "mfts_Akita_forc_female_annuity",
                                  "mfts_Yamagata_forc_female_annuity", "mfts_Fukushima_forc_female_annuity", "mfts_Ibaraki_forc_female_annuity",
                                  "mfts_Tochigi_forc_female_annuity", "mfts_Gunma_forc_female_annuity", "mfts_Saitama_forc_female_annuity",
                                  "mfts_Chiba_forc_female_annuity", "mfts_Tokyo_forc_female_annuity", "mfts_Kanagawa_forc_female_annuity",
                                  "mfts_Niigata_forc_female_annuity", "mfts_Toyama_forc_female_annuity", "mfts_Ishikawa_forc_female_annuity",
                                  "mfts_Fukui_forc_female_annuity", "mfts_Yamanashi_forc_female_annuity", "mfts_Nagano_forc_female_annuity",
                                  "mfts_Gifu_forc_female_annuity", "mfts_Shizuoka_forc_female_annuity", "mfts_Aichi_forc_female_annuity",
                                  "mfts_Mie_forc_female_annuity", "mfts_Shiga_forc_female_annuity", "mfts_Kyoto_forc_female_annuity",
                                  "mfts_Osaka_forc_female_annuity", "mfts_Hyogo_forc_female_annuity", "mfts_Nara_forc_female_annuity",
                                  "mfts_Wakayama_forc_female_annuity", "mfts_Tottori_forc_female_annuity", "mfts_Shimane_forc_female_annuity",
                                  "mfts_Okayama_forc_female_annuity", "mfts_Hiroshima_forc_female_annuity", "mfts_Yamaguchi_forc_female_annuity",
                                  "mfts_Tokushima_forc_female_annuity", "mfts_Kagawa_forc_female_annuity", "mfts_Ehime_forc_female_annuity",
                                  "mfts_Kochi_forc_female_annuity", "mfts_Fukuoka_forc_female_annuity", "mfts_Saga_forc_female_annuity",
                                  "mfts_Nagasaki_forc_female_annuity", "mfts_Kumamoto_forc_female_annuity", "mfts_Oita_forc_female_annuity",
                                  "mfts_Miyazaki_forc_female_annuity", "mfts_Kagoshima_forc_female_annuity", "mfts_Okinawa_forc_female_annuity")

mfts_state_forc_male_annuity = c("mfts_Japan_forc_male_annuity", "mfts_Hokkaido_forc_male_annuity", "mfts_Aomori_forc_male_annuity",
                                "mfts_Iwate_forc_male_annuity", "mfts_Miyagi_forc_male_annuity", "mfts_Akita_forc_male_annuity",
                                "mfts_Yamagata_forc_male_annuity", "mfts_Fukushima_forc_male_annuity", "mfts_Ibaraki_forc_male_annuity",
                                "mfts_Tochigi_forc_male_annuity", "mfts_Gunma_forc_male_annuity", "mfts_Saitama_forc_male_annuity",
                                "mfts_Chiba_forc_male_annuity", "mfts_Tokyo_forc_male_annuity", "mfts_Kanagawa_forc_male_annuity",
                                "mfts_Niigata_forc_male_annuity", "mfts_Toyama_forc_male_annuity", "mfts_Ishikawa_forc_male_annuity",
                                "mfts_Fukui_forc_male_annuity", "mfts_Yamanashi_forc_male_annuity", "mfts_Nagano_forc_male_annuity",
                                "mfts_Gifu_forc_male_annuity", "mfts_Shizuoka_forc_male_annuity", "mfts_Aichi_forc_male_annuity",
                                "mfts_Mie_forc_male_annuity", "mfts_Shiga_forc_male_annuity", "mfts_Kyoto_forc_male_annuity",
                                "mfts_Osaka_forc_male_annuity", "mfts_Hyogo_forc_male_annuity", "mfts_Nara_forc_male_annuity",
                                "mfts_Wakayama_forc_male_annuity", "mfts_Tottori_forc_male_annuity", "mfts_Shimane_forc_male_annuity",
                                "mfts_Okayama_forc_male_annuity", "mfts_Hiroshima_forc_male_annuity", "mfts_Yamaguchi_forc_male_annuity",
                                "mfts_Tokushima_forc_male_annuity", "mfts_Kagawa_forc_male_annuity", "mfts_Ehime_forc_male_annuity",
                                "mfts_Kochi_forc_male_annuity", "mfts_Fukuoka_forc_male_annuity", "mfts_Saga_forc_male_annuity",
                                "mfts_Nagasaki_forc_male_annuity", "mfts_Kumamoto_forc_male_annuity", "mfts_Oita_forc_male_annuity",
                                "mfts_Miyazaki_forc_male_annuity", "mfts_Kagoshima_forc_male_annuity", "mfts_Okinawa_forc_male_annuity")

mfts_state_forc_total_annuity = c("mfts_Japan_forc_total_annuity", "mfts_Hokkaido_forc_total_annuity", "mfts_Aomori_forc_total_annuity",
                                  "mfts_Iwate_forc_total_annuity", "mfts_Miyagi_forc_total_annuity", "mfts_Akita_forc_total_annuity",
                                  "mfts_Yamagata_forc_total_annuity", "mfts_Fukushima_forc_total_annuity", "mfts_Ibaraki_forc_total_annuity",
                                  "mfts_Tochigi_forc_total_annuity", "mfts_Gunma_forc_total_annuity", "mfts_Saitama_forc_total_annuity",
                                  "mfts_Chiba_forc_total_annuity", "mfts_Tokyo_forc_total_annuity", "mfts_Kanagawa_forc_total_annuity",
                                  "mfts_Niigata_forc_total_annuity", "mfts_Toyama_forc_total_annuity", "mfts_Ishikawa_forc_total_annuity",
                                  "mfts_Fukui_forc_total_annuity", "mfts_Yamanashi_forc_total_annuity", "mfts_Nagano_forc_total_annuity",
                                  "mfts_Gifu_forc_total_annuity", "mfts_Shizuoka_forc_total_annuity", "mfts_Aichi_forc_total_annuity",
                                  "mfts_Mie_forc_total_annuity", "mfts_Shiga_forc_total_annuity", "mfts_Kyoto_forc_total_annuity",
                                  "mfts_Osaka_forc_total_annuity", "mfts_Hyogo_forc_total_annuity", "mfts_Nara_forc_total_annuity",
                                  "mfts_Wakayama_forc_total_annuity", "mfts_Tottori_forc_total_annuity", "mfts_Shimane_forc_total_annuity",
                                  "mfts_Okayama_forc_total_annuity", "mfts_Hiroshima_forc_total_annuity", "mfts_Yamaguchi_forc_total_annuity",
                                  "mfts_Tokushima_forc_total_annuity", "mfts_Kagawa_forc_total_annuity", "mfts_Ehime_forc_total_annuity",
                                  "mfts_Kochi_forc_total_annuity", "mfts_Fukuoka_forc_total_annuity", "mfts_Saga_forc_total_annuity",
                                  "mfts_Nagasaki_forc_total_annuity", "mfts_Kumamoto_forc_total_annuity", "mfts_Oita_forc_total_annuity",
                                  "mfts_Miyazaki_forc_total_annuity", "mfts_Kagoshima_forc_total_annuity", "mfts_Okinawa_forc_total_annuity")


mfts_back_annuity <- function(iw, fmethod, year_horizon, prop_var)
{
    ind_dat = get(state_smooth[iw])
    
    # forecast 41 years ahead
    
    fun_forc = mfts_decomp(dat = ind_dat, year_horizon = year_horizon, fmethod = fmethod,
                           variation_prop = prop_var)
    res_female = fun_forc$fore_res[1:41,]
    res_male = fun_forc$fore_res[42:82,]
    return(list(res_female = res_female, res_male = res_male))
}

for(ik in 1:48)
{
    dum = mfts_back_annuity(iw = ik, fmethod = "arima", year_horizon = 41, prop_var = 0.9)
    assign(mfts_state_forc_female_annuity[ik], dum$res_female)
    assign(mfts_state_forc_male_annuity[ik],   dum$res_male)
    print(ik)
    rm(dum)
}

###################################################
# Forecast mortality rates (Female & Male regions)
###################################################


mfts_region_forc_female_annuity = c("mfts_region_R1_forc_female_annuity", "mfts_region_R2_forc_female_annuity",
                                    "mfts_region_R3_forc_female_annuity", "mfts_region_R4_forc_female_annuity",
                                    "mfts_region_R5_forc_female_annuity", "mfts_region_R6_forc_female_annuity",
                                    "mfts_region_R7_forc_female_annuity", "mfts_region_R8_forc_female_annuity")

mfts_region_forc_male_annuity = c("mfts_region_R1_forc_male_annuity", "mfts_region_R2_forc_male_annuity",
                                  "mfts_region_R3_forc_male_annuity", "mfts_region_R4_forc_male_annuity",
                                  "mfts_region_R5_forc_male_annuity", "mfts_region_R6_forc_male_annuity",
                                  "mfts_region_R7_forc_male_annuity", "mfts_region_R8_forc_male_annuity")

mfts_region_forc_total_annuity = c("mfts_region_R1_forc_total_annuity", "mfts_region_R2_forc_total_annuity",
                                   "mfts_region_R3_forc_total_annuity", "mfts_region_R4_forc_total_annuity",
                                   "mfts_region_R5_forc_total_annuity", "mfts_region_R6_forc_total_annuity",
                                   "mfts_region_R7_forc_total_annuity", "mfts_region_R8_forc_total_annuity")


mfts_back_region_annuity <- function(iw, fmethod, year_horizon, prop_var)
{
    ind_dat = get(region_smooth[iw])
    
    # forecast 41 years ahead
    
    fun_forc = mfts_decomp(dat = ind_dat, year_horizon = year_horizon, fmethod = fmethod,
                           variation_prop = prop_var)
    res_female = fun_forc$fore_res[1:41,]
    res_male = fun_forc$fore_res[42:82,]
    return(list(res_female = res_female, res_male = res_male))
}

for(ik in 1:8)
{
    dum = mfts_back_region_annuity(iw = ik, fmethod = "arima", year_horizon = 41,
                                   prop_var = 0.9)
    assign(mfts_region_forc_female_annuity[ik], dum$res_female)
    assign(mfts_region_forc_male_annuity[ik], dum$res_male)
    print(ik)
    rm(dum)
}

##############################################
# Forecast mortality rates (Total prefecture)
##############################################

coherent_back_test_total_annuity <- function(fmethod = "classical", year_horizon, prop_var)
{
    setwd("/Volumes/MY PASSPORT/Dropbox/Todos/Grouped functional time series forecasting-An application to annuity pricing/code_pre_submitted_v1/gmfts")
    ind_dat = read.demogdata("total_comb.txt", "total_comb_pop.txt", type = "mortality",
                             label = "total_comb", skip = 0)
    
    # forecast 41 years ahead
    
    fun_forc = mfts(ind_dat, year_horizon = year_horizon, variation_prop = prop_var)
    res_prefecture = array(NA, dim = c(41, 41, 47))
    for(iwk in 1:47)
    {
        res_prefecture[,,iwk] = fun_forc[((iwk-1)*41+1):(iwk*41),]
    }
    return(res_prefecture)
}

dum_prefecture = coherent_back_test_total_annuity(year_horizon = 41, prop_var = 0.9)
for(ik in 1:47)
{
    assign(mfts_state_forc_total_annuity[ik+1], dum_prefecture[,,ik])
}

########################################################
# Independent forecast mortality rates (for Japan only)
########################################################

ind_back_test_total_annuity <- function(iw, fmethod = "classical")
{
    res_total = matrix(NA, 41, 41)
    ind_dat = get(state_smooth[1])
    
    # forecast 41 years ahead
    
    fdm_total_order = head(which(round(cumsum(fdm(ind_dat, series = "total", max.age = 100, method = fmethod,
                            lambda = 2.33, order = length(ind_dat$year))$varprop), 3) >= 0.9), 1)
    fun_forc_total = forecast(fdm(ind_dat, series = "total", order = fdm_total_order, max.age = 100,
                                method = fmethod, lambda = 2.33), h = 41)
    return(fun_forc_total$rate$total)
}

mfts_Japan_forc_total_annuity = ind_back_test_total_annuity(iw = 1, fmethod = "classical")


##########################################
# Forecast mortality rates (Total region)
##########################################

coherent_back_test_region_total_annuity <- function(fmethod = "classical", year_horizon, prop_var)
{
    setwd("/Volumes/MY PASSPORT/Dropbox/Todos/Grouped functional time series forecasting-An application to annuity pricing/code_pre_submitted_v1/gmfts")
    ind_dat = read.demogdata("total_region_comb.txt", "total_region_comb_pop.txt",
                                                 type = "mortality", label = "total_region_comb", skip = 0)
    
    # forecast 41 years ahead
    
    fun_forc = mfts(ind_dat, year_horizon = year_horizon, variation_prop = prop_var)
    res_region = array(NA, dim = c(41, 41, 8))
    for(iwk in 1:8)
    {
        res_region[,,iwk] = fun_forc[((iwk-1)*41+1):(iwk*41),]
    }
    return(res_region)
}

dum_region = coherent_back_test_region_total_annuity(year_horizon = 41, prop_var = 0.9)
for(ik in 1:8)
{
    assign(mfts_region_forc_total_annuity[ik], dum_region[,,ik])
}

############################################
# Bottom-up and optimal-combination methods
############################################

BU_optim_hier_for_annuity <- function(total_data_raw_rate_region, female_data_raw_rate_region,
                                      male_data_raw_rate_region, female_data_raw_rate,
                                      male_data_raw_rate, total_data_raw_rate,
                                      age, hier_method = c("BU", "OLS"))
{
    hier_method = match.arg(hier_method)
    hier_rate = matrix(0, 168, 41)
    # Level_0 (Total)
    hier_rate[1,] = get(total_data_raw_rate[1])[age,]
    # Level_1 (Sex)
    hier_rate[2,] = get(female_data_raw_rate[1])[age,]
    hier_rate[3,] = get(male_data_raw_rate[1])[age,]
    
    # Level_2 (Region + Total, Female, Male)
    for(iw in 1:8)
    {
        hier_rate[4:11,] = get(total_data_raw_rate_region[iw])[age,]
        hier_rate[12:19,] = get(female_data_raw_rate_region[iw])[age,]
        hier_rate[20:27,] = get(male_data_raw_rate_region[iw])[age,]
    }
    
    # Level_3 (Prefecture + Total, Female, Male)
    for(iw in 2:48)
    {
        hier_rate[iw+26,] = get(total_data_raw_rate[iw])[age,]
    }
    for(iw in 2:48)
    {
        hier_rate[(2*iw+71),] = get(female_data_raw_rate[iw])[age,]
        hier_rate[(2*iw+72),] = get(male_data_raw_rate[iw])[age,]
    }
    
    # forecast via bottom-up or optimal combination
    hier_fore = matrix(0, 168, 41)
    summing_mat = Smat_fun_out(age = age, year_horizon = 41)
    for(ik in 1:41)
    {
        hier = summing_mat[,,ik]
        if(hier_method == "BU")
        {
            hier_fore[,ik] = (hier %*% hier_rate[75:168,ik])
        }
        if(hier_method == "OLS")
        {
            hier_fore[,ik] = hier %*% ginv(t(hier) %*% hier) %*% t(hier) %*% hier_rate[,ik]
        }
    }
    return(hier_fore)
}

#############################################################
# With inputs 41-years-ahead forecasts, BU and OLS forecasts
#############################################################

BU_optim_annuity <- function(hier_method, total_data_raw_rate_region, female_data_raw_rate_region,
                             male_data_raw_rate_region, female_data_raw_rate, male_data_raw_rate,
                             total_data_raw_rate)
{
    BU_optim_hier_comb = array(NA, dim = c(41, 168, 41))
    for(ik_age in 1:41)
    {
        BU_optim_hier_comb[ik_age,,] = BU_optim_hier_for_annuity(total_data_raw_rate_region = total_data_raw_rate_region,
                                                                 female_data_raw_rate_region = female_data_raw_rate_region,
                                                                 male_data_raw_rate_region = male_data_raw_rate_region,
                                                                 female_data_raw_rate = female_data_raw_rate,
                                                                 male_data_raw_rate = male_data_raw_rate,
                                                                 total_data_raw_rate = total_data_raw_rate,
                                                                 age = ik_age, hier_method = hier_method)
    }
    return(BU_optim_hier_comb)
}

############################################
# bottom-up and optimal combination methods
############################################

# annuities_BU_hier denotes mortality rate by BU

annuities_BU_hier = BU_optim_annuity(hier_method = "BU", total_data_raw_rate_region = mfts_region_forc_total_annuity,
                                     female_data_raw_rate_region = mfts_region_forc_female_annuity,
                                     male_data_raw_rate_region = mfts_region_forc_male_annuity,
                                     female_data_raw_rate = mfts_state_forc_female_annuity,
                                     male_data_raw_rate = mfts_state_forc_male_annuity,
                                     total_data_raw_rate = mfts_state_forc_total_annuity)

# annuities_OLS_hier denotes mortality rate by OLS

annuities_OLS_hier = BU_optim_annuity(hier_method = "OLS", total_data_raw_rate_region = mfts_region_forc_total_annuity,
                                      female_data_raw_rate_region = mfts_region_forc_female_annuity,
                                      male_data_raw_rate_region = mfts_region_forc_male_annuity,
                                      female_data_raw_rate = mfts_state_forc_female_annuity,
                                      male_data_raw_rate = mfts_state_forc_male_annuity,
                                      total_data_raw_rate = mfts_state_forc_total_annuity)

# forecast combination (equal weight)

annuities_Comb_hier = (annuities_BU_hier + annuities_OLS_hier)/2

############################################
# Bottom-up and optimal-combination methods
############################################

PI_prefecture_out_mfts <- function(fh)
{
    prefecture_fh_PI_mfts = array(NA, dim = c(41, 2, 168))
    for(ik in 1:2)
    {
        prefecture_fh_PI_mfts[,ik,] = exp(cbind(Japan_total_fh_PI_out_mfts[[fh]][,ik],
                                                   
                                                   Japan_female_fh_PI_out_mfts[[fh]][,ik], Japan_male_fh_PI_out_mfts[[fh]][,ik],
                                                   
                                                   R1_total_fh_PI_out_mfts[[fh]][,ik], R2_total_fh_PI_out_mfts[[fh]][,ik],
                                                   R3_total_fh_PI_out_mfts[[fh]][,ik], R4_total_fh_PI_out_mfts[[fh]][,ik],
                                                   R5_total_fh_PI_out_mfts[[fh]][,ik], R6_total_fh_PI_out_mfts[[fh]][,ik],
                                                   R7_total_fh_PI_out_mfts[[fh]][,ik], R8_total_fh_PI_out_mfts[[fh]][,ik],
                                                   
                                                   R1_female_fh_PI_out_mfts[[fh]][,ik], R2_female_fh_PI_out_mfts[[fh]][,ik],
                                                   R3_female_fh_PI_out_mfts[[fh]][,ik], R4_female_fh_PI_out_mfts[[fh]][,ik],
                                                   R5_female_fh_PI_out_mfts[[fh]][,ik], R6_female_fh_PI_out_mfts[[fh]][,ik],
                                                   R7_female_fh_PI_out_mfts[[fh]][,ik], R8_female_fh_PI_out_mfts[[fh]][,ik],
                                                   
                                                   R1_male_fh_PI_out_mfts[[fh]][,ik], R2_male_fh_PI_out_mfts[[fh]][,ik],
                                                   R3_male_fh_PI_out_mfts[[fh]][,ik], R4_male_fh_PI_out_mfts[[fh]][,ik],
                                                   R5_male_fh_PI_out_mfts[[fh]][,ik], R6_male_fh_PI_out_mfts[[fh]][,ik],
                                                   R7_male_fh_PI_out_mfts[[fh]][,ik], R8_male_fh_PI_out_mfts[[fh]][,ik],
                                                   
                                                   P1_total_fh_PI_out_mfts[[fh]][,ik],   P2_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P3_total_fh_PI_out_mfts[[fh]][,ik],   P4_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P5_total_fh_PI_out_mfts[[fh]][,ik],   P6_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P7_total_fh_PI_out_mfts[[fh]][,ik],   P8_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P9_total_fh_PI_out_mfts[[fh]][,ik],   P10_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P11_total_fh_PI_out_mfts[[fh]][,ik],  P12_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P13_total_fh_PI_out_mfts[[fh]][,ik],  P14_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P15_total_fh_PI_out_mfts[[fh]][,ik],  P16_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P17_total_fh_PI_out_mfts[[fh]][,ik],  P18_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P19_total_fh_PI_out_mfts[[fh]][,ik],  P20_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P21_total_fh_PI_out_mfts[[fh]][,ik],  P22_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P23_total_fh_PI_out_mfts[[fh]][,ik],  P24_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P25_total_fh_PI_out_mfts[[fh]][,ik],  P26_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P27_total_fh_PI_out_mfts[[fh]][,ik],  P28_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P29_total_fh_PI_out_mfts[[fh]][,ik],  P30_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P31_total_fh_PI_out_mfts[[fh]][,ik],  P32_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P33_total_fh_PI_out_mfts[[fh]][,ik],  P34_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P35_total_fh_PI_out_mfts[[fh]][,ik],  P36_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P37_total_fh_PI_out_mfts[[fh]][,ik],  P38_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P39_total_fh_PI_out_mfts[[fh]][,ik],  P40_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P41_total_fh_PI_out_mfts[[fh]][,ik],  P42_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P43_total_fh_PI_out_mfts[[fh]][,ik],  P44_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P45_total_fh_PI_out_mfts[[fh]][,ik],  P46_total_fh_PI_out_mfts[[fh]][,ik],
                                                   P47_total_fh_PI_out_mfts[[fh]][,ik],
                                                   
                                                   Hokkaido_female_fh_PI_out_mfts[[fh]][,ik],  Hokkaido_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Aomori_female_fh_PI_out_mfts[[fh]][,ik],    Aomori_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Iwate_female_fh_PI_out_mfts[[fh]][,ik],     Iwate_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Miyagi_female_fh_PI_out_mfts[[fh]][,ik],    Miyagi_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Akita_female_fh_PI_out_mfts[[fh]][,ik],     Akita_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Yamagata_female_fh_PI_out_mfts[[fh]][,ik],  Yamagata_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Fukushima_female_fh_PI_out_mfts[[fh]][,ik], Fukushima_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Ibaraki_female_fh_PI_out_mfts[[fh]][,ik],   Ibaraki_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Tochigi_female_fh_PI_out_mfts[[fh]][,ik],   Tochigi_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Gunma_female_fh_PI_out_mfts[[fh]][,ik],     Gunma_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Saitama_female_fh_PI_out_mfts[[fh]][,ik],   Saitama_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Chiba_female_fh_PI_out_mfts[[fh]][,ik],     Chiba_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Tokyo_female_fh_PI_out_mfts[[fh]][,ik],     Tokyo_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Kanagawa_female_fh_PI_out_mfts[[fh]][,ik],  Kanagawa_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Niigata_female_fh_PI_out_mfts[[fh]][,ik],   Niigata_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Toyama_female_fh_PI_out_mfts[[fh]][,ik],    Toyama_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Ishikawa_female_fh_PI_out_mfts[[fh]][,ik],  Ishikawa_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Fukui_female_fh_PI_out_mfts[[fh]][,ik],     Fukui_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Yamanashi_female_fh_PI_out_mfts[[fh]][,ik], Yamanashi_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Nagano_female_fh_PI_out_mfts[[fh]][,ik],    Nagano_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Gifu_female_fh_PI_out_mfts[[fh]][,ik],      Gifu_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Shizuoka_female_fh_PI_out_mfts[[fh]][,ik],  Shizuoka_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Aichi_female_fh_PI_out_mfts[[fh]][,ik],     Aichi_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Mie_female_fh_PI_out_mfts[[fh]][,ik],       Mie_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Shiga_female_fh_PI_out_mfts[[fh]][,ik],     Shiga_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Kyoto_female_fh_PI_out_mfts[[fh]][,ik],     Kyoto_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Osaka_female_fh_PI_out_mfts[[fh]][,ik],     Osaka_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Hyogo_female_fh_PI_out_mfts[[fh]][,ik],     Hyogo_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Nara_female_fh_PI_out_mfts[[fh]][,ik],      Nara_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Wakayama_female_fh_PI_out_mfts[[fh]][,ik],  Wakayama_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Tottori_female_fh_PI_out_mfts[[fh]][,ik],   Tottori_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Shimane_female_fh_PI_out_mfts[[fh]][,ik],   Shimane_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Okayama_female_fh_PI_out_mfts[[fh]][,ik],   Okayama_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Hiroshima_female_fh_PI_out_mfts[[fh]][,ik], Hiroshima_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Yamaguchi_female_fh_PI_out_mfts[[fh]][,ik], Yamaguchi_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Tokushima_female_fh_PI_out_mfts[[fh]][,ik], Tokushima_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Kagawa_female_fh_PI_out_mfts[[fh]][,ik],    Kagawa_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Ehime_female_fh_PI_out_mfts[[fh]][,ik],     Ehime_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Kochi_female_fh_PI_out_mfts[[fh]][,ik],     Kochi_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Fukuoka_female_fh_PI_out_mfts[[fh]][,ik],   Fukuoka_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Saga_female_fh_PI_out_mfts[[fh]][,ik],      Saga_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Nagasaki_female_fh_PI_out_mfts[[fh]][,ik],  Nagasaki_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Kumamoto_female_fh_PI_out_mfts[[fh]][,ik],  Kumamoto_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Oita_female_fh_PI_out_mfts[[fh]][,ik],      Oita_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Miyazaki_female_fh_PI_out_mfts[[fh]][,ik],  Miyazaki_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Kagoshima_female_fh_PI_out_mfts[[fh]][,ik], Kagoshima_male_fh_PI_out_mfts[[fh]][,ik],
                                                   Okinawa_female_fh_PI_out_mfts[[fh]][,ik],   Okinawa_male_fh_PI_out_mfts[[fh]][,ik]))
    }
    return(prefecture_fh_PI_mfts)
}

##################################################################
# one- to 15-step-ahead bootstrapped mortality samples (B = 1000)
##################################################################

PI_prefecture_h1to15_out_mfts = list()
for(ik in 1:41)
{
    PI_prefecture_h1to15_out_mfts[[ik]] = PI_prefecture_out_mfts(fh = ik)
    print(ik)
}


# kj: forecast horizon from h = 1 to 15
# age: age indexes from 1 to 41 (ages 60 to 100+)

BU_optim_hier_PI_out_mfts <- function(fh, age, hier_method = c("BU", "OLS"))
{
    hier_method = match.arg(hier_method)
    hier_fore = matrix(NA, 168, 2)
    
    # Summing matrix for kj horizon at a given age
    summing_out = Smat_fun_out(age = age, year_horizon = 41)
    hier = summing_out[,,fh]
    if(hier_method == "BU")
    {
        for(ij in 1:2)
        {
            hier_fore[,ij] = hier %*% (PI_prefecture_h1to15_out_mfts[[fh]])[age, ij, 75:168]
        }
    }
    if(hier_method == "OLS")
    {
        for(ij in 1:2)
        {
            hier_fore[,ij] = hier %*% ginv(t(hier) %*% hier) %*% t(hier) %*% (PI_prefecture_h1to15_out_mfts[[fh]])[age,ij,]
        }
    }
    return(hier_fore)
}

## hier_method = "BU" (output: h1 to h15 BU reconciled bootstrap sample) (debug here)

BU_fun_out_mfts <- function(kj)
{
    dum = array(NA, dim = c(41, 168, 2))
    for(ij in 1:41)
    {
        dum[ij,,] = BU_optim_hier_PI_out_mfts(fh = kj, age = ij, hier_method = "BU")
    }
    return(dum)
}

BU_optim_hier_comb_out_mfts = list()
for(kj in 1:41)
{
    BU_optim_hier_comb_out_mfts[[kj]] = BU_fun_out_mfts(kj = kj)
    print(kj)
}

## hier_method = "OLS" (output: h1 to h15 OLS reconciled bootstrap samples)

OLS_fun_out_mfts <- function(kj)
{
    dum = array(NA, dim = c(41, 168, 2))
    for(ij in 1:41)
    {
        dum[ij,,] = BU_optim_hier_PI_out_mfts(fh = kj, age = ij, hier_method = "OLS")
    }
    return(dum)
}

OLS_hier_comb_out_mfts = list()
for(kj in 1:41)
{
    OLS_hier_comb_out_mfts[[kj]] = OLS_fun_out_mfts(kj = kj)
    print(kj)
}

#########################################################
## bottom-up and optimal combination methods (to a list)
#########################################################

# bottom-up

BU_optim_hier_comb_out_arrange = array(NA, dim = c(41, 168, 2, 41))
for(ik in 1:41)
{
    BU_optim_hier_comb_out_arrange[,,,ik] = BU_optim_hier_comb_out_mfts[[ik]]
}

# OLS

OLS_hier_comb_out_arrange = array(NA, dim = c(41, 168, 2, 41))
for(ik in 1:41)
{
    OLS_hier_comb_out_arrange[,,,ik] = OLS_hier_comb_out_mfts[[ik]]
}

# Comb (equal weight)

Comb_optim_hier_comb_out_arrange = (BU_optim_hier_comb_out_arrange + OLS_hier_comb_out_arrange)/2

# Comb (AvInt)

Comb_AvInt_optim_hier_comb_out_arrange = (apply(BU_optim_hier_comb_out_arrange, c(1, 2, 4), mean) + apply(OLS_hier_comb_out_arrange, c(1, 2, 4), mean))/2


################################
# ind (R2) (as an illustration)
################################

R2_female_fh_PI_out_arrange = array(NA, dim = c(41, 2, 15))
for(ik in 1:15)
{
    R2_female_fh_PI_out_arrange[,,ik] = (R2_female_fh_PI_out_mfts[[ik]])
}

##################################################################################################
# age: age at the time of annuity contract
# maturity: fixed-term maturity, T = 5, 10, 15, 20, 25, 30
# inRate: constant interest rate
##################################################################################################

# Function for annuity price (mean, quantiles):

AnnuityPrice <- function(y_predict, age, maturity, inRate, nboot)
{
    if(age < 60 || age > 100) return(print("age is outside range"))
    if(age + maturity > 101)  return(print("age + maturity is outside range"))
    
    # 1000: number of bootstrapped log mortality rate
    
    surv_prob = matrix(0, nboot, maturity)
    for(l in 1:nboot)
    {
        # l: number of bootstrapped samples
        for(i in 1:maturity)
        {
            surv_prob[l,i] = exp(-exp(y.predict[[i]][age-60+i,l]))
        }
    }
    
    surv_curve = matrix(0, nboot, maturity)
    for(l in 1:nboot)
    {
        surv_curve[l,] = cumprod(surv_prob[l,])
    }
    
    annuity.price = rep(0,l)
    for(l in 1:nboot)
    {
        for(i in 1:maturity)
        {
            annuity.price[l] = annuity.price[l] + exp(-inRate*i) * surv_curve[l,i]  #inRate: interest rate
        }
    }
    
    # summary statistics (find median, 2.5% and 97.5% quantiles)
    
    annuity.price.sort   = sort(annuity.price)
    annuity.price.median = annuity.price.sort[nboot*0.5+1]
    annuity.price.q025   = annuity.price.sort[nboot*0.025+1]
    annuity.price.q975   = annuity.price.sort[nboot*0.975+1]
    
    # indices associated with summary statistics
    
    sample.index.median = which(annuity.price == annuity.price.median)
    sample.index.q025   = which(annuity.price == annuity.price.q025)
    sample.index.q975   = which(annuity.price == annuity.price.q975)
    
    # plotting survival probability curves
    
    plot(1:30, c(surv_curve[sample.index.median,], rep(NA, 30 - maturity)), main = paste("Survival Curve (",age,"-year-old )"), xlab = expression(paste(tau)),
    ylab = "Probability", type = "l", lty = 1, lwd = 2)
    points(1:30, c(surv_curve[sample.index.q025,], rep(NA, 30 - maturity)), lwd = 2, pch = 4)
    points(1:30, c(surv_curve[sample.index.q975,], rep(NA, 30 - maturity)), lwd = 2, pch = 1)
    legend(x = "bottomleft", legend = c("median", "0.025 quantile", "0.975 quantile"), lwd = c(2, 2, 2), lty = c(1, NA, NA),
    pch = c(NA, 4, 1), cex = 1, bty = "n")
    
    # plotting annuity prices
    
    print("median price; 2.5% quantile price; 97.5% quantile price")
    cat(signif(annuity.price.median,4),signif(annuity.price.q025,4),signif(annuity.price.q975,4),"\n")
    print("percentage difference")
    cat(signif(signif(annuity.price.q025,4)/signif(annuity.price.median,4)-1,4),
    signif(signif(annuity.price.q975,4)/signif(annuity.price.median,4)-1,4))
}

# y.predict: forecast log mortality rates
# age: age
# maturity: fixed-term annuities
# inRate: interest rate

AnnuityPrice_point <- function(y.predict, age, maturity, inRate)
{
    if(age < 60 || age > 100) return(print("age is outside range"))
    if(age + maturity > 101)  return(print("age + maturity is outside range"))
    
    surv_prob = vector("numeric", maturity)
    for(iw in 1:maturity)
    {
        surv_prob[iw] = exp(-(y.predict[age-60+iw]))
    }
    surv_curve = cumprod(surv_prob)
    
    annuity.price = 0
    for(iw in 1:maturity)
    {
        annuity.price = annuity.price + exp(-inRate * iw) * surv_curve[iw]
    }
    return(round(annuity.price, 4))
}

# define ages and maturities

ages = seq(60, 95, by = 5)
maturities = seq(5, 30, by = 5)

# independent functional time series method (prefecture)

mfts_annuities_female = mfts_annuities_male = mfts_annuities_total = array(NA, dim = c(48, length(maturities), length(ages)))
for(ik in 1:48)
{
    for(ij in 1:length(maturities))
    {
        for(iw in 1:length(ages))
        {
            # prefecture
            
            mfts_annuities_female[ik,ij,iw] = try(AnnuityPrice_point(y.predict = diag(get(mfts_state_forc_female_annuity[ik])), age = ages[iw],
                                                                maturity = maturities[ij], inRate = 0.03), silent=TRUE)
            
            mfts_annuities_male[ik,ij,iw] = try(AnnuityPrice_point(y.predict = diag(get(mfts_state_forc_male_annuity[ik])), age = ages[iw],
                                                              maturity = maturities[ij], inRate = 0.03), silent=TRUE)
            
            mfts_annuities_total[ik,ij,iw] = try(AnnuityPrice_point(y.predict = diag(get(mfts_state_forc_total_annuity[ik])), age = ages[iw],
                                                               maturity = maturities[ij], inRate = 0.03), silent=TRUE)
        }
    }
    print(ik)
}

# independent functional time series method (region)

mfts_annuities_region_female = mfts_annuities_region_male = mfts_annuities_region_total = array(NA, dim = c(8, length(maturities), length(ages)))
for(ik in 1:8)
{
    for(ij in 1:length(maturities))
    {
        for(iw in 1:length(ages))
        {
            # region
            
            mfts_annuities_region_female[ik,ij,iw] = try(AnnuityPrice_point(y.predict = diag(get(mfts_region_forc_female_annuity[ik])), age = ages[iw],
                                                                       maturity = maturities[ij], inRate = 0.03), silent=TRUE)
            
            mfts_annuities_region_male[ik,ij,iw] = try(AnnuityPrice_point(y.predict = diag(get(mfts_region_forc_male_annuity[ik])), age = ages[iw],
                                                                     maturity = maturities[ij], inRate = 0.03), silent=TRUE)
            
            mfts_annuities_region_total[ik,ij,iw] = try(AnnuityPrice_point(y.predict = diag(get(mfts_region_forc_total_annuity[ik])), age = ages[iw],
                                                                      maturity = maturities[ij], inRate = 0.03), silent=TRUE)
        }
    }
    print(ik)
}

# bottom-up and optimal combination methods (point forecasts)

mfts_annuities_BU = mfts_annuities_OLS = mfts_annuities_Comb = mfts_annuities_Comb_midpoints =  array(NA, dim = c(168, length(maturities), length(ages)))
for(ik in 1:168)
{
    for(ij in 1:length(maturities))
    {
        for(iw in 1:length(ages))
        {
            mfts_annuities_BU[ik,ij,iw] = try(AnnuityPrice_point(y.predict = diag(annuities_BU_hier[,ik,]), age = ages[iw],
                                                            maturity = maturities[ij], inRate = 0.03), silent = TRUE)
            
            mfts_annuities_OLS[ik,ij,iw] = try(AnnuityPrice_point(y.predict = diag(annuities_OLS_hier[,ik,]), age = ages[iw],
                                                             maturity = maturities[ij], inRate = 0.03), silent=TRUE)
            
            mfts_annuities_Comb[ik,ij,iw] = try(AnnuityPrice_point(y.predict = diag(annuities_Comb_hier[,ik,]), age = ages[iw],
                                                                  maturity = maturities[ij], inRate = 0.03), silent=TRUE)
            
            mfts_annuities_Comb_midpoints[ik,ij,iw] = try(AnnuityPrice_point(y.predict = diag(Comb_AvInt_optim_hier_comb_out_arrange[,ik,]), age = ages[iw],
                                                                             maturity = maturities[ij], inRate = 0.03), silent=TRUE)
        }
    }
    print(ik)
}



#################################################################
# bottom-up and optimal combination methods (interval forecasts)
#################################################################

int_maturities = seq(5, 15, by = 5)
int_ages = seq(60, 70, by = 5)

# indepentent forecasting method (bootstrap PI)

annuities_ind_mat = array(NA, dim = c(length(int_maturities), length(int_ages), 2))
for(boot in 1:2)
{
    for(ij in 1:length(int_maturities))
    {
        for(iw in 1:length(int_ages))
        {
            annuities_ind_mat[ij,iw,boot] = AnnuityPrice_point(y.predict = diag(exp(R2_female_fh_PI_out_arrange[,boot,])), age = int_ages[iw],
                                                               maturity = int_maturities[ij], inRate = 0.03)
        }
    }
}

# BU

annuities_BU_mat = array(NA, dim = c(168, length(int_maturities), length(int_ages), 2))
for(boot in 1:2)
{
    for(ik in 1:168)
    {
        for(ij in 1:length(int_maturities))
        {
            for(iw in 1:length(int_ages))
            {
                annuities_BU_mat[ik, ij, iw, boot] = AnnuityPrice_point(y.predict = diag((BU_optim_hier_comb_out_arrange[,,boot,])[,ik,]), age = int_ages[iw],
                                                                        maturity = int_maturities[ij], inRate = 0.03)
            }
        }
    }
}

# OLS

annuities_OLS_mat = array(NA, dim = c(168, length(int_maturities), length(int_ages), 2))
for(boot in 1:2)
{
    for(ik in 1:168)
    {
        for(ij in 1:length(int_maturities))
        {
            for(iw in 1:length(int_ages))
            {
                annuities_OLS_mat[ik, ij, iw, boot] = AnnuityPrice_point(y.predict = diag((OLS_hier_comb_out_arrange[,,boot,])[,ik,]), age = int_ages[iw],
                                                                        maturity = int_maturities[ij], inRate = 0.03)
            }
        }
    }
}

# Comb

Comb_hier_comb_out_arrange  = (BU_optim_hier_comb_out_arrange + OLS_hier_comb_out_arrange)/2

annuities_Comb_mat = array(NA, dim = c(168, length(int_maturities), length(int_ages), 2))
for(boot in 1:2)
{
    for(ik in 1:168)
    {
        for(ij in 1:length(int_maturities))
        {
            for(iw in 1:length(int_ages))
            {
                annuities_Comb_mat[ik, ij, iw, boot] = AnnuityPrice_point(y.predict = diag((Comb_hier_comb_out_arrange[,,boot,])[,ik,]), age = int_ages[iw],
                                                                         maturity = int_maturities[ij], inRate = 0.03)
            }
        }
    }
}

# Comb AvInt

annuities_Comb_mat_int_midpoints = array(NA, dim = c(168, length(int_maturities), length(int_ages), 2))
for(boot in 1:2)
{
    for(ik in 1:168)
    {
        for(ij in 1:length(int_maturities))
        {
            for(iw in 1:length(int_ages))
            {
                annuities_Comb_mat_int_midpoints[ik, ij, iw, boot] = AnnuityPrice_point(y.predict = diag((Comb_hier_comb_out_mfts_logit_int_midpoints[,,boot,1:15])[,ik,]), age = int_ages[iw],
                                                                          maturity = int_maturities[ij], inRate = 0.03)
            }
        }
    }
}


#############################################
# summary results (Female series & Region 2)
#############################################

# point forecasts

xtable(matrix(as.numeric(t(mfts_annuities_region_female[2,,])), 8, 6), digits = 4)
xtable(matrix(as.numeric(t(mfts_annuities_BU[13,,])), 8, 6), digits = 4)
xtable(matrix(as.numeric(t(mfts_annuities_OLS[13,,])), 8, 6), digits = 4)
xtable(matrix(as.numeric(t(mfts_annuities_Comb[13,,])), 8, 6), digits = 4)
xtable(matrix(as.numeric(t(mfts_annuities_Comb_midpoints[13,,])), 8, 6), digits = 4)

# interval forecasts

xtable(rbind(t(annuities_ind_mat[,,2]), t(annuities_ind_mat[,,1])), digits = 4)
xtable(rbind(t(annuities_BU_mat[13,,,2]), t(annuities_BU_mat[13,,,1])), digits = 4)
xtable(rbind(t(annuities_OLS_mat[13,,,2]), t(annuities_OLS_mat[13,,,1])), digits = 4)
xtable(rbind(t(annuities_Comb_mat[13,,,2]), t(annuities_Comb_mat[13,,,1])), digits = 4)
xtable(rbind(t(annuities_Comb_mat_int_midpoints[13,,,2]), t(annuities_Comb_mat_int_midpoints[13,,,1])), digits = 4)

